(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   6198289,     162364]*)
(*NotebookOutlinePosition[   6199258,     162392]*)
(*  CellTagsIndexPosition[   6199214,     162388]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["asymptotic analysis of the bootstrap methods 20030721", "Text"],

Cell["\<\
Hidetoshi Shimodaira 

Department of Mathematical and Computing Sciences 
Tokyo Institute of Technology 
Ookayama, Meguro, Tokyo 152-8552, JAPAN. 

EMAIL: shimo@is.titech.ac.jp 
URL: http://www.is.titech.ac.jp/~shimo/ \
\>", "Text"],

Cell[CellGroupData[{

Cell["Asymptotic Analysis of the Bootstrap Methods", "Subtitle"],

Cell[TextData[{
  "This documentation consists of three parts, namely \"Exponential Family of \
Distributions\", \"Tube-Coordinates and ",
  Cell[BoxData[
      \(TraditionalForm\`z\_c\)]],
  "-formula\", and \"Bootstrap Methods\".  Each part is an independent ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session, and should be run separately."
}], "Text"],

Cell[TextData[{
  "The calculation is third-order accurate, correct  up to ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(-1\))\)]],
  " terms ignoring the error of ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(\(-3\)/2\))\)]],
  ". We use \"o\" to indicate ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(\(-1\)/2\))\)]],
  " quantities. So, ",
  Cell[BoxData[
      \(TraditionalForm\`o\^2\)]],
  " indicates ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(-1\))\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`o\^3\)]],
  " indicates ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(\(-3\)/2\))\)]],
  ", etc. We repeatedly use a simplification function to keep only up to ",
  Cell[BoxData[
      \(TraditionalForm\`o\^2\)]],
  " terms."
}], "Text"],

Cell[TextData[{
  "In the first two ",
  "part",
  "s, the tensor notation is heavily used. The add-on package \"MathTensor\" \
is required to run the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session by yourself."
}], "Text"],

Cell[CellGroupData[{

Cell["Exponential Family of Distributions", "Subsubtitle"],

Cell["\<\
In this part, we will provide a canonical form the density function of the \
exponential family of distributions. First, some basic results for normal \
density is obtained. Then, the distribution function of the exponential \
family of distributions specified in the natural parameter will be \
transformed to an expression using the expectation parameter and the \
derivatives of the potential function.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Startup", "Section"],

Cell[TextData[{
  "This section initializes the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session."
}], "Text"],

Cell[CellGroupData[{

Cell["packages", "Subsubsection"],

Cell[BoxData[
    \(<< \ Statistics`ContinuousDistributions`\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< MathTens.m\ \((Windows)\)\)], "Input"],

Cell[BoxData[
    \("Loading MathTensor for DOS/Windows . . ."\)], "Print"],

Cell[BoxData[
    \("\n\n"\)], "Print"],

Cell[BoxData[
    \("======================================================="\)], "Print"],

Cell[BoxData[
    \("MathTensor (TM) 2.2.1 (Windows) (September 17, 2000)"\)], "Print"],

Cell[BoxData[
    \("by Leonard Parker and Steven M. Christensen"\)], "Print"],

Cell[BoxData[
    \("Copyright (c) 1991-2000 MathTensor, Inc."\)], "Print"],

Cell[BoxData[
    \("Runs with Mathematica (R) Versions 2.2, 3.0, 4.0"\)], "Print"],

Cell[BoxData[
    \("======================================================="\)], "Print"],

Cell[BoxData[
    \("No unit system is chosen. If you want one,"\)], "Print"],

Cell[BoxData[
    \("you must edit the file called Conventions.m,"\)], "Print"],

Cell[BoxData[
    \("or enter a command to interactively set units."\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Units: "\[InvisibleSpace]{}\),
      SequenceForm[ "Units: ", {}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Sign conventions: Rmsign = "\[InvisibleSpace]1\
\[InvisibleSpace]" Rcsign = "\[InvisibleSpace]1\),
      SequenceForm[ "Sign conventions: Rmsign = ", 1, " Rcsign = ", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("MetricgSign = "\[InvisibleSpace]1\[InvisibleSpace]" \
DetgSign = "\[InvisibleSpace]\(-1\)\),
      SequenceForm[ "MetricgSign = ", 1, " DetgSign = ", -1],
      Editable->False]], "Print"],

Cell[BoxData[
    \("TensorForm turned on,\nShowTime turned off,\nMetricgFlag = True."\)], \
"Print"],

Cell[BoxData[
    \("========================================="\)], "Print"],

Cell[BoxData[
    \(Null\ Windows\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["error messages", "Subsubsection"],

Cell[BoxData[
    \(Off[General::spell1]\)], "Input"],

Cell[BoxData[
    \(Off[General::spell]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["distribution functions", "Subsubsection"],

Cell[BoxData[{
    \(gammadist[x_, m_, \[Alpha]_] := 
      PDF[GammaDistribution[m, \[Alpha]], x]\), "\n", 
    \(Gammadist[x_, m_, \[Alpha]_] := 
      CDF[GammaDistribution[m, \[Alpha]], x]\), "\n", 
    \(f[x_] := PDF[NormalDistribution[0, 1], x]\), "\n", 
    \(F[x_] := CDF[NormalDistribution[0, 1], x]\), "\n", 
    \(Q[x_] := Quantile[NormalDistribution[0, 1], x]\), "\n", 
    \(Chidist[x_, {di_, nc_}] := 
      CDF[NoncentralChiSquareDistribution[di, nc], x]\)}], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Normal distribution", "Section"],

Cell["\<\
This section first calculates the moments of the normal variables, which will \
be used to calculate the expected value of the exponential of normal \
variables. \
\>", "Text"],

Cell[CellGroupData[{

Cell["the moments of the multivariate normal distribution", "Subsection"],

Cell[TextData[{
  "We consider the multivariate normal random vector ",
  Cell[BoxData[
      \(TraditionalForm\`x = \((x\_1,  ... , x\_dim)\)\)]],
  " of dim-dimensions with mean ",
  Cell[BoxData[
      \(TraditionalForm\`b = \((b\_1,  ... , b\_dim)\)\)]],
  ", and the identity covariance matrix. The density function is ",
  Cell[BoxData[
      \(TraditionalForm\`f(x) = \(f[x\_1 - b\_1] f[x\_2 - b\_2] ... \) 
          f[x\_dim - b\_dim]\)]],
  ". In this subsection, we define \"ruleintx\" to calculate the central \
moments of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(,\)\)\)]],
  " such as ",
  Cell[BoxData[
      \(TraditionalForm\`E(\(x\_a\) x\_b)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`E(\(x\_a\) \(x\_b\) \(x\_c\) x\_d)\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`E(\(x\_a\) \(x\_b\) \(x\_c\) \(x\_d\) \(x\_e\) 
          x\_f)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`b = 0\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
the central moments of the standard normal variable in one dimension\
\>", "Subsubsection"],

Cell[BoxData[
    \(The\ following\ intx2f[
          n] = \ \(E \((x\^\(2  n\))\) = \[Integral]\_\(-\[Infinity]\)\%\
\[Infinity]\( x\^\(2  n\)\) 
            f[x] \[DifferentialD]x\ gives\ \(\(\(\((2  
                        n)\)!\)\/\(\(2\^n\) \(n!\)\)\)\(.\)\)\)\)], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(intx2f[n_] = 
      FullSimplify[\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( x\^\(2  n\)\) 
            f[x] \[DifferentialD]x, 
        n \[GreaterEqual] 0 \[And] n \[Element] Integers]\)], "Input"],

Cell[BoxData[
    \(\(2\^n\ Gamma[1\/2 + n]\)\/\@\[Pi]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[intx2f[n], {n, 10}]\)], "Input"],

Cell[BoxData[
    \({1, 3, 15, 105, 945, 10395, 135135, 2027025, 34459425, 
      654729075}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["define tensors", "Subsubsection"],

Cell[TextData[{
  "This ",
  Cell[BoxData[
      \(TraditionalForm\`x\_a\)]],
  "or ",
  Cell[BoxData[
      \(TraditionalForm\`x\^a\)]],
  "denotes a component of the random vector ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[tx, "\<x\>", {{1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"x\"\) defined"\)], "Message"],

Cell["PermWeight::def: Object x defined", "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[TextData[{
  "This ",
  Cell[BoxData[
      \(TraditionalForm\`b\_a\)]],
  "or ",
  Cell[BoxData[
      \(TraditionalForm\`b\^a\)]],
  "denotes a component of the mean vector ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[sb, "\<b\>", {{1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"b\"\) defined"\)], "Message"]
}, Open  ]],

Cell[TextData[{
  "The following a0, a1, a2, a3, a4, a5, and a6 are used for coefficients in \
a series expansion with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[ta0, "\<a0\>", {{}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"a0\"\) defined"\)], "Message"],

Cell["PermWeight::def: Object a0 defined", "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[ta1, "\<a1\>", {{1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"a1\"\) defined"\)], "Message"],

Cell["PermWeight::def: Object a1 defined", "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[ta2, "\<a2\>", {{2, 1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"a2\"\) assigned"\)], "Message"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"a2\"\) defined"\)], "Message"],

Cell["PermWeight::sym: Symmetries of a2 assigned", "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False],

Cell["PermWeight::def: Object a2 defined", "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[ta3, "\<a3\>", {{1, 2, 3}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"a3\"\) defined"\)], "Message"],

Cell["PermWeight::def: Object a3 defined", "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetSymmetric[ta3[la, lb, lc]]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"a3\"\) assigned"\)], "Message"],

Cell["PermWeight::sym: Symmetries of a3 assigned", "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[ta4, "\<a4\>", {{1, 2, 3, 4}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"a4\"\) defined"\)], "Message"],

Cell["PermWeight::def: Object a4 defined", "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetSymmetric[ta4[la, lb, lc, ld]]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"a4\"\) assigned"\)], "Message"],

Cell["PermWeight::sym: Symmetries of a4 assigned", "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[ta6, "\<a6\>", {{1, 2, 3, 4, 5, 6}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"a6\"\) defined"\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetSymmetric[ta6[la, lb, lc, ld, le, lf]]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"a6\"\) assigned"\)], "Message"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["the central moments for the multivariate case", "Subsubsection"],

Cell[TextData[{
  "Here we assume ",
  Cell[BoxData[
      \(TraditionalForm\`b = 0\)]],
  ", and define the second central moment ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\_ab = E(\(x\_a\) x\_b)\)]],
  ", the fourth central moment ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\_abcd = 
        E(\(x\_a\) \(x\_b\) \(x\_c\) x\_d)\)]],
  ", etc. The central moments of odd degrees are zero. Considering the \
symmetry of the normal distribution, these central moments of even degrees \
are expressed by the following partition indicators."
}], "Text"],

Cell[BoxData[
    \(\(kd2[la_, lb_] = Kdelta[la, lb];\)\)], "Input"],

Cell[BoxData[
    \(\(kd4[la_, lb_, lc_, ld_] = 
        3  Symmetrize[
            Kdelta[la, lb] Kdelta[lc, ld], {la, lb, lc, ld}];\)\)], "Input"],

Cell[BoxData[
    \(\(kd6[la_, lb_, lc_, ld_, le_, lf_] = \ 
        15  Symmetrize[
            Kdelta[la, lb] Kdelta[lc, ld] Kdelta[le, lf], {la, lb, lc, ld, 
              le, lf}];\)\)], "Input"],

Cell[TextData[{
  "Then,  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\_ab = kd2[a, b]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\_abcd = kd4[a, b, c, d]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\_abcdef = kd6[a, b, c, d, e, f]\)]],
  ", etc."
}], "Text"],

Cell[BoxData[
    \(RuleUnique[ruleintx1, tx[ui_], 0]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[ruleintx2, tx[ui_] tx[uj_], kd2[ui, uj]]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[ruleintx3, tx[ui_] tx[uj_] tx[uk_], 0]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[ruleintx4, tx[ui_] tx[uj_] tx[uk_] tx[ul_], 
      kd4[ui, uj, uk, ul]]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[ruleintx5, tx[ui_] tx[uj_] tx[uk_] tx[ul_] tx[um_], 
      0]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[ruleintx6, tx[ui_] tx[uj_] tx[uk_] tx[ul_] tx[um_] tx[un_], 
      kd6[ui, uj, uk, ul, um, un]]\)], "Input"],

Cell[BoxData[
    \(\(ruleintx = {ruleintx6, ruleintx5, ruleintx4, ruleintx3, ruleintx2, 
          ruleintx1};\)\)], "Input"],

Cell[TextData[{
  "Check if this rule works for one-dimension case; ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\_11, \ \[Alpha]\_1111, \ \
\[Alpha]\_111111\)]],
  "are given by"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({kd2[1, 1], kd4[1, 1, 1, 1], kd6[1, 1, 1, 1, 1, 1]}\)], "Input"],

Cell[BoxData[
    \({1, 3, 15}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "They should be equal to ",
  Cell[BoxData[
      \(TraditionalForm\`E(x\^2), \ E(x\^4), \ E(x\^6)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({intx2f[1], intx2f[2], intx2f[3]}\)], "Input"],

Cell[BoxData[
    \({1, 3, 15}\)], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Alpha]\_1122 = \(\(E(x\_1\^2)\) \(E(
            x\_2\^2)\) = \(E(x\^2)\)\^2\)\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({kd4[1, 1, 2, 2], intx2f[1]\^2}\)], "Input"],

Cell[BoxData[
    \({1, 1}\)], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Alpha]\_112233 = \(\(E(x\_1\^2)\) \(E(x\_2\^2)\) \(E(
            x\_3\^2)\) = \(E(x\^2)\)\^3\)\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({kd6[1, 1, 2, 2, 3, 3], intx2f[1]\^3}\)], "Input"],

Cell[BoxData[
    \({1, 1}\)], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Alpha]\_112222 = \(\(E(x\_1\^2)\) \(E(
            x\_2\^4)\) = \(E(x\^2)\) \(E(x\^4)\)\)\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({kd6[1, 1, 2, 2, 2, 2], intx2f[1] intx2f[2]}\)], "Input"],

Cell[BoxData[
    \({3, 3}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In the below, we rather use superscript to indicate the components of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". For example, we use ",
  Cell[BoxData[
      \(TraditionalForm\`x = \((x\^a)\)\)]],
  ", instead of x=",
  Cell[BoxData[
      \(TraditionalForm\`\((x\_a)\)\)]],
  ". ",
  Cell[BoxData[
      \(TraditionalForm\`\(a2\_ij\) \(x\^i\) x\^j\)]],
  " denotes a quadratic form with symmetric matrix ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(a2\_ij\)\(.\)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ta2[li, lj]\ tx[ui] tx[uj]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"a2\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"i"\),
                  Subscript[ "i"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"j"\),
                  Subscript[ "j"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "a2"], 
            Format[ li], 
            Format[ lj]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"x\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"i"\),
                  Superscript[ "i"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "x"], 
            Format[ ui]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"x\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"j"\),
                  Superscript[ "j"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "x"], 
            Format[ uj]],
          Editable->False], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The expectation ",
  Cell[BoxData[
      \(TraditionalForm\`E(\(a2\_ij\) \(x\^i\) x\^j)\)]],
  " is"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ApplyRules[%, ruleintx]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"Kdelta\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"p"\),
                  Superscript[ "p"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"q"\),
                  Superscript[ "q"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ Kdelta], 
            Format[ u1], 
            Format[ u2]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"a2\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"p"\),
                  Subscript[ "p"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"q"\),
                  Subscript[ "q"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "a2"], 
            Format[ l1], 
            Format[ l2]],
          Editable->False], ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AbsorbKdelta[%]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          FormBox["\<\"a2\"\>",
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\_"q"\),
              Subscript[ "q"],
              Editable->False],
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"q"\),
              Superscript[ "q"],
              Editable->False],
            "StandardForm"],
          Format]}],
      SequenceForm[ 
        Format[ "a2"], 
        Format[ l2], 
        Format[ u2]],
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Tsimplify[%]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          FormBox["\<\"a2\"\>",
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\_"q"\),
              Subscript[ "q"],
              Editable->False],
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"q"\),
              Superscript[ "q"],
              Editable->False],
            "StandardForm"],
          Format]}],
      SequenceForm[ 
        Format[ "a2"], 
        Format[ l2], 
        Format[ u2]],
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Similarly, for the symmetric 4-form ",
  Cell[BoxData[
      \(TraditionalForm\`\(a4\_ijkl\) \(x\^i\) \(x\^j\) \(x\^k\) x\^l\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ta4[li, lj, lk, ll]\ tx[ui] tx[uj]\ tx[uk] tx[ul]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"a4\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"i"\),
                  Subscript[ "i"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"j"\),
                  Subscript[ "j"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"k"\),
                  Subscript[ "k"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"l"\),
                  Subscript[ "l"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "a4"], 
            Format[ li], 
            Format[ lj], 
            Format[ lk], 
            Format[ ll]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"x\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"i"\),
                  Superscript[ "i"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "x"], 
            Format[ ui]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"x\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"j"\),
                  Superscript[ "j"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "x"], 
            Format[ uj]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"x\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"k"\),
                  Superscript[ "k"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "x"], 
            Format[ uk]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"x\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"l"\),
                  Superscript[ "l"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "x"], 
            Format[ ul]],
          Editable->False], ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ApplyRules[%, ruleintx]\)], "Input"],

Cell[BoxData[
    RowBox[{"3", " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"Kdelta\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"p"\),
                  Superscript[ "p"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"q"\),
                  Superscript[ "q"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ Kdelta], 
            Format[ u1], 
            Format[ u2]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"Kdelta\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"r"\),
                  Superscript[ "r"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"s"\),
                  Superscript[ "s"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ Kdelta], 
            Format[ u3], 
            Format[ u4]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"a4\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"p"\),
                  Subscript[ "p"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"q"\),
                  Subscript[ "q"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"r"\),
                  Subscript[ "r"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"s"\),
                  Subscript[ "s"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "a4"], 
            Format[ l1], 
            Format[ l2], 
            Format[ l3], 
            Format[ l4]],
          Editable->False], ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AbsorbKdelta[%]\)], "Input"],

Cell[BoxData[
    RowBox[{"3", " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"a4\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"q"\),
                  Subscript[ "q"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"s"\),
                  Subscript[ "s"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"q"\),
                  Superscript[ "q"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"s"\),
                  Superscript[ "s"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "a4"], 
            Format[ l2], 
            Format[ l4], 
            Format[ u2], 
            Format[ u4]],
          Editable->False], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Similarly, for the symmetric 6-form ",
  Cell[BoxData[
      \(TraditionalForm\`\(a6\_ijklmn\) \(x\^i\) \(x\^j\) \(x\^k\) \(x\^l\) \
\(x\^m\) x\^n\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ta6[li, lj, lk, ll, lm, ln]\ tx[ui] tx[uj]\ tx[uk] tx[ul] tx[um] 
      tx[un]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"a6\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"i"\),
                  Subscript[ "i"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"j"\),
                  Subscript[ "j"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"k"\),
                  Subscript[ "k"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"l"\),
                  Subscript[ "l"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"m"\),
                  Subscript[ "m"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"n"\),
                  Subscript[ "n"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "a6"], 
            Format[ li], 
            Format[ lj], 
            Format[ lk], 
            Format[ ll], 
            Format[ lm], 
            Format[ ln]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"x\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"i"\),
                  Superscript[ "i"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "x"], 
            Format[ ui]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"x\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"j"\),
                  Superscript[ "j"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "x"], 
            Format[ uj]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"x\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"k"\),
                  Superscript[ "k"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "x"], 
            Format[ uk]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"x\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"l"\),
                  Superscript[ "l"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "x"], 
            Format[ ul]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"x\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"m"\),
                  Superscript[ "m"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "x"], 
            Format[ um]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"x\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"n"\),
                  Superscript[ "n"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "x"], 
            Format[ un]],
          Editable->False], ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ApplyRules[%, ruleintx]\)], "Input"],

Cell[BoxData[
    RowBox[{"15", " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"Kdelta\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"p"\),
                  Superscript[ "p"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"q"\),
                  Superscript[ "q"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ Kdelta], 
            Format[ u1], 
            Format[ u2]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"Kdelta\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"r"\),
                  Superscript[ "r"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"s"\),
                  Superscript[ "s"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ Kdelta], 
            Format[ u3], 
            Format[ u4]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"Kdelta\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"t"\),
                  Superscript[ "t"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"u"\),
                  Superscript[ "u"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ Kdelta], 
            Format[ u5], 
            Format[ u6]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"a6\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"p"\),
                  Subscript[ "p"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"q"\),
                  Subscript[ "q"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"r"\),
                  Subscript[ "r"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"s"\),
                  Subscript[ "s"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"t"\),
                  Subscript[ "t"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"u"\),
                  Subscript[ "u"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "a6"], 
            Format[ l1], 
            Format[ l2], 
            Format[ l3], 
            Format[ l4], 
            Format[ l5], 
            Format[ l6]],
          Editable->False], ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AbsorbKdelta[%]\)], "Input"],

Cell[BoxData[
    RowBox[{"15", " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"a6\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"q"\),
                  Subscript[ "q"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"s"\),
                  Subscript[ "s"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"u"\),
                  Subscript[ "u"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"q"\),
                  Superscript[ "q"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"s"\),
                  Superscript[ "s"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"u"\),
                  Superscript[ "u"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "a6"], 
            Format[ l2], 
            Format[ l4], 
            Format[ l6], 
            Format[ u2], 
            Format[ u4], 
            Format[ u6]],
          Editable->False], ")"}]}]], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["the expectation of the exponential of polynomial functions", \
"Subsection"],

Cell[TextData[{
  "Here we would like to calculate the log of the expectation of  the \
exponential of ",
  Cell[BoxData[
      \(TraditionalForm\`poly(x) = 
        a0 + \(a1\_i\) x\^i + \(a2\_ij\) \(x\^i\) 
            x\^j + \(a3\_ijk\) \(x\^i\) \(x\^j\) 
            x\^k + \(a4\_ijkl\) \(x\^i\) \(x\^j\) \(x\^k\) x\^l\)]],
  ", where a1, a2, and a3 are of order ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(\(-1\)/2\))\)]],
  ", and a4 is ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(-1\))\)]],
  ". Note that ",
  Cell[BoxData[
      \(TraditionalForm\`x\^i\)]],
  " here indicates the ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  "-th element of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(=\)\((x\^1,  ... , x\^dim)\)\(\ \)\)\)]],
  " instead of the ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  "-th power of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ".  ",
  Cell[BoxData[
      \(TraditionalForm\`logeexppoly = log\ E {exp(poly(x))}\)]],
  " is first obtained for ",
  Cell[BoxData[
      \(TraditionalForm\`b = 0\)]],
  ", and next for general ",
  Cell[BoxData[
      \(TraditionalForm\`b \[NotEqual] 0\)]],
  "up to ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(-1\))\)]],
  "terms."
}], "Text"],

Cell[CellGroupData[{

Cell["central case (b=0)", "Subsubsection"],

Cell["\<\
First poly(x)-a0 is set in foo1. The constant term a0 can be removed from \
poly in the following argument, but only be added in logexppoly later.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo1 = 
      o\ ta1[li] tx[ui] + o\ ta2[li, lj] tx[ui] tx[uj] + 
        o\ ta3[li, lj, lk] tx[ui] tx[uj] tx[uk] + \(o\^\(\(2\)\(\ \)\)\) 
          ta4[li, lj, lk, ll] tx[ui] tx[uj] tx[uk] tx[ul]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"i"\),
                    Subscript[ "i"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ li]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"i"\),
                    Superscript[ "i"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ ui]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"i"\),
                    Subscript[ "i"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"j"\),
                    Subscript[ "j"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ li], 
              Format[ lj]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"i"\),
                    Superscript[ "i"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ ui]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"j"\),
                    Superscript[ "j"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ uj]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"i"\),
                    Subscript[ "i"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"j"\),
                    Subscript[ "j"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"k"\),
                    Subscript[ "k"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ li], 
              Format[ lj], 
              Format[ lk]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"i"\),
                    Superscript[ "i"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ ui]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"j"\),
                    Superscript[ "j"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ uj]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"k"\),
                    Superscript[ "k"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ uk]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"i"\),
                    Subscript[ "i"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"j"\),
                    Subscript[ "j"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"k"\),
                    Subscript[ "k"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"l"\),
                    Subscript[ "l"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a4"], 
              Format[ li], 
              Format[ lj], 
              Format[ lk], 
              Format[ ll]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"i"\),
                    Superscript[ "i"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ ui]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"j"\),
                    Superscript[ "j"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ uj]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"k"\),
                    Superscript[ "k"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ uk]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"l"\),
                    Superscript[ "l"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ ul]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["Make rule \"rulepoly\" to substitute \"poly\" for foo1.", "Text"],

Cell[BoxData[
    \(RuleUnique[rulepoly, poly, foo1]\)], "Input"],

Cell["Considering", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Series[Exp[x], {x, 0, 2}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"1", "+", "x", "+", \(x\^2\/2\), "+", 
        InterpretationBox[\(O[x]\^3\),
          SeriesData[ x, 0, {}, 0, 3, 1]]}],
      SeriesData[ x, 0, {1, 1, 
        Rational[ 1, 2]}, 0, 3, 1]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "we can calculate ",
  Cell[BoxData[
      \(TraditionalForm\`exp(poly(x))\)]],
  " as follows, and stored in foo4 up to ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(-1\))\)]],
  " terms."
}], "Text"],

Cell[BoxData[
    \(\(foo3 = 
        ApplyRules[1 + poly + \(1\/2\) poly\^2, rulepoly];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo4 = 
      Sum[Tsimplify[Coefficient[foo3, o, i]] o\^i, {i, 0, 2}]\)], "Input"],

Cell[BoxData[
    RowBox[{"1", "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l1], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l2], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l1], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l3], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l2], 
                    Format[ l3], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a4"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ l3], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l1], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l3], 
                    Format[ l4], 
                    Format[ l5]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u5]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"u"\),
                          Subscript[ "u"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l4], 
                    Format[ l5], 
                    Format[ l6]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u5]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"u"\),
                          Superscript[ "u"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u6]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Then, we take the expectation of foo4, calculating ",
  Cell[BoxData[
      \(TraditionalForm\`E {exp(poly(x))}\)]],
  ", and stored in foo5 below."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ApplyRules[foo4, ruleintx]\)], "Input"],

Cell[BoxData[
    RowBox[{"1", "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ l2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l1], 
              Format[ l2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l1], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ l4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l1], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l3], 
              Format[ l4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l3], 
              Format[ l4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u5], 
              Format[ u6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l1], 
              Format[ l3], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l4], 
              Format[ l6]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(3\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u5], 
              Format[ u6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l1], 
              Format[ l3], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l5], 
              Format[ l6]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u5], 
              Format[ u6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l1], 
              Format[ l2], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l4], 
              Format[ l5], 
              Format[ l6]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a4"], 
              Format[ l1], 
              Format[ l2], 
              Format[ l3], 
              Format[ l4]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AbsorbKdelta[%]\)], "Input"],

Cell[BoxData[
    RowBox[{"1", "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l4], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u2], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l4], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ u2], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l4], 
              Format[ l6], 
              Format[ u6]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(3\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l6], 
              Format[ u6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l4], 
              Format[ u2], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l4], 
              Format[ l6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u2], 
              Format[ u4], 
              Format[ u6]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a4"], 
              Format[ l2], 
              Format[ l4], 
              Format[ u2], 
              Format[ u4]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo5 = Tsimplify[%]\)], "Input"],

Cell[BoxData[
    RowBox[{"1", "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l4], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u2], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l4], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ u2], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l4], 
              Format[ l6], 
              Format[ u6]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(3\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l6], 
              Format[ u6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l4], 
              Format[ u2], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l4], 
              Format[ l6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u2], 
              Format[ u4], 
              Format[ u6]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a4"], 
              Format[ l2], 
              Format[ l4], 
              Format[ u2], 
              Format[ u4]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["Considering ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Series[Log[1 + x], {x, 0, 2}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"x", "-", \(x\^2\/2\), "+", 
        InterpretationBox[\(O[x]\^3\),
          SeriesData[ x, 0, {}, 1, 3, 1]]}],
      SeriesData[ x, 0, {1, 
        Rational[ -1, 2]}, 1, 3, 1]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "we take the log of foo5, and stored in foo8 up to ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(-1\))\)]],
  " terms below."
}], "Text"],

Cell[BoxData[
    \(RuleUnique[foo6rule, foo6, foo5 - 1]\)], "Input"],

Cell[BoxData[
    \(\(foo7 = ApplyRules[foo6 - foo6\^2/2, foo6rule];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo8 = 
      Sum[CanAll[Tsimplify[Coefficient[foo7, o, i]]] o\^i, {i, 0, 
          2}]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l1], 
              Format[ u1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ u1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l1], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l2], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(9\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l3], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a4"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["This is logeexppoly for b=0.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(logeexppolyb0 = ta0 + foo8\)], "Input"],

Cell[BoxData[
    RowBox[{"\<\"a0\"\>", "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l1], 
              Format[ u1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ u1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l1], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l2], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(9\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l3], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a4"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["\<\
The following expression may be easier to read for us, but violating the \
summation convention rule of subscripts.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(logeexppolyb0 /. {u1 \[Rule] l1, u2 \[Rule] l2, 
        u3 \[Rule] l3}\)], "Input"],

Cell[BoxData[
    RowBox[{"\<\"a0\"\>", "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l1], 
              Format[ l1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(1\/2\), " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"a1\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p"\),
                            Subscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "a1"], 
                      Format[ l1]],
                    Editable->False], ")"}], "2"]}], "+", 
            SuperscriptBox[
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l1], 
                    Format[ l2]],
                  Editable->False], ")"}], "2"], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ l2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"a3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p"\),
                            Subscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"q"\),
                            Subscript[ "q"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"r"\),
                            Subscript[ "r"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "a3"], 
                      Format[ l1], 
                      Format[ l2], 
                      Format[ l3]],
                    Editable->False], ")"}], "2"]}], "+", 
            RowBox[{\(9\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l1], 
                    Format[ l1], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l2], 
                    Format[ l3], 
                    Format[ l3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a4"], 
                    Format[ l1], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ l2]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["noncentral case (b\[NotEqual]0)", "Subsubsection"],

Cell[TextData[{
  "We assume the mean of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is zero, but replacing ",
  Cell[BoxData[
      \(TraditionalForm\`x\_i\)]],
  "with ",
  Cell[BoxData[
      \(TraditionalForm\`x\^i + b\^i\)]],
  " to calculate the case for ",
  Cell[BoxData[
      \(TraditionalForm\`b \[NotEqual] 0\)]],
  ". foo11 is the same as poly(x)-a0, but with this substitution."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo11 = foo1 /. {tx[ui_] \[Rule] tx[ui] + sb[ui]}\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"i"\),
                    Subscript[ "i"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ li]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"b\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"i"\),
                      Superscript[ "i"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "b"], 
                Format[ ui]],
              Editable->False], "+", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"x\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"i"\),
                      Superscript[ "i"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "x"], 
                Format[ ui]],
              Editable->False]}], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"i"\),
                    Subscript[ "i"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"j"\),
                    Subscript[ "j"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ li], 
              Format[ lj]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"b\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"i"\),
                      Superscript[ "i"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "b"], 
                Format[ ui]],
              Editable->False], "+", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"x\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"i"\),
                      Superscript[ "i"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "x"], 
                Format[ ui]],
              Editable->False]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"b\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"j"\),
                      Superscript[ "j"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "b"], 
                Format[ uj]],
              Editable->False], "+", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"x\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"j"\),
                      Superscript[ "j"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "x"], 
                Format[ uj]],
              Editable->False]}], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"i"\),
                    Subscript[ "i"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"j"\),
                    Subscript[ "j"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"k"\),
                    Subscript[ "k"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ li], 
              Format[ lj], 
              Format[ lk]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"b\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"i"\),
                      Superscript[ "i"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "b"], 
                Format[ ui]],
              Editable->False], "+", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"x\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"i"\),
                      Superscript[ "i"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "x"], 
                Format[ ui]],
              Editable->False]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"b\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"j"\),
                      Superscript[ "j"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "b"], 
                Format[ uj]],
              Editable->False], "+", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"x\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"j"\),
                      Superscript[ "j"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "x"], 
                Format[ uj]],
              Editable->False]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"b\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"k"\),
                      Superscript[ "k"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "b"], 
                Format[ uk]],
              Editable->False], "+", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"x\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"k"\),
                      Superscript[ "k"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "x"], 
                Format[ uk]],
              Editable->False]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"i"\),
                    Subscript[ "i"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"j"\),
                    Subscript[ "j"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"k"\),
                    Subscript[ "k"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"l"\),
                    Subscript[ "l"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a4"], 
              Format[ li], 
              Format[ lj], 
              Format[ lk], 
              Format[ ll]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"b\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"i"\),
                      Superscript[ "i"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "b"], 
                Format[ ui]],
              Editable->False], "+", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"x\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"i"\),
                      Superscript[ "i"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "x"], 
                Format[ ui]],
              Editable->False]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"b\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"j"\),
                      Superscript[ "j"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "b"], 
                Format[ uj]],
              Editable->False], "+", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"x\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"j"\),
                      Superscript[ "j"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "x"], 
                Format[ uj]],
              Editable->False]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"b\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"k"\),
                      Superscript[ "k"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "b"], 
                Format[ uk]],
              Editable->False], "+", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"x\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"k"\),
                      Superscript[ "k"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "x"], 
                Format[ uk]],
              Editable->False]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"b\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"l"\),
                      Superscript[ "l"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "b"], 
                Format[ ul]],
              Editable->False], "+", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"x\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"l"\),
                      Superscript[ "l"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "x"], 
                Format[ ul]],
              Editable->False]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["\<\
Obtain the canonical expression of the tensor usage, and redefine \
\"rulepoly\".\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo12 = CanAll[Expand[foo11]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a4"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ u1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"2", " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ u1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l1], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ u1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l3], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l3], 
              Format[ u1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l1], 
              Format[ l2], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ u1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"4", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a4"], 
              Format[ l4], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"6", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a4"], 
              Format[ l3], 
              Format[ l4], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ u3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"4", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a4"], 
              Format[ l2], 
              Format[ l3], 
              Format[ l4], 
              Format[ u1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ u3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a4"], 
              Format[ l1], 
              Format[ l2], 
              Format[ l3], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ u1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ u3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"x\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "x"], 
              Format[ u4]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rulepoly, poly, foo12]\)], "Input"],

Cell[TextData[{
  "we can calculate ",
  Cell[BoxData[
      \(TraditionalForm\`exp(poly(x))\)]],
  " as follows, and stored in foo14 up to ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(-1\))\)]],
  " terms."
}], "Text"],

Cell[BoxData[
    \(\(foo13 = 
        ApplyRules[1 + poly + \(1\/2\) poly\^2, rulepoly];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo14 = 
      Sum[Tsimplify[Coefficient[foo13, o, i]] o\^i, {i, 0, 2}]\)], "Input"],

Cell[BoxData[
    RowBox[{"1", "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ u1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l2], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l1], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l3], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l2], 
                    Format[ l3], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u3], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ u4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l5]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u4], 
                    Format[ u5]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l5]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"u"\),
                          Subscript[ "u"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l6]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"u"\),
                          Superscript[ "u"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u4], 
                    Format[ u5], 
                    Format[ u6]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a4"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l3], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l2], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l3], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l2], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l4], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l4], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"4", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a4"], 
                    Format[ l4], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l3], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l4], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l3], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l3], 
                    Format[ l4], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l4], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"6", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a4"], 
                    Format[ l3], 
                    Format[ l4], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l2], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l3], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l2], 
                    Format[ l3], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l3], 
                    Format[ l4], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"4", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a4"], 
                    Format[ l2], 
                    Format[ l3], 
                    Format[ l4], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l1], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l3], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l2], 
                    Format[ l3], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a4"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ l3], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u3], 
                    Format[ u4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l5], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u5]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l5], 
                    Format[ u4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u5]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l4], 
                    Format[ l5], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u5]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"6", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l4], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l5], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u5]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l4], 
                    Format[ l5]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u5]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l3], 
                    Format[ l4], 
                    Format[ l5]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u5]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"6", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l3], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l4], 
                    Format[ l5], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u5]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l3], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l5], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u5]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l2], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l3], 
                    Format[ l4], 
                    Format[ l5]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u5]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l2], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l4], 
                    Format[ l5], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u5]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l1], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l3], 
                    Format[ l4], 
                    Format[ l5]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u5]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l5]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"u"\),
                          Subscript[ "u"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l6], 
                    Format[ u4], 
                    Format[ u5]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"u"\),
                          Superscript[ "u"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u6]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(9\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l5], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"u"\),
                          Subscript[ "u"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l6], 
                    Format[ u3], 
                    Format[ u4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u5]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"u"\),
                          Superscript[ "u"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u6]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"u"\),
                          Subscript[ "u"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l5], 
                    Format[ l6], 
                    Format[ u4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u5]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"u"\),
                          Superscript[ "u"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u6]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"9", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l4], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"u"\),
                          Subscript[ "u"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l5], 
                    Format[ l6], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u5]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"u"\),
                          Superscript[ "u"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u6]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"u"\),
                          Subscript[ "u"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l4], 
                    Format[ l5], 
                    Format[ l6]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u5]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"u"\),
                          Superscript[ "u"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u6]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l3], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"u"\),
                          Subscript[ "u"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l4], 
                    Format[ l5], 
                    Format[ l6]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u5]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"u"\),
                          Superscript[ "u"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u6]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(9\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l3], 
                    Format[ l4], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"u"\),
                          Subscript[ "u"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l5], 
                    Format[ l6], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u5]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"u"\),
                          Superscript[ "u"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u6]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l2], 
                    Format[ l3], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"u"\),
                          Subscript[ "u"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l4], 
                    Format[ l5], 
                    Format[ l6]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u5]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"u"\),
                          Superscript[ "u"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u6]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"u"\),
                          Subscript[ "u"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l4], 
                    Format[ l5], 
                    Format[ l6]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u5]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"x\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"u"\),
                          Superscript[ "u"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "x"], 
                    Format[ u6]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Then, we take the expectation of foo14, calculating ",
  Cell[BoxData[
      \(TraditionalForm\`E {exp(poly(x))}\)]],
  ", and stored in foo15 below."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ApplyRules[foo14, ruleintx]\)], "Input"],

Cell[BoxData[
    RowBox[{"1", "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ l2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l1], 
              Format[ l2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l1], 
              Format[ l2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l1], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ l4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l1], 
              Format[ u3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l1], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l3], 
              Format[ l4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l1], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l1], 
              Format[ l2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l1], 
              Format[ l2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u4], 
              Format[ u5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l1], 
              Format[ l2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l3], 
              Format[ l4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"6", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l1], 
              Format[ u5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l3], 
              Format[ l4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"9", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l1], 
              Format[ u5], 
              Format[ u6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l3], 
              Format[ l4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u5], 
              Format[ u6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l1], 
              Format[ l3], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l4], 
              Format[ l6]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"6", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l1], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l4], 
              Format[ u5]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"9", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l1], 
              Format[ l3], 
              Format[ u5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l4], 
              Format[ u6]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(3\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u5], 
              Format[ u6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l1], 
              Format[ l3], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l5], 
              Format[ l6]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"6", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l1], 
              Format[ u5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(9\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l1], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ u5], 
              Format[ u6]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l1], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l3], 
              Format[ l4], 
              Format[ u5]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(9\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l1], 
              Format[ l2], 
              Format[ u5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l3], 
              Format[ l4], 
              Format[ u6]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u5], 
              Format[ u6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l1], 
              Format[ l2], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l4], 
              Format[ l5], 
              Format[ l6]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u4], 
              Format[ u5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l1], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u3], 
              Format[ u4], 
              Format[ u5]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l1], 
              Format[ l2], 
              Format[ u6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u3], 
              Format[ u4], 
              Format[ u5]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u4], 
              Format[ u5], 
              Format[ u6]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a4"], 
              Format[ l1], 
              Format[ l2], 
              Format[ l3], 
              Format[ l4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"6", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a4"], 
              Format[ l1], 
              Format[ l2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a4"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AbsorbKdelta[%]\)], "Input"],

Cell[BoxData[
    RowBox[{"1", "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l4], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u2], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l4], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"6", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u2], 
              Format[ u5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l4], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"6", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u2], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l4], 
              Format[ u5]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u4], 
              Format[ u5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"6", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u2], 
              Format[ u5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ u2], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l4], 
              Format[ l6], 
              Format[ u6]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(3\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l6], 
              Format[ u6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l4], 
              Format[ u2], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l4], 
              Format[ u4], 
              Format[ u5]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(9\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ u2], 
              Format[ u5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l4], 
              Format[ u4], 
              Format[ u6]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u4], 
              Format[ u5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(9\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ u5], 
              Format[ u6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"9", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l4], 
              Format[ u6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u2], 
              Format[ u4], 
              Format[ u5]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l4], 
              Format[ l6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u2], 
              Format[ u4], 
              Format[ u6]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"9", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l4], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u2], 
              Format[ u5], 
              Format[ u6]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u3], 
              Format[ u4], 
              Format[ u5]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ u2], 
              Format[ u6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u3], 
              Format[ u4], 
              Format[ u5]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u4], 
              Format[ u5], 
              Format[ u6]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a4"], 
              Format[ l2], 
              Format[ l4], 
              Format[ u2], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"6", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a4"], 
              Format[ l2], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a4"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo15 = Tsimplify[%]\)], "Input"],

Cell[BoxData[
    RowBox[{"1", "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l4], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u2], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l4], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"6", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u2], 
              Format[ u5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l4], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"6", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u2], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l4], 
              Format[ u5]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u4], 
              Format[ u5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"6", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u2], 
              Format[ u5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ u2], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l4], 
              Format[ l6], 
              Format[ u6]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(3\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l6], 
              Format[ u6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l4], 
              Format[ u2], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l4], 
              Format[ u4], 
              Format[ u5]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(9\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ u2], 
              Format[ u5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l4], 
              Format[ u4], 
              Format[ u6]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a1"], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ u4], 
              Format[ u5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(9\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ u5], 
              Format[ u6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"9", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l4], 
              Format[ u6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u2], 
              Format[ u4], 
              Format[ u5]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l4], 
              Format[ l6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u2], 
              Format[ u4], 
              Format[ u6]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"9", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ l4], 
              Format[ u4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u2], 
              Format[ u5], 
              Format[ u6]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a2"], 
              Format[ l2], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u3], 
              Format[ u4], 
              Format[ u5]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ l2], 
              Format[ u2], 
              Format[ u6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u3], 
              Format[ u4], 
              Format[ u5]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l5]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"u"\),
                    Subscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l6]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"u"\),
                    Superscript[ "u"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a3"], 
              Format[ u4], 
              Format[ u5], 
              Format[ u6]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a4"], 
              Format[ l2], 
              Format[ l4], 
              Format[ u2], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"6", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a4"], 
              Format[ l2], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"b\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "b"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"a4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "a4"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "we take the log of foo15, and stored in foo18 up to ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(-1\))\)]],
  " terms below."
}], "Text"],

Cell[BoxData[
    \(RuleUnique[foo16rule, foo16, foo15 - 1]\)], "Input"],

Cell[BoxData[
    \(\(foo17 = ApplyRules[foo16 - foo16\^2/2, foo16rule];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo18 = 
      Sum[CanAll[Tsimplify[Coefficient[foo17, o, i]]] o\^i, {i, 0, 
          2}]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ u1]],
                  Editable->False], ")"}]}], "+", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"a2\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\_"p"\),
                      Subscript[ "p"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"p"\),
                      Superscript[ "p"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "a2"], 
                Format[ l1], 
                Format[ u1]],
              Editable->False], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l2], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ u1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l1], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l3], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l2], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"6", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l2], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l3], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(9\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l3], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"6", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l2], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"9", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l3], 
                    Format[ l4], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"6", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l4], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u2], 
                    Format[ u3], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"9", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l3], 
                    Format[ l4], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u2], 
                    Format[ u3], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(9\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l5], 
                    Format[ u1], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u2], 
                    Format[ u4], 
                    Format[ u5]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a4"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"6", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a4"], 
                    Format[ l3], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a4"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3], 
                    Format[ u4]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["This is logeexppoly for b\[NotEqual]0.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(logeexppoly = ta0 + foo18\)], "Input"],

Cell[BoxData[
    RowBox[{"\<\"a0\"\>", "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ u1]],
                  Editable->False], ")"}]}], "+", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"a2\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\_"p"\),
                      Subscript[ "p"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"p"\),
                      Superscript[ "p"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "a2"], 
                Format[ l1], 
                Format[ u1]],
              Editable->False], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l2], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ u1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l1], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l3], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l2], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"6", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l2], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l3], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(9\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l3], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"6", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l2], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"9", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l3], 
                    Format[ l4], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"6", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l4], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u2], 
                    Format[ u3], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"9", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l3], 
                    Format[ l4], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u2], 
                    Format[ u3], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(9\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l5], 
                    Format[ u1], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u2], 
                    Format[ u4], 
                    Format[ u5]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a4"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"6", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a4"], 
                    Format[ l3], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a4"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3], 
                    Format[ u4]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(InputForm[logeexppoly]\)], "Input"],

Cell["\<\
ta0 + o*(sb[l1]*ta1[u1] + ta2[l1, u1] + 
   sb[l1]*sb[l2]*ta2[u1, u2] + 3*sb[l1]*ta3[l2, u1, u2] + 
   sb[l1]*sb[l2]*sb[l3]*ta3[u1, u2, u3]) + 
 o^2*((ta1[l1]*ta1[u1])/2 + 2*sb[l1]*ta1[l2]*ta2[u1, u2] + 
   ta2[l1, l2]*ta2[u1, u2] + 2*sb[l1]*sb[l2]*ta2[l3, u1]*
    ta2[u2, u3] + 3*ta1[l1]*ta3[l2, u1, u2] + 
   6*sb[l1]*ta2[l2, u1]*ta3[l3, u2, u3] + 
   (9*ta3[l1, l2, u1]*ta3[l3, u2, u3])/2 + 
   3*sb[l1]*sb[l2]*ta1[l3]*ta3[u1, u2, u3] + 
   6*sb[l1]*ta2[l2, l3]*ta3[u1, u2, u3] + 
   3*ta3[l1, l2, l3]*ta3[u1, u2, u3] + 
   9*sb[l1]*sb[l2]*ta3[l3, l4, u3]*ta3[u1, u2, u4] + 
   6*sb[l1]*sb[l2]*sb[l3]*ta2[l4, u1]*ta3[u2, u3, u4] + 
   9*sb[l1]*sb[l2]*ta3[l3, l4, u1]*ta3[u2, u3, u4] + 
   (9*sb[l1]*sb[l2]*sb[l3]*sb[l4]*ta3[l5, u1, u3]*
     ta3[u2, u4, u5])/2 + 3*ta4[l1, l2, u1, u2] + 
   6*sb[l1]*sb[l2]*ta4[l3, u1, u2, u3] + 
   sb[l1]*sb[l2]*sb[l3]*sb[l4]*ta4[u1, u2, u3, u4])\
\>", "Output"]
}, Open  ]],

Cell["\<\
The following expression may be easier to read for us, but violating the \
summation convention rule of subscripts.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Collect[
      logeexppoly, {o, sb[l1] sb[l2] sb[l3] sb[l4], sb[l1] sb[l2] sb[l3], 
        sb[l1] sb[l2], sb[l1]}]\)], "Input"],

Cell[BoxData[
    RowBox[{"\<\"a0\"\>", "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"a2\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\_"p"\),
                      Subscript[ "p"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"p"\),
                      Superscript[ "p"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "a2"], 
                Format[ l1], 
                Format[ u1]],
              Editable->False], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"a1\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"p"\),
                            Superscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "a1"], 
                      Format[ u1]],
                    Editable->False], "+", 
                  RowBox[{"3", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q"\),
                                Subscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p"\),
                                Superscript[ "p"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q"\),
                                Superscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a3"], 
                          Format[ l2], 
                          Format[ u1], 
                          Format[ u2]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ u1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l1], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l2], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(9\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l3], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"2", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a1\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q"\),
                                Subscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a1"], 
                          Format[ l2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a2\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p"\),
                                Superscript[ "p"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q"\),
                                Superscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a2"], 
                          Format[ u1], 
                          Format[ u2]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"6", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a2\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q"\),
                                Subscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p"\),
                                Superscript[ "p"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a2"], 
                          Format[ l2], 
                          Format[ u1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r"\),
                                Subscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q"\),
                                Superscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r"\),
                                Superscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a3"], 
                          Format[ l3], 
                          Format[ u2], 
                          Format[ u3]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"6", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a2\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q"\),
                                Subscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r"\),
                                Subscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a2"], 
                          Format[ l2], 
                          Format[ l3]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p"\),
                                Superscript[ "p"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q"\),
                                Superscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r"\),
                                Superscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a3"], 
                          Format[ u1], 
                          Format[ u2], 
                          Format[ u3]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{"6", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l4], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u2], 
                    Format[ u3], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a4"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"2", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a2\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r"\),
                                Subscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p"\),
                                Superscript[ "p"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a2"], 
                          Format[ l3], 
                          Format[ u1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a2\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q"\),
                                Superscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r"\),
                                Superscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a2"], 
                          Format[ u2], 
                          Format[ u3]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"3", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a1\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r"\),
                                Subscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a1"], 
                          Format[ l3]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p"\),
                                Superscript[ "p"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q"\),
                                Superscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r"\),
                                Superscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a3"], 
                          Format[ u1], 
                          Format[ u2], 
                          Format[ u3]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"9", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r"\),
                                Subscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"s"\),
                                Subscript[ "s"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r"\),
                                Superscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a3"], 
                          Format[ l3], 
                          Format[ l4], 
                          Format[ u3]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p"\),
                                Superscript[ "p"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q"\),
                                Superscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"s"\),
                                Superscript[ "s"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a3"], 
                          Format[ u1], 
                          Format[ u2], 
                          Format[ u4]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"9", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r"\),
                                Subscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"s"\),
                                Subscript[ "s"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p"\),
                                Superscript[ "p"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a3"], 
                          Format[ l3], 
                          Format[ l4], 
                          Format[ u1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q"\),
                                Superscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r"\),
                                Superscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"s"\),
                                Superscript[ "s"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a3"], 
                          Format[ u2], 
                          Format[ u3], 
                          Format[ u4]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"6", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r"\),
                                Subscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p"\),
                                Superscript[ "p"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q"\),
                                Superscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r"\),
                                Superscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a4"], 
                          Format[ l3], 
                          Format[ u1], 
                          Format[ u2], 
                          Format[ u3]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(9\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"t"\),
                                Subscript[ "t"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p"\),
                                Superscript[ "p"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r"\),
                                Superscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a3"], 
                          Format[ l5], 
                          Format[ u1], 
                          Format[ u3]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q"\),
                                Superscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"s"\),
                                Superscript[ "s"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"t"\),
                                Superscript[ "t"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a3"], 
                          Format[ u2], 
                          Format[ u4], 
                          Format[ u5]],
                        Editable->False], ")"}]}], "+", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"a4\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"p"\),
                            Superscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"q"\),
                            Superscript[ "q"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"r"\),
                            Superscript[ "r"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"s"\),
                            Superscript[ "s"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "a4"], 
                      Format[ u1], 
                      Format[ u2], 
                      Format[ u3], 
                      Format[ u4]],
                    Editable->False]}], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. {u1 \[Rule] l1, u2 \[Rule] l2, u3 \[Rule] l3, u4 \[Rule] l4, 
        u5 \[Rule] l5}\)], "Input"],

Cell[BoxData[
    RowBox[{"\<\"a0\"\>", "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"a2\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\_"p"\),
                      Subscript[ "p"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\_"p"\),
                      Subscript[ "p"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "a2"], 
                Format[ l1], 
                Format[ l1]],
              Editable->False], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l1], 
                    Format[ l2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"a1\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p"\),
                            Subscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "a1"], 
                      Format[ l1]],
                    Editable->False], "+", 
                  RowBox[{"3", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p"\),
                                Subscript[ "p"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q"\),
                                Subscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q"\),
                                Subscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a3"], 
                          Format[ l1], 
                          Format[ l2], 
                          Format[ l2]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ l3]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(1\/2\), " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"a1\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p"\),
                            Subscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "a1"], 
                      Format[ l1]],
                    Editable->False], ")"}], "2"]}], "+", 
            SuperscriptBox[
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l1], 
                    Format[ l2]],
                  Editable->False], ")"}], "2"], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ l2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"a3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p"\),
                            Subscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"q"\),
                            Subscript[ "q"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"r"\),
                            Subscript[ "r"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "a3"], 
                      Format[ l1], 
                      Format[ l2], 
                      Format[ l3]],
                    Editable->False], ")"}], "2"]}], "+", 
            RowBox[{\(9\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l1], 
                    Format[ l1], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l2], 
                    Format[ l3], 
                    Format[ l3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"2", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a1\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q"\),
                                Subscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a1"], 
                          Format[ l2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a2\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p"\),
                                Subscript[ "p"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q"\),
                                Subscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a2"], 
                          Format[ l1], 
                          Format[ l2]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"6", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a2\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q"\),
                                Subscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r"\),
                                Subscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a2"], 
                          Format[ l2], 
                          Format[ l3]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p"\),
                                Subscript[ "p"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q"\),
                                Subscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r"\),
                                Subscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a3"], 
                          Format[ l1], 
                          Format[ l2], 
                          Format[ l3]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"6", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a2\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p"\),
                                Subscript[ "p"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q"\),
                                Subscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a2"], 
                          Format[ l1], 
                          Format[ l2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q"\),
                                Subscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r"\),
                                Subscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r"\),
                                Subscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a3"], 
                          Format[ l2], 
                          Format[ l3], 
                          Format[ l3]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{"6", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l1], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l2], 
                    Format[ l3], 
                    Format[ l4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a4"], 
                    Format[ l1], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ l2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"2", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a2\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p"\),
                                Subscript[ "p"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r"\),
                                Subscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a2"], 
                          Format[ l1], 
                          Format[ l3]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a2\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q"\),
                                Subscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r"\),
                                Subscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a2"], 
                          Format[ l2], 
                          Format[ l3]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"3", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a1\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r"\),
                                Subscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a1"], 
                          Format[ l3]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p"\),
                                Subscript[ "p"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q"\),
                                Subscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r"\),
                                Subscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a3"], 
                          Format[ l1], 
                          Format[ l2], 
                          Format[ l3]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"9", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p"\),
                                Subscript[ "p"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r"\),
                                Subscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"s"\),
                                Subscript[ "s"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a3"], 
                          Format[ l1], 
                          Format[ l3], 
                          Format[ l4]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q"\),
                                Subscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r"\),
                                Subscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"s"\),
                                Subscript[ "s"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a3"], 
                          Format[ l2], 
                          Format[ l3], 
                          Format[ l4]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"9", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p"\),
                                Subscript[ "p"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q"\),
                                Subscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"s"\),
                                Subscript[ "s"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a3"], 
                          Format[ l1], 
                          Format[ l2], 
                          Format[ l4]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r"\),
                                Subscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r"\),
                                Subscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"s"\),
                                Subscript[ "s"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a3"], 
                          Format[ l3], 
                          Format[ l3], 
                          Format[ l4]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"6", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p"\),
                                Subscript[ "p"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q"\),
                                Subscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r"\),
                                Subscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r"\),
                                Subscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a4"], 
                          Format[ l1], 
                          Format[ l2], 
                          Format[ l3], 
                          Format[ l3]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(9\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p"\),
                                Subscript[ "p"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r"\),
                                Subscript[ "r"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"t"\),
                                Subscript[ "t"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a3"], 
                          Format[ l1], 
                          Format[ l3], 
                          Format[ l5]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"a3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q"\),
                                Subscript[ "q"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"s"\),
                                Subscript[ "s"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"t"\),
                                Subscript[ "t"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "a3"], 
                          Format[ l2], 
                          Format[ l4], 
                          Format[ l5]],
                        Editable->False], ")"}]}], "+", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"a4\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p"\),
                            Subscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"q"\),
                            Subscript[ "q"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"r"\),
                            Subscript[ "r"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"s"\),
                            Subscript[ "s"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "a4"], 
                      Format[ l1], 
                      Format[ l2], 
                      Format[ l3], 
                      Format[ l4]],
                    Editable->False]}], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exponential family", "Section"],

Cell["\<\
The density function of the exponential family is first specified by using \
the natural parameter vector. This standard form is transformed into our \
canonical expression of the density with respect to the expectation parameter \
vector. Since the exponential family is not uniquely expressed up to the \
affine transformation, we assume without loss of generality that origin of \
the expectation parameter coincides with that of the natural parameter, and \
the covariance matrix of the random variable is identity at the origin. We \
consider only the continuous random variable throughout. The canonical form \
will be stored in \"logdensityy\".\
\>", "Text"],

Cell[CellGroupData[{

Cell["the standard form", "Subsection"],

Cell[TextData[{
  "Let ",
  Cell[BoxData[
      \(TraditionalForm\`f(y; \[Theta]) = 
        exp(\(\[Theta]\^a\) y\_a - h(y) - \[Psi](\[Theta]))\)]],
  " denote the density function of random variable ",
  Cell[BoxData[
      \(TraditionalForm\`y = \((y\_1,  ... , y\_dim)\)\)]],
  " with the natural parameter vector ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = \((\[Theta]\^1,  ... , \
\[Theta]\^dim)\)\)]],
  ". The log of the density function is specified by logdensity=log f(y;\
\[Theta]) using the cumulant function \[Psi](\[Theta]) and the measure \
function h(y)."
}], "Text"],

Cell[CellGroupData[{

Cell["simplification functions", "Subsubsection"],

Cell["Some simplification functions are defined here for later use", "Text"],

Cell[BoxData[
    \(tsimp[exp_] := CanAll[AbsorbKdelta[CanAll[exp]]]\)], "Input"],

Cell[BoxData[
    \(geto2[exp_] := 
      Sum[Simplify[Coefficient[exp, o, i]] o\^i, {i, \(-1\), 2}]\)], "Input"],

Cell[BoxData[
    \(tgeto2[exp_] := 
      Sum[tsimp[Coefficient[exp, o, i]] o\^i, {i, \(-1\), 2}]\)], "Input"],

Cell["Define differential operator (for type-a index)", "Text"],

Cell[BoxData[
    \(difa[exp_, ru_, 
        ala_] := \((exp\  - \ \((exp /. {ru[al_] \[Rule] 0})\))\) /. {ru[
                al1_] ru[al2_] ru[al3_] ru[al4_] \[Rule] 
            ru[al1] ru[al2] ru[al3] Kdelta[al4, ala] + 
              ru[al1] ru[al2] ru[al4] Kdelta[al3, ala] + 
              ru[al1] ru[al4] ru[al3] Kdelta[al2, ala] + 
              ru[al4] ru[al2] ru[al3] Kdelta[al1, ala], \[IndentingNewLine]ru[
                al1_] ru[al2_] ru[al3_] \[Rule] 
            ru[al1] ru[al2] Kdelta[al3, ala] + 
              ru[al1] ru[al3] Kdelta[al2, ala] + 
              ru[al2] ru[al3] Kdelta[al1, ala], 
          ru[al1_] ru[al2_] \[Rule] \ 
            ru[al1] Kdelta[al2, ala] + ru[al2] Kdelta[al1, ala], 
          ru[al1_] \[Rule] Kdelta[al1, ala]}\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["define tensors", "Subsubsection"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = \((\[Theta]\^1,  ... , \
\[Theta]\^dim)\)\)]],
  " is the natural parameter vector"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[st, "\<\[Theta]\>", {{1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"\\[Theta]\"\) defined"\)], "Message"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Eta] = \((\[Eta]\_1,  ... , \[Eta]\_dim)\)\)]],
  " is the expectation parameter vector"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[se, "\<\[Eta]\>", {{1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"\\[Eta]\"\) defined"\)], "Message"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]3\^abc = \(\(\[PartialD]\^3\ \[Phi]\/\(\
\[PartialD]\[Eta]\_a \[PartialD]\[Eta]\_b \[PartialD]\[Eta]\_c\)\)\( | \
\_0\)\)\)]],
  " is the third derivative of the potential function \[Phi](\[Eta]) at the \
origin \[Eta]=0."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[tp3, "\<\[Phi]3\>", {{1, 2, 3}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"\\[Phi]3\"\) defined"\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetSymmetric[tp3[la, lb, lc]]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"\\[Phi]3\"\) assigned"\)], "Message"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]4\^abcd = \(\(\[PartialD]\^4\ \[Phi]\/\(\
\[PartialD]\[Eta]\_a \[PartialD]\[Eta]\_b \[PartialD]\[Eta]\_c \[PartialD]\
\[Eta]\_d\)\)\( | \_0\)\)\)]],
  " is the fourth derivative of the potential function \[Phi](\[Eta]) at the \
origin \[Eta]=0."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[tp4, "\<\[Phi]4\>", {{1, 2, 3, 4}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"\\[Phi]4\"\) defined"\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetSymmetric[tp4[la, lb, lc, ld]]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"\\[Phi]4\"\) assigned"\)], "Message"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]3\_abc = \(\(\[PartialD]\^3 \[Psi]\/\(\
\[PartialD]\[Theta]\^a \[PartialD]\[Theta]\^b \[PartialD]\[Theta]\^c\)\)\( | \
\_0\)\)\)]],
  " is the third derivative of the cumulant function \[Psi](\[Theta]) at the \
origin \[Theta]=0."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[tq3, "\<\[Psi]3\>", {{1, 2, 3}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"\\[Psi]3\"\) defined"\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetSymmetric[tq3[la, lb, lc]]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"\\[Psi]3\"\) assigned"\)], "Message"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]4\_abcd = \(\(\[PartialD]\^4 \[Psi]\/\(\
\[PartialD]\[Theta]\^a \[PartialD]\[Theta]\^b \[PartialD]\[Theta]\^c \
\[PartialD]\[Theta]\^d\)\)\( | \_0\)\)\)]],
  " is the fourth derivative of the cumulant function \[Psi](\[Theta]) at the \
origin \[Theta]=0."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[tq4, "\<\[Psi]4\>", {{1, 2, 3, 4}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"\\[Psi]4\"\) defined"\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetSymmetric[tq4[la, lb, lc, ld]]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"\\[Psi]4\"\) assigned"\)], "Message"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`y = \((y\_1,  ... , y\_dim)\)\)]],
  " is the random variable"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[ry, "\<y\>", {{1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"y\"\) defined"\)], "Message"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`h1\^a = \(\(\[PartialD]h\/\[PartialD]y\_a\)\( | \
\_0\)\)\)]],
  " is the first derivative of ",
  Cell[BoxData[
      \(TraditionalForm\`h(y)\)]],
  " at the origin ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[th1, "\<h1\>", {{1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"h1\"\) defined"\)], "Message"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`h2\^ab = \(\(\[PartialD]\^2 
                h\/\(\[PartialD]y\_a \[PartialD]y\_b\)\)\( | \_0\)\)\)]],
  " is the second derivative of ",
  Cell[BoxData[
      \(TraditionalForm\`h(y)\)]],
  " at the origin ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[th2, "\<h2\>", {{2, 1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"h2\"\) assigned"\)], "Message"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"h2\"\) defined"\)], "Message"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`ih\_\(2  ab\) = \((h2\^ab)\)\^\(-1\)\)]],
  " is the inverse matrix of ",
  Cell[BoxData[
      \(TraditionalForm\`h2\^ab\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[tih2, "\<ih2\>", {{2, 1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"ih2\"\) assigned"\)], "Message"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"ih2\"\) defined"\)], "Message"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`h3\^abc = \(\(\[PartialD]\^3 
                h\/\(\[PartialD]y\_a \[PartialD]y\_b \[PartialD]y\_c\)\)\( | \
\_0\)\)\)]],
  " is the third derivative of ",
  Cell[BoxData[
      \(TraditionalForm\`h(y)\)]],
  " at the origin ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[th3, "\<h3\>", {{1, 2, 3}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"h3\"\) defined"\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetSymmetric[th3[la, lb, lc]]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"h3\"\) assigned"\)], "Message"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`h4\^abcd = \(\(\[PartialD]\^4 
                h\/\(\[PartialD]y\_a \[PartialD]y\_b \[PartialD]y\_c \
\[PartialD]y\_d\)\)\( | \_0\)\)\)]],
  " is the fourth derivative of ",
  Cell[BoxData[
      \(TraditionalForm\`h(y)\)]],
  " at the origin ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[th4, "\<h4\>", {{1, 2, 3, 4}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"h4\"\) defined"\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetSymmetric[th4[la, lb, lc, ld]]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"h4\"\) assigned"\)], "Message"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["the log of the density function", "Subsubsection"],

Cell["\<\
logdensity=log f(y;\[Theta]) is specified here.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(logdensity = st[ua] ry[la] - psi[theta] - h[y]\)], "Input"],

Cell[BoxData[
    RowBox[{\(-h[y]\), "-", \(psi[theta]\), "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ la]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ ua]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\(f(y; \[Theta])\) \[DifferentialD]y = 
        1\)]],
  ", the cumulant function is defined formally by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](\[Theta]) = 
        log \(\[Integral]\(exp(\(\[Theta]\^a\) y\_a - 
                  h(y))\) \[DifferentialD]y\)\)]],
  ". The expectation parameter vector is defined by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta] = \(E(
            y; \ \[Theta]) = \[Integral]y\ \(f(
                y; \[Theta])\) \[DifferentialD]y\)\)]],
  ". The potential function \[Phi](\[Eta]) is defined by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](\[Eta]) = 
        max\+\[Theta]{\(\[Theta]\^a\) \[Eta]\_a - \[Psi](\[Theta])}\)]],
  ". The two parametrizations are related to each other by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_a = \
\[PartialD]\[Psi]\/\[PartialD]\[Theta]\^a\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\^a = \
\[PartialD]\[Phi]\/\[PartialD]\[Eta]\_a\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Without losing generality, we assume ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]\[Phi]\/\[PartialD]\[Eta]\_a\)\( | \
\_0\)\) = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]\^2\ \[Phi]\/\(\[PartialD]\[Eta]\_a \
\[PartialD]\[Eta]\_b\)\)\( | \_0\)\) = \[Delta]\^ab\)]],
  "."
}], "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
the expression of \[Psi](\[Theta]) in terms of \[Eta]\
\>", "Subsection"],

Cell["\<\
In this subsection,  we derive the expression of \[Psi](\[Theta]) using \
\[Eta] and  the \[Phi] derivatives. The result will be stored in \
\"psieta\".\
\>", "Text"],

Cell[CellGroupData[{

Cell["derivation", "Subsubsection"],

Cell[TextData[{
  "Define \"ruleeta1\" for the Taylor series of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_a\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_a = \(\(\[PartialD]\ \[Psi]\/\[PartialD]\ \
\[Theta]\^a\)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\ \[Psi]\/\[PartialD]\ \[Theta]\^a\( | \
\_0\)\(+\(\[PartialD]\^2\ \[Psi]\/\(\[PartialD]\ \[Theta]\^a \[PartialD]\ \
\[Theta]\^b\)\)\)\( | \_0\)\[Theta]\^b + \(1\/2\) \[PartialD]\^3\ \[Psi]\/\(\
\[PartialD]\ \[Theta]\^a \[PartialD]\ \[Theta]\^b \[PartialD]\ \
\[Theta]\^c\)\( | \_0\)\(\[Theta]\^b\) \[Theta]\^c + \(1\/6\) \[PartialD]\^4\ \
\[Psi]\/\(\[PartialD]\ \[Theta]\^a \[PartialD]\ \[Theta]\^b \[PartialD]\ \
\[Theta]\^c \[PartialD]\ \[Theta]\^d\)\( | \_0\)\(\[Theta]\^b\) \(\[Theta]\^c\
\) \[Theta]\^d\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]3\_abc = O(n\^\(\(-1\)/2\))\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]4\_abcd = O(n\^\(-1\))\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(RuleUnique[ruleeta1, se[la_], 
      Kdelta[la, lb] st[ub] + \(1\/2\) o\ tq3[la, lb, lc] st[ub] 
          st[uc] + \(1\/6\) o\^2\ tq4[la, lb, lc, ld] st[ub] st[uc] 
          st[ud]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ApplyRules[se[la], ruleeta1]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ l1], 
              Format[ la]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ u1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ u1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Psi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Psi]3"], 
              Format[ l1], 
              Format[ l2], 
              Format[ la]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/6\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ u1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ u3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Psi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Psi]4"], 
              Format[ l1], 
              Format[ l2], 
              Format[ l3], 
              Format[ la]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Define \"ruletheta1\" for the Taylor series of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\^a = \(\(\[PartialD]\ \[Phi]\/\[PartialD]\ \
\[Eta]\_a\)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\ \[Phi]\/\[PartialD]\[Eta]\_a\( | \
\_0\)\(+\(\[PartialD]\^2\ \[Phi]\/\(\[PartialD]\[Eta]\_a \[PartialD]\[Eta]\_b\
\)\)\)\( | \_0\)\[Eta]\_b + \(1\/2\) \[PartialD]\^3\ \[Phi]\/\(\[PartialD]\
\[Eta]\_a \[PartialD]\[Eta]\_b \[PartialD]\[Eta]\_c\)\( | \_0\)\(\[Eta]\_b\) \
\[Eta]\_c + \(1\/6\) \[PartialD]\^3\ \[Phi]\/\(\[PartialD]\[Eta]\_a \
\[PartialD]\[Eta]\_b \[PartialD]\[Eta]\_c \[PartialD]\[Eta]\_d\)\( | \_0\)\(\
\[Eta]\_b\) \(\[Eta]\_c\) \[Eta]\_d\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]3\^abc = O(n\^\(\(-1\)/2\))\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]4\^abcd = O(n\^\(-1\))\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(RuleUnique[ruletheta1, 
      st[ua_], \[IndentingNewLine]Kdelta[ua, ub] se[lb] + \(1\/2\) 
          o\ tp3[ua, ub, uc] se[lb] se[lc] + \(1\/6\) \(o\^2\) 
          tp4[ua, ub, uc, ud] se[lb] se[lc] se[ld]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo21 = ApplyRules[st[ua], ruletheta1]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ ua]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/6\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3], 
              Format[ ua]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Calculate ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2\ \[Phi]\/\(\[PartialD]\[Eta]\_a \
\[PartialD]\[Eta]\_b\) = \(\[PartialD]\ \[Theta]\^a\/\[PartialD]\[Eta]\_b = \
\(\(\[Delta]\^ab\)\(+\)\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^3\ \[Phi]\/\(\[PartialD]\[Eta]\_a \
\[PartialD]\[Eta]\_b \[PartialD]\[Eta]\_c\)\( | \_0\)\[Eta]\_c + \(1\/2\) \
\[PartialD]\^4\ \[Phi]\/\(\[PartialD]\[Eta]\_a \[PartialD]\[Eta]\_b \
\[PartialD]\[Eta]\_c \[PartialD]\[Eta]\_d\)\( | \_0\)\(\[Eta]\_c\) \
\[Eta]\_d\)]],
  " by taking the partial differentiation of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\^a\)]],
  " with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_b\)]],
  ". Define \"rulephi2\" for ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2\ \[Phi]\/\(\[PartialD]\[Eta]\_a \
\[PartialD]\[Eta]\_b\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo22 = tsimp[difa[foo21, se, ub]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"Kdelta\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"a"\),
                Superscript[ "a"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"b"\),
                Superscript[ "b"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ Kdelta], 
          Format[ ua], 
          Format[ ub]],
        Editable->False], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u1], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ u1], 
              Format[ u2], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[dp2, {{2, 1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"dp2\"\) assigned"\)], "Message"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"dp2\"\) defined"\)], "Message"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rulephi2, dp2[ua_, ub_], foo22]\)], "Input"],

Cell[TextData[{
  "Apply ",
  Cell[BoxData[
      \(TraditionalForm\`\((I + A)\)\^\(-1\) = 
        I - A + A\^2 + O(n\^\(\(-3\)/2\))\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`A = O(n\^\(\(-1\)/2\))\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2\ \[Phi]\/\(\[PartialD]\[Eta]\_a \
\[PartialD]\[Eta]\_b\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo23 = 
      tgeto2[ApplyRules[
          Kdelta[ua, 
              ub] - \((dp2[ua, ub] - 
                Kdelta[ua, ub])\) + \((dp2[ua, uc] - 
                  Kdelta[ua, uc])\) \((dp2[lc, ub] - Kdelta[lc, ub])\), 
          rulephi2]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"Kdelta\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"a"\),
                Superscript[ "a"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"b"\),
                Superscript[ "b"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ Kdelta], 
          Format[ ua], 
          Format[ ub]],
        Editable->False], "-", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u1], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ l3], 
                    Format[ u1], 
                    Format[ ub]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ u2], 
                    Format[ u3], 
                    Format[ ua]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Substitute ruleeta1 for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_a\)]],
  " to get ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(\[PartialD]\^2 \[Psi]\/\(\[PartialD]\[Theta]\^a \
\[PartialD]\[Theta]\^b\)\),
            "TraditionalForm"], 
          "=", \(\((\[PartialD]\^2\ \[Phi]\/\(\[PartialD]\[Eta]\_a \
\[PartialD]\[Eta]\_b\))\)\^\(-1\)\)}], TraditionalForm]]],
  " using \[Phi] derivatives as well as \[Psi] derivatives."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo24 = tgeto2[ApplyRules[foo23, ruleeta1]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"Kdelta\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"a"\),
                Superscript[ "a"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"b"\),
                Superscript[ "b"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ Kdelta], 
          Format[ ua], 
          Format[ ub]],
        Editable->False], "-", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u1], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Theta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Theta]"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Theta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Theta]"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ l3], 
                    Format[ u1], 
                    Format[ ub]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ u2], 
                    Format[ u3], 
                    Format[ ua]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Theta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Theta]"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Theta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Theta]"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Theta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Theta]"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Theta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Theta]"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ l3], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Psi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Psi]3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The above expression is compared with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]\^2 \[Psi]\/\(\[PartialD]\[Theta]\^a \
\[PartialD]\[Theta]\^b\)\)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Delta]\_ab\)\(+\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^3 \[Psi]\/\(\[PartialD]\[Theta]\^a \
\[PartialD]\[Theta]\^b \[PartialD]\[Theta]\^c\)\( | \_0\)\[Theta]\^c + \
\[PartialD]\^4 \[Psi]\/\(\[PartialD]\[Theta]\^a \[PartialD]\[Theta]\^b \
\[PartialD]\[Theta]\^c \[PartialD]\[Theta]\^d\)\( | \_0\)\(\[Theta]\^c\) \
\[Theta]\^d\)]],
  ", and the coefficients are obtained below."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo25 = 
      Collect[CoefficientList[foo24 /. {st[l1_] \[Rule] x}, x], o, 
        tsimp[CanAll[# /. {u1 \[Rule] uc, u2 \[Rule] ud, u3 \[Rule] ue, 
                  u4 \[Rule] uf, l1 \[Rule] lc, l2 \[Rule] ld, l3 \[Rule] le, 
                  l4 \[Rule] lf}]] &]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"Kdelta\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"a"\),
                  Superscript[ "a"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"b"\),
                  Superscript[ "b"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ Kdelta], 
            Format[ ua], 
            Format[ ub]],
          Editable->False], ",", 
        RowBox[{\(-o\), " ", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[Phi]3\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"a"\),
                      Superscript[ "a"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"b"\),
                      Superscript[ "b"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"c"\),
                      Superscript[ "c"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "\[Phi]3"], 
                Format[ ua], 
                Format[ ub], 
                Format[ uc]],
              Editable->False], ")"}]}], ",", 
        RowBox[{\(o\^2\), " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p"\),
                            Subscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a"\),
                            Superscript[ "a"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"d"\),
                            Superscript[ "d"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      Format[ l1], 
                      Format[ ua], 
                      Format[ ud]],
                    Editable->False], ")"}], " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"p"\),
                            Superscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b"\),
                            Superscript[ "b"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"c"\),
                            Superscript[ "c"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      Format[ u1], 
                      Format[ ub], 
                      Format[ uc]],
                    Editable->False], ")"}]}], "-", 
              RowBox[{\(1\/2\), " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]4\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a"\),
                            Superscript[ "a"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b"\),
                            Superscript[ "b"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"c"\),
                            Superscript[ "c"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"d"\),
                            Superscript[ "d"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "\[Phi]4"], 
                      Format[ ua], 
                      Format[ ub], 
                      Format[ uc], 
                      Format[ ud]],
                    Editable->False], ")"}]}], "-", 
              RowBox[{\(1\/2\), " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p"\),
                            Subscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a"\),
                            Superscript[ "a"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b"\),
                            Superscript[ "b"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      Format[ l1], 
                      Format[ ua], 
                      Format[ ub]],
                    Editable->False], ")"}], " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Psi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"p"\),
                            Superscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"c"\),
                            Superscript[ "c"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"d"\),
                            Superscript[ "d"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "\[Psi]3"], 
                      Format[ u1], 
                      Format[ uc], 
                      Format[ ud]],
                    Editable->False], ")"}]}]}], ")"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo26 = 
      Simplify[{foo25[\([2]\)]/o, foo25[\([3]\)] \((2/o\^2)\)}]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"-", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[Phi]3\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"a"\),
                      Superscript[ "a"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"b"\),
                      Superscript[ "b"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"c"\),
                      Superscript[ "c"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "\[Phi]3"], 
                Format[ ua], 
                Format[ ub], 
                Format[ uc]],
              Editable->False], ")"}]}], ",", 
        RowBox[{
          RowBox[{"2", " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"p"\),
                        Subscript[ "p"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a"\),
                        Superscript[ "a"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"d"\),
                        Superscript[ "d"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  Format[ l1], 
                  Format[ ua], 
                  Format[ ud]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"p"\),
                        Superscript[ "p"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b"\),
                        Superscript[ "b"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c"\),
                        Superscript[ "c"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  Format[ u1], 
                  Format[ ub], 
                  Format[ uc]],
                Editable->False], ")"}]}], "-", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c"\),
                    Superscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"d"\),
                    Superscript[ "d"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ ua], 
              Format[ ub], 
              Format[ uc], 
              Format[ ud]],
            Editable->False], "-", 
          RowBox[{
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"p"\),
                        Subscript[ "p"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a"\),
                        Superscript[ "a"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b"\),
                        Superscript[ "b"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  Format[ l1], 
                  Format[ ua], 
                  Format[ ub]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Psi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"p"\),
                        Superscript[ "p"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c"\),
                        Superscript[ "c"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"d"\),
                        Superscript[ "d"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Psi]3"], 
                  Format[ u1], 
                  Format[ uc], 
                  Format[ ud]],
                Editable->False], ")"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[ruletq3, tq3[ua_, ub_, uc_], foo26[\([1]\)]]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[ruletq4, tq4[ua_, ub_, uc_, ud_], 
      ApplyRules[foo26[\([2]\)], ruletq3]]\)], "Input"],

Cell[TextData[{
  "We have obtained ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]\^3 \[Psi]\/\(\[PartialD]\[Theta]\^a \
\[PartialD]\[Theta]\^b \[PartialD]\[Theta]\^c\)\)\( | \_0\)\)\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]\^4 \[Psi]\/\(\[PartialD]\[Theta]\^a \
\[PartialD]\[Theta]\^b \[PartialD]\[Theta]\^c \[PartialD]\[Theta]\^d\)\)\( | \
\_0\)\)\)]],
  "  as follows."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ApplyRules[tq3[ua, ub, uc], ruletq3]\)], "Input"],

Cell[BoxData[
    RowBox[{"-", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"\[Phi]3\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"a"\),
                  Superscript[ "a"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"b"\),
                  Superscript[ "b"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"c"\),
                  Superscript[ "c"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "\[Phi]3"], 
            Format[ ua], 
            Format[ ub], 
            Format[ uc]],
          Editable->False], ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ApplyRules[tq4[ua, ub, uc, ud], ruletq4]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"2", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"d"\),
                    Superscript[ "d"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ l1], 
              Format[ ua], 
              Format[ ud]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c"\),
                    Superscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u1], 
              Format[ ub], 
              Format[ uc]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ l1], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c"\),
                    Superscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"d"\),
                    Superscript[ "d"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u1], 
              Format[ uc], 
              Format[ ud]],
            Editable->False], ")"}]}], "-", 
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"\[Phi]4\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"a"\),
                Superscript[ "a"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"b"\),
                Superscript[ "b"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"c"\),
                Superscript[ "c"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"d"\),
                Superscript[ "d"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ "\[Phi]4"], 
          Format[ ua], 
          Format[ ub], 
          Format[ uc], 
          Format[ ud]],
        Editable->False]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Let us write down the Taylor series ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](\[Theta]) = \(\(\[Psi](0)\)\(+\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\ \[Psi]\/\[PartialD]\ \[Theta]\^a\( | \
\_0\)\[Theta]\^a + \(1\/2\) \[PartialD]\^2\ \[Psi]\/\(\[PartialD]\ \
\[Theta]\^a \[PartialD]\ \[Theta]\^b\)\( | \_0\)\(\[Theta]\^a\) \[Theta]\^b + \
\(1\/6\) \[PartialD]\^3\ \[Psi]\/\(\[PartialD]\ \[Theta]\^a \[PartialD]\ \
\[Theta]\^b \[PartialD]\ \[Theta]\^c\)\( | \_0\)\(\[Theta]\^a\) \(\[Theta]\^b\
\) \[Theta]\^c + \(1\/24\) \[PartialD]\^4\ \[Psi]\/\(\[PartialD]\ \[Theta]\^a \
\[PartialD]\ \[Theta]\^b \[PartialD]\ \[Theta]\^c \[PartialD]\ \
\[Theta]\^d\)\( | \_0\)\(\[Theta]\^a\) \(\[Theta]\^b\) \(\[Theta]\^c\) \
\[Theta]\^d\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(psitheta = 
      psi[0] + \(1\/2\) Kdelta[la, lb] st[ua] st[ub] + 
        1\/6\ o\ tq3[la, lb, lc] st[ua] st[ub] st[uc] + \(1\/24\) 
          o\^2\ tq4[la, lb, lc, ld] st[ua] st[ub] st[uc] st[ud]\)], "Input"],

Cell[BoxData[
    RowBox[{\(psi[0]\), "+", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b"\),
                    Subscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ la], 
              Format[ lb]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ ub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/6\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c"\),
                    Superscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ uc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Psi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b"\),
                    Subscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"c"\),
                    Subscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Psi]3"], 
              Format[ la], 
              Format[ lb], 
              Format[ lc]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/24\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c"\),
                    Superscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ uc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"d"\),
                    Superscript[ "d"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ ud]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Psi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b"\),
                    Subscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"c"\),
                    Subscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"d"\),
                    Subscript[ "d"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Psi]4"], 
              Format[ la], 
              Format[ lb], 
              Format[ lc], 
              Format[ ld]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["result", "Subsubsection"],

Cell["\<\
Now express \[Psi](\[Theta]) in terms of \[Eta] and \[Phi] derivatives. This \
gives eq.(3.8) of SH02.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(psieta = 
      CanAll[ApplyRules[
          CanAll[tgeto2[ApplyRules[psitheta, ruletheta1]]], {ruletq3, 
            ruletq4}]]\)], "Input"],

Cell[BoxData[
    RowBox[{\(psi[0]\), "+", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ u1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/3\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/8\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(psieta // InputForm\)], "Input"],

Cell["\<\
psi[0] + (se[l1]*se[u1])/2 + 
 (o*se[l1]*se[l2]*se[l3]*tp3[u1, u2, u3])/3 + 
 (o^2*se[l1]*se[l2]*se[l3]*se[l4]*tp4[u1, u2, u3, u4])/8\
\>", "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
the expression of h(y) in terms of \[Phi] derivatives\
\>", "Subsection"],

Cell["\<\
In this subsection, we derive the expression of h(y) using \[Phi] \
derivatives. The result will be stored in \"hinyphi\".\
\>", "Text"],

Cell[CellGroupData[{

Cell["derivation", "Subsubsection"],

Cell[TextData[{
  "Consider Taylor series ",
  Cell[BoxData[
      \(TraditionalForm\`h(y) = 
        h(0) + \(h1\^a\) y\_a + \(1\/2\) \(h2\^ab\) \(y\_a\) 
            y\_b + \(1\/6\) \(h3\^abc\) \(y\_a\) \(y\_b\) 
            y\_c + \(1\/24\) \(h4\^abcd\) \(y\_a\) \(y\_b\) \(y\_c\) 
            y\_d\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`h1\^a = O(n\^\(1/2\)), \ h2\^ab = O(1), \ 
      h3\^abc = O(n\^\(\(-1\)/2\)), \ 
      h4\^abcd = \(\(O(n\^\(-1\))\)\(.\)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(hiny = 
      h[0] + \(o\^\(-1\)\) th1[ua] ry[la] + \(1\/2\) th2[ua, ub] ry[la] 
          ry[lb] + \(1\/6\) o\ th3[ua, ub, uc] ry[la] ry[lb] 
          ry[lc] + \(1\/24\) \(o\^2\) th4[ua, ub, uc, ud] ry[la] ry[lb] 
          ry[lc] ry[ld]\)], "Input"],

Cell[BoxData[
    RowBox[{\(h[0]\), "+", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"y\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\_"a"\),
                      Subscript[ "a"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "y"], 
                Format[ la]],
              Editable->False], ")"}], " ", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"h1\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"a"\),
                      Superscript[ "a"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "h1"], 
                Format[ ua]],
              Editable->False], ")"}]}], "o"], "+", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ la]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b"\),
                    Subscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ lb]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h2"], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/6\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ la]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b"\),
                    Subscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ lb]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"c"\),
                    Subscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ lc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c"\),
                    Superscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h3"], 
              Format[ ua], 
              Format[ ub], 
              Format[ uc]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/24\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ la]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b"\),
                    Subscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ lb]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"c"\),
                    Subscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ lc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"d"\),
                    Subscript[ "d"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ ld]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c"\),
                    Superscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"d"\),
                    Superscript[ "d"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h4"], 
              Format[ ua], 
              Format[ ub], 
              Format[ uc], 
              Format[ ud]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Define foo31 and foo32 below, which will satisfy ",
  Cell[BoxData[
      \(TraditionalForm\`foo31 + foo32 = \(\[Theta]\^a\) y\_a - h(y)\  + \ 
          O(n\^\(\(-1\)/2\))\)]],
  "as shown later."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo31 = \(\(-1\)\/2\) 
        th2[ua, ub] \((ry[la] - 
            tih2[la, lc] \((st[uc] - \(o\^\(-1\)\) th1[uc])\))\)\ \((ry[lb] - 
            tih2[lb, ld] \((st[ud] - \(o\^\(-1\)\) th1[ud])\))\)\)], "Input"],

Cell[BoxData[
    RowBox[{\(-\(1\/2\)\), " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"h2\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"a"\),
                  Superscript[ "a"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"b"\),
                  Superscript[ "b"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "h2"], 
            Format[ ua], 
            Format[ ub]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        RowBox[{
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ la]],
            Editable->False], "-", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Theta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c"\),
                          Superscript[ "c"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Theta]"], 
                    Format[ uc]],
                  Editable->False], "-", 
                FractionBox[
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"h1\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"c"\),
                            Superscript[ "c"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "h1"], 
                      Format[ uc]],
                    Editable->False], "o"]}], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"ih2\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"a"\),
                        Subscript[ "a"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"c"\),
                        Subscript[ "c"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "ih2"], 
                  Format[ la], 
                  Format[ lc]],
                Editable->False], ")"}]}]}], ")"}], " ", 
      RowBox[{"(", 
        RowBox[{
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b"\),
                    Subscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ lb]],
            Editable->False], "-", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Theta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"d"\),
                          Superscript[ "d"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Theta]"], 
                    Format[ ud]],
                  Editable->False], "-", 
                FractionBox[
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"h1\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"d"\),
                            Superscript[ "d"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "h1"], 
                      Format[ ud]],
                    Editable->False], "o"]}], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"ih2\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"b"\),
                        Subscript[ "b"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"d"\),
                        Subscript[ "d"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "ih2"], 
                  Format[ lb], 
                  Format[ ld]],
                Editable->False], ")"}]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo32 = \(-h[0]\) + \ \(1\/2\) 
          tih2[la, 
            lb] \((st[ua] - \(o\^\(-1\)\) th1[ua])\) \((st[
                ub] - \(o\^\(-1\)\) th1[ub])\)\)], "Input"],

Cell[BoxData[
    RowBox[{\(-h[0]\), "+", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[Theta]\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"a"\),
                      Superscript[ "a"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "\[Theta]"], 
                Format[ ua]],
              Editable->False], "-", 
            FractionBox[
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"h1\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a"\),
                        Superscript[ "a"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "h1"], 
                  Format[ ua]],
                Editable->False], "o"]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[Theta]\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"b"\),
                      Superscript[ "b"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "\[Theta]"], 
                Format[ ub]],
              Editable->False], "-", 
            FractionBox[
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"h1\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b"\),
                        Superscript[ "b"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "h1"], 
                  Format[ ub]],
                Editable->False], "o"]}], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"ih2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b"\),
                    Subscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "ih2"], 
              Format[ la], 
              Format[ lb]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Define a rule to make ",
  Cell[BoxData[
      \(TraditionalForm\`\(h2\_a\^b\) ih2\^ac = \[Delta]\^bc\)]],
  ", thus ih2 is the inverse matrix of h2."
}], "Text"],

Cell[BoxData[
    \(RuleUnique[absorbth2, th2[la_, ub_] tih2[uc_, ua_], 
      Kdelta[ub, uc]]\)], "Input"],

Cell["Apply this rule to foo31+foo32 to get foo33.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo33 = 
      CanAll[AbsorbKdelta[
          ApplyRules[CanAll[foo31 + foo32], absorbth2]]]\)], "Input"],

Cell[BoxData[
    RowBox[{\(-h[0]\), "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ u1]],
            Editable->False], ")"}]}], "-", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"y\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\_"p"\),
                      Subscript[ "p"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "y"], 
                Format[ l1]],
              Editable->False], ")"}], " ", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"h1\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"p"\),
                      Superscript[ "p"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "h1"], 
                Format[ u1]],
              Editable->False], ")"}]}], "o"], "-", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h2"], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Confirming foo33=",
  Cell[BoxData[
      \(TraditionalForm\`foo31 + foo32 = \(\[Theta]\^a\) y\_a - 
          h(y)\  + \ \(\(O(n\^\(\(-1\)/2\))\)\(.\)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CanAll[foo33 - \((ry[la] st[ua] - hiny)\)]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(1\/6\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/24\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h4"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((2  Pi)\)\^\(\(-dim\)\/2\)\) \(\(det(
              h2\^ab)\)\^\(1\/2\)\) \(exp(foo31)\)\)]],
  " is the multivariate normal density function with mean specified above and \
",
  Cell[BoxData[
      \(TraditionalForm\`ih2\_ab\)]],
  " covariance, ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Integral]", 
          RowBox[{
            RowBox[{"exp", "(", 
              
              FormBox[\(\(\[Theta]\^a\) y\_a - h(y)\  - foo32 + \ 
                  O(n\^\(\(-1\)/2\))\),
                "TraditionalForm"], ")"}], \(\[DifferentialD]y\)}]}], 
        TraditionalForm]]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\(exp(
              foo31)\) \[DifferentialD]y = \(\((2  \[Pi])\)\^\(dim\/2\)\) \
\(det(h2\^ab)\)\^\(-\(1\/2\)\)\)]],
  ". Then, \[Psi](\[Theta])=log",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\(exp(\(\[Theta]\^a\) y\_a - 
                h(y))\) \[DifferentialD]y = \(dim\/2\) \(log(
              2  \[Pi])\) - \(1\/2\) \(det(h2\^ab)\) + 
          foo32 + \ \(\(O(n\^\(\(-1\)/2\))\)\(.\)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo34 = \(dim\/2\) Log[2  Pi] - \(1\/2\) deth2 + 
        CanAll[Expand[foo32]]\)], "Input"],

Cell[BoxData[
    RowBox[{\(-\(deth2\/2\)\), "-", \(h[0]\), 
      "+", \(1\/2\ dim\ Log[2\ \[Pi]]\), "+", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"ih2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "ih2"], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}]}], "-", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[Theta]\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\_"p"\),
                      Subscript[ "p"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "\[Theta]"], 
                Format[ l1]],
              Editable->False], ")"}], " ", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"h1\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\_"q"\),
                      Subscript[ "q"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "h1"], 
                Format[ l2]],
              Editable->False], ")"}], " ", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"ih2\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"p"\),
                      Superscript[ "p"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"q"\),
                      Superscript[ "q"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "ih2"], 
                Format[ u1], 
                Format[ u2]],
              Editable->False], ")"}]}], "o"], "+", 
      FractionBox[
        RowBox[{
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"h1\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\_"p"\),
                      Subscript[ "p"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "h1"], 
                Format[ l1]],
              Editable->False], ")"}], " ", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"h1\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\_"q"\),
                      Subscript[ "q"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "h1"], 
                Format[ l2]],
              Editable->False], ")"}], " ", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"ih2\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"p"\),
                      Superscript[ "p"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"q"\),
                      Superscript[ "q"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "ih2"], 
                Format[ u1], 
                Format[ u2]],
              Editable->False], ")"}]}], \(2\ o\^2\)]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Considering ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]\ \[Psi]\/\[PartialD]\ \
\[Theta]\^a\)\( | \_0\)\) = 
        0, \(\(\[PartialD]\^2\ \[Psi]\/\(\[PartialD]\ \[Theta]\^a \[PartialD]\
\ \[Theta]\^b\)\)\( | \_0\)\) = \[Delta]\_ab\)]],
  ", we find that ",
  Cell[BoxData[
      \(TraditionalForm\`ih2\^ab = \[Delta]\^ab + O(n\^\(\(-1\)/2\))\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`h1\_a = O(n\^\(\(-1\)/2\))\)]],
  "from the above expression of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](\[Theta]) = foo34 + O(n\^\(\(-1\)/2\))\)]],
  ".  Let us write ",
  Cell[BoxData[
      \(TraditionalForm\`h2\^ab = \[Delta]\^ab + ah2\^ab\)]],
  "with ",
  Cell[BoxData[
      \(TraditionalForm\`ah2\^ab = \(\(O(n\^\(\(-1\)/2\))\)\(.\)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[tah2, "\<ah2\>", {{2, 1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"ah2\"\) assigned"\)], "Message"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"ah2\"\) defined"\)], "Message"]
}, Open  ]],

Cell[BoxData[
    \(\(ruleth2ah2 = 
        th2[ua_, ub_] \[Rule] Kdelta[ua, ub] + o\ tah2[ua, ub];\)\)], "Input"],

Cell[TextData[{
  "Rewrite the Taylor series of h(y) by noting the first derivative h1 is in \
fact ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(\(-1\)/2\))\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(hiny = 
      h[0] + o\ th1[ua] ry[la] + \(1\/2\) th2[ua, ub] ry[la] 
            ry[lb] + \(1\/6\) o\ th3[ua, ub, uc] ry[la] ry[lb] 
            ry[lc] + \(1\/24\) \(o\^2\) th4[ua, ub, uc, ud] ry[la] ry[lb] 
            ry[lc] ry[ld] /. ruleth2ah2\)], "Input"],

Cell[BoxData[
    RowBox[{\(h[0]\), "+", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ la]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b"\),
                    Subscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ lb]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"Kdelta\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"a"\),
                      Superscript[ "a"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"b"\),
                      Superscript[ "b"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ Kdelta], 
                Format[ ua], 
                Format[ ub]],
              Editable->False], "+", 
            RowBox[{"o", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"ah2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "ah2"], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ la]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h1"], 
              Format[ ua]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/6\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ la]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b"\),
                    Subscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ lb]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"c"\),
                    Subscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ lc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c"\),
                    Superscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h3"], 
              Format[ ua], 
              Format[ ub], 
              Format[ uc]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/24\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ la]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b"\),
                    Subscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ lb]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"c"\),
                    Subscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ lc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"d"\),
                    Subscript[ "d"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ ld]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c"\),
                    Superscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"d"\),
                    Superscript[ "d"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h4"], 
              Format[ ua], 
              Format[ ub], 
              Format[ uc], 
              Format[ ud]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "In the following, ",
  Cell[BoxData[
      \(TraditionalForm\`exp(\(\[Theta]\^a\) y\_a - h(y)) = \(exp(
            foo35) = \(exp(foo36)\) \(exp(
              foo37 + O(n\^\(\(-3\)/2\)))\)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\(exp(foo31)\) \[DifferentialD]y = 1\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo35 = ry[la] st[ua] - hiny\)], "Input"],

Cell[BoxData[
    RowBox[{\(-h[0]\), "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ la]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ ua]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ la]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b"\),
                    Subscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ lb]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"Kdelta\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"a"\),
                      Superscript[ "a"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"b"\),
                      Superscript[ "b"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ Kdelta], 
                Format[ ua], 
                Format[ ub]],
              Editable->False], "+", 
            RowBox[{"o", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"ah2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "ah2"], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}]}], ")"}]}], "-", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ la]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h1"], 
              Format[ ua]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/6\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ la]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b"\),
                    Subscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ lb]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"c"\),
                    Subscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ lc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c"\),
                    Superscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h3"], 
              Format[ ua], 
              Format[ ub], 
              Format[ uc]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/24\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ la]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b"\),
                    Subscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ lb]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"c"\),
                    Subscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ lc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"d"\),
                    Subscript[ "d"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ ld]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c"\),
                    Superscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"d"\),
                    Superscript[ "d"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h4"], 
              Format[ ua], 
              Format[ ub], 
              Format[ uc], 
              Format[ ud]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo36 = \(\(-dim\)\/2\) 
          Log[2  Pi] + \(\(-1\)\/2\) \((ry[la] - \ st[la])\) \((ry[ua] - \ 
              st[ua])\)\)], "Input"],

Cell[BoxData[
    RowBox[{\(\(-\(1\/2\)\)\ dim\ Log[2\ \[Pi]]\), "-", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"y\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\_"a"\),
                      Subscript[ "a"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "y"], 
                Format[ la]],
              Editable->False], "-", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[Theta]\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\_"a"\),
                      Subscript[ "a"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "\[Theta]"], 
                Format[ la]],
              Editable->False]}], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"y\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"a"\),
                      Superscript[ "a"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "y"], 
                Format[ ua]],
              Editable->False], "-", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[Theta]\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"a"\),
                      Superscript[ "a"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "\[Theta]"], 
                Format[ ua]],
              Editable->False]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo37 = CanAll[AbsorbKdelta[CanAll[foo35 - foo36]]]\)], "Input"],

Cell[BoxData[
    RowBox[{\(-h[0]\), "+", \(1\/2\ dim\ Log[2\ \[Pi]]\), "+", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ u1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"ah2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "ah2"], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h1"], 
              Format[ u1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/6\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/24\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h4"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Noting ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](\[Theta]) = \(log \(\[Integral]\(exp(
                  foo35)\) \[DifferentialD]y\) = 
          log\ \(E(exp(foo37 + O(n\^\(\(-3\)/2\))))\)\)\)]],
  ", where the expectation is taken for the multivariate normal with mean ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Theta]\^1,  ... , \[Theta]\^dim)\)\)]],
  " and covariance identity. We apply \"logeexppoly\" to foo37. First, we get \
foo38={a0,a1,a2,a3,a4} for the coefficients of ",
  Cell[BoxData[
      \(TraditionalForm\`a0 + \(a1\^i\) x\_i + \(a2\^ij\) \(x\_i\) 
          x\_j + \(a3\^ijk\) \(x\_i\) \(x\_j\) 
          x\_k + \(a4\^ijkl\) \(x\_i\) \(x\_j\) \(x\_k\) x\_l\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](\[Theta]) = foo39\)]],
  "below."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo38 = 
      CoefficientList[foo37 /. ry[la_] \[Rule] x, x]/{1, o, o, o, 
          o\^2}\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{\(-h[0]\), "+", \(1\/2\ dim\ Log[2\ \[Pi]]\), "+", 
          RowBox[{\(1\/2\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Theta]\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"p"\),
                        Subscript[ "p"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Theta]"], 
                  Format[ l1]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Theta]\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"p"\),
                        Superscript[ "p"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Theta]"], 
                  Format[ u1]],
                Editable->False], ")"}]}]}], ",", 
        RowBox[{"-", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"h1\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"p"\),
                      Superscript[ "p"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "h1"], 
                Format[ u1]],
              Editable->False], ")"}]}], ",", 
        RowBox[{\(-\(1\/2\)\), " ", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"ah2\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"p"\),
                      Superscript[ "p"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"q"\),
                      Superscript[ "q"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "ah2"], 
                Format[ u1], 
                Format[ u2]],
              Editable->False], ")"}]}], ",", 
        RowBox[{\(-\(1\/6\)\), " ", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"h3\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"p"\),
                      Superscript[ "p"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"q"\),
                      Superscript[ "q"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"r"\),
                      Superscript[ "r"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "h3"], 
                Format[ u1], 
                Format[ u2], 
                Format[ u3]],
              Editable->False], ")"}]}], ",", 
        RowBox[{\(-\(1\/24\)\), " ", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"h4\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"p"\),
                      Superscript[ "p"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"q"\),
                      Superscript[ "q"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"r"\),
                      Superscript[ "r"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"s"\),
                      Superscript[ "s"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "h4"], 
                Format[ u1], 
                Format[ u2], 
                Format[ u3], 
                Format[ u4]],
              Editable->False], ")"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo39 = 
      CanAll[logeexppoly /. {sb \[Rule] st, ta0 \[Rule] foo38[\([1]\)], 
            ta1[u1_] \[Rule] foo38[\([2]\)], 
            ta2[u1_, u2_] \[Rule] foo38[\([3]\)], 
            ta3[u1_, u2_, u3_] \[Rule] foo38[\([4]\)], 
            ta4[u1_, u2_, u3_, u4_] \[Rule] foo38[\([5]\)]}]\)], "Input"],

Cell[BoxData[
    RowBox[{\(-h[0]\), "+", \(1\/2\ dim\ Log[2\ \[Pi]]\), "+", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ u1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"ah2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "ah2"], 
              Format[ l1], 
              Format[ u1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"ah2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "ah2"], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"ah2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "ah2"], 
              Format[ l1], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"ah2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "ah2"], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"ah2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "ah2"], 
              Format[ l3], 
              Format[ u1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"ah2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "ah2"], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h1"], 
              Format[ u1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h1"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h1"], 
              Format[ u1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"ah2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "ah2"], 
              Format[ l2], 
              Format[ u1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h1"], 
              Format[ u2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h3"], 
              Format[ l2], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h1"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h3"], 
              Format[ l2], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"ah2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "ah2"], 
              Format[ l2], 
              Format[ u1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h3"], 
              Format[ l3], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/8\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h3"], 
              Format[ l1], 
              Format[ l2], 
              Format[ u1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h3"], 
              Format[ l3], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/6\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"ah2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "ah2"], 
              Format[ l2], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h1"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/12\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h3"], 
              Format[ l1], 
              Format[ l2], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h3"], 
              Format[ l3], 
              Format[ l4], 
              Format[ u3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"ah2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "ah2"], 
              Format[ l4], 
              Format[ u1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h3"], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h3"], 
              Format[ l3], 
              Format[ l4], 
              Format[ u1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h3"], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/8\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"t"\),
                    Subscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h3"], 
              Format[ l5], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"t"\),
                    Superscript[ "t"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h3"], 
              Format[ u3], 
              Format[ u4], 
              Format[ u5]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/8\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h4"], 
              Format[ l1], 
              Format[ l2], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h4"], 
              Format[ l3], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/24\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h4"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now substitute ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\^a = \(\(\[PartialD]\ \[Phi]\/\[PartialD]\ \
\[Eta]\_a\)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\^ab\) \[Eta]\_b + \(1\/2\) \
\(\[Phi]\^abc\) \(\[Eta]\_b\) \[Eta]\_c + \(1\/6\) \(\[Phi]\^abcd\) \
\(\[Eta]\_b\) \(\[Eta]\_c\) \[Eta]\_d\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\^a\)]],
  " in foo39 to get \[Psi](\[Theta])=foo40 in terms of \[Eta] below. The \
coefficients for the polynomial of \[Eta] is stored in foo41."
}], "Text"],

Cell[BoxData[
    \(\(foo40 = CanAll[tgeto2[ApplyRules[foo39, ruletheta1]]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo41 = 
      Collect[CoefficientList[foo40 /. {se[l1_] \[Rule] x}, x], o, 
        tsimp[# /. {u1 \[Rule] ua, u2 \[Rule] ub, u3 \[Rule] uc, 
                u4 \[Rule] ud, l1 \[Rule] la, l2 \[Rule] lb, l3 \[Rule] lc, 
                l4 \[Rule] ld}] &]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{\(-h[0]\), "+", \(1\/2\ dim\ Log[2\ \[Pi]]\), "-", 
          RowBox[{\(1\/2\), " ", "o", " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"ah2\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"p"\),
                        Subscript[ "p"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"p"\),
                        Superscript[ "p"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "ah2"], 
                  Format[ l1], 
                  Format[ u1]],
                Editable->False], ")"}]}], "+", 
          RowBox[{\(o\^2\), " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(1\/4\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"ah2\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q"\),
                              Subscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "ah2"], 
                        Format[ l1], 
                        Format[ l2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"ah2\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q"\),
                              Superscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "ah2"], 
                        Format[ u1], 
                        Format[ u2]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h1\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h1"], 
                        Format[ l1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h1\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h1"], 
                        Format[ u1]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h1\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h1"], 
                        Format[ l1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q"\),
                              Subscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q"\),
                              Superscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h3"], 
                        Format[ l2], 
                        Format[ u1], 
                        Format[ u2]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(1\/8\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q"\),
                              Subscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h3"], 
                        Format[ l1], 
                        Format[ l2], 
                        Format[ u1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"r"\),
                              Subscript[ "r"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q"\),
                              Superscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"r"\),
                              Superscript[ "r"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h3"], 
                        Format[ l3], 
                        Format[ u2], 
                        Format[ u3]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(1\/12\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q"\),
                              Subscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"r"\),
                              Subscript[ "r"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h3"], 
                        Format[ l1], 
                        Format[ l2], 
                        Format[ l3]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q"\),
                              Superscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"r"\),
                              Superscript[ "r"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h3"], 
                        Format[ u1], 
                        Format[ u2], 
                        Format[ u3]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{\(1\/8\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h4\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q"\),
                              Subscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q"\),
                              Superscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h4"], 
                        Format[ l1], 
                        Format[ l2], 
                        Format[ u1], 
                        Format[ u2]],
                      Editable->False], ")"}]}]}], ")"}]}]}], ",", 
        RowBox[{
          RowBox[{"o", " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h1\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h1"], 
                        Format[ ua]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h3"], 
                        Format[ l1], 
                        Format[ u1], 
                        Format[ ua]],
                      Editable->False], ")"}]}]}], ")"}]}], "+", 
          RowBox[{\(o\^2\), " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"ah2\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "ah2"], 
                        Format[ l1], 
                        Format[ ua]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h1\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h1"], 
                        Format[ u1]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"ah2\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "ah2"], 
                        Format[ l1], 
                        Format[ ua]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q"\),
                              Subscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q"\),
                              Superscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h3"], 
                        Format[ l2], 
                        Format[ u1], 
                        Format[ u2]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"ah2\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q"\),
                              Subscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "ah2"], 
                        Format[ l1], 
                        Format[ l2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q"\),
                              Superscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h3"], 
                        Format[ u1], 
                        Format[ u2], 
                        Format[ ua]],
                      Editable->False], ")"}]}]}], ")"}]}]}], ",", 
        RowBox[{\(1\/2\), "-", 
          RowBox[{\(1\/2\), " ", "o", " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"ah2\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a"\),
                        Superscript[ "a"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b"\),
                        Superscript[ "b"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "ah2"], 
                  Format[ ua], 
                  Format[ ub]],
                Editable->False], ")"}]}], "+", 
          RowBox[{\(o\^2\), " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"ah2\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "ah2"], 
                        Format[ l1], 
                        Format[ ua]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"ah2\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "ah2"], 
                        Format[ u1], 
                        Format[ ub]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(1\/4\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q"\),
                              Subscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h3"], 
                        Format[ l1], 
                        Format[ l2], 
                        Format[ ua]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q"\),
                              Superscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h3"], 
                        Format[ u1], 
                        Format[ u2], 
                        Format[ ub]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h1\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h1"], 
                        Format[ l1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h3"], 
                        Format[ u1], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(1\/4\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q"\),
                              Subscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h3"], 
                        Format[ l1], 
                        Format[ l2], 
                        Format[ u1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q"\),
                              Superscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h3"], 
                        Format[ u2], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{\(1\/4\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h4\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h4"], 
                        Format[ l1], 
                        Format[ u1], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h1\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h1"], 
                        Format[ l1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        Format[ u1], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{\(1\/4\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q"\),
                              Subscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h3"], 
                        Format[ l1], 
                        Format[ l2], 
                        Format[ u1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q"\),
                              Superscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        Format[ u2], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}]}], ")"}]}]}], ",", 
        RowBox[{
          RowBox[{\(o\^2\), " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"ah2\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "ah2"], 
                        Format[ l1], 
                        Format[ ua]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"c"\),
                              Superscript[ "c"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h3"], 
                        Format[ u1], 
                        Format[ ub], 
                        Format[ uc]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"ah2\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "ah2"], 
                        Format[ l1], 
                        Format[ ua]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"c"\),
                              Superscript[ "c"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        Format[ u1], 
                        Format[ ub], 
                        Format[ uc]],
                      Editable->False], ")"}]}]}], ")"}]}], "+", 
          RowBox[{"o", " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(-\(1\/6\)\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"c"\),
                              Superscript[ "c"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h3"], 
                        Format[ ua], 
                        Format[ ub], 
                        Format[ uc]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"c"\),
                              Superscript[ "c"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        Format[ ua], 
                        Format[ ub], 
                        Format[ uc]],
                      Editable->False], ")"}]}]}], ")"}]}]}], ",", 
        RowBox[{\(o\^2\), " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{\(1\/8\), " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"h3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p"\),
                            Subscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a"\),
                            Superscript[ "a"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b"\),
                            Superscript[ "b"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "h3"], 
                      Format[ l1], 
                      Format[ ua], 
                      Format[ ub]],
                    Editable->False], ")"}], " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"h3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"p"\),
                            Superscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"c"\),
                            Superscript[ "c"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"d"\),
                            Superscript[ "d"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "h3"], 
                      Format[ u1], 
                      Format[ uc], 
                      Format[ ud]],
                    Editable->False], ")"}]}], "-", 
              RowBox[{\(1\/24\), " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"h4\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a"\),
                            Superscript[ "a"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b"\),
                            Superscript[ "b"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"c"\),
                            Superscript[ "c"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"d"\),
                            Superscript[ "d"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "h4"], 
                      Format[ ua], 
                      Format[ ub], 
                      Format[ uc], 
                      Format[ ud]],
                    Editable->False], ")"}]}], "-", 
              RowBox[{\(1\/4\), " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"h3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p"\),
                            Subscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a"\),
                            Superscript[ "a"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b"\),
                            Superscript[ "b"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "h3"], 
                      Format[ l1], 
                      Format[ ua], 
                      Format[ ub]],
                    Editable->False], ")"}], " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"p"\),
                            Superscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"c"\),
                            Superscript[ "c"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"d"\),
                            Superscript[ "d"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      Format[ u1], 
                      Format[ uc], 
                      Format[ ud]],
                    Editable->False], ")"}]}], "+", 
              RowBox[{\(1\/8\), " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p"\),
                            Subscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a"\),
                            Superscript[ "a"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b"\),
                            Superscript[ "b"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      Format[ l1], 
                      Format[ ua], 
                      Format[ ub]],
                    Editable->False], ")"}], " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"p"\),
                            Superscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"c"\),
                            Superscript[ "c"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"d"\),
                            Superscript[ "d"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      Format[ u1], 
                      Format[ uc], 
                      Format[ ud]],
                    Editable->False], ")"}]}], "+", 
              RowBox[{\(1\/6\), " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]4\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a"\),
                            Superscript[ "a"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b"\),
                            Superscript[ "b"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"c"\),
                            Superscript[ "c"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"d"\),
                            Superscript[ "d"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "\[Phi]4"], 
                      Format[ ua], 
                      Format[ ub], 
                      Format[ uc], 
                      Format[ ud]],
                    Editable->False], ")"}]}]}], ")"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Since foo40=\[Psi](\[Theta])=psieta, foo41 must be equal to foo42 below.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo42 = 
      CoefficientList[psieta /. se[la_] \[Rule] x, x] /. {u1 \[Rule] ua, 
          u2 \[Rule] ub, u3 \[Rule] uc, u4 \[Rule] ud}\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(psi[0]\), ",", "0", ",", \(1\/2\), ",", 
        RowBox[{\(1\/3\), " ", "o", " ", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[Phi]3\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"a"\),
                      Superscript[ "a"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"b"\),
                      Superscript[ "b"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"c"\),
                      Superscript[ "c"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "\[Phi]3"], 
                Format[ ua], 
                Format[ ub], 
                Format[ uc]],
              Editable->False], ")"}]}], ",", 
        RowBox[{\(1\/8\), " ", \(o\^2\), " ", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[Phi]4\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"a"\),
                      Superscript[ "a"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"b"\),
                      Superscript[ "b"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"c"\),
                      Superscript[ "c"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"d"\),
                      Superscript[ "d"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "\[Phi]4"], 
                Format[ ua], 
                Format[ ub], 
                Format[ uc], 
                Format[ ud]],
              Editable->False], ")"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "At first, we compare the coefficient for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Eta]\^a\) \[Eta]\^b\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo41[\([3]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(1\/2\), "-", 
      RowBox[{\(1\/2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"ah2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "ah2"], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"ah2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "ah2"], 
                    Format[ l1], 
                    Format[ ua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"ah2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "ah2"], 
                    Format[ u1], 
                    Format[ ub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"h3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "h3"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ ua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"h3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "h3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ ub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"h1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "h1"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"h3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "h3"], 
                    Format[ u1], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"h3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "h3"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"h3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "h3"], 
                    Format[ u2], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"h4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "h4"], 
                    Format[ l1], 
                    Format[ u1], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"h1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "h1"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ u1], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"h3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "h3"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ u2], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo42[\([3]\)]\)], "Input"],

Cell[BoxData[
    \(1\/2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Thus, ah2 is in fact ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(-1\))\)]],
  " instead of ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(\(-1\)/2\))\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(hiny = hiny /. {\ tah2[ua_, ub_] \[Rule] o\ tah2[ua, ub]}\)], "Input"],

Cell[BoxData[
    RowBox[{\(h[0]\), "+", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ la]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b"\),
                    Subscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ lb]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"Kdelta\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"a"\),
                      Superscript[ "a"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"b"\),
                      Superscript[ "b"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ Kdelta], 
                Format[ ua], 
                Format[ ub]],
              Editable->False], "+", 
            RowBox[{\(o\^2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"ah2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "ah2"], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ la]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h1"], 
              Format[ ua]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/6\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ la]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b"\),
                    Subscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ lb]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"c"\),
                    Subscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ lc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c"\),
                    Superscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h3"], 
              Format[ ua], 
              Format[ ub], 
              Format[ uc]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/24\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ la]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b"\),
                    Subscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ lb]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"c"\),
                    Subscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ lc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"d"\),
                    Subscript[ "d"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ ld]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c"\),
                    Superscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"d"\),
                    Superscript[ "d"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h4"], 
              Format[ ua], 
              Format[ ub], 
              Format[ uc], 
              Format[ ud]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["We rewrite foo43=foo42-foo41.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo43 = 
      Map[tgeto2, \((foo42 - foo41)\) /. \ {tah2[u1_, u2_] \[Rule] 
              o\ tah2[u1, u2]}]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{\(h[0]\), "-", \(1\/2\ dim\ Log[2\ \[Pi]]\), "+", \(psi[0]\), 
          "+", 
          RowBox[{\(o\^2\), " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"ah2\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "ah2"], 
                        Format[ l1], 
                        Format[ u1]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h1\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h1"], 
                        Format[ l1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h1\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h1"], 
                        Format[ u1]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h1\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h1"], 
                        Format[ l1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q"\),
                              Subscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q"\),
                              Superscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h3"], 
                        Format[ l2], 
                        Format[ u1], 
                        Format[ u2]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{\(1\/8\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q"\),
                              Subscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h3"], 
                        Format[ l1], 
                        Format[ l2], 
                        Format[ u1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"r"\),
                              Subscript[ "r"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q"\),
                              Superscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"r"\),
                              Superscript[ "r"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h3"], 
                        Format[ l3], 
                        Format[ u2], 
                        Format[ u3]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{\(1\/12\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q"\),
                              Subscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"r"\),
                              Subscript[ "r"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h3"], 
                        Format[ l1], 
                        Format[ l2], 
                        Format[ l3]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q"\),
                              Superscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"r"\),
                              Superscript[ "r"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h3"], 
                        Format[ u1], 
                        Format[ u2], 
                        Format[ u3]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(1\/8\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"h4\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q"\),
                              Subscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q"\),
                              Superscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "h4"], 
                        Format[ l1], 
                        Format[ l2], 
                        Format[ u1], 
                        Format[ u2]],
                      Editable->False], ")"}]}]}], ")"}]}]}], ",", 
        RowBox[{"o", " ", 
          RowBox[{"(", 
            RowBox[{
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"h1\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a"\),
                        Superscript[ "a"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "h1"], 
                  Format[ ua]],
                Editable->False], "+", 
              RowBox[{\(1\/2\), " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"h3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p"\),
                            Subscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"p"\),
                            Superscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a"\),
                            Superscript[ "a"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "h3"], 
                      Format[ l1], 
                      Format[ u1], 
                      Format[ ua]],
                    Editable->False], ")"}]}]}], ")"}]}], ",", 
        RowBox[{\(o\^2\), " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{\(1\/2\), " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"ah2\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a"\),
                            Superscript[ "a"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b"\),
                            Superscript[ "b"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "ah2"], 
                      Format[ ua], 
                      Format[ ub]],
                    Editable->False], ")"}]}], "-", 
              RowBox[{\(1\/4\), " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"h3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p"\),
                            Subscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"q"\),
                            Subscript[ "q"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a"\),
                            Superscript[ "a"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "h3"], 
                      Format[ l1], 
                      Format[ l2], 
                      Format[ ua]],
                    Editable->False], ")"}], " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"h3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"p"\),
                            Superscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"q"\),
                            Superscript[ "q"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b"\),
                            Superscript[ "b"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "h3"], 
                      Format[ u1], 
                      Format[ u2], 
                      Format[ ub]],
                    Editable->False], ")"}]}], "-", 
              RowBox[{\(1\/2\), " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"h1\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p"\),
                            Subscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "h1"], 
                      Format[ l1]],
                    Editable->False], ")"}], " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"h3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"p"\),
                            Superscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a"\),
                            Superscript[ "a"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b"\),
                            Superscript[ "b"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "h3"], 
                      Format[ u1], 
                      Format[ ua], 
                      Format[ ub]],
                    Editable->False], ")"}]}], "-", 
              RowBox[{\(1\/4\), " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"h3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p"\),
                            Subscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"q"\),
                            Subscript[ "q"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"p"\),
                            Superscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "h3"], 
                      Format[ l1], 
                      Format[ l2], 
                      Format[ u1]],
                    Editable->False], ")"}], " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"h3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"q"\),
                            Superscript[ "q"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a"\),
                            Superscript[ "a"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b"\),
                            Superscript[ "b"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "h3"], 
                      Format[ u2], 
                      Format[ ua], 
                      Format[ ub]],
                    Editable->False], ")"}]}], "+", 
              RowBox[{\(1\/4\), " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"h4\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p"\),
                            Subscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"p"\),
                            Superscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a"\),
                            Superscript[ "a"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b"\),
                            Superscript[ "b"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "h4"], 
                      Format[ l1], 
                      Format[ u1], 
                      Format[ ua], 
                      Format[ ub]],
                    Editable->False], ")"}]}], "+", 
              RowBox[{\(1\/2\), " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"h1\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p"\),
                            Subscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "h1"], 
                      Format[ l1]],
                    Editable->False], ")"}], " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"p"\),
                            Superscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a"\),
                            Superscript[ "a"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b"\),
                            Superscript[ "b"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      Format[ u1], 
                      Format[ ua], 
                      Format[ ub]],
                    Editable->False], ")"}]}], "+", 
              RowBox[{\(1\/4\), " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"h3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p"\),
                            Subscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"q"\),
                            Subscript[ "q"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"p"\),
                            Superscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "h3"], 
                      Format[ l1], 
                      Format[ l2], 
                      Format[ u1]],
                    Editable->False], ")"}], " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"q"\),
                            Superscript[ "q"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a"\),
                            Superscript[ "a"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b"\),
                            Superscript[ "b"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      Format[ u2], 
                      Format[ ua], 
                      Format[ ub]],
                    Editable->False], ")"}]}]}], ")"}]}], ",", 
        RowBox[{"o", " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{\(1\/6\), " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"h3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a"\),
                            Superscript[ "a"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b"\),
                            Superscript[ "b"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"c"\),
                            Superscript[ "c"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "h3"], 
                      Format[ ua], 
                      Format[ ub], 
                      Format[ uc]],
                    Editable->False], ")"}]}], "-", 
              RowBox[{\(1\/6\), " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a"\),
                            Superscript[ "a"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b"\),
                            Superscript[ "b"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"c"\),
                            Superscript[ "c"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      Format[ ua], 
                      Format[ ub], 
                      Format[ uc]],
                    Editable->False], ")"}]}]}], ")"}]}], ",", 
        RowBox[{\(o\^2\), " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{\(-\(1\/8\)\), " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"h3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p"\),
                            Subscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a"\),
                            Superscript[ "a"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b"\),
                            Superscript[ "b"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "h3"], 
                      Format[ l1], 
                      Format[ ua], 
                      Format[ ub]],
                    Editable->False], ")"}], " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"h3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"p"\),
                            Superscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"c"\),
                            Superscript[ "c"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"d"\),
                            Superscript[ "d"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "h3"], 
                      Format[ u1], 
                      Format[ uc], 
                      Format[ ud]],
                    Editable->False], ")"}]}], "+", 
              RowBox[{\(1\/24\), " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"h4\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a"\),
                            Superscript[ "a"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b"\),
                            Superscript[ "b"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"c"\),
                            Superscript[ "c"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"d"\),
                            Superscript[ "d"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "h4"], 
                      Format[ ua], 
                      Format[ ub], 
                      Format[ uc], 
                      Format[ ud]],
                    Editable->False], ")"}]}], "+", 
              RowBox[{\(1\/4\), " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"h3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p"\),
                            Subscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a"\),
                            Superscript[ "a"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b"\),
                            Superscript[ "b"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "h3"], 
                      Format[ l1], 
                      Format[ ua], 
                      Format[ ub]],
                    Editable->False], ")"}], " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"p"\),
                            Superscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"c"\),
                            Superscript[ "c"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"d"\),
                            Superscript[ "d"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      Format[ u1], 
                      Format[ uc], 
                      Format[ ud]],
                    Editable->False], ")"}]}], "-", 
              RowBox[{\(1\/8\), " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p"\),
                            Subscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a"\),
                            Superscript[ "a"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b"\),
                            Superscript[ "b"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      Format[ l1], 
                      Format[ ua], 
                      Format[ ub]],
                    Editable->False], ")"}], " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"p"\),
                            Superscript[ "p"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"c"\),
                            Superscript[ "c"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"d"\),
                            Superscript[ "d"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      Format[ u1], 
                      Format[ uc], 
                      Format[ ud]],
                    Editable->False], ")"}]}], "-", 
              RowBox[{\(1\/24\), " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]4\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a"\),
                            Superscript[ "a"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b"\),
                            Superscript[ "b"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"c"\),
                            Superscript[ "c"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"d"\),
                            Superscript[ "d"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "\[Phi]4"], 
                      Format[ ua], 
                      Format[ ub], 
                      Format[ uc], 
                      Format[ ud]],
                    Editable->False], ")"}]}]}], ")"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "We solve these five equations \[Equal] 0. At first, foo43[[4]]==0 gives ",
  Cell[BoxData[
      \(TraditionalForm\`h3\^abc = \(\(\[Phi]3\^abc\)\(.\)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo44 = Solve[foo43[\([4]\)] \[Equal] 0, th3[ua, ub, uc]]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c"\),
                    Superscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h3"], 
              Format[ ua], 
              Format[ ub], 
              Format[ uc]],
            Editable->False], "\[Rule]", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c"\),
                    Superscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ ua], 
              Format[ ub], 
              Format[ uc]],
            Editable->False]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule44, th3[ua_, ub_, uc_], foo44[\([1, 1, 2]\)]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo45 = 
      Solve[ApplyRules[foo43[\([2]\)], rule44] \[Equal] 0, 
        th1[ua]]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h1"], 
              Format[ ua]],
            Editable->False], "\[Rule]", 
          RowBox[{\(-\(1\/2\)\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"p"\),
                        Subscript[ "p"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"p"\),
                        Superscript[ "p"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a"\),
                        Superscript[ "a"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  Format[ l1], 
                  Format[ u1], 
                  Format[ ua]],
                Editable->False], ")"}]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule45, th1[ua_], foo45[\([1, 1, 2]\)]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo46 = 
      Solve[ApplyRules[foo43[\([5]\)], {rule44, rule45}] \[Equal] 0, 
        th4[ua, ub, uc, ud]]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"h4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c"\),
                    Superscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"d"\),
                    Superscript[ "d"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "h4"], 
              Format[ ua], 
              Format[ ub], 
              Format[ uc], 
              Format[ ud]],
            Editable->False], "\[Rule]", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c"\),
                    Superscript[ "c"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"d"\),
                    Superscript[ "d"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ ua], 
              Format[ ub], 
              Format[ uc], 
              Format[ ud]],
            Editable->False]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule46, th4[ua_, ub_, uc_, ud_], 
      foo46[\([1, 1, 2]\)]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo47 = 
      Simplify[Solve[
          ApplyRules[foo43[\([3]\)], {rule44, rule45, rule46}] \[Equal] 0, 
          tah2[ua, ub]]]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"ah2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "ah2"], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], "\[Rule]", 
          RowBox[{\(1\/2\), " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q"\),
                              Subscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        Format[ l1], 
                        Format[ l2], 
                        Format[ ua]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q"\),
                              Superscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        Format[ u1], 
                        Format[ u2], 
                        Format[ ub]],
                      Editable->False], ")"}]}], "-", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ l1], 
                    Format[ u1], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False]}], ")"}]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule47, tah2[ua_, ub_], foo47[\([1, 1, 2]\)]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo48 = 
      Simplify[Solve[
          ApplyRules[
              foo43[\([1]\)], {rule44, rule45, rule46, rule47}] \[Equal] 0, 
          h[0]]]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{\(h[0]\), "\[Rule]", 
          RowBox[{\(1\/24\), " ", 
            RowBox[{"(", 
              RowBox[{\(12\ dim\ Log[2\ \[Pi]]\), "-", \(24\ psi[0]\), "-", 
                RowBox[{"3", " ", \(o\^2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q"\),
                              Subscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q"\),
                              Superscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        Format[ l1], 
                        Format[ l2], 
                        Format[ u2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"r"\),
                              Subscript[ "r"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"r"\),
                              Superscript[ "r"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        Format[ l3], 
                        Format[ u1], 
                        Format[ u3]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{"3", " ", \(o\^2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q"\),
                              Subscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        Format[ l1], 
                        Format[ l2], 
                        Format[ u1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"r"\),
                              Subscript[ "r"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q"\),
                              Superscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"r"\),
                              Superscript[ "r"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        Format[ l3], 
                        Format[ u2], 
                        Format[ u3]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{"4", " ", \(o\^2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q"\),
                              Subscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"r"\),
                              Subscript[ "r"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        Format[ l1], 
                        Format[ l2], 
                        Format[ l3]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q"\),
                              Superscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"r"\),
                              Superscript[ "r"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        Format[ u1], 
                        Format[ u2], 
                        Format[ u3]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{"3", " ", \(o\^2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]4\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q"\),
                              Subscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q"\),
                              Superscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]4"], 
                        Format[ l1], 
                        Format[ l2], 
                        Format[ u1], 
                        Format[ u2]],
                      Editable->False], ")"}]}]}], ")"}]}]}], "}"}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule48, h[0], foo48[\([1, 1, 2]\)]]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["result", "Subsubsection"],

Cell[TextData[{
  "Now, it is time to express ",
  Cell[BoxData[
      \(TraditionalForm\`h(y)\)]],
  " in terms of the \[Phi] derivatives."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(hinyphi = 
      CanAll[AbsorbKdelta[
          ApplyRules[
            hiny, {rule44, rule45, rule46, rule47, rule48}]]]\)], "Input"],

Cell[BoxData[
    RowBox[{\(1\/2\ dim\ Log[2\ \[Pi]]\), "-", \(psi[0]\), "+", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ u1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ l2], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/6\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/6\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ l1], 
              Format[ l2], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ l3], 
              Format[ l4], 
              Format[ u1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/8\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ l1], 
              Format[ l2], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ l3], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/24\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(hinyphi // InputForm\)], "Input"],

Cell["\<\
(dim*Log[2*Pi])/2 - psi[0] + (ry[l1]*ry[u1])/2 - 
 (o*ry[l1]*tp3[l2, u1, u2])/2 + 
 (o*ry[l1]*ry[l2]*ry[l3]*tp3[u1, u2, u3])/6 - 
 (o^2*tp3[l1, l2, l3]*tp3[u1, u2, u3])/6 + 
 (o^2*ry[l1]*ry[l2]*tp3[l3, l4, u1]*tp3[u2, u3, u4])/4 + 
 (o^2*tp4[l1, l2, u1, u2])/8 - 
 (o^2*ry[l1]*ry[l2]*tp4[l3, u1, u2, u3])/4 + 
 (o^2*ry[l1]*ry[l2]*ry[l3]*ry[l4]*tp4[u1, u2, u3, u4])/24\
\>", "Output"]
}, Open  ]],

Cell[TextData[{
  "The coefficients of ",
  Cell[BoxData[
      \(TraditionalForm\`h(y)\)]],
  " as a polynomial of ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " are as follows."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo49 = 
      Collect[CoefficientList[hinyphi /. ry[l1_] \[Rule] x, 
            x] /. {u1 \[Rule] ua, u2 \[Rule] ub, u3 \[Rule] uc, 
            u4 \[Rule] ud, l1 \[Rule] la, l2 \[Rule] lb, l3 \[Rule] lc, 
            l4 \[Rule] ld}, o, tsimp[#] &]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{\(1\/2\ dim\ Log[2\ \[Pi]]\), "-", \(psi[0]\), "+", 
          RowBox[{\(o\^2\), " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(-\(1\/6\)\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q"\),
                              Subscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"r"\),
                              Subscript[ "r"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        Format[ l1], 
                        Format[ l2], 
                        Format[ l3]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q"\),
                              Superscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"r"\),
                              Superscript[ "r"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        Format[ u1], 
                        Format[ u2], 
                        Format[ u3]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(1\/8\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]4\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q"\),
                              Subscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q"\),
                              Superscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]4"], 
                        Format[ l1], 
                        Format[ l2], 
                        Format[ u1], 
                        Format[ u2]],
                      Editable->False], ")"}]}]}], ")"}]}]}], ",", 
        RowBox[{\(-\(1\/2\)\), " ", "o", " ", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[Phi]3\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\_"p"\),
                      Subscript[ "p"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"p"\),
                      Superscript[ "p"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"a"\),
                      Superscript[ "a"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "\[Phi]3"], 
                Format[ l1], 
                Format[ u1], 
                Format[ ua]],
              Editable->False], ")"}]}], ",", 
        RowBox[{\(1\/2\), "+", 
          RowBox[{\(o\^2\), " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(1\/4\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q"\),
                              Subscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        Format[ l1], 
                        Format[ l2], 
                        Format[ ua]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q"\),
                              Superscript[ "q"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        Format[ u1], 
                        Format[ u2], 
                        Format[ ub]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{\(1\/4\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]4\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p"\),
                              Subscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p"\),
                              Superscript[ "p"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]4"], 
                        Format[ l1], 
                        Format[ u1], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}]}], ")"}]}]}], ",", 
        RowBox[{\(1\/6\), " ", "o", " ", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[Phi]3\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"a"\),
                      Superscript[ "a"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"b"\),
                      Superscript[ "b"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"c"\),
                      Superscript[ "c"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "\[Phi]3"], 
                Format[ ua], 
                Format[ ub], 
                Format[ uc]],
              Editable->False], ")"}]}], ",", 
        RowBox[{\(1\/24\), " ", \(o\^2\), " ", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[Phi]4\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"a"\),
                      Superscript[ "a"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"b"\),
                      Superscript[ "b"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"c"\),
                      Superscript[ "c"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"d"\),
                      Superscript[ "d"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "\[Phi]4"], 
                Format[ ua], 
                Format[ ub], 
                Format[ uc], 
                Format[ ud]],
              Editable->False], ")"}]}]}], "}"}]], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["the canonical form", "Subsection"],

Cell[TextData[{
  "Now we get the canonical form of ",
  Cell[BoxData[
      \(TraditionalForm\`log\ \(f(y; \[Eta])\)\)]],
  " in \"logdensityy\"."
}], "Text"],

Cell[CellGroupData[{

Cell["the summary of the previous sections", "Subsubsection"],

Cell["\<\
The standard form of the density function is specified by logdensity=log f(y;\
\[Theta]).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(logdensity\)], "Input"],

Cell[BoxData[
    RowBox[{\(-h[y]\), "-", \(psi[theta]\), "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ la]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Theta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Theta]"], 
              Format[ ua]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["\<\
By applying \"ruletheta1\" to logdensity, \[Theta] can be expressed in terms \
of \[Eta] and \[Phi] derivatives.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo51 = ApplyRules[logdensity, ruletheta1]\)], "Input"],

Cell[BoxData[
    RowBox[{\(-h[y]\), "-", \(psi[theta]\), "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/6\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["\<\
The cumulant function \[Psi](\[Theta]) can be expressed in terms of \[Eta] \
and \[Phi] derivatives as shown in psieta.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(psieta\)], "Input"],

Cell[BoxData[
    RowBox[{\(psi[0]\), "+", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ u1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/3\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/8\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["\<\
The measure function h(y) can be expressed in terms of y and \[Phi] \
derivatives as shown in hinyphi.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(hinyphi\)], "Input"],

Cell[BoxData[
    RowBox[{\(1\/2\ dim\ Log[2\ \[Pi]]\), "-", \(psi[0]\), "+", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ u1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ l2], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/6\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/6\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ l1], 
              Format[ l2], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ l3], 
              Format[ l4], 
              Format[ u1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/8\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ l1], 
              Format[ l2], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ l3], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/24\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["result", "Subsubsection"],

Cell["\<\
By substituting psieta and hinyphi for psi[theta] and h[y] respectively in \
foo51=log f(y;\[Theta]), we obtain the canonical form of log f(y;\[Eta]) as \
follows.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo52 = 
      Collect[foo51 /. {psi[theta] \[Rule] psieta, h[y] \[Rule] hinyphi}, o, 
        tsimp]\)], "Input"],

Cell[BoxData[
    RowBox[{\(\(-\(1\/2\)\)\ dim\ Log[2\ \[Pi]]\), "-", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ u1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ u1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ u1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ l2], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/6\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/3\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(1\/6\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ l3], 
                    Format[ l4], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ u2], 
                    Format[ u3], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/8\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ l3], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/24\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/6\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/8\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3], 
                    Format[ u4]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["\<\
This is the canonical form  of log f(y;\[Eta]).\
\>", "Text"],

Cell[BoxData[
    \(\(logdensityy = \ Expand[foo52];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(logdensityy // InputForm\)], "Input"],

Cell["\<\
-(dim*Log[2*Pi])/2 - (ry[l1]*ry[u1])/2 + ry[l1]*se[u1] - 
 (se[l1]*se[u1])/2 + (o*ry[l1]*tp3[l2, u1, u2])/2 - 
 (o*ry[l1]*ry[l2]*ry[l3]*tp3[u1, u2, u3])/6 + 
 (o*ry[l1]*se[l2]*se[l3]*tp3[u1, u2, u3])/2 - 
 (o*se[l1]*se[l2]*se[l3]*tp3[u1, u2, u3])/3 + 
 (o^2*tp3[l1, l2, l3]*tp3[u1, u2, u3])/6 - 
 (o^2*ry[l1]*ry[l2]*tp3[l3, l4, u1]*tp3[u2, u3, u4])/4 - 
 (o^2*tp4[l1, l2, u1, u2])/8 + 
 (o^2*ry[l1]*ry[l2]*tp4[l3, u1, u2, u3])/4 - 
 (o^2*ry[l1]*ry[l2]*ry[l3]*ry[l4]*tp4[u1, u2, u3, u4])/24 + 
 (o^2*ry[l1]*se[l2]*se[l3]*se[l4]*tp4[u1, u2, u3, u4])/6 - 
 (o^2*se[l1]*se[l2]*se[l3]*se[l4]*tp4[u1, u2, u3, u4])/8\
\>", "Output"]
}, Open  ]],

Cell[TextData[{
  "We also show the metric ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2\ \[Phi]\/\(\[PartialD]\[Eta]\_a \
\[PartialD]\[Eta]\_b\)\)]],
  " by using rulephi2, and name it \"phi2eta\" for later use."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(phi2eta = ApplyRules[dp2[ua, ub], rulephi2]\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"Kdelta\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"a"\),
                Superscript[ "a"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"b"\),
                Superscript[ "b"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ Kdelta], 
          Format[ ua], 
          Format[ ub]],
        Editable->False], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u1], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ u1], 
              Format[ u2], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(InputForm[phi2eta]\)], "Input"],

Cell["\<\
Kdelta[ua, ub] + o*se[l1]*tp3[u1, ua, ub] + 
 (o^2*se[l1]*se[l2]*tp4[u1, u2, ua, ub])/2\
\>", "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Tube-Coordinates and ",
  Cell[BoxData[
      \(TraditionalForm\`z\_c\)]],
  "-formula"
}], "Subsubtitle"],

Cell[TextData[{
  "In this part, we first give an expression of the smooth surface in ",
  Cell[BoxData[
      \(TraditionalForm\`R\^dim\)]],
  " which specifies the boundary of the region of interest in the \
\[Eta]-space. The tube-coordinate system is then defined as a pair of the \
coordinate system on the surface and the coordinate along the normal \
direction. The signed distance from the boundary is slightly modified for \
generalization, and named as  a modified signed distance characterized  by a \
coefficient vector ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ". The ",
  Cell[BoxData[
      \(TraditionalForm\`z\_c\)]],
  "-formula is derived as an expression of  the distribution function of the \
modified signed distance, which is obtained up to ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(-1\))\)]],
  " terms ignoring the error of ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(\(-3\)/2\))\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell["Startup", "Section"],

Cell[TextData[{
  "This section initializes the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session."
}], "Text"],

Cell[CellGroupData[{

Cell["packages", "Subsubsection"],

Cell[BoxData[
    \(<< \ Statistics`ContinuousDistributions`\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< MathTens.m\ \((Windows)\)\)], "Input"],

Cell[BoxData[
    \("Loading MathTensor for DOS/Windows . . ."\)], "Print"],

Cell[BoxData[
    \("\n\n"\)], "Print"],

Cell[BoxData[
    \("======================================================="\)], "Print"],

Cell[BoxData[
    \("MathTensor (TM) 2.2.1 (Windows) (September 17, 2000)"\)], "Print"],

Cell[BoxData[
    \("by Leonard Parker and Steven M. Christensen"\)], "Print"],

Cell[BoxData[
    \("Copyright (c) 1991-2000 MathTensor, Inc."\)], "Print"],

Cell[BoxData[
    \("Runs with Mathematica (R) Versions 2.2, 3.0, 4.0"\)], "Print"],

Cell[BoxData[
    \("======================================================="\)], "Print"],

Cell[BoxData[
    \("No unit system is chosen. If you want one,"\)], "Print"],

Cell[BoxData[
    \("you must edit the file called Conventions.m,"\)], "Print"],

Cell[BoxData[
    \("or enter a command to interactively set units."\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Units: "\[InvisibleSpace]{}\),
      SequenceForm[ "Units: ", {}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Sign conventions: Rmsign = "\[InvisibleSpace]1\
\[InvisibleSpace]" Rcsign = "\[InvisibleSpace]1\),
      SequenceForm[ "Sign conventions: Rmsign = ", 1, " Rcsign = ", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("MetricgSign = "\[InvisibleSpace]1\[InvisibleSpace]" \
DetgSign = "\[InvisibleSpace]\(-1\)\),
      SequenceForm[ "MetricgSign = ", 1, " DetgSign = ", -1],
      Editable->False]], "Print"],

Cell[BoxData[
    \("TensorForm turned on,\nShowTime turned off,\nMetricgFlag = True."\)], \
"Print"],

Cell[BoxData[
    \("========================================="\)], "Print"],

Cell[BoxData[
    \(Null\ Windows\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["error messages", "Subsubsection"],

Cell[BoxData[
    \(Off[General::spell1]\)], "Input"],

Cell[BoxData[
    \(Off[General::spell]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["distribution functions", "Subsubsection"],

Cell[BoxData[{
    \(gammadist[x_, m_, \[Alpha]_] := 
      PDF[GammaDistribution[m, \[Alpha]], x]\), "\n", 
    \(Gammadist[x_, m_, \[Alpha]_] := 
      CDF[GammaDistribution[m, \[Alpha]], x]\), "\n", 
    \(f[x_] := PDF[NormalDistribution[0, 1], x]\), "\n", 
    \(F[x_] := CDF[NormalDistribution[0, 1], x]\), "\n", 
    \(Q[x_] := Quantile[NormalDistribution[0, 1], x]\), "\n", 
    \(Chidist[x_, {di_, nc_}] := 
      CDF[NoncentralChiSquareDistribution[di, nc], x]\)}], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exponential family", "Section"],

Cell["\<\
This section summarizes the results for the exponential family derived in the \
previous part.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
the expectation of the exponential of a polynomial function of the normal \
vector\
\>", "Subsection"],

Cell[TextData[{
  "Here we give the log of the expectation of  the exponential of ",
  Cell[BoxData[
      \(TraditionalForm\`poly(x) = 
        a0 + \(a1\_i\) x\^i + \(a2\_ij\) \(x\^i\) 
            x\^j + \(a3\_ijk\) \(x\^i\) \(x\^j\) 
            x\^k + \(a4\_ijkl\) \(x\^i\) \(x\^j\) \(x\^k\) x\^l\)]],
  ", where a1, a2, and a3 are of order ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(\(-1\)/2\))\)]],
  ", and a4 is ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(-1\))\)]],
  ". ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is a multivariate normal random vector ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(=\)\((x\^1,  ... , x\^dim)\)\(\ \)\)\)]],
  "of dim-dimensions with mean ",
  Cell[BoxData[
      \(TraditionalForm\`b = \((b\^1,  ... , b\^dim)\)\)]],
  ", and the identity covariance matrix.  ",
  Cell[BoxData[
      \(TraditionalForm\`logeexppoly = log\ E {exp(poly(x))}\)]],
  " is obtained up to ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(-1\))\)]],
  "terms."
}], "Text"],

Cell[CellGroupData[{

Cell["define tensors", "Subsubsection"],

Cell[TextData[{
  "This ",
  Cell[BoxData[
      \(TraditionalForm\`b\_a\)]],
  "or ",
  Cell[BoxData[
      \(TraditionalForm\`b\^a\)]],
  "denotes a component of the mean vector ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[sb, "\<b\>", {{1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"b\"\) defined"\)], "Message"]
}, Open  ]],

Cell[TextData[{
  "The following a0, a1, a2, a3, a4, a5, and a6 are used for coefficients in \
a series expansion with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[ta0, "\<a0\>", {{}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"a0\"\) defined"\)], "Message"],

Cell["PermWeight::def: Object a0 defined", "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[ta1, "\<a1\>", {{1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"a1\"\) defined"\)], "Message"],

Cell["PermWeight::def: Object a1 defined", "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[ta2, "\<a2\>", {{2, 1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"a2\"\) assigned"\)], "Message"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"a2\"\) defined"\)], "Message"],

Cell["PermWeight::sym: Symmetries of a2 assigned", "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False],

Cell["PermWeight::def: Object a2 defined", "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[ta3, "\<a3\>", {{1, 2, 3}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"a3\"\) defined"\)], "Message"],

Cell["PermWeight::def: Object a3 defined", "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetSymmetric[ta3[la, lb, lc]]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"a3\"\) assigned"\)], "Message"],

Cell["PermWeight::sym: Symmetries of a3 assigned", "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[ta4, "\<a4\>", {{1, 2, 3, 4}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"a4\"\) defined"\)], "Message"],

Cell["PermWeight::def: Object a4 defined", "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetSymmetric[ta4[la, lb, lc, ld]]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"a4\"\) assigned"\)], "Message"],

Cell["PermWeight::sym: Symmetries of a4 assigned", "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[ta6, "\<a6\>", {{1, 2, 3, 4, 5, 6}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"a6\"\) defined"\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetSymmetric[ta6[la, lb, lc, ld, le, lf]]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"a6\"\) assigned"\)], "Message"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\"logeexppoly\"", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(logeexppoly = 
      ta0 + o*\((sb[l1]*ta1[u1] + ta2[l1, u1] + sb[l1]*sb[l2]*ta2[u1, u2] + 
              3*sb[l1]*ta3[l2, u1, u2] + 
              sb[l1]*sb[l2]*sb[l3]*ta3[u1, u2, u3])\) + 
        o^2*\((\((ta1[l1]*ta1[u1])\)/2 + 2*sb[l1]*ta1[l2]*ta2[u1, u2] + 
              ta2[l1, l2]*ta2[u1, u2] + 
              2*sb[l1]*sb[l2]*ta2[l3, u1]*ta2[u2, u3] + 
              3*ta1[l1]*ta3[l2, u1, u2] + 
              6*sb[l1]*ta2[l2, u1]*
                ta3[l3, u2, u3] + \((9*ta3[l1, l2, u1]*ta3[l3, u2, u3])\)/2 + 
              3*sb[l1]*sb[l2]*ta1[l3]*ta3[u1, u2, u3] + 
              6*sb[l1]*ta2[l2, l3]*ta3[u1, u2, u3] + 
              3*ta3[l1, l2, l3]*ta3[u1, u2, u3] + 
              9*sb[l1]*sb[l2]*ta3[l3, l4, u3]*ta3[u1, u2, u4] + 
              6*sb[l1]*sb[l2]*sb[l3]*ta2[l4, u1]*ta3[u2, u3, u4] + 
              9*sb[l1]*sb[l2]*ta3[l3, l4, u1]*
                ta3[u2, u3, 
                  u4] + \((9*sb[l1]*sb[l2]*sb[l3]*sb[l4]*ta3[l5, u1, u3]*
                    ta3[u2, u4, u5])\)/2 + 3*ta4[l1, l2, u1, u2] + 
              6*sb[l1]*sb[l2]*ta4[l3, u1, u2, u3] + 
              sb[l1]*sb[l2]*sb[l3]*sb[l4]*ta4[u1, u2, u3, u4])\)\)], "Input"],

Cell[BoxData[
    RowBox[{"\<\"a0\"\>", "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ u1]],
                  Editable->False], ")"}]}], "+", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"a2\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\_"p"\),
                      Subscript[ "p"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"p"\),
                      Superscript[ "p"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "a2"], 
                Format[ l1], 
                Format[ u1]],
              Editable->False], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l2], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ u1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l1], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l3], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l2], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"6", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l2], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l3], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(9\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l3], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a1"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"6", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l2], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"9", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l3], 
                    Format[ l4], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"6", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a2"], 
                    Format[ l4], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u2], 
                    Format[ u3], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"9", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l3], 
                    Format[ l4], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u2], 
                    Format[ u3], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(9\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"t"\),
                          Subscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ l5], 
                    Format[ u1], 
                    Format[ u3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"t"\),
                          Superscript[ "t"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a3"], 
                    Format[ u2], 
                    Format[ u4], 
                    Format[ u5]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a4"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"6", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a4"], 
                    Format[ l3], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"b\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "b"], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"a4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "a4"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3], 
                    Format[ u4]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["the canonical form of the density function", "Subsection"],

Cell[TextData[{
  "Here we give the canonical form of log f(y;\[Eta]) for the exponential \
family of distributions, and store it in logdensityy. The metric phi2eta=",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]\^2\( \[Phi](\[Eta])\)\)\(\ \)\)\/\(\
\[PartialD]\ \[Eta]\_a \[PartialD]\ \[Eta]\_b\)\)]],
  "is also given here."
}], "Text"],

Cell[CellGroupData[{

Cell["define tensors", "Subsubsection"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = \((\[Theta]\^1,  ... , \
\[Theta]\^dim)\)\)]],
  " is the natural parameter vector"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[st, "\<\[Theta]\>", {{1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"\\[Theta]\"\) defined"\)], "Message"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Eta] = \((\[Eta]\_1,  ... , \[Eta]\_dim)\)\)]],
  " is the expectation parameter vector"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[se, "\<\[Eta]\>", {{1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"\\[Eta]\"\) defined"\)], "Message"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`y = \((y\_1,  ... , y\_dim)\)\)]],
  " is the random variable"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[ry, "\<y\>", {{1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"y\"\) defined"\)], "Message"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]3\^abc = \(\(\[PartialD]\^3\ \[Phi]\/\(\
\[PartialD]\[Eta]\_a \[PartialD]\[Eta]\_b \[PartialD]\[Eta]\_c\)\)\( | \
\_0\)\)\)]],
  " is the third derivative of the potential function \[Phi](\[Eta]) at the \
origin \[Eta]=0."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[tp3, "\<\[Phi]3\>", {{1, 2, 3}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"\\[Phi]3\"\) defined"\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetSymmetric[tp3[la, lb, lc]]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"\\[Phi]3\"\) assigned"\)], "Message"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]4\^abcd = \(\(\[PartialD]\^4\ \[Phi]\/\(\
\[PartialD]\[Eta]\_a \[PartialD]\[Eta]\_b \[PartialD]\[Eta]\_c \[PartialD]\
\[Eta]\_d\)\)\( | \_0\)\)\)]],
  " is the fourth derivative of the potential function \[Phi](\[Eta]) at the \
origin \[Eta]=0."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[tp4, "\<\[Phi]4\>", {{1, 2, 3, 4}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"\\[Phi]4\"\) defined"\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetSymmetric[tp4[la, lb, lc, ld]]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"\\[Phi]4\"\) assigned"\)], "Message"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\"logdensityy\"", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(logdensityy = \(-\((dim*Log[2*Pi])\)\)/2 - \((ry[l1]*ry[u1])\)/2 + 
        ry[l1]*se[u1] - \((se[l1]*se[u1])\)/
          2 + \((o*ry[l1]*tp3[l2, u1, u2])\)/
          2 - \((o*ry[l1]*ry[l2]*ry[l3]*tp3[u1, u2, u3])\)/
          6 + \((o*ry[l1]*se[l2]*se[l3]*tp3[u1, u2, u3])\)/
          2 - \((o*se[l1]*se[l2]*se[l3]*tp3[u1, u2, u3])\)/
          3 + \((o^2*tp3[l1, l2, l3]*tp3[u1, u2, u3])\)/
          6 - \((o^2*ry[l1]*ry[l2]*tp3[l3, l4, u1]*tp3[u2, u3, u4])\)/
          4 - \((o^2*tp4[l1, l2, u1, u2])\)/
          8 + \((o^2*ry[l1]*ry[l2]*tp4[l3, u1, u2, u3])\)/
          4 - \((o^2*ry[l1]*ry[l2]*ry[l3]*ry[l4]*tp4[u1, u2, u3, u4])\)/
          24 + \((o^2*ry[l1]*se[l2]*se[l3]*se[l4]*tp4[u1, u2, u3, u4])\)/
          6 - \((o^2*se[l1]*se[l2]*se[l3]*se[l4]*tp4[u1, u2, u3, u4])\)/
          8\)], "Input"],

Cell[BoxData[
    RowBox[{\(\(-\(1\/2\)\)\ dim\ Log[2\ \[Pi]]\), "-", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ u1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ u1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ u1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ l2], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/6\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/3\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/6\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ l1], 
              Format[ l2], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ l3], 
              Format[ l4], 
              Format[ u1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/8\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ l1], 
              Format[ l2], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ l3], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/24\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/6\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/8\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\"phi2eta\"", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(phi2eta\  = \ 
      Kdelta[ua, ub] + 
        o*se[l1]*
          tp3[u1, ua, ub] + \((o^2*se[l1]*se[l2]*tp4[u1, u2, ua, ub])\)/
          2\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"Kdelta\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"a"\),
                Superscript[ "a"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"b"\),
                Superscript[ "b"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ Kdelta], 
          Format[ ua], 
          Format[ ub]],
        Editable->False], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u1], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ u1], 
              Format[ u2], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tube-coordinates", "Section"],

Cell[TextData[{
  "First, the expression of the surface is specified in the Taylor series. \
Then, the tangent vectors and the normal vector are obtained. The \
tube-coordinates (u,v) are defined and used instead of the \
\[Eta]-parametrization. Here u is dim-1 dimensional vector specifying a point \
on the surface, and v is the signed distance. The density function ",
  Cell[BoxData[
      \(TraditionalForm\`f(u, v | v0)\)]],
  " is obtained from ",
  Cell[BoxData[
      \(TraditionalForm\`f(y | \[Eta])\)]],
  ", where the parameter value is specified as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta] = \((0,  ... , 0, v0)\)\)]],
  " without losing the generality."
}], "Text"],

Cell[CellGroupData[{

Cell["preliminary", "Subsection"],

Cell["Some functions and tensors are defined here.", "Text"],

Cell[CellGroupData[{

Cell["indices", "Subsubsection"],

Cell["\<\
Here the dimension of the space is denoted by \"9\" for the index, whereas it \
is denoted by \"dim\" for the regular number.  type-a index may run from 1 to \
8, although it is not used explicitly, but only assumes type-a index cannot \
be 9.\
\>", "Text"],

Cell[BoxData[
    \(AddIndexTypes\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["simplification functions", "Subsubsection"],

Cell["type-a index cannot be \"9\".", "Text"],

Cell[BoxData[
    \(RuleUnique[rulekdelta1, Kdelta[a_, 9], 0, IndexaQ[a]]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[rulekdelta2, Kdelta[a_, \(-9\)], 0, IndexaQ[a]]\)], "Input"],

Cell["using the above fact.", "Text"],

Cell[BoxData[
    \(\(tsimp[exp_] := 
        CanAll[AbsorbKdelta[
            CanAll[ApplyRules[
                exp, {rulekdelta1, rulekdelta2}]]]];\)\)], "Input"],

Cell["raising -9 to 9 for a unique expression.", "Text"],

Cell[BoxData[
    \(\(ruletps9 = {tp3[\(-9\), l1_, l2_] \[Rule] tp3[9, l1, l2], 
          tp4[\(-9\), l1_, l2_, l3_] \[Rule] 
            tp4[9, l1, l2, l3]};\)\)], "Input"],

Cell["further simplification", "Text"],

Cell[BoxData[
    \(\(tsimpp[exp_] := 
        Tsimplify[
          CanAll[AbsorbKdelta[
              CanAll[ApplyRules[\(\(\(exp /. ruletps9\) /. ruletps9\) /. 
                      ruletps9\) /. ruletps9, {rulekdelta1, 
                    rulekdelta2}]]]]];\)\)], "Input"],

Cell[TextData[{
  "Ignore ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(\(-3\)/2\))\)]],
  " terms for scalar"
}], "Text"],

Cell[BoxData[
    \(geto2[exp_] := 
      Sum[Simplify[Coefficient[exp, o, i]] o\^i, {i, \(-1\), 2}]\)], "Input"],

Cell[TextData[{
  "Ignore ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(\(-3\)/2\))\)]],
  " terms for tensor."
}], "Text"],

Cell[BoxData[
    \(tgeto2[exp_] := 
      Sum[tsimp[Coefficient[exp, o, i]] o\^i, {i, \(-1\), 2}]\)], "Input"],

Cell[TextData[{
  "Series expansion for scalar ignoring ",
  Cell[BoxData[
      \(TraditionalForm\`\(O(n\^\(\(-3\)/2\))\)\ \(\(terms\)\(.\)\)\)]]
}], "Text"],

Cell[BoxData[
    \(gets2[exp_] := geto2[Series[exp, {o, 0, 2}]]\)], "Input"],

Cell[TextData[{
  "Series expansion for tensor  ignoring ",
  Cell[BoxData[
      \(TraditionalForm\`\(O(n\^\(\(-3\)/2\))\)\ \(\(terms\)\(.\)\)\)]]
}], "Text"],

Cell[BoxData[
    \(tgetrule[tx_] := 
      Module[{coefs, coef0, coef1, coef2, rule0, rule1, rule2}, 
        coefs = CoefficientList[tx, o]; 
        RuleUnique[rule0, coef0, coefs[\([1]\)]]; 
        RuleUnique[rule1, coef1, coefs[\([2]\)]]; 
        RuleUnique[rule2, coef2, 
          coefs[\([3]\)]]; {{coef0, coef1, coef2}, {rule0, rule1, 
            rule2}}]\)], "Input"],

Cell[BoxData[
    \(tgets2[exp_, x_, tx_] := 
      Module[{xcoef, xrule}, {xcoef, xrule} = tgetrule[tx]; 
        ApplyRules[
          gets2[exp /. {x \[Rule] 
                  Sum[xcoef[\([i]\)]\ o\^\(i - 1\), {i, 3}]}], 
          xrule]]\)], "Input"],

Cell[BoxData[
    \(tgets2[exp_, x_, tx_, y_, ty_] := 
      Module[{xcoef, xrule, ycoef, yrule}, {xcoef, xrule} = 
          tgetrule[tx]; {ycoef, yrule} = tgetrule[ty]; 
        ApplyRules[
          gets2[exp /. {x \[Rule] Sum[xcoef[\([i]\)]\ o\^\(i - 1\), {i, 3}], 
                y \[Rule] Sum[ycoef[\([i]\)]\ o\^\(i - 1\), {i, 3}]}], 
          Join[xrule, yrule]]]\)], "Input"],

Cell["\<\
Define an operator to separate the regular index into the type-a index and \
dim.\
\>", "Text"],

Cell[BoxData[
    \(\(\(sepa[foo_, l_] := 
        Module[{aup, alo}, \[IndentingNewLine]UpLoa[{aup}, {alo}]; 
          MakeSumRange[foo, {l, alo, \(-9\)}]];\)\(\[IndentingNewLine]\)
    \)\)], "Input"],

Cell["Define differential operator (for type-a index)", "Text"],

Cell[BoxData[
    \(difa[exp_, ru_, 
        ala_] := \((exp\  - \ \((exp /. {ru[al_] \[Rule] 0})\))\) /. {ru[
                al1_] ru[al2_] ru[al3_] ru[al4_] \[Rule] 
            ru[al1] ru[al2] ru[al3] Kdelta[al4, ala] + 
              ru[al1] ru[al2] ru[al4] Kdelta[al3, ala] + 
              ru[al1] ru[al4] ru[al3] Kdelta[al2, ala] + 
              ru[al4] ru[al2] ru[al3] Kdelta[al1, ala], \[IndentingNewLine]ru[
                al1_] ru[al2_] ru[al3_] \[Rule] 
            ru[al1] ru[al2] Kdelta[al3, ala] + 
              ru[al1] ru[al3] Kdelta[al2, ala] + 
              ru[al2] ru[al3] Kdelta[al1, ala], 
          ru[al1_] ru[al2_] \[Rule] \ 
            ru[al1] Kdelta[al2, ala] + ru[al2] Kdelta[al1, ala], 
          ru[al1_] \[Rule] Kdelta[al1, ala]}\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["define tensors", "Subsubsection"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`u = \((u\_1,  ... , u\_\(dim - 1\))\)\)]],
  " is the parametrization of the surface. Type-a index indicate the suffix \
such as ",
  Cell[BoxData[
      \(TraditionalForm\`u = \((u\_\(b'\))\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`b' = 1,  ... , dim - 1\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[ru, "\<u\>", {{1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"u\"\) defined"\)], "Message"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`d\^\(a' b'\) = O(n\^\(\(-1\)/2\))\)]],
  " is the curvature matrix (second derivative) of the surface at the \
origin."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[td, "\<d\>", {{2, 1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"d\"\) assigned"\)], "Message"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"d\"\) defined"\)], "Message"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`e\^\(a' b' c'\) = O(n\^\(-1\))\)]],
  "is the third derivative at the origin."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[te, "\<e\>", {{1, 2, 3}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"e\"\) defined"\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetSymmetric[te[la, lb, lc]]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"e\"\) assigned"\)], "Message"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`B\_b\^a' = \[PartialD]\ \[Eta]\_b\/\[PartialD]\ \
u\_\(a'\)\)]],
  ", b=1,...,dim is the tangent vector for a'=1,...,dim-1. Here the regular \
type index runs 1,...,dim, whereas the type-a index runs 1,...,",
  "dim",
  "-1."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[tB, "\<B\>", {{1, 2}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"B\"\) defined"\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(tB[lb, aua]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          FormBox["\<\"B\"\>",
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\_"b"\),
              Subscript[ "b"],
              Editable->False],
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"a'"\),
              Superscript[ "a'"],
              Editable->False],
            "StandardForm"],
          Format]}],
      SequenceForm[ 
        Format[ "B"], 
        Format[ lb], 
        Format[ aua]],
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[Phi]\^\(a' b'\)\)(u)\)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]\^2\( \[Phi](\[Eta])\)\)\(\ \)\)\/\(\
\[PartialD]\ \[Eta]\_p \[PartialD]\ \[Eta]\_q\)\( | \_\(\[Eta](
              u)\)\)\(\(B\_p\^a'\)(u)\) \(\(B\_q\^b'\)(u)\)\)]],
  " is the metric in the tangent space."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[tpa, "\<\[Phi]\>", {{2, 1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"\\[Phi]\"\) assigned"\)], "Message"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"\\[Phi]\"\) defined"\)], "Message"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["the coordinates around the smooth surface", "Subsection"],

Cell[TextData[{
  "The surface is specified by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Eta]\_\(b'\)\)(u) = u\_\(b'\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b' = 1,  ... , dim - 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Eta]\_dim\)(
          u) = \(-d\^\(a' b'\)\) \(u\_\(a'\)\) 
            u\_\(b'\) - \(e\^\(a' b' c'\)\) \(u\_\(a'\)\) \(u\_\(b'\)\) 
            u\_\(c'\)\)]],
  ".  They are stored in \"foo1\" and \"foo2\" or corresponding \"rule1\" and \
\"rule2\".  The region of interest is specified by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_dim \[LessEqual] \(\[Eta]\_dim\)(u)\)]],
  ". The tangent vectors are given by foo3=",
  Cell[BoxData[
      \(TraditionalForm\`B\_\(b'\)\^a' = \[PartialD]\ \[Eta]\_\(b'\)\/\
\[PartialD]\ u\_\(a'\)\)]],
  " and  foo4=",
  Cell[BoxData[
      \(TraditionalForm\`B\_dim\^a' = \[PartialD]\ \[Eta]\_dim\/\[PartialD]\ \
u\_\(a'\)\)]],
  ", or corresponding \"rule3\" and \"rule4\".  We also obtain phi2bu= ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[Phi]\^\(a' b'\)\)(u)\)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]\^2\( \[Phi](\[Eta])\)\)\(\ \)\)\/\(\
\[PartialD]\ \[Eta]\_p \[PartialD]\ \[Eta]\_q\)\( | \_\(\[Eta](
              u)\)\)\(\(B\_p\^a'\)(u)\) \(\(B\_q\^b'\)(u)\)\)]],
  " , which is the metric in the tangent space. The elements of the normal \
vector are denoted as ",
  Cell[BoxData[
      \(TraditionalForm\`B\_a\^dim\)]],
  ", a=1,...,dim, which are given in foo15=",
  Cell[BoxData[
      \(TraditionalForm\`\(B\_\(a'\)\^dim\)(u)\)]],
  " and foo16= ",
  Cell[BoxData[
      \(TraditionalForm\`\(B\_dim\^dim\)(u)\)]],
  ", or in the corresponding \"rule15\" and \"rule16\". The reparametrization \
between \[Eta]-coordinates and (u,v)-coordinates are specified by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Eta]\_a\)(u, 
          v) = \(\[Eta]\_a\)(u) + \(\(B\_a\^dim\)(u)\)\ v\)]],
  ", and given in foo21 = ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Eta]\_\(a'\)\)(u, v)\)]],
  " and foo22 = ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Eta]\_dim\)(u, v)\)]],
  ", or in \"rule21\", \"rule22\", and \"rule22b\"."
}], "Text"],

Cell[CellGroupData[{

Cell["smooth surface", "Subsubsection"],

Cell["Define rules for the surface.", "Text"],

Cell[BoxData[
    \(RuleUnique[rule1, se[ala_], Kdelta[ala, aub] ru[alb], 
      IndexaQ[ala]]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[rule2, 
      se[\(-9\)], \(-o\)\ td[aua, aub] ru[ala] ru[alb] - \(o\^2\) 
          te[aua, aub, auc] ru[ala] ru[alb] ru[alc]]\)], "Input"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Eta]\_\(b'\)\)(u) = u\_\(b'\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b' = 1,  ... , dim - 1\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo1 = ApplyRules[se[alb], {rule1, rule2}]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"Kdelta\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"b'"\),
                  Subscript[ "b'"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"p'"\),
                  Superscript[ "p'"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ Kdelta], 
            Format[ alb], 
            Format[ au1]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"u\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"p'"\),
                  Subscript[ "p'"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "u"], 
            Format[ al1]],
          Editable->False], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\[Eta]\_dim\)(
        u) = \(-d\^\(a' b'\)\) \(u\_\(a'\)\) 
          u\_\(b'\) - \(e\^\(a' b' c'\)\) \(u\_\(a'\)\) \(u\_\(b'\)\) 
          u\_\(c'\)\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo2 = ApplyRules[se[\(-9\)], {rule1, rule2}]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(-o\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["tangent vectors", "Subsubsection"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`B\_\(b'\)\^a' = \[PartialD]\ \[Eta]\_\(b'\)\/\
\[PartialD]\ u\_\(a'\)\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo3 = tsimp[difa[foo1, ru, aua]]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          FormBox["\<\"Kdelta\"\>",
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\_"b'"\),
              Subscript[ "b'"],
              Editable->False],
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"a'"\),
              Superscript[ "a'"],
              Editable->False],
            "StandardForm"],
          Format]}],
      SequenceForm[ 
        Format[ Kdelta], 
        Format[ alb], 
        Format[ aua]],
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`B\_dim\^a' = \[PartialD]\ \[Eta]\_dim\/\[PartialD]\ \
u\_\(a'\)\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo4 = tsimp[difa[foo2, ru, aua]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(-2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ aua]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ au1], 
              Format[ au2], 
              Format[ aua]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["Define rules for the tangent vectors.", "Text"],

Cell[BoxData[
    \(RuleUnique[rule3, tB[alb_, aua_], foo3, 
      IndexaQ[alb] \[And] IndexaQ[aua]]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[rule4, tB[\(-9\), aua_], foo4, IndexaQ[aua]]\)], "Input"],

Cell["check if they work", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ApplyRules[tB[alb, aua], {rule3, rule4}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          FormBox["\<\"Kdelta\"\>",
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\_"b'"\),
              Subscript[ "b'"],
              Editable->False],
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"a'"\),
              Superscript[ "a'"],
              Editable->False],
            "StandardForm"],
          Format]}],
      SequenceForm[ 
        Format[ Kdelta], 
        Format[ alb], 
        Format[ aua]],
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ApplyRules[tB[\(-9\), aua], {rule3, rule4}]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(-2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ aua]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ au1], 
              Format[ au2], 
              Format[ aua]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Next, we will calculate ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[Phi]\^\(a' b'\)\)(u)\)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]\^2\( \[Phi](\[Eta])\)\)\(\ \)\)\/\(\
\[PartialD]\ \[Eta]\_p \[PartialD]\ \[Eta]\_q\)\( | \_\(\[Eta](
              u)\)\)\(\(B\_p\^a'\)(u)\) \(\(B\_q\^b'\)(u)\)\)]],
  " below."
}], "Text"],

Cell[TextData[{
  "Apply the separate operator to phi2eta=",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]\^2\( \[Phi](\[Eta])\)\)\(\ \)\)\/\(\
\[PartialD]\ \[Eta]\_a \[PartialD]\ \[Eta]\_b\)\)]],
  ", and evaluate it on the surface to get phi2u=",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\(\[PartialD]\^2\( \[Phi](\[Eta])\)\)\(\ \
\)\)\/\(\[PartialD]\ \[Eta]\_a \[PartialD]\ \[Eta]\_b\)\)\( | \_\(\[Eta](
              u)\)\)\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(phi2eta\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"Kdelta\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"a"\),
                Superscript[ "a"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"b"\),
                Superscript[ "b"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ Kdelta], 
          Format[ ua], 
          Format[ ub]],
        Editable->False], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u1], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ u1], 
              Format[ u2], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(tsimp[sepa[sepa[phi2eta, l1], l2]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"Kdelta\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"a"\),
                Superscript[ "a"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"b"\),
                Superscript[ "b"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ Kdelta], 
          Format[ ua], 
          Format[ ub]],
        Editable->False], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au1], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        SuperscriptBox[
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[Eta]\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\_"9"\),
                    Subscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Subscript[ "9"]],
                  Editable->False]}],
              SequenceForm[ 
                Format[ "\[Eta]"], 
                SequenceForm[ 
                  Subscript[ "9"]]],
              Editable->False], ")"}], "2"], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ au1], 
              Format[ au2], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(phi2u = tgeto2[ApplyRules[%, {rule1, rule2}]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"Kdelta\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"a"\),
                Superscript[ "a"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"b"\),
                Superscript[ "b"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ Kdelta], 
          Format[ ua], 
          Format[ ub]],
        Editable->False], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au1], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"u\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p'"\),
                            Subscript[ "p'"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "u"], 
                      Format[ al1]],
                    Editable->False], ")"}]}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Using phi2u above, we write phi2bu= ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[Phi]\^\(a' b'\)\)(u)\)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]\^2\( \[Phi](\[Eta])\)\)\(\ \)\)\/\(\
\[PartialD]\ \[Eta]\_p \[PartialD]\ \[Eta]\_q\)\( | \_\(\[Eta](
              u)\)\)\(\(B\_p\^a'\)(u)\) \(\(B\_q\^b'\)(u)\)\)]],
  " as follows. First, the summation range of phi2bu is separated into type-a \
and dim. Then,  ",
  Cell[BoxData[
      \(TraditionalForm\`\(B\_p\^a'\)(u)\)]],
  " are substituted by their expressions."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(phi2u\ tB[la, aua]\ tB[lb, aub]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"B\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"a"\),
                  Subscript[ "a"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"a'"\),
                  Superscript[ "a'"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "B"], 
            Format[ la], 
            Format[ aua]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"B\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"b"\),
                  Subscript[ "b"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"b'"\),
                  Superscript[ "b'"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "B"], 
            Format[ lb], 
            Format[ aub]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        RowBox[{
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], "+", 
          RowBox[{"o", " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"u\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"p'"\),
                        Subscript[ "p'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "u"], 
                  Format[ al1]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"p'"\),
                        Superscript[ "p'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a"\),
                        Superscript[ "a"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b"\),
                        Superscript[ "b"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  Format[ au1], 
                  Format[ ua], 
                  Format[ ub]],
                Editable->False], ")"}]}], "+", 
          RowBox[{\(o\^2\), " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"-", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"u\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "u"], 
                          Format[ al1]],
                        Editable->False], ")"}]}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u"], 
                        Format[ al2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"d\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "d"], 
                        Format[ au1], 
                        Format[ au2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p'"\),
                              Subscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u"], 
                        Format[ al1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u"], 
                        Format[ al2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]4\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]4"], 
                        Format[ au1], 
                        Format[ au2], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}]}], ")"}]}]}], 
        ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CanAll[sepa[sepa[%, la], lb]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al1], 
              Format[ aua]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al1], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al1], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ aub]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s'"\),
                    Subscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al4], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s'"\),
                    Superscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au3], 
              Format[ au4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s'"\),
                    Subscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al4], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s'"\),
                    Superscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3], 
              Format[ au4]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(phi2bu = tgeto2[ApplyRules[%, {rule3, rule4}]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"Kdelta\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"a'"\),
                Superscript[ "a'"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"b'"\),
                Superscript[ "b'"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ Kdelta], 
          Format[ aua], 
          Format[ aub]],
        Editable->False], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au1], 
              Format[ aua], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"4", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au2], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au2], 
                    Format[ aub]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au2], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["We may symmetrize the coefficients of phi2bu.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(phi2bucoef = 
      Simplify[CoefficientList[phi2bu /. {ru[al1_] \[Rule] x}, x]/{1, o, 
              o\^2}] /. {au1 \[Rule] auc, au2 \[Rule] aud}\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"Kdelta\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"a'"\),
                  Superscript[ "a'"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"b'"\),
                  Superscript[ "b'"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ Kdelta], 
            Format[ aua], 
            Format[ aub]],
          Editable->False], ",", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"\[Phi]3\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"a'"\),
                  Superscript[ "a'"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"b'"\),
                  Superscript[ "b'"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"c'"\),
                  Superscript[ "c'"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "\[Phi]3"], 
            Format[ aua], 
            Format[ aub], 
            Format[ auc]],
          Editable->False], ",", 
        RowBox[{\(1\/2\), " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"8", " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"d\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a'"\),
                            Superscript[ "a'"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"c'"\),
                            Superscript[ "c'"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "d"], 
                      Format[ aua], 
                      Format[ auc]],
                    Editable->False], ")"}], " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"d\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b'"\),
                            Superscript[ "b'"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"d'"\),
                            Superscript[ "d'"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "d"], 
                      Format[ aub], 
                      Format[ aud]],
                    Editable->False], ")"}]}], "-", 
              RowBox[{"2", " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"d\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"c'"\),
                            Superscript[ "c'"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"d'"\),
                            Superscript[ "d'"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "d"], 
                      Format[ auc], 
                      Format[ aud]],
                    Editable->False], ")"}], " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a'"\),
                            Superscript[ "a'"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b'"\),
                            Superscript[ "b'"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      Format[ aua], 
                      Format[ aub]],
                    Editable->False], ")"}]}], "-", 
              RowBox[{"4", " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"d\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b'"\),
                            Superscript[ "b'"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"d'"\),
                            Superscript[ "d'"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "d"], 
                      Format[ aub], 
                      Format[ aud]],
                    Editable->False], ")"}], " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a'"\),
                            Superscript[ "a'"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"c'"\),
                            Superscript[ "c'"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      Format[ aua], 
                      Format[ auc]],
                    Editable->False], ")"}]}], "-", 
              RowBox[{"4", " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"d\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"a'"\),
                            Superscript[ "a'"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"d'"\),
                            Superscript[ "d'"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "d"], 
                      Format[ aua], 
                      Format[ aud]],
                    Editable->False], ")"}], " ", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"b'"\),
                            Superscript[ "b'"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"c'"\),
                            Superscript[ "c'"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      Format[ aub], 
                      Format[ auc]],
                    Editable->False], ")"}]}], "+", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]4\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a'"\),
                        Superscript[ "a'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"d'"\),
                        Superscript[ "d'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]4"], 
                  Format[ aua], 
                  Format[ aub], 
                  Format[ auc], 
                  Format[ aud]],
                Editable->False]}], ")"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(phi2bucoef[\([3]\)] = 
      tsimp[Symmetrize[
          Symmetrize[phi2bucoef[\([3]\)], {aua, aub}], {auc, 
            aud}]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"2", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"d'"\),
                    Superscript[ "d'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ aua], 
              Format[ aud]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ aub], 
              Format[ auc]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"2", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ aua], 
              Format[ auc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"d'"\),
                    Superscript[ "d'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ aub], 
              Format[ aud]],
            Editable->False], ")"}]}], "-", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"d'"\),
                    Superscript[ "d'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ auc], 
              Format[ aud]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aua], 
              Format[ aub]],
            Editable->False], ")"}]}], "-", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"d'"\),
                    Superscript[ "d'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ aub], 
              Format[ aud]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aua], 
              Format[ auc]],
            Editable->False], ")"}]}], "-", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ aub], 
              Format[ auc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"d'"\),
                    Superscript[ "d'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aua], 
              Format[ aud]],
            Editable->False], ")"}]}], "-", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"d'"\),
                    Superscript[ "d'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ aua], 
              Format[ aud]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aub], 
              Format[ auc]],
            Editable->False], ")"}]}], "-", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ aua], 
              Format[ auc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"d'"\),
                    Superscript[ "d'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aub], 
              Format[ aud]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"d'"\),
                    Superscript[ "d'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ aua], 
              Format[ aub], 
              Format[ auc], 
              Format[ aud]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(phi2bu = 
      phi2bucoef[\([1]\)]\  + \ 
        o\ phi2bucoef[\([2]\)]\ ru[alc]\  + \ \(o\^2\) 
          phi2bucoef[\([3]\)]\ ru[alc] ru[ald]\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"Kdelta\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"a'"\),
                Superscript[ "a'"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"b'"\),
                Superscript[ "b'"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ Kdelta], 
          Format[ aua], 
          Format[ aub]],
        Editable->False], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"c'"\),
                    Subscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ alc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ aua], 
              Format[ aub], 
              Format[ auc]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"c'"\),
                    Subscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ alc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"d'"\),
                    Subscript[ "d'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ ald]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"d'"\),
                          Superscript[ "d'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ aua], 
                    Format[ aud]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c'"\),
                          Superscript[ "c'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ aub], 
                    Format[ auc]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c'"\),
                          Superscript[ "c'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ aua], 
                    Format[ auc]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"d'"\),
                          Superscript[ "d'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ aub], 
                    Format[ aud]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c'"\),
                          Superscript[ "c'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"d'"\),
                          Superscript[ "d'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ auc], 
                    Format[ aud]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"d'"\),
                          Superscript[ "d'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ aub], 
                    Format[ aud]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c'"\),
                          Superscript[ "c'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua], 
                    Format[ auc]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c'"\),
                          Superscript[ "c'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ aub], 
                    Format[ auc]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"d'"\),
                          Superscript[ "d'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua], 
                    Format[ aud]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"d'"\),
                          Superscript[ "d'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ aua], 
                    Format[ aud]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c'"\),
                          Superscript[ "c'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aub], 
                    Format[ auc]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c'"\),
                          Superscript[ "c'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ aua], 
                    Format[ auc]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"d'"\),
                          Superscript[ "d'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aub], 
                    Format[ aud]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c'"\),
                          Superscript[ "c'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"d'"\),
                          Superscript[ "d'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ aua], 
                    Format[ aub], 
                    Format[ auc], 
                    Format[ aud]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["\<\
Further simplification is possible. Here the phi2bu is essentially the same \
as above although the warning messages appear.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tsimpp[phi2bu]\)], "Input"],

Cell[BoxData[
    \("The assigned symmetries may be inconsistent.\n"\)], "Print"],

Cell[BoxData[
    \("The assigned symmetries may be inconsistent.\n"\)], "Print"],

Cell[BoxData[
    \("The assigned symmetries may be inconsistent.\n"\)], "Print"],

Cell[BoxData[
    \("The assigned symmetries may be inconsistent.\n"\)], "Print"],

Cell[BoxData[
    \("The assigned symmetries may be inconsistent.\n"\)], "Print"],

Cell[BoxData[
    \("The assigned symmetries may be inconsistent.\n"\)], "Print"],

Cell[BoxData[
    \("The assigned symmetries may be inconsistent.\n"\)], "Print"],

Cell[BoxData[
    \("The assigned symmetries may be inconsistent.\n"\)], "Print"],

Cell[BoxData[
    \("The assigned symmetries may be inconsistent.\n"\)], "Print"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"Kdelta\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"a'"\),
                Superscript[ "a'"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"b'"\),
                Superscript[ "b'"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ Kdelta], 
          Format[ aua], 
          Format[ aub]],
        Editable->False], "+", 
      RowBox[{"4", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au2], 
              Format[ aua]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au2], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ aua]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au2], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ aub]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aua], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au1], 
              Format[ aua], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ au1], 
              Format[ au2], 
              Format[ aua], 
              Format[ aub]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(phi2bu = %;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["the normal vector", "Subsubsection"],

Cell[TextData[{
  "The elements of the normal vector are denoted as ",
  Cell[BoxData[
      \(TraditionalForm\`B\_a\^dim\)]],
  ", a=1,...,dim. But for the moment, we use \"norma\" for ",
  Cell[BoxData[
      \(TraditionalForm\`B\_\(a'\)\^dim\)]],
  ", and \"normb\" for ",
  Cell[BoxData[
      \(TraditionalForm\`B\_dim\^dim\)]],
  ". First of all, we assume the following expressions of these values using \
unknown na2, na3, nb2, nb3."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[tna2, "\<na2\>", {{1, 2}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"na2\"\) defined"\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[tna3, "\<na3\>", {{1, 3, 2}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"na3\"\) assigned"\)], "Message"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"na3\"\) defined"\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(norma\  = 
      o\ \ tna2[ala, aub] ru[alb] + \(o\^2\) tna3[ala, aub, auc] ru[alb] 
          ru[alc]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b'"\),
                    Subscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ alb]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"na2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "na2"], 
              Format[ ala], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b'"\),
                    Subscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ alb]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"c'"\),
                    Subscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ alc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"na3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "na3"], 
              Format[ ala], 
              Format[ aub], 
              Format[ auc]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule5, tB[ala_, 9], norma, IndexaQ[ala]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[tnb1, "\<nb1\>", {{1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"nb1\"\) defined"\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[tnb2, "\<nb2\>", {{2, 1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"nb2\"\) assigned"\)], "Message"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"nb2\"\) defined"\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(normb\  = 
      1 + o\ \ tnb1[aub] ru[alb] + \(o\^2\) tnb2[aub, auc] ru[alb] 
          ru[alc]\)], "Input"],

Cell[BoxData[
    RowBox[{"1", "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b'"\),
                    Subscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ alb]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"nb1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "nb1"], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b'"\),
                    Subscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ alb]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"c'"\),
                    Subscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ alc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"nb2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "nb2"], 
              Format[ aub], 
              Format[ auc]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule6, tB[\(-9\), 9], normb]\)], "Input"],

Cell[TextData[{
  "The inner product of the normal vector ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          FormBox[\(B\_a\),
            "TraditionalForm"], "dim"], TraditionalForm]]],
  " and a tangent vector ",
  Cell[BoxData[
      \(TraditionalForm\`B\_a\^a'\)]],
  " is foo7=",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]\^2\( \[Phi](\[Eta])\)\)\(\ \)\)\/\(\
\[PartialD]\ \[Eta]\_p \[PartialD]\ \[Eta]\_q\)\( | \_\(\[Eta](
              u)\)\)\(\(B\_p\^a'\)(u)\) \(\(B\_q\^dim\)(u)\)\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(phi2u\ tB[la, aua]\ tB[lb, 9]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"B\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"a"\),
                  Subscript[ "a"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"a'"\),
                  Superscript[ "a'"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "B"], 
            Format[ la], 
            Format[ aua]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"B\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"b"\),
                  Subscript[ "b"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            InterpretationBox[
              InterpretationBox[\(\[Null]\^"9"\),
                Superscript[ "9"],
                Editable->False],
              SequenceForm[ 
                Superscript[ "9"]],
              Editable->False]}],
          SequenceForm[ 
            Format[ "B"], 
            Format[ lb], 
            SequenceForm[ 
              Superscript[ "9"]]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        RowBox[{
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], "+", 
          RowBox[{"o", " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"u\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"p'"\),
                        Subscript[ "p'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "u"], 
                  Format[ al1]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"p'"\),
                        Superscript[ "p'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a"\),
                        Superscript[ "a"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b"\),
                        Superscript[ "b"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  Format[ au1], 
                  Format[ ua], 
                  Format[ ub]],
                Editable->False], ")"}]}], "+", 
          RowBox[{\(o\^2\), " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"-", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"u\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "u"], 
                          Format[ al1]],
                        Editable->False], ")"}]}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u"], 
                        Format[ al2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"d\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "d"], 
                        Format[ au1], 
                        Format[ au2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p'"\),
                              Subscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u"], 
                        Format[ al1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u"], 
                        Format[ al2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]4\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]4"], 
                        Format[ au1], 
                        Format[ au2], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}]}], ")"}]}]}], 
        ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CanAll[sepa[sepa[%, la], lb]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ aua]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al1], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al1], 
              Format[ aua]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al1], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s'"\),
                    Subscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al4], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s'"\),
                    Superscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au3], 
              Format[ au4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s'"\),
                    Subscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al4], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s'"\),
                    Superscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3], 
              Format[ au4]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo7 = tgeto2[ApplyRules[%, {rule3, rule4, rule5, rule6}]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(-2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"na2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "na2"], 
                    Format[ aua], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(-3\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"e\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "e"], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"na3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "na3"], 
                    Format[ aua], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au2], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"nb1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "nb1"], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au2], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"nb1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "nb1"], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"na2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "na2"], 
                    Format[ al3], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au1], 
                    Format[ au3], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ aua]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The squared norm of the normal vector ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          FormBox[\(B\_a\),
            "TraditionalForm"], "dim"], TraditionalForm]]],
  "  is foo8= ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]\^2\( \[Phi](\[Eta])\)\)\(\ \)\)\/\(\
\[PartialD]\ \[Eta]\_p \[PartialD]\ \[Eta]\_q\)\( | \_\(\[Eta](
              u)\)\)\(\(B\_p\^dim\)(u)\) \(\(B\_q\^dim\)(u)\)\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(phi2u\ tB[la, 9]\ tB[lb, 9]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"B\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"a"\),
                  Subscript[ "a"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            InterpretationBox[
              InterpretationBox[\(\[Null]\^"9"\),
                Superscript[ "9"],
                Editable->False],
              SequenceForm[ 
                Superscript[ "9"]],
              Editable->False]}],
          SequenceForm[ 
            Format[ "B"], 
            Format[ la], 
            SequenceForm[ 
              Superscript[ "9"]]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"B\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"b"\),
                  Subscript[ "b"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            InterpretationBox[
              InterpretationBox[\(\[Null]\^"9"\),
                Superscript[ "9"],
                Editable->False],
              SequenceForm[ 
                Superscript[ "9"]],
              Editable->False]}],
          SequenceForm[ 
            Format[ "B"], 
            Format[ lb], 
            SequenceForm[ 
              Superscript[ "9"]]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        RowBox[{
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], "+", 
          RowBox[{"o", " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"u\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"p'"\),
                        Subscript[ "p'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "u"], 
                  Format[ al1]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"p'"\),
                        Superscript[ "p'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a"\),
                        Superscript[ "a"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b"\),
                        Superscript[ "b"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  Format[ au1], 
                  Format[ ua], 
                  Format[ ub]],
                Editable->False], ")"}]}], "+", 
          RowBox[{\(o\^2\), " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"-", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"u\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "u"], 
                          Format[ al1]],
                        Editable->False], ")"}]}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u"], 
                        Format[ al2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"d\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "d"], 
                        Format[ au1], 
                        Format[ au2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p'"\),
                              Subscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u"], 
                        Format[ al1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u"], 
                        Format[ al2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]4\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]4"], 
                        Format[ au1], 
                        Format[ au2], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}]}], ")"}]}]}], 
        ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CanAll[sepa[sepa[%, la], lb]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      SuperscriptBox[
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], "2"], "+", 
      RowBox[{"2", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al1], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al1], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        SuperscriptBox[
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"B\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\_"9"\),
                    Subscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Subscript[ "9"]],
                  Editable->False], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False]}],
              SequenceForm[ 
                Format[ "B"], 
                SequenceForm[ 
                  Subscript[ "9"]], 
                SequenceForm[ 
                  Superscript[ "9"]]],
              Editable->False], ")"}], "2"], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        SuperscriptBox[
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"B\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\_"9"\),
                    Subscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Subscript[ "9"]],
                  Editable->False], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False]}],
              SequenceForm[ 
                Format[ "B"], 
                SequenceForm[ 
                  Subscript[ "9"]], 
                SequenceForm[ 
                  Superscript[ "9"]]],
              Editable->False], ")"}], "2"], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"2", " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s'"\),
                    Subscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al4], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s'"\),
                    Superscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au3], 
              Format[ au4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        SuperscriptBox[
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"B\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\_"9"\),
                    Subscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Subscript[ "9"]],
                  Editable->False], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False]}],
              SequenceForm[ 
                Format[ "B"], 
                SequenceForm[ 
                  Subscript[ "9"]], 
                SequenceForm[ 
                  Superscript[ "9"]]],
              Editable->False], ")"}], "2"], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s'"\),
                    Subscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al4], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s'"\),
                    Superscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3], 
              Format[ au4]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo8 = tgeto2[ApplyRules[%, {rule3, rule4, rule5, rule6}]]\)], "Input"],

Cell[BoxData[
    RowBox[{"1", "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"nb1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "nb1"], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"na2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "na2"], 
                    Format[ al3], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"na2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "na2"], 
                    Format[ au3], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"nb1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "nb1"], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"nb1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "nb1"], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"nb2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "nb2"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"nb1\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "nb1"], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"na2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "na2"], 
                    Format[ al3], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["\<\
Now, we will solve na2, na3, nb2, nb3 from the equations foo7==0, foo8==1. \
First we get the coefficients in foo7 and foo8, and relabel nonfree \
indexes.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo9 = 
      Simplify[CoefficientList[foo7 /. {ru[al_] \[Rule] x}, x]/{1, o, 
              o\^2}] /. {au1 \[Rule] aub, au2 \[Rule] auc}\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"0", ",", 
        RowBox[{
          RowBox[{\(-2\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"d\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a'"\),
                        Superscript[ "a'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "d"], 
                  Format[ aua], 
                  Format[ aub]],
                Editable->False], ")"}]}], "+", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"na2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "na2"], 
              Format[ aua], 
              Format[ aub]],
            Editable->False], "+", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aua], 
              Format[ aub]],
            Editable->False]}], ",", 
        RowBox[{
          RowBox[{\(-3\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"e\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a'"\),
                        Superscript[ "a'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "e"], 
                  Format[ aua], 
                  Format[ aub], 
                  Format[ auc]],
                Editable->False], ")"}]}], "+", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"na3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "na3"], 
              Format[ aua], 
              Format[ aub], 
              Format[ auc]],
            Editable->False], "-", 
          RowBox[{"2", " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"d\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a'"\),
                        Superscript[ "a'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "d"], 
                  Format[ aua], 
                  Format[ auc]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"nb1\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "nb1"], 
                  Format[ aub]],
                Editable->False], ")"}]}], "-", 
          RowBox[{
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"d\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "d"], 
                  Format[ aub], 
                  Format[ auc]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a'"\),
                        Superscript[ "a'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  Format[ aua]],
                Editable->False], ")"}]}], "-", 
          RowBox[{"2", " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"d\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a'"\),
                        Superscript[ "a'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "d"], 
                  Format[ aua], 
                  Format[ auc]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  Format[ aub]],
                Editable->False], ")"}]}], "+", 
          RowBox[{
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"nb1\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "nb1"], 
                  Format[ auc]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a'"\),
                        Superscript[ "a'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  Format[ aua], 
                  Format[ aub]],
                Editable->False], ")"}]}], "+", 
          RowBox[{
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"na2\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"r'"\),
                        Subscript[ "r'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "na2"], 
                  Format[ al3], 
                  Format[ auc]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"r'"\),
                        Superscript[ "r'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a'"\),
                        Superscript[ "a'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  Format[ au3], 
                  Format[ aua], 
                  Format[ aub]],
                Editable->False], ")"}]}], "+", 
          RowBox[{\(1\/2\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]4\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a'"\),
                        Superscript[ "a'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]4"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  Format[ aua], 
                  Format[ aub], 
                  Format[ auc]],
                Editable->False], ")"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo10 = 
      Simplify[CoefficientList[foo8 - 1 /. {ru[al_] \[Rule] x}, x]/{1, o, 
              o\^2}] /. {au1 \[Rule] aub, au2 \[Rule] auc}\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"0", ",", 
        RowBox[{
          RowBox[{"2", " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"nb1\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "nb1"], 
                  Format[ aub]],
                Editable->False], ")"}]}], "+", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aub]],
            Editable->False]}], ",", 
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"nb1\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "nb1"], 
                  Format[ aub]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"nb1\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "nb1"], 
                  Format[ auc]],
                Editable->False], ")"}]}], "+", 
          RowBox[{"2", " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"nb2\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "nb2"], 
                  Format[ aub], 
                  Format[ auc]],
                Editable->False], ")"}]}], "-", 
          RowBox[{
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"d\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "d"], 
                  Format[ aub], 
                  Format[ auc]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]]],
                Editable->False], ")"}]}], "+", 
          RowBox[{"2", " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"nb1\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "nb1"], 
                  Format[ auc]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  Format[ aub]],
                Editable->False], ")"}]}], "+", 
          RowBox[{
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"na2\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"r'"\),
                        Subscript[ "r'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "na2"], 
                  Format[ al3], 
                  Format[ auc]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              RowBox[{
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"na2\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "na2"], 
                    Format[ au3], 
                    Format[ aub]],
                  Editable->False], "+", 
                RowBox[{"2", " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"r'"\),
                              Superscript[ "r'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b'"\),
                              Superscript[ "b'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ au3], 
                        Format[ aub]],
                      Editable->False], ")"}]}]}], ")"}]}], "+", 
          RowBox[{\(1\/2\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]4\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]4"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  Format[ aub], 
                  Format[ auc]],
                Editable->False], ")"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(aoo = Solve[foo9[\([2]\)] \[Equal] 0, tna2[aua, aub]]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"na2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "na2"], 
              Format[ aua], 
              Format[ aub]],
            Editable->False], "\[Rule]", 
          RowBox[{
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "-", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[Phi]3\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"a'"\),
                      Superscript[ "a'"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"b'"\),
                      Superscript[ "b'"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "\[Phi]3"], 
                SequenceForm[ 
                  Superscript[ "9"]], 
                Format[ aua], 
                Format[ aub]],
              Editable->False]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule11, tna2[aua_, aub_], aoo[\([1, 1, 2]\)], 
      IndexaQ[aua] \[And] IndexaQ[aub]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(aoo = Solve[foo10[\([2]\)] \[Equal] 0, tnb1[aub]]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"nb1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "nb1"], 
              Format[ aub]],
            Editable->False], "\[Rule]", 
          RowBox[{\(-\(1\/2\)\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  Format[ aub]],
                Editable->False], ")"}]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule12, tnb1[aub_], aoo[\([1, 1, 2]\)], 
      IndexaQ[aub]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(aoo = 
      Solve[ApplyRules[foo9[\([3]\)], {rule11, rule12}] \[Equal] 0, 
        tna3[aua, aub, auc]]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"na3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "na3"], 
              Format[ aua], 
              Format[ aub], 
              Format[ auc]],
            Editable->False], "\[Rule]", 
          RowBox[{
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"e\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c'"\),
                          Superscript[ "c'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "e"], 
                    Format[ aua], 
                    Format[ aub], 
                    Format[ auc]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c'"\),
                          Superscript[ "c'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ aub], 
                    Format[ auc]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c'"\),
                          Superscript[ "c'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ aua], 
                    Format[ auc]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c'"\),
                          Superscript[ "c'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ auc]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c'"\),
                          Superscript[ "c'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ auc]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au1], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c'"\),
                          Superscript[ "c'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ auc]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au1], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c'"\),
                          Superscript[ "c'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua], 
                    Format[ aub], 
                    Format[ auc]],
                  Editable->False], ")"}]}]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(aoo2 = tsimp[Symmetrize[aoo[\([1, 1, 2]\)], {aub, auc}]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"3", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ aua], 
              Format[ aub], 
              Format[ auc]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ aub], 
              Format[ auc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aua]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ aua], 
              Format[ auc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ aua], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ auc]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/4\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ auc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aua], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/4\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aua], 
              Format[ auc]],
            Editable->False], ")"}]}], "-", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al1], 
              Format[ auc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au1], 
              Format[ aua], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al1], 
              Format[ auc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au1], 
              Format[ aua], 
              Format[ aub]],
            Editable->False], ")"}]}], "-", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al1], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au1], 
              Format[ aua], 
              Format[ auc]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al1], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au1], 
              Format[ aua], 
              Format[ auc]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aua], 
              Format[ aub], 
              Format[ auc]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule13, tna3[aua_, aub_, auc_], aoo2, 
      IndexaQ[aua] \[And] IndexaQ[aub] \[And] IndexaQ[auc]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(aoo = 
      Solve[ApplyRules[foo10[\([3]\)], {rule11, rule12, rule13}] \[Equal] 0, 
        tnb2[aub, auc]]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"nb2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "nb2"], 
              Format[ aub], 
              Format[ auc]],
            Editable->False], "\[Rule]", 
          RowBox[{\(1\/2\), " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(-4\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"d\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p'"\),
                              Subscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"c'"\),
                              Superscript[ "c'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "d"], 
                        Format[ al1], 
                        Format[ auc]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"d\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b'"\),
                              Superscript[ "b'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "d"], 
                        Format[ au1], 
                        Format[ aub]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"d\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b'"\),
                              Superscript[ "b'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"c'"\),
                              Superscript[ "c'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "d"], 
                        Format[ aub], 
                        Format[ auc]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(3\/4\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b'"\),
                              Superscript[ "b'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ aub]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"c'"\),
                              Superscript[ "c'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ auc]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{"2", " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"d\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b'"\),
                              Superscript[ "b'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "d"], 
                        Format[ au1], 
                        Format[ aub]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p'"\),
                              Subscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"c'"\),
                              Superscript[ "c'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ al1], 
                        Format[ auc]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{"2", " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"d\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p'"\),
                              Subscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"c'"\),
                              Superscript[ "c'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "d"], 
                        Format[ al1], 
                        Format[ auc]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b'"\),
                              Superscript[ "b'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ au1], 
                        Format[ aub]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p'"\),
                              Subscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"c'"\),
                              Superscript[ "c'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ al1], 
                        Format[ auc]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b'"\),
                              Superscript[ "b'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ au1], 
                        Format[ aub]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]4\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b'"\),
                              Superscript[ "b'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"c'"\),
                              Superscript[ "c'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]4"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ aub], 
                        Format[ auc]],
                      Editable->False], ")"}]}]}], ")"}]}]}], "}"}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(aoo2 = tsimp[Symmetrize[aoo[\([1, 1, 2]\)], {aub, auc}]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"-", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"d\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\_"p'"\),
                      Subscript[ "p'"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"c'"\),
                      Superscript[ "c'"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "d"], 
                Format[ al1], 
                Format[ auc]],
              Editable->False], ")"}]}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ aub]],
            Editable->False], ")"}]}], "-", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al1], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ auc]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ aub], 
              Format[ auc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(3\/8\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ auc]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ auc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al1], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al1], 
              Format[ auc]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al1], 
              Format[ auc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/4\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al1], 
              Format[ auc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ aub]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al1], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ auc]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/4\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al1], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ auc]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/4\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aub], 
              Format[ auc]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(aoo2 = tsimpp[%]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(-2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al1], 
              Format[ auc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ aub], 
              Format[ auc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(3\/8\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ auc]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al1], 
              Format[ auc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ aub]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/4\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aub], 
              Format[ auc]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule14, tnb2[aub_, auc_], aoo2, 
      IndexaQ[aub] \[And] IndexaQ[auc]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ApplyRules[tnb2[aua, aub], rule14]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(-2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al1], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ aua]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ aua], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(3\/8\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al1], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ aua]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/4\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aua], 
              Format[ aub]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "We get foo15=",
  Cell[BoxData[
      \(TraditionalForm\`\(B\_\(a'\)\^dim\)(u)\)]],
  " and foo16= ",
  Cell[BoxData[
      \(TraditionalForm\`\(B\_dim\^dim\)(u)\)]],
  " below."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(norma\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b'"\),
                    Subscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ alb]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"na2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "na2"], 
              Format[ ala], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b'"\),
                    Subscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ alb]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"c'"\),
                    Subscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ alc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"na3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "na3"], 
              Format[ ala], 
              Format[ aub], 
              Format[ auc]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo15 = 
      tgeto2[ApplyRules[norma, {rule11, rule12, rule13, rule14}]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"a'"\),
                          Subscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ ala], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"a'"\),
                          Subscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ ala], 
                    Format[ au1]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"e\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"a'"\),
                          Subscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "e"], 
                    Format[ ala], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"a'"\),
                          Subscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ ala]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"a'"\),
                          Subscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ ala], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"a'"\),
                          Subscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ ala], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"a'"\),
                          Subscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ ala], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"a'"\),
                          Subscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ ala], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al3], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"a'"\),
                          Subscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ ala], 
                    Format[ au1], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al3], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"a'"\),
                          Subscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ ala], 
                    Format[ au1], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al3], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"a'"\),
                          Subscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ ala], 
                    Format[ au2], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al3], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"a'"\),
                          Subscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ ala], 
                    Format[ au2], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"a'"\),
                          Subscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ ala], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo15 = tsimpp[foo15]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"2", " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ ala], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ ala], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ ala], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ ala], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule15, tB[ala_, 9], foo15, IndexaQ[ala]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ApplyRules[tB[ala, 9], rule15]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"2", " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ ala], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ ala], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ ala], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ ala], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(normb\)], "Input"],

Cell[BoxData[
    RowBox[{"1", "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b'"\),
                    Subscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ alb]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"nb1\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "nb1"], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b'"\),
                    Subscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ alb]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"c'"\),
                    Subscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ alc]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"nb2\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "nb2"], 
              Format[ aub], 
              Format[ auc]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo16 = 
      tgeto2[ApplyRules[normb, {rule11, rule12, rule13, rule14}]]\)], "Input"],

Cell[BoxData[
    RowBox[{"1", "-", 
      RowBox[{\(1\/2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(-2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al3], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(3\/8\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al3], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule16, tB[\(-9\), 9], foo16]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ApplyRules[tB[\(-9\), 9], rule16]\)], "Input"],

Cell[BoxData[
    RowBox[{"1", "-", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(3\/8\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["\<\
In the below, we confirm if the normal vector is orthogonal to the tangent \
vectors and if the length of the normal vector is 1.\
\>", "Text"],

Cell[TextData[{
  "The inner product of the normal vector ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          FormBox[\(B\_a\),
            "TraditionalForm"], "dim"], TraditionalForm]]],
  " and a tangent vector ",
  Cell[BoxData[
      \(TraditionalForm\`B\_a\^a'\)]],
  " is foo17=",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]\^2\( \[Phi](\[Eta])\)\)\(\ \)\)\/\(\
\[PartialD]\ \[Eta]\_p \[PartialD]\ \[Eta]\_q\)\( | \_\(\[Eta](
              u)\)\)\(\(B\_p\^a'\)(u)\) \(\(B\_q\^dim\)(u)\)\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(phi2u\ tB[la, aua]\ tB[lb, 9]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"B\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"a"\),
                  Subscript[ "a"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"a'"\),
                  Superscript[ "a'"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "B"], 
            Format[ la], 
            Format[ aua]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"B\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"b"\),
                  Subscript[ "b"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            InterpretationBox[
              InterpretationBox[\(\[Null]\^"9"\),
                Superscript[ "9"],
                Editable->False],
              SequenceForm[ 
                Superscript[ "9"]],
              Editable->False]}],
          SequenceForm[ 
            Format[ "B"], 
            Format[ lb], 
            SequenceForm[ 
              Superscript[ "9"]]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        RowBox[{
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], "+", 
          RowBox[{"o", " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"u\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"p'"\),
                        Subscript[ "p'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "u"], 
                  Format[ al1]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"p'"\),
                        Superscript[ "p'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a"\),
                        Superscript[ "a"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b"\),
                        Superscript[ "b"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  Format[ au1], 
                  Format[ ua], 
                  Format[ ub]],
                Editable->False], ")"}]}], "+", 
          RowBox[{\(o\^2\), " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"-", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"u\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "u"], 
                          Format[ al1]],
                        Editable->False], ")"}]}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u"], 
                        Format[ al2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"d\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "d"], 
                        Format[ au1], 
                        Format[ au2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p'"\),
                              Subscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u"], 
                        Format[ al1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u"], 
                        Format[ al2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]4\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]4"], 
                        Format[ au1], 
                        Format[ au2], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}]}], ")"}]}]}], 
        ")"}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(CanAll[sepa[sepa[%, la], lb]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo17 = 
      tgeto2[ApplyRules[%, {rule3, rule4, rule15, rule16}]]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The squared norm of the normal vector ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          FormBox[\(B\_a\),
            "TraditionalForm"], "dim"], TraditionalForm]]],
  "  is foo18= ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]\^2\( \[Phi](\[Eta])\)\)\(\ \)\)\/\(\
\[PartialD]\ \[Eta]\_p \[PartialD]\ \[Eta]\_q\)\( | \_\(\[Eta](
              u)\)\)\(\(B\_p\^dim\)(u)\) \(\(B\_q\^dim\)(u)\)\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(phi2u\ tB[la, 9]\ tB[lb, 9]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"B\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"a"\),
                  Subscript[ "a"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            InterpretationBox[
              InterpretationBox[\(\[Null]\^"9"\),
                Superscript[ "9"],
                Editable->False],
              SequenceForm[ 
                Superscript[ "9"]],
              Editable->False]}],
          SequenceForm[ 
            Format[ "B"], 
            Format[ la], 
            SequenceForm[ 
              Superscript[ "9"]]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"B\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"b"\),
                  Subscript[ "b"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            InterpretationBox[
              InterpretationBox[\(\[Null]\^"9"\),
                Superscript[ "9"],
                Editable->False],
              SequenceForm[ 
                Superscript[ "9"]],
              Editable->False]}],
          SequenceForm[ 
            Format[ "B"], 
            Format[ lb], 
            SequenceForm[ 
              Superscript[ "9"]]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        RowBox[{
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], "+", 
          RowBox[{"o", " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"u\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"p'"\),
                        Subscript[ "p'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "u"], 
                  Format[ al1]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"p'"\),
                        Superscript[ "p'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a"\),
                        Superscript[ "a"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b"\),
                        Superscript[ "b"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  Format[ au1], 
                  Format[ ua], 
                  Format[ ub]],
                Editable->False], ")"}]}], "+", 
          RowBox[{\(o\^2\), " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"-", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"u\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "u"], 
                          Format[ al1]],
                        Editable->False], ")"}]}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u"], 
                        Format[ al2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"d\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "d"], 
                        Format[ au1], 
                        Format[ au2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p'"\),
                              Subscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u"], 
                        Format[ al1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u"], 
                        Format[ al2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]4\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]4"], 
                        Format[ au1], 
                        Format[ au2], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}]}], ")"}]}]}], 
        ")"}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(CanAll[sepa[sepa[%, la], lb]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo18 = 
      tgeto2[ApplyRules[%, {rule3, rule4, rule15, rule16}]]\)], "Input"],

Cell[BoxData[
    RowBox[{"1", "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(-2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al3], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al3], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ au3]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(tsimpp[foo18]\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["(u,v)-coordinate system", "Subsubsection"],

Cell[TextData[{
  "foo20 = ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Eta]\_a\)(u, 
          v) = \(\[Eta]\_a\)(u) + \(\(B\_a\^dim\)(u)\)\ v\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo20 = se[la] + tB[la, 9] v\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"\[Eta]\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\_"a"\),
                Subscript[ "a"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ "\[Eta]"], 
          Format[ la]],
        Editable->False], "+", 
      RowBox[{"v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ la], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "foo21 = ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Eta]\_\(a'\)\)(u, v)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo21 = 
      ApplyRules[
        foo20 /. {la \[Rule] ala}, {rule1, rule2, rule15, rule16}]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"2", " ", "o", " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ ala], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ ala], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"o", " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ ala], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ ala], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule21, se[ala_], foo21, IndexaQ[ala]]\)], "Input"],

Cell[TextData[{
  "foo22 = ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Eta]\_dim\)(u, v)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo22 = 
      ApplyRules[
        foo20 /. {la \[Rule] \(-9\)}, {rule1, rule2, rule15, 
          rule16}]\)], "Input"],

Cell[BoxData[
    RowBox[{"v", "-", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", "o", " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(3\/8\), " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule22, se[\(-9\)], foo22]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[rule22b, se[9], foo22]\)], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["change of variables", "Subsection"],

Cell[TextData[{
  "The Jacobian of the change of variables \[Eta]\[LeftRightArrow](u,v) is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"J", "=", 
          RowBox[{"det", "(", 
            FractionBox[
              RowBox[{" ", 
                FormBox[\(\[PartialD]\ \(\[Eta](u, v)\)\),
                  "TraditionalForm"]}], 
              RowBox[{" ", 
                FormBox[\(\[PartialD]\((u, v)\)\),
                  "TraditionalForm"]}]], ")"}]}], TraditionalForm]]],
  ". The asymptotic expression of  ",
  Cell[BoxData[
      \(TraditionalForm\`log\ det\ J\)]],
  " is obtained up to ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(-1\))\)]],
  " term in \"logdetJ\". The density function ",
  Cell[BoxData[
      \(TraditionalForm\`f(u, v | v0)\)]],
  " is obtained from ",
  Cell[BoxData[
      \(TraditionalForm\`f(y | \[Eta])\)]],
  " as shown in \"logdensityuv\", where the parameter value is specified as \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta] = \((0,  ... , 0, v0)\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["Jacobian", "Subsubsection"],

Cell[TextData[{
  "Here we will calculate the log of the Jacobian ",
  Cell[BoxData[
      FormBox[
        RowBox[{"J", "=", 
          RowBox[{"det", "(", 
            FractionBox[
              RowBox[{" ", 
                FormBox[\(\[PartialD]\ \(\(\[Eta]\_a\)(u, v)\)\),
                  "TraditionalForm"]}], 
              RowBox[{" ", 
                FormBox[\(\[PartialD]\((u, v)\)\),
                  "TraditionalForm"]}]], ")"}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "First, we obtain the expression of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", GridBox[{
              {
                FractionBox[
                  RowBox[{" ", 
                    FormBox[\(\[PartialD]\ \(\(\[Eta]\_\(a'\)\)(u, v)\)\),
                      "TraditionalForm"]}], 
                  RowBox[{" ", 
                    FormBox[\(\[PartialD]u\_\(b'\)\),
                      "TraditionalForm"]}]], 
                FractionBox[
                  RowBox[{" ", 
                    FormBox[\(\[PartialD]\ \(\(\[Eta]\_\(a'\)\)(u, v)\)\),
                      "TraditionalForm"]}], 
                  RowBox[{" ", 
                    FormBox[\(\[PartialD]v\),
                      "TraditionalForm"]}]]},
              {
                FractionBox[
                  RowBox[{" ", 
                    FormBox[\(\[PartialD]\ \(\(\[Eta]\_dim\)(u, v)\)\),
                      "TraditionalForm"]}], 
                  RowBox[{" ", 
                    FormBox[\(\[PartialD]u\_\(b'\)\),
                      "TraditionalForm"]}]], 
                FractionBox[
                  RowBox[{" ", 
                    FormBox[\(\[PartialD]\ \(\(\[Eta]\_dim\)(u, v)\)\),
                      "TraditionalForm"]}], 
                  RowBox[{" ", 
                    FormBox[\(\[PartialD]v\),
                      "TraditionalForm"]}]]}
              }], ")"}], TraditionalForm]]],
  "=",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", GridBox[{
              {"foo23", "foo25"},
              {"foo24", "foo26"}
              }], ")"}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "foo23 =",
  Cell[BoxData[
      FormBox[
        FractionBox[
          RowBox[{" ", 
            FormBox[\(\[PartialD]\ \(\(\[Eta]\_\(a'\)\)(u, v)\)\),
              "TraditionalForm"]}], 
          RowBox[{" ", 
            FormBox[\(\[PartialD]u\_\(b'\)\),
              "TraditionalForm"]}]], TraditionalForm]]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo23 = tsimp[difa[foo21, ru, aub]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"Kdelta\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\_"a'"\),
                Subscript[ "a'"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"b'"\),
                Superscript[ "b'"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ Kdelta], 
          Format[ ala], 
          Format[ aub]],
        Editable->False], "+", 
      RowBox[{"2", " ", "o", " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ ala], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"6", " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ ala], 
              Format[ au1], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"2", " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ ala], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"o", " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ aub]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al2], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ ala], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al2], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ ala], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al2], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ ala], 
              Format[ au2], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al2], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ ala], 
              Format[ au2], 
              Format[ aub]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ au1], 
              Format[ aub]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "foo24 =",
  Cell[BoxData[
      FormBox[
        FractionBox[
          RowBox[{" ", 
            FormBox[\(\[PartialD]\ \(\(\[Eta]\_dim\)(u, v)\)\),
              "TraditionalForm"]}], 
          RowBox[{" ", 
            FormBox[\(\[PartialD]u\_\(b'\)\),
              "TraditionalForm"]}]], TraditionalForm]]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo24 = tsimp[difa[foo22, ru, aub]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(-2\), " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al2], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ aub]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al2], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au2], 
              Format[ aub]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ au1], 
              Format[ au2], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", "o", " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(3\/4\), " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al2], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al2], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2], 
              Format[ aub]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ aub]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "foo25 =",
  Cell[BoxData[
      FormBox[
        FractionBox[
          RowBox[{" ", 
            FormBox[\(\[PartialD]\ \(\(\[Eta]\_\(a'\)\)(u, v)\)\),
              "TraditionalForm"]}], 
          RowBox[{" ", 
            FormBox[\(\[PartialD]v\),
              "TraditionalForm"]}]], TraditionalForm]]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo25 = tsimp[D[foo21, v]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"2", " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ ala], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ ala], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ ala], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ ala], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "foo26 =",
  Cell[BoxData[
      FormBox[
        FractionBox[
          RowBox[{" ", 
            FormBox[\(\[PartialD]\ \(\(\[Eta]\_dim\)(u, v)\)\),
              "TraditionalForm"]}], 
          RowBox[{" ", 
            FormBox[\(\[PartialD]v\),
              "TraditionalForm"]}]], TraditionalForm]]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo26 = tsimp[D[foo22, v]]\)], "Input"],

Cell[BoxData[
    RowBox[{"1", "-", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(3\/8\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`foo27 = foo25\/foo26\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo27 = tsimpp[tgets2[y/x, x, foo26, y, foo25]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"2", " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ ala], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ ala], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ ala], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ ala], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "foo28=foo27 foo24 =",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(foo24\ foo25\)\)\/foo26\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo28 = tsimpp[tgets2[x\ y, x, foo27, y, foo24]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(-4\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au2], 
              Format[ aub]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au2], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "foo29=foo23-foo28",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Delta]\_\(a'\)\^b'\)\)]],
  "=foo23-",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(foo24\ foo25\)\)\/foo26\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Delta]\_\(a'\)\^b'\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo29 = 
      tsimp[tgets2[x - \ y, x, foo23, y, foo28]] - 
        Kdelta[ala, aub]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"2", " ", "o", " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ ala], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"4", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au2], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"6", " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ ala], 
              Format[ au1], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"2", " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ ala], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"2", " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aub]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au2], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"o", " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ aub]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al2], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ ala], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al2], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ ala], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al2], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ ala], 
              Format[ au2], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al2], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ ala], 
              Format[ au2], 
              Format[ aub]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ au1], 
              Format[ aub]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now, ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", GridBox[{
              {"foo23", "foo25"},
              {"foo24", "foo26"}
              }], ")"}], TraditionalForm]]],
  " is transformed to ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", GridBox[{
              {\(I + foo29\), "0"},
              {"foo24", "foo26"}
              }], ")"}], TraditionalForm]]],
  " by the simple conventions preserving the determinant."
}], "Text"],

Cell[TextData[{
  "Then, ",
  Cell[BoxData[
      \(TraditionalForm\`log\ J = 
        log\ \(det(I + foo29)\)\  + \ \(\(log\)\((\)\)\)]],
  "1+(foo26-1)) = ",
  Cell[BoxData[
      \(TraditionalForm\`trace(foo29) - \(1\/2\) \(trace(foo29\^2)\)\  + \ 
        foo26 - 1\  - \ \(1\/2\) \((foo26 - 1)\)\^2\)]],
  "."
}], "Text"],

Cell["foo30=trace(foo29)", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo30 = tsimpp[Kdelta[aua, alb]\ foo29]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"2", " ", "o", " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al1], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"4", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al3], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"6", " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ al2], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"4", " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al2], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"o", " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al1], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al2], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al3], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al2], 
              Format[ au3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ al3], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al2], 
              Format[ au3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ al3], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al2], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ al3], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al2], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ al3], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al2], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`foo31 = trace(foo29\^2)\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo31 = 
      tsimp[tgets2[x\ y, x, foo29, y, 
          foo29 /. {ala \[Rule] aua, aub \[Rule] alb}]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"4", " ", \(o\^2\), " ", \(v\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al2], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"4", " ", \(o\^2\), " ", \(v\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al2], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", \(v\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al2], 
              Format[ au1]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`foo32 = \((foo26 - 1)\)\^2\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo32 = tsimp[tgets2[x\^2, x, foo26 - 1]]\)], "Input"],

Cell[BoxData[
    RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"u\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"p'"\),
                  Subscript[ "p'"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "u"], 
            Format[ al1]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"u\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"q'"\),
                  Subscript[ "q'"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "u"], 
            Format[ al2]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"\[Phi]3\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            InterpretationBox[
              InterpretationBox[\(\[Null]\^"9"\),
                Superscript[ "9"],
                Editable->False],
              SequenceForm[ 
                Superscript[ "9"]],
              Editable->False], "\[InvisibleSpace]", 
            InterpretationBox[
              InterpretationBox[\(\[Null]\^"9"\),
                Superscript[ "9"],
                Editable->False],
              SequenceForm[ 
                Superscript[ "9"]],
              Editable->False], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"p'"\),
                  Superscript[ "p'"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "\[Phi]3"], 
            SequenceForm[ 
              Superscript[ "9"]], 
            SequenceForm[ 
              Superscript[ "9"]], 
            Format[ au1]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"\[Phi]3\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            InterpretationBox[
              InterpretationBox[\(\[Null]\^"9"\),
                Superscript[ "9"],
                Editable->False],
              SequenceForm[ 
                Superscript[ "9"]],
              Editable->False], "\[InvisibleSpace]", 
            InterpretationBox[
              InterpretationBox[\(\[Null]\^"9"\),
                Superscript[ "9"],
                Editable->False],
              SequenceForm[ 
                Superscript[ "9"]],
              Editable->False], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"q'"\),
                  Superscript[ "q'"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "\[Phi]3"], 
            SequenceForm[ 
              Superscript[ "9"]], 
            SequenceForm[ 
              Superscript[ "9"]], 
            Format[ au2]],
          Editable->False], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Finally,  logdetJ=",
  Cell[BoxData[
      \(TraditionalForm\`log\ det\ J = foo30 - 1\/2\)]],
  "foo31 ",
  Cell[BoxData[
      \(TraditionalForm\`\(+foo26\) - 1 - \(1\/2\) \(\(foo32\)\(.\)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(logdetJ = 
      tgeto2[tsimpp[
          foo30 - \(1\/2\) foo31 + foo26 - 1 - \(1\/2\) foo32]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"2", " ", "v", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"v", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(-2\), " ", \(v\^2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al3], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"6", " ", "v", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"e\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "e"], 
                    Format[ al2], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"4", " ", "v", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"v", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al2], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", \(v\^2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", \(v\^2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", "v", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au2], 
                    Format[ au3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al3], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al3], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", "v", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al2], 
                    Format[ au3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al3], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"v", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al3], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", "v", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al3], 
                    Format[ au2], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"v", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al3], 
                    Format[ au2], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"v", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Collect[logdetJ /. {ru[al_] \[Rule] u}, {o, v, u}, Simplify]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(-\(1\/2\)\), " ", "u", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"v", " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"2", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p'"\),
                            Subscript[ "p'"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"p'"\),
                            Superscript[ "p'"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      Format[ al1], 
                      Format[ au1]],
                    Editable->False]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(v\^2\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(-2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      RowBox[{
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              FormBox["\<\"d\"\>",
                                "StandardForm"],
                              Format], "\[InvisibleSpace]", 
                            TagBox[
                              FormBox[
                                InterpretationBox[\(\[Null]\_"q'"\),
                                  Subscript[ "q'"],
                                  Editable->False],
                                "StandardForm"],
                              Format], "\[InvisibleSpace]", 
                            TagBox[
                              FormBox[
                                InterpretationBox[\(\[Null]\^"p'"\),
                                  Superscript[ "p'"],
                                  Editable->False],
                                "StandardForm"],
                              Format]}],
                          SequenceForm[ 
                            Format[ "d"], 
                            Format[ al2], 
                            Format[ au1]],
                          Editable->False], "-", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              FormBox["\<\"\[Phi]3\"\>",
                                "StandardForm"],
                              Format], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            TagBox[
                              FormBox[
                                InterpretationBox[\(\[Null]\_"q'"\),
                                  Subscript[ "q'"],
                                  Editable->False],
                                "StandardForm"],
                              Format], "\[InvisibleSpace]", 
                            TagBox[
                              FormBox[
                                InterpretationBox[\(\[Null]\^"p'"\),
                                  Superscript[ "p'"],
                                  Editable->False],
                                "StandardForm"],
                              Format]}],
                          SequenceForm[ 
                            Format[ "\[Phi]3"], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            Format[ al2], 
                            Format[ au1]],
                          Editable->False]}], ")"}]}], "-", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{\(1\/4\), " ", \(u\^2\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"8", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r'"\),
                                Subscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al3], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r'"\),
                                Superscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au1], 
                          Format[ au3]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"2", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au2]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{"8", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r'"\),
                                Superscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au2], 
                          Format[ au3]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r'"\),
                                Subscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al3], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"2", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r'"\),
                                Subscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al3], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r'"\),
                                Superscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1], 
                          Format[ au3]],
                        Editable->False], ")"}]}], "-", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]4\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"p'"\),
                            Superscript[ "p'"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"q'"\),
                            Superscript[ "q'"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "\[Phi]4"], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      Format[ au1], 
                      Format[ au2]],
                    Editable->False]}], ")"}]}], "+", 
            RowBox[{"u", " ", "v", " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"6", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"e\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "e"], 
                          Format[ al2], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"4", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al2]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al2], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al2], 
                          Format[ au2]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{"2", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r'"\),
                                Superscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al2], 
                          Format[ au3]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r'"\),
                                Subscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          Format[ al3], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r'"\),
                                Superscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al2], 
                          Format[ au3]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r'"\),
                                Subscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          Format[ al3], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{"2", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r'"\),
                                Subscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r'"\),
                                Superscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          Format[ al3], 
                          Format[ au2], 
                          Format[ au3]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r'"\),
                                Subscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r'"\),
                                Superscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          Format[ al3], 
                          Format[ au2], 
                          Format[ au3]],
                        Editable->False], ")"}]}], "-", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]4\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"q'"\),
                            Subscript[ "q'"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"p'"\),
                            Superscript[ "p'"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"q'"\),
                            Superscript[ "q'"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "\[Phi]4"], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      Format[ al2], 
                      Format[ au1], 
                      Format[ au2]],
                    Editable->False]}], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["density function f(u,v|v0)", "Subsubsection"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`log\ \(f(y | \[Eta])\)\)]],
  " is given as follows."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tgeto2[logdensityy]\)], "Input"],

Cell[BoxData[
    RowBox[{\(\(-\(1\/2\)\)\ dim\ Log[2\ \[Pi]]\), "-", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ u1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ u1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ u1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ l2], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/6\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/3\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(1\/6\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ l3], 
                    Format[ l4], 
                    Format[ u1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ u2], 
                    Format[ u3], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/8\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ l1], 
                    Format[ l2], 
                    Format[ u1], 
                    Format[ u2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ l3], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/24\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/6\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3], 
                    Format[ u4]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/8\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p"\),
                          Subscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q"\),
                          Subscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r"\),
                          Subscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s"\),
                          Subscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Eta]"], 
                    Format[ l4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p"\),
                          Superscript[ "p"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q"\),
                          Superscript[ "q"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r"\),
                          Superscript[ "r"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s"\),
                          Superscript[ "s"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ u1], 
                    Format[ u2], 
                    Format[ u3], 
                    Format[ u4]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "First, we set \[Eta]=(0,...,0,v0). In other words, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_\(a'\) = 0\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_dim = v0\)]],
  ". Here we use symbol v0 for \[Lambda]."
}], "Text"],

Cell[BoxData[
    \(RuleUnique[rule35, se[la_], v0\ Kdelta[la, 9]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo35 = tsimpp[ApplyRules[logdensityy, rule35]]\)], "Input"],

Cell[BoxData[
    RowBox[{\(-\(v0\^2\/2\)\), "-", \(1\/2\ dim\ Log[2\ \[Pi]]\), "+", 
      RowBox[{"v0", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "y"], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ u1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/3\), " ", "o", " ", \(v0\^3\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", "o", " ", \(v0\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ u1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ l2], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/6\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/6\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ l1], 
              Format[ l2], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ l3], 
              Format[ l4], 
              Format[ u1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/8\), " ", \(o\^2\), " ", \(v0\^4\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/6\), " ", \(o\^2\), " ", \(v0\^3\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ u1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/8\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ l1], 
              Format[ l2], 
              Format[ u1], 
              Format[ u2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ l3], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/24\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r"\),
                    Subscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s"\),
                    Subscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ l4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r"\),
                    Superscript[ "r"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s"\),
                    Superscript[ "s"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ u1], 
              Format[ u2], 
              Format[ u3], 
              Format[ u4]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["\<\
Then, change of variables y=\[Eta](u,v).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo36 = 
      tsimpp[CanAll[
          sepa[CanAll[sepa[CanAll[sepa[CanAll[sepa[foo35, l1]], l1]], l1]], 
            l1]]]\)], "Input"],

Cell[BoxData[
    RowBox[{\(-\(v0\^2\/2\)\), "-", \(1\/2\ dim\ Log[2\ \[Pi]]\), "+", 
      RowBox[{"v0", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "y"], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "y"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "y"], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/3\), " ", "o", " ", \(v0\^3\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "y"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", "o", " ", \(v0\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "y"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/6\), " ", "o", " ", 
        SuperscriptBox[
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"y\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\_"9"\),
                    Subscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Subscript[ "9"]],
                  Editable->False]}],
              SequenceForm[ 
                Format[ "y"], 
                SequenceForm[ 
                  Subscript[ "9"]]],
              Editable->False], ")"}], "3"], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/6\), " ", \(o\^2\), " ", 
        SuperscriptBox[
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[Phi]3\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False]}],
              SequenceForm[ 
                Format[ "\[Phi]3"], 
                SequenceForm[ 
                  Superscript[ "9"]], 
                SequenceForm[ 
                  Superscript[ "9"]], 
                SequenceForm[ 
                  Superscript[ "9"]]],
              Editable->False], ")"}], "2"]}], "-", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
        SuperscriptBox[
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"y\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\_"9"\),
                    Subscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Subscript[ "9"]],
                  Editable->False]}],
              SequenceForm[ 
                Format[ "y"], 
                SequenceForm[ 
                  Subscript[ "9"]]],
              Editable->False], ")"}], "2"], " ", 
        SuperscriptBox[
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[Phi]3\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False]}],
              SequenceForm[ 
                Format[ "\[Phi]3"], 
                SequenceForm[ 
                  Superscript[ "9"]], 
                SequenceForm[ 
                  Superscript[ "9"]], 
                SequenceForm[ 
                  Superscript[ "9"]]],
              Editable->False], ")"}], "2"]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{\(o\/2\), "+", \(\(o\ v0\^2\)\/2\), "-", 
            RowBox[{\(1\/2\), " ", "o", " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"y\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\_"9"\),
                          Subscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Subscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "y"], 
                      SequenceForm[ 
                        Subscript[ "9"]]],
                    Editable->False], ")"}], "2"]}], "-", 
            RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{\(o\^2\/2\), "-", 
            RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"y\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\_"9"\),
                          Subscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Subscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "y"], 
                      SequenceForm[ 
                        Subscript[ "9"]]],
                    Editable->False], ")"}], "2"]}]}], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "y"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al1], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "y"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "y"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{\(o\^2\/2\), "-", 
            RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"y\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\_"9"\),
                          Subscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Subscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "y"], 
                      SequenceForm[ 
                        Subscript[ "9"]]],
                    Editable->False], ")"}], "2"]}]}], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al1], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al3], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ al2], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/6\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "y"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al2], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/6\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ al1], 
              Format[ al2], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s'"\),
                    Subscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ al3], 
              Format[ al4], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s'"\),
                    Superscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au2], 
              Format[ au3], 
              Format[ au4]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/8\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/8\), " ", \(o\^2\), " ", \(v0\^4\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/6\), " ", \(o\^2\), " ", \(v0\^3\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "y"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
        SuperscriptBox[
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"y\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\_"9"\),
                    Subscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Subscript[ "9"]],
                  Editable->False]}],
              SequenceForm[ 
                Format[ "y"], 
                SequenceForm[ 
                  Subscript[ "9"]]],
              Editable->False], ")"}], "2"], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/24\), " ", \(o\^2\), " ", 
        SuperscriptBox[
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"y\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\_"9"\),
                    Subscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Subscript[ "9"]],
                  Editable->False]}],
              SequenceForm[ 
                Format[ "y"], 
                SequenceForm[ 
                  Subscript[ "9"]]],
              Editable->False], ")"}], "4"], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{\(\(o\^2\ v0\^3\)\/6\), "+", 
            RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"y\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "y"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/6\), " ", \(o\^2\), " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"y\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\_"9"\),
                          Subscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Subscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "y"], 
                      SequenceForm[ 
                        Subscript[ "9"]]],
                    Editable->False], ")"}], "3"]}]}], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{\(-\(o\^2\/4\)\), "+", 
            RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"y\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\_"9"\),
                          Subscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Subscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "y"], 
                      SequenceForm[ 
                        Subscript[ "9"]]],
                    Editable->False], ")"}], "2"]}]}], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al1], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{\(o\^2\/4\), "-", 
            RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"y\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\_"9"\),
                          Subscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Subscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "y"], 
                      SequenceForm[ 
                        Subscript[ "9"]]],
                    Editable->False], ")"}], "2"]}]}], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "y"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al2], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/6\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "y"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/8\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ al1], 
              Format[ al2], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ al3], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/24\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"y\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s'"\),
                    Subscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "y"], 
              Format[ al4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s'"\),
                    Superscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3], 
              Format[ au4]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo37 = 
      tsimpp[tgeto2[
            ApplyRules[foo36 /. ry \[Rule] se, {rule21, rule22, rule22b}]] + 
          logdetJ]\)], "Input"],

Cell[BoxData[
    RowBox[{\(-\(v\^2\/2\)\), "+", \(v\ v0\), "-", \(v0\^2\/2\), 
      "-", \(1\/2\ dim\ Log[2\ \[Pi]]\), "-", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"2", " ", "o", " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al1], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", \(v\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al2], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\((2\ o\^2 - 2\ o\^2\ v\ v0)\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s'"\),
                    Subscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s'"\),
                    Superscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au3], 
              Format[ au4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"6", " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ al2], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\((\(-2\)\ o\^2\ v - o\^2\ v0)\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", "o", " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/6\), " ", "o", " ", \(v\^3\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", "o", " ", "v", " ", \(v0\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/3\), " ", "o", " ", \(v0\^3\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/6\), " ", \(o\^2\), " ", 
        SuperscriptBox[
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[Phi]3\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False]}],
              SequenceForm[ 
                Format[ "\[Phi]3"], 
                SequenceForm[ 
                  Superscript[ "9"]], 
                SequenceForm[ 
                  Superscript[ "9"]], 
                SequenceForm[ 
                  Superscript[ "9"]]],
              Editable->False], ")"}], "2"]}], "-", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", \(v\^2\), " ", 
        SuperscriptBox[
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[Phi]3\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False]}],
              SequenceForm[ 
                Format[ "\[Phi]3"], 
                SequenceForm[ 
                  Superscript[ "9"]], 
                SequenceForm[ 
                  Superscript[ "9"]], 
                SequenceForm[ 
                  Superscript[ "9"]]],
              Editable->False], ")"}], "2"]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{\(\(-o\)\ v\), "-", \(o\ v0\), "+", 
            RowBox[{\(1\/2\), " ", \(o\^2\), " ", "v", " ", "v0", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", \(o\^2\), " ", \(v0\^2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\((5\ o\^2\ v - o\^2\ v\^3 + o\^2\ v\ v0\^2)\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al2], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(3\/2\), " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          
          RowBox[{\(\(-\(1\/2\)\)\ o\ v\ v0\), "+", \(\(o\ v0\^2\)\/2\), "-", 
            
            RowBox[{\(3\/4\), " ", \(o\^2\), " ", "v", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/4\), " ", \(o\^2\), " ", \(v\^3\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/4\), " ", \(o\^2\), " ", "v", " ", \(v0\^2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\((o\^2\/2 - \(o\^2\ v\^2\)\/2)\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(3\/8\), " ", \(o\^2\), " ", "v", " ", "v0", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", "o", " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al1], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"2", " ", \(o\^2\), " ", \(v\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al2], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\((\(-\(\(3\ o\^2\ v\)\/2\)\) + \(o\^2\ v\^3\)\/2 - 
            1\/2\ o\^2\ v\ v0\^2)\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al2], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\((o\^2\/2 - \(3\ o\^2\ v\^2\)\/4)\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al2], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al2], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al3], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al3], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", "o", " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s'"\),
                    Subscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s'"\),
                    Superscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au3], 
              Format[ au4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", "v", " ", "v0", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ al2], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al2], 
              Format[ au3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ al3], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al2], 
              Format[ au3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ al3], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al2], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ al3], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al2], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ al3], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/6\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/6\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ al1], 
              Format[ al2], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s'"\),
                    Subscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al4], 
              Format[ au3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s'"\),
                    Superscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au4]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s'"\),
                    Subscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al4], 
              Format[ au3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s'"\),
                    Superscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au4]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s'"\),
                    Subscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ al3], 
              Format[ al4], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s'"\),
                    Superscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au2], 
              Format[ au3], 
              Format[ au4]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/8\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", \(v\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/24\), " ", \(o\^2\), " ", \(v\^4\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/6\), " ", \(o\^2\), " ", "v", " ", \(v0\^3\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/8\), " ", \(o\^2\), " ", \(v0\^4\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\((\(o\^2\ v\)\/2 - \(o\^2\ v\^3\)\/6 + \(o\^2\ v0\^3\)\/6)\), 
        " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\((\(-\(o\^2\/4\)\) + \(o\^2\ v\^2\)\/4)\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al1], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", "v", " ", "v0", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al2], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/3\), " ", \(o\^2\), " ", "v", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/8\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ al1], 
              Format[ al2], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ al3], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/24\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s'"\),
                    Subscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s'"\),
                    Superscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3], 
              Format[ au4]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["Now we get logdensityuv=foo38=f(u,v|v0).", "Text"],

Cell[BoxData[
    \(\(foo38 = 
        Collect[foo37, {o, v, ru[al1] ru[al2] ru[al3] ru[al4], 
            ru[al1] ru[al2] ru[al3], ru[al1] ru[al2], ru[al1]}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(logdensityuv = foo38\)], "Input"],

Cell[BoxData[
    RowBox[{\(-\(v\^2\/2\)\), "+", \(v\ v0\), "-", \(v0\^2\/2\), 
      "-", \(1\/2\ dim\ Log[2\ \[Pi]]\), "-", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(-v0\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/6\), " ", \(v\^3\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/3\), " ", \(v0\^3\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"v", " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"2", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/2\), " ", \(v0\^2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/2\), " ", "v0", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"u\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "u"], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"u\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "u"], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"u\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "u"], 
                          Format[ al2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"-", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}]}]}], ")"}]}]}], ")"}]}],
             "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(1\/2\), " ", \(v0\^2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          Format[ al2], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}]}]}], ")"}]}], "-", 
            RowBox[{\(1\/6\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ au3]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(-v0\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"e\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "e"], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/6\), " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]]],
                    Editable->False], ")"}], "2"]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/6\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al1], 
                    Format[ al2], 
                    Format[ al3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/8\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/24\), " ", \(v\^4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/8\), " ", \(v0\^4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(v\^3\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"-", 
                      RowBox[{"(", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              FormBox["\<\"d\"\>",
                                "StandardForm"],
                              Format], "\[InvisibleSpace]", 
                            TagBox[
                              FormBox[
                                InterpretationBox[\(\[Null]\^"p'"\),
                                  Superscript[ "p'"],
                                  Editable->False],
                                "StandardForm"],
                              Format], "\[InvisibleSpace]", 
                            TagBox[
                              FormBox[
                                InterpretationBox[\(\[Null]\^"q'"\),
                                  Superscript[ "q'"],
                                  Editable->False],
                                "StandardForm"],
                              Format]}],
                          SequenceForm[ 
                            Format[ "d"], 
                            Format[ au1], 
                            Format[ au2]],
                          Editable->False], ")"}]}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al2]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/4\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/6\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{\(1\/6\), " ", \(v0\^3\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(v\^2\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(-2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/4\), " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              FormBox["\<\"\[Phi]3\"\>",
                                "StandardForm"],
                              Format], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False]}],
                          SequenceForm[ 
                            Format[ "\[Phi]3"], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]]],
                          Editable->False], ")"}], "2"]}], "-", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"2", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(3\/4\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/4\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/4\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}]}]}], ")"}]}], "-", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"v", " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(1\/6\), " ", \(v0\^3\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"u\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "u"], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"u\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "u"], 
                          Format[ al2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{\(-2\), " ", "v0", " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"r'"\),
                                      Subscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al3], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"r'"\),
                                      Superscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ au1], 
                                Format[ au3]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/2\), " ", "v0", " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(3\/8\), " ", "v0", " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au2]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/2\), " ", "v0", " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"r'"\),
                                      Subscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al3], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"r'"\),
                                      Superscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1], 
                                Format[ au3]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/4\), " ", "v0", " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}]}]}], ")"}]}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"u\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "u"], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"6", " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"e\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "e"], 
                                Format[ al2], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{"5", " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al2]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(v0\^2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al2]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al2], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(3\/4\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/4\), " ", \(v0\^2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(3\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al2], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/2\), " ", \(v0\^2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al2], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/4\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al2], 
                                Format[ au2]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"r'"\),
                                      Superscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al2], 
                                Format[ au3]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"r'"\),
                                      Subscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                Format[ al3], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"r'"\),
                                      Superscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al2], 
                                Format[ au3]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"r'"\),
                                      Subscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                Format[ al3], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al2], 
                                Format[ au1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"r'"\),
                                      Subscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"r'"\),
                                      Superscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                Format[ al3], 
                                Format[ au2], 
                                Format[ au3]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al2], 
                                Format[ au1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"r'"\),
                                      Subscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"r'"\),
                                      Superscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                Format[ al3], 
                                Format[ au2], 
                                Format[ au3]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al2], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}]}]}], ")"}]}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"u\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "u"], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"u\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "u"], 
                          Format[ al2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"u\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r'"\),
                                Subscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "u"], 
                          Format[ al3]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{\(-2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"e\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"r'"\),
                                      Superscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "e"], 
                                Format[ au1], 
                                Format[ au2], 
                                Format[ au3]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(3\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"r'"\),
                                      Superscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ au2], 
                                Format[ au3]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/4\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"r'"\),
                                      Superscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au3]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"s'"\),
                                      Subscript[ "s'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"r'"\),
                                      Superscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al4], 
                                Format[ au3]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"s'"\),
                                      Superscript[ "s'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                Format[ au1], 
                                Format[ au2], 
                                Format[ au4]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"s'"\),
                                      Subscript[ "s'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"r'"\),
                                      Superscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al4], 
                                Format[ au3]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"s'"\),
                                      Superscript[ "s'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                Format[ au1], 
                                Format[ au2], 
                                Format[ au4]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/3\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"r'"\),
                                      Superscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1], 
                                Format[ au2], 
                                Format[ au3]],
                              Editable->False], ")"}]}]}], ")"}]}]}], ")"}]}],
             "-", 
            RowBox[{\(1\/8\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ al1], 
                    Format[ al2], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"2", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r'"\),
                                Subscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al3], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r'"\),
                                Superscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au1], 
                          Format[ au3]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/2\), " ", \(v0\^2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{"2", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r'"\),
                                Superscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au2], 
                          Format[ au3]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r'"\),
                                Subscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al3], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r'"\),
                                Subscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r'"\),
                                Superscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al3], 
                          Format[ au3]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/4\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r'"\),
                                Subscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"s'"\),
                                Subscript[ "s'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          Format[ al3], 
                          Format[ al4], 
                          Format[ au1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r'"\),
                                Superscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"s'"\),
                                Superscript[ "s'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          Format[ au2], 
                          Format[ au3], 
                          Format[ au4]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/4\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r'"\),
                                Subscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r'"\),
                                Superscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          Format[ al3], 
                          Format[ au1], 
                          Format[ au2], 
                          Format[ au3]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"s'"\),
                          Subscript[ "s'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ al4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(-\(1\/2\)\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r'"\),
                                Superscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"s'"\),
                                Superscript[ "s'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au3], 
                          Format[ au4]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r'"\),
                                Superscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"s'"\),
                                Superscript[ "s'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au3], 
                          Format[ au4]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/24\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r'"\),
                                Superscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"s'"\),
                                Superscript[ "s'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          Format[ au1], 
                          Format[ au2], 
                          Format[ au3], 
                          Format[ au4]],
                        Editable->False], ")"}]}]}], ")"}]}]}], 
          ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(InputForm[foo38]\)], "Input"],

Cell["\<\
-v^2/2 + v*v0 - v0^2/2 - (dim*Log[2*Pi])/2 - (ru[al1]*ru[au1])/2 + 
 o*(-(v0*ru[al1]*ru[al2]*td[au1, au2]) - (v^3*tp3[9, 9, 9])/6 - 
   (v0^3*tp3[9, 9, 9])/3 + v*(2*td[al1, au1] + tp3[9, 9, 9]/2 + 
     (v0^2*tp3[9, 9, 9])/2 - (v0*ru[al1]*tp3[9, 9, au1])/2 - 
     tp3[9, al1, au1]/2 + ru[al1]*ru[al2]*(-td[au1, au2] + 
       tp3[9, au1, au2]/2)) + ru[al1]*((v0^2*tp3[9, 9, au1])/2 + 
     tp3[al2, au1, au2]/2) - (ru[al1]*ru[al2]*ru[al3]*
     tp3[au1, au2, au3])/6) + 
 o^2*(-(v0*ru[al1]*ru[al2]*ru[al3]*te[au1, au2, au3]) + 
   tp3[9, 9, 9]^2/6 + (tp3[9, 9, al1]*tp3[9, 9, au1])/2 + 
   (tp3[9, al1, au2]*tp3[9, al2, au1])/2 + 
   (tp3[al1, al2, al3]*tp3[au1, au2, au3])/6 - tp4[9, 9, 9, 9]/8 - 
   (v^4*tp4[9, 9, 9, 9])/24 - (v0^4*tp4[9, 9, 9, 9])/8 + 
   v^3*ru[al1]*(-(td[au1, au2]*tp3[9, 9, al2]) + 
     (tp3[9, 9, 9]*tp3[9, 9, au1])/4 + 
     (tp3[9, 9, au2]*tp3[9, al2, au1])/2 - tp4[9, 9, 9, au1]/6) + 
   (v0^3*ru[al1]*tp4[9, 9, 9, au1])/6 + 
   v^2*(-2*td[al1, au2]*td[al2, au1] - tp3[9, 9, 9]^2/4 - 
     (tp3[9, 9, al1]*tp3[9, 9, au1])/2 + 2*td[al1, au2]*
      tp3[9, al2, au1] - (3*tp3[9, al1, au2]*tp3[9, al2, au1])/4 + 
     tp4[9, 9, 9, 9]/4 + tp4[9, 9, al1, au1]/4) - 
   tp4[9, 9, al1, au1]/4 + v*((v0^3*tp4[9, 9, 9, 9])/6 + 
     ru[al1]*ru[al2]*(-2*v0*td[al3, au2]*td[au1, au3] + 
       (v0*td[au1, au2]*tp3[9, 9, 9])/2 + 
       (3*v0*tp3[9, 9, au1]*tp3[9, 9, au2])/8 + 
       (v0*tp3[9, al3, au2]*tp3[9, au1, au3])/2 - 
       (v0*tp4[9, 9, au1, au2])/4) + 
     ru[al1]*(6*te[al2, au1, au2] + 5*td[au1, au2]*tp3[9, 9, al2] + 
       v0^2*td[au1, au2]*tp3[9, 9, al2] + td[al2, au2]*
        tp3[9, 9, au1] - (3*tp3[9, 9, 9]*tp3[9, 9, au1])/4 - 
       (v0^2*tp3[9, 9, 9]*tp3[9, 9, au1])/4 - 
       (3*tp3[9, 9, au2]*tp3[9, al2, au1])/2 - 
       (v0^2*tp3[9, 9, au2]*tp3[9, al2, au1])/2 + 
       (tp3[9, 9, au1]*tp3[9, al2, au2])/4 - 2*td[al2, au3]*
        tp3[al3, au1, au2] + (tp3[9, al2, au3]*tp3[al3, au1, au2])/
        2 - td[al2, au1]*tp3[al3, au2, au3] + 
       (tp3[9, al2, au1]*tp3[al3, au2, au3])/2 + 
       tp4[9, 9, 9, au1]/2 - tp4[9, al2, au1, au2]/2) + 
     ru[al1]*ru[al2]*ru[al3]*(-2*te[au1, au2, au3] - 
       (3*td[au2, au3]*tp3[9, 9, au1])/2 - 
       (tp3[9, 9, au3]*tp3[9, au1, au2])/4 + 
       td[al4, au3]*tp3[au1, au2, au4] - 
       (tp3[9, al4, au3]*tp3[au1, au2, au4])/2 + 
       tp4[9, au1, au2, au3]/3)) - tp4[al1, al2, au1, au2]/8 + 
   ru[al1]*ru[al2]*(2*td[al3, au2]*td[au1, au3] - 
     (v0^2*td[au1, au2]*tp3[9, 9, 9])/2 - 2*td[au2, au3]*
      tp3[9, al3, au1] - (td[au1, au2]*tp3[9, al3, au3])/2 - 
     (tp3[al3, al4, au1]*tp3[au2, au3, au4])/4 + 
     tp4[al3, au1, au2, au3]/4) + ru[al1]*ru[al2]*ru[al3]*ru[al4]*
    (-(td[au1, au2]*td[au3, au4])/2 + 
     (td[au3, au4]*tp3[9, au1, au2])/2 - tp4[au1, au2, au3, au4]/
      24))\
\>", "Output"]
}, Open  ]],

Cell["\<\
We extract the coefficients for u, v from the density function f(u,v|v0).\
\>", "Text"],

Cell[BoxData[
    \(\(foo39 = 
        Collect[CoefficientList[foo38 /. {ru[al_] \[Rule] u}, {v, u}], {o, 
            v0}, tsimpp[
              CanAll[# /. {au1 \[Rule] aua, au2 \[Rule] aub, au3 \[Rule] auc, 
                    au4 \[Rule] aud, au5 \[Rule] aue, al1 \[Rule] ala, 
                    al2 \[Rule] alb, al3 \[Rule] alc, al4 \[Rule] ald, 
                    al5 \[Rule] ale}]] &];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dimensions[foo39]\)], "Input"],

Cell[BoxData[
    \({5, 5}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(foo40 = foo39;\)\)], "Input"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`u\^0\)]],
  "-coefficients"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(v\^0\) u\^0\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo40[\([1, 1]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(-\(v0\^2\/2\)\), "-", \(1\/2\ dim\ Log[2\ \[Pi]]\), "-", 
      RowBox[{\(1\/3\), " ", "o", " ", \(v0\^3\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(1\/6\), " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]]],
                    Editable->False], ")"}], "2"]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/6\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al1], 
                    Format[ al2], 
                    Format[ al3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/8\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/8\), " ", \(v0\^4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/8\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ al1], 
                    Format[ al2], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(v\^1\) u\^0\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(foo40[\([2, 1]\)]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    RowBox[{"v0", "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", \(v0\^2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(1\/6\), " ", \(o\^2\), " ", \(v0\^3\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(v\^2\) u\^0\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo40[\([3, 1]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(-\(1\/2\)\), "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(-2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/4\), " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]]],
                    Editable->False], ")"}], "2"]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(3\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(v\^3\) u\^0\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo40[\([4, 1]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(-\(1\/6\)\), " ", "o", " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"\[Phi]3\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            InterpretationBox[
              InterpretationBox[\(\[Null]\^"9"\),
                Superscript[ "9"],
                Editable->False],
              SequenceForm[ 
                Superscript[ "9"]],
              Editable->False], "\[InvisibleSpace]", 
            InterpretationBox[
              InterpretationBox[\(\[Null]\^"9"\),
                Superscript[ "9"],
                Editable->False],
              SequenceForm[ 
                Superscript[ "9"]],
              Editable->False], "\[InvisibleSpace]", 
            InterpretationBox[
              InterpretationBox[\(\[Null]\^"9"\),
                Superscript[ "9"],
                Editable->False],
              SequenceForm[ 
                Superscript[ "9"]],
              Editable->False]}],
          SequenceForm[ 
            Format[ "\[Phi]3"], 
            SequenceForm[ 
              Superscript[ "9"]], 
            SequenceForm[ 
              Superscript[ "9"]], 
            SequenceForm[ 
              Superscript[ "9"]]],
          Editable->False], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(v\^4\) u\^0\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo40[\([5, 1]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(-\(1\/24\)\), " ", \(o\^2\), " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"\[Phi]4\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            InterpretationBox[
              InterpretationBox[\(\[Null]\^"9"\),
                Superscript[ "9"],
                Editable->False],
              SequenceForm[ 
                Superscript[ "9"]],
              Editable->False], "\[InvisibleSpace]", 
            InterpretationBox[
              InterpretationBox[\(\[Null]\^"9"\),
                Superscript[ "9"],
                Editable->False],
              SequenceForm[ 
                Superscript[ "9"]],
              Editable->False], "\[InvisibleSpace]", 
            InterpretationBox[
              InterpretationBox[\(\[Null]\^"9"\),
                Superscript[ "9"],
                Editable->False],
              SequenceForm[ 
                Superscript[ "9"]],
              Editable->False], "\[InvisibleSpace]", 
            InterpretationBox[
              InterpretationBox[\(\[Null]\^"9"\),
                Superscript[ "9"],
                Editable->False],
              SequenceForm[ 
                Superscript[ "9"]],
              Editable->False]}],
          SequenceForm[ 
            Format[ "\[Phi]4"], 
            SequenceForm[ 
              Superscript[ "9"]], 
            SequenceForm[ 
              Superscript[ "9"]], 
            SequenceForm[ 
              Superscript[ "9"]], 
            SequenceForm[ 
              Superscript[ "9"]]],
          Editable->False], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`u\^1\)]],
  "-coefficients"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(v\^0\) u\^1\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo40[\([1, 2]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(1\/2\), " ", \(v0\^2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al1], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(1\/6\), " ", \(o\^2\), " ", \(v0\^3\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aua]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(v\^1\) u\^1\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(foo40[\([2, 2]\)]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(-\(1\/2\)\), " ", "o", " ", "v0", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aua]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"6", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"e\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "e"], 
                    Format[ al1], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"5", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(3\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(3\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(v0\^2\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"a'"\),
                                Superscript[ "a'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au1], 
                          Format[ aua]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/4\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"a'"\),
                                Superscript[ "a'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ aua]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"a'"\),
                                Superscript[ "a'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ aua]],
                        Editable->False], ")"}]}]}], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al2], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al2], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al2], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al2], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(v\^2\) u\^1\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo40[\([3, 2]\)]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(v\^3\) u\^1\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo40[\([4, 2]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(o\^2\), " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"p'"\),
                        Subscript[ "p'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  Format[ al1]],
                Editable->False], ")"}]}], "+", 
          RowBox[{\(1\/4\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a'"\),
                        Superscript[ "a'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  Format[ aua]],
                Editable->False], ")"}]}], "+", 
          RowBox[{\(1\/2\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"p'"\),
                        Superscript[ "p'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  Format[ au1]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"p'"\),
                        Subscript[ "p'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a'"\),
                        Superscript[ "a'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  Format[ al1], 
                  Format[ aua]],
                Editable->False], ")"}]}], "-", 
          RowBox[{\(1\/6\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]4\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a'"\),
                        Superscript[ "a'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]4"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  Format[ aua]],
                Editable->False], ")"}]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(v\^4\) u\^1\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo40[\([5, 2]\)]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`u\^2\)]],
  "-coefficients"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(v\^0\) u\^2\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo40[\([1, 3]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(-\(1\/2\)\), "-", 
      RowBox[{"o", " ", "v0", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ aua], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ aub]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", \(v0\^2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ aub]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al1], 
                    Format[ al2], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ al1], 
                    Format[ au1], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(v\^1\) u\^2\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(foo40[\([2, 3]\)]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", "v0", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(-2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ aub]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(3\/8\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ aub]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(v\^2\) u\^2\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo40[\([3, 3]\)]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(v\^3\) u\^2\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo40[\([4, 3]\)]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(v\^4\) u\^2\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo40[\([5, 3]\)]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`u\^3\)]],
  "-coefficients"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(v\^0\) u\^3\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo40[\([1, 4]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(-o\^2\), " ", "v0", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ aua], 
              Format[ aub], 
              Format[ auc]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/6\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ aua], 
              Format[ aub], 
              Format[ auc]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(v\^1\) u\^3\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(foo40[\([2, 4]\)]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    RowBox[{\(o\^2\), " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{\(-2\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"e\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a'"\),
                        Superscript[ "a'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "e"], 
                  Format[ aua], 
                  Format[ aub], 
                  Format[ auc]],
                Editable->False], ")"}]}], "-", 
          RowBox[{\(3\/2\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"d\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "d"], 
                  Format[ aub], 
                  Format[ auc]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a'"\),
                        Superscript[ "a'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  Format[ aua]],
                Editable->False], ")"}]}], "-", 
          RowBox[{\(1\/4\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  Format[ auc]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a'"\),
                        Superscript[ "a'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  Format[ aua], 
                  Format[ aub]],
                Editable->False], ")"}]}], "+", 
          RowBox[{
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"d\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"p'"\),
                        Subscript[ "p'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "d"], 
                  Format[ al1], 
                  Format[ auc]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"p'"\),
                        Superscript[ "p'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a'"\),
                        Superscript[ "a'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  Format[ au1], 
                  Format[ aua], 
                  Format[ aub]],
                Editable->False], ")"}]}], "-", 
          RowBox[{\(1\/2\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"p'"\),
                        Subscript[ "p'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  Format[ al1], 
                  Format[ auc]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"p'"\),
                        Superscript[ "p'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a'"\),
                        Superscript[ "a'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  Format[ au1], 
                  Format[ aua], 
                  Format[ aub]],
                Editable->False], ")"}]}], "+", 
          RowBox[{\(1\/3\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]4\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a'"\),
                        Superscript[ "a'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]4"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  Format[ aua], 
                  Format[ aub], 
                  Format[ auc]],
                Editable->False], ")"}]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(v\^2\) u\^3\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo40[\([3, 4]\)]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(v\^3\) u\^3\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo40[\([4, 4]\)]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(v\^4\) u\^3\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo40[\([5, 4]\)]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`u\^4\)]],
  "-coefficients"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(v\^0\) u\^4\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo40[\([1, 5]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(o\^2\), " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{\(-\(1\/2\)\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"d\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a'"\),
                        Superscript[ "a'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "d"], 
                  Format[ aua], 
                  Format[ aub]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"d\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"d'"\),
                        Superscript[ "d'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "d"], 
                  Format[ auc], 
                  Format[ aud]],
                Editable->False], ")"}]}], "+", 
          RowBox[{\(1\/2\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"d\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"d'"\),
                        Superscript[ "d'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "d"], 
                  Format[ auc], 
                  Format[ aud]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a'"\),
                        Superscript[ "a'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  Format[ aua], 
                  Format[ aub]],
                Editable->False], ")"}]}], "-", 
          RowBox[{\(1\/24\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]4\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a'"\),
                        Superscript[ "a'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"d'"\),
                        Superscript[ "d'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]4"], 
                  Format[ aua], 
                  Format[ aub], 
                  Format[ auc], 
                  Format[ aud]],
                Editable->False], ")"}]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(v\^1\) u\^4\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(foo40[\([2, 5]\)]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(v\^2\) u\^4\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo40[\([3, 5]\)]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(v\^3\) u\^4\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo40[\([4, 5]\)]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(v\^4\) u\^4\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo40[\([5, 5]\)]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`z\_c\)]],
  "-formula"
}], "Section"],

Cell[TextData[{
  "We modify the signed distance v to obtain a modified signed distance \
specified by ",
  Cell[BoxData[
      \(TraditionalForm\`w = 
        v + \[Sum]\+\(r = 0\)\%\[Infinity] cbr[
                r]\ v\^r + \(u\_\(a'\)\) \(\[Sum]\+\(r = 0\)\%\[Infinity] br[
                  a', r]\ v\^r\)\)]],
  ". The density function of w and its cumulants are obtained up to ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(-1\))\)]],
  " terms. The distribution function of w is calculated by applying the \
Cornish-Fisher expansion to the cumulants of w. We would also take account of \
the scaling by the factor tau as well as the local coordinates at the \
projection in the below."
}], "Text"],

Cell[CellGroupData[{

Cell["modified signed distance w", "Subsection"],

Cell[TextData[{
  "The inverse series of the modified signed distance specifies  ",
  Cell[BoxData[
      \(TraditionalForm\`v = 
        w - \[Sum]\+\(r = 0\)\%\[Infinity] cr[
                r]\ w\^r - \(u\_\(a'\)\) \(\[Sum]\+\(r = 0\)\%\[Infinity] br[
                  a', r]\ w\^r\)\)]],
  ". We have assumed that cbr[0] and cbr[2] are ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(\(-1\)/2\))\)]],
  " and cbr[1], cbr[3], and all br[a',r] are ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(-1\))\)]],
  ". The other coefficients are ",
  Cell[BoxData[
      \(TraditionalForm\`cbr[r] = O(n\^\(\(-3\)/2\))\)]],
  " for r\[GreaterEqual]4. Then the same order applies to cr[r]'s. The \
modified signed distance w is characterized by the coefficient vector \
c=(cr[0],cr[1],cr[2],cr[3]) up to ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(-1\))\)]],
  " terms, since we can ignore the linear term in u as explained later. The \
change of variable is given in \"rulevinuw\" for v expressed in terms of u \
and w. The Jacobian is given in logjvw=log ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\ v\/\[PartialD]\ w\)]],
  ". The joint density of (u,w) is obtained by f(u,w|v0)=f(u,v(w,u)|v0)J , \
and log f(u,w|v0) is stored in \"logdensityuw\".  We then calculate  ",
  Cell[BoxData[
      \(TraditionalForm\`log\ \(f(
            w | v0)\) = \ \ \ log\ \(\[Integral]\(f(u, 
                w | v0)\) \[DifferentialD]u\)\)]],
  " as an application of \"logeexppoly\" to logdensityuw, and stored in \
\"logdensityw\". In fact, the linear term in ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  ", namely ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_\(a'\)\) \(\[Sum]\+\(r = 0\)\%\[Infinity] br[
              a', r]\ w\^r\)\)]],
  " does not contribute to the argument for deriving the distribution \
function of w as seen in logdensityw. By using \"logeexppoly\" again, we \
obtain the cumulants of ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  " as shown in \"cumulantw\"."
}], "Text"],

Cell[CellGroupData[{

Cell["define the modified signed distance as a series of v.", "Subsubsection"],

Cell["Define w = foo45 as a function of v below.", "Text"],

Cell[BoxData[
    \(\(foo44 = {o, o\^2, o, o\^2};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo45 = \(\(v\)\(\ \)\(+\)\(\ \)\(Sum[
          foo44[\([i + 1]\)]\ cbr[i]\ v\^i\ , \ {i, 0, 
            3}\ ]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(v + o\ cbr[0] + o\^2\ v\ cbr[1] + o\ v\^2\ cbr[2] + 
      o\^2\ v\^3\ cbr[3]\)], "Output"]
}, Open  ]],

Cell["\<\
Then consider the inversion v=foo46 as a function of w  below.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo46 = 
      w - \ Sum[foo44[\([i + 1]\)]\ cr[i]\ w\^i\ , \ {i, 0, 3}\ ]\)], "Input"],

Cell[BoxData[
    \(w - o\ cr[0] - o\^2\ w\ cr[1] - o\ w\^2\ cr[2] - 
      o\^2\ w\^3\ cr[3]\)], "Output"]
}, Open  ]],

Cell["\<\
The relations between the two sets of the coefficients are given below.\
\>", "Text"],

Cell[BoxData[
    \(func47[cbs_] := 
      Table[gets2[
          cbs[\([i + 1]\)] - 
            Sum[\((i - j + 1)\) cbs[\([i - j + 1 + 1]\)] 
                cbs[\([j + 1]\)], {j, 0, i}]], {i, 0, 
          Length[cbs] - 2}]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo47 = 
      func47[{\ o\ cbr[0]\ , \ o\^2\ cbr[1]\ , \ o\ cbr[2], \ o\^2\ cbr[3], 
            0}]/foo44\)], "Input"],

Cell[BoxData[
    \({cbr[0], cbr[1] - 2\ cbr[0]\ cbr[2], 
      cbr[2], \(-2\)\ cbr[2]\^2 + cbr[3]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(rule47 = Table[cr[i] \[Rule] foo47[\([i + 1]\)], {i, 0, 3}]\)], "Input"],

Cell[BoxData[
    \({cr[0] \[Rule] cbr[0], cr[1] \[Rule] cbr[1] - 2\ cbr[0]\ cbr[2], 
      cr[2] \[Rule] cbr[2], 
      cr[3] \[Rule] \(-2\)\ cbr[2]\^2 + cbr[3]}\)], "Output"]
}, Open  ]],

Cell["\<\
The relation is actually obtained by solving the following coefficients==0.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[
      CoefficientList[gets2[foo45 /. {v \[Rule] foo46}], w]]\)], "Input"],

Cell[BoxData[
    \({o\ \((cbr[0] - cr[0])\), 
      1 + o\^2\ \((cbr[1] - 2\ cbr[2]\ cr[0] - cr[1])\), 
      o\ \((cbr[2] - cr[2])\), 
      o\^2\ \((cbr[3] - 2\ cbr[2]\ cr[2] - cr[3])\)}\)], "Output"]
}, Open  ]],

Cell["Checking if the relation is correct by seeing the identity.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gets2[\(foo45 /. {v \[Rule] foo46}\) /. rule47]\)], "Input"],

Cell[BoxData[
    \(w\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Consider the following ",
  Cell[BoxData[
      \(TraditionalForm\`\(O(n\^\(-1\))\)\ \(\(term\)\(.\)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(func48[v_] = 
      ru[ala]\ \(o\^2\) \(\[Sum]\+\(r = 0\)\%\[Infinity] br[aua, r] 
            v\^r\)\)], "Input"],

Cell[BoxData[
    RowBox[{\(o\^2\), " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"u\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"a'"\),
                  Subscript[ "a'"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "u"], 
            Format[ ala]],
          Editable->False], ")"}], " ", 
      RowBox[{\(\[Sum]\+\(r = 0\)\%\[Infinity]\), 
        RowBox[{
          RowBox[{"br", "[", 
            RowBox[{
              InterpretationBox[\(\[Null]\^"a'"\),
                Superscript[ "a'"],
                Editable->False], ",", "r"}], "]"}], 
          " ", \(v\^r\)}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(v = w + O(n\^\(\(-1\)/2\))\)\(,\)\)\)]],
  " func48[v] = func48[w] + ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(\(-3\)/2\))\)]],
  ", and we can ignore the difference between func48[v] and func48[w]. So, if \
we redefine w = foo45+func48[v], and v=foo46-func48[w], the inversion \
relation still holds.  We call \"v\" as the signed distance, and \"w\" as a \
modified signed distance characterized by the coefficients cr[r] and br[r]."
}], "Text"],

Cell[TextData[{
  "Jacobian ",
  Cell[BoxData[
      \(TraditionalForm\`J = \[PartialD]\ v\/\[PartialD]\ w\)]],
  " of the transformation from v to w is given below. Here D[func48[w],w] is \
denoted as ",
  Cell[BoxData[
      \(TraditionalForm\`o\^2\ u\_\(a'\)\ \(\(dbr\^a'\)\(.\)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[tdbr, "\<dbr\>", {{1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"dbr\"\) defined"\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo49 = D[foo46, w] - \(o\^2\) ru[ala]\ \ tdbr[aua]\)], "Input"],

Cell[BoxData[
    RowBox[{
    "1", "-", \(o\^2\ cr[1]\), "-", \(2\ o\ w\ cr[2]\), 
      "-", \(3\ o\^2\ w\^2\ cr[3]\), "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ ala]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"dbr\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "dbr"], 
              Format[ aua]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "We need the log of the Jacobian for later use. logjvw=log ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\ v\/\[PartialD]\ w\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(logjvw = 
      geto2[\((foo49 - 1)\) - \(1\/2\) \((foo49 - 1)\)\^2]\)], "Input"],

Cell[BoxData[
    RowBox[{\(\(-2\)\ o\ w\ cr[2]\), "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          
          RowBox[{\(-cr[1]\), "-", \(2\ w\^2\ cr[2]\^2\), 
            "-", \(3\ w\^2\ cr[3]\), "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"a'"\),
                          Subscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ ala]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"dbr\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "dbr"], 
                    Format[ aua]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Similarly, we write func48[w] as ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(o\^2\) \(u\_\(a'\)\) br\^a'\)\(,\)\)\)]],
  "and vinuw is v expressed by u and w."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[tbr, "\<br\>", {{1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"br\"\) defined"\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(vinuw\  = \ CanAll[foo46 - \(o\^2\) ru[ala] tbr[aua]]\)], "Input"],

Cell[BoxData[
    RowBox[{
    "w", "-", \(o\ cr[0]\), "-", \(o\^2\ w\ cr[1]\), "-", \(o\ w\^2\ cr[2]\), 
      "-", \(o\^2\ w\^3\ cr[3]\), "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"br\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "br"], 
              Format[ au1]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rulevinuw, v, vinuw]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["density function of w", "Subsubsection"],

Cell["\<\
First, we obtain the joint density of (u,w) i.e., f(u,w|v0)=f(u,v(w,u)|v0)J \
from the joint density of (u,v), the transformation v=v(w,u), and the \
Jacobian.\
\>", "Text"],

Cell[BoxData[
    \(\(foo50 = 
        tsimpp[tgeto2[
            ApplyRules[logdensityuv, rulevinuw] + logjvw]];\)\)], "Input"],

Cell["\<\
This is the log of the density. logdensityuw = log f(u,w|v0).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(logdensityuw = 
      Collect[foo50, {ru[al1] ru[al2] ru[al3] ru[al4], 
          ru[al1] ru[al2] ru[al3], ru[al1] ru[al2], ru[al1], o, w, 
          v0}]\)], "Input"],

Cell[BoxData[
    RowBox[{\(-\(v0\^2\/2\)\), "+", \(v0\ w\), "-", \(w\^2\/2\), 
      "-", \(1\/2\ dim\ Log[2\ \[Pi]]\), "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{\(\(-v0\)\ cr[0]\), "-", \(v0\ w\^2\ cr[2]\), "+", 
            RowBox[{\(w\^3\), " ", 
              RowBox[{"(", 
                RowBox[{\(cr[2]\), "-", 
                  RowBox[{\(1\/6\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "-", 
            RowBox[{\(1\/3\), " ", \(v0\^3\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"w", " ", 
              RowBox[{"(", 
                RowBox[{\(cr[0]\), "-", \(2\ cr[2]\), "+", 
                  RowBox[{"2", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/2\), " ", \(v0\^2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
      
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(-\(1\/2\)\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u"], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"o", " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(1\/2\), " ", \(v0\^2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/2\), " ", "v0", " ", "w", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          Format[ al2], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{\(o\^2\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"dbr\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "dbr"], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  
                  RowBox[{\(1\/2\), " ", "v0", " ", \(w\^2\), " ", \(cr[2]\), 
                    " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"v0", " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"-", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"br\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "br"], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/2\), " ", \(cr[0]\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}]}], ")"}]}], "+", 
                  RowBox[{\(w\^3\), " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          RowBox[{"-", 
                            RowBox[{"(", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    FormBox["\<\"d\"\>",
                                      "StandardForm"],
                                    Format], "\[InvisibleSpace]", 
                                  TagBox[
                                    FormBox[
                                      InterpretationBox[\(\[Null]\^"p'"\),
                                        Superscript[ "p'"],
                                        Editable->False],
                                      "StandardForm"],
                                    Format], "\[InvisibleSpace]", 
                                  TagBox[
                                    FormBox[
                                      InterpretationBox[\(\[Null]\^"q'"\),
                                        Superscript[ "q'"],
                                        Editable->False],
                                      "StandardForm"],
                                    Format]}],
                                SequenceForm[ 
                                  Format[ "d"], 
                                  Format[ au1], 
                                  Format[ au2]],
                                Editable->False], ")"}]}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al2]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/4\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al2], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/6\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}]}], ")"}]}], "+", 
                  RowBox[{\(1\/6\), " ", \(v0\^3\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"w", " ", 
                    RowBox[{"(", 
                      RowBox[{
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              FormBox["\<\"br\"\>",
                                "StandardForm"],
                              Format], "\[InvisibleSpace]", 
                            TagBox[
                              FormBox[
                                InterpretationBox[\(\[Null]\^"p'"\),
                                  Superscript[ "p'"],
                                  Editable->False],
                                "StandardForm"],
                              Format]}],
                          SequenceForm[ 
                            Format[ "br"], 
                            Format[ au1]],
                          Editable->False], "+", 
                        RowBox[{"6", " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"e\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "e"], 
                                Format[ al2], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{"5", " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al2]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al2], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(3\/4\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(3\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al2], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(v0\^2\), " ", 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"d\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\^"p'"\),
                                        Superscript[ "p'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\^"q'"\),
                                        Superscript[ "q'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "d"], 
                                      Format[ au1], 
                                      Format[ au2]],
                                    Editable->False], ")"}], " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]3\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\_"q'"\),
                                        Subscript[ "q'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]3"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      Format[ al2]],
                                    Editable->False], ")"}]}], "-", 
                              RowBox[{\(1\/4\), " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]3\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]3"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]]],
                                    Editable->False], ")"}], " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]3\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\^"p'"\),
                                        Superscript[ "p'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]3"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      Format[ au1]],
                                    Editable->False], ")"}]}], "-", 
                              RowBox[{\(1\/2\), " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]3\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\^"q'"\),
                                        Superscript[ "q'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]3"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      Format[ au2]],
                                    Editable->False], ")"}], " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]3\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\_"q'"\),
                                        Subscript[ "q'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\^"p'"\),
                                        Superscript[ "p'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]3"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      Format[ al2], 
                                      Format[ au1]],
                                    Editable->False], ")"}]}]}], ")"}]}], "+",
                         
                        RowBox[{\(1\/4\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al2], 
                                Format[ au2]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"r'"\),
                                      Superscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al2], 
                                Format[ au3]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"r'"\),
                                      Subscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                Format[ al3], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"r'"\),
                                      Superscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al2], 
                                Format[ au3]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"r'"\),
                                      Subscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                Format[ al3], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al2], 
                                Format[ au1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"r'"\),
                                      Subscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"r'"\),
                                      Superscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                Format[ al3], 
                                Format[ au2], 
                                Format[ au3]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al2], 
                                Format[ au1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"r'"\),
                                      Subscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"r'"\),
                                      Superscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                Format[ al3], 
                                Format[ au2], 
                                Format[ au3]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al2], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}]}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(-\(1\/6\)\), " ", "o", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(o\^2\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(-v0\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"e\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r'"\),
                                Superscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "e"], 
                          Format[ au1], 
                          Format[ au2], 
                          Format[ au3]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"w", " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{\(-2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"e\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"r'"\),
                                      Superscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "e"], 
                                Format[ au1], 
                                Format[ au2], 
                                Format[ au3]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(3\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"r'"\),
                                      Superscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ au2], 
                                Format[ au3]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/4\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"r'"\),
                                      Superscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au3]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"s'"\),
                                      Subscript[ "s'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"r'"\),
                                      Superscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al4], 
                                Format[ au3]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"s'"\),
                                      Superscript[ "s'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                Format[ au1], 
                                Format[ au2], 
                                Format[ au4]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"s'"\),
                                      Subscript[ "s'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"r'"\),
                                      Superscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al4], 
                                Format[ au3]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"s'"\),
                                      Superscript[ "s'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                Format[ au1], 
                                Format[ au2], 
                                Format[ au4]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/3\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"r'"\),
                                      Superscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1], 
                                Format[ au2], 
                                Format[ au3]],
                              Editable->False], ")"}]}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          
          RowBox[{\(\(-\(1\/2\)\)\ cr[0]\^2\), "-", \(cr[1]\), 
            "-", \(v0\ w\^3\ cr[3]\), "-", 
            RowBox[{"2", " ", \(cr[0]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", \(cr[0]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", \(v0\^2\), " ", \(cr[0]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/6\), " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]]],
                    Editable->False], ")"}], "2"]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", \(cr[0]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/6\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al1], 
                    Format[ al2], 
                    Format[ al3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(w\^4\), " ", 
              RowBox[{"(", 
                RowBox[{\(\(-\(1\/2\)\)\ cr[2]\^2\), "+", \(cr[3]\), "+", 
                  RowBox[{\(1\/2\), " ", \(cr[2]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/24\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "-", 
            RowBox[{\(1\/8\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/8\), " ", \(v0\^4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"w", " ", 
              RowBox[{"(", 
                RowBox[{\(\(-v0\)\ cr[1]\), "+", 
                  RowBox[{\(1\/6\), " ", \(v0\^3\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{\(w\^2\), " ", 
              RowBox[{"(", 
                
                RowBox[{\(cr[1]\), "-", \(cr[0]\ cr[2]\), 
                  "-", \(2\ cr[2]\^2\), "-", \(3\ cr[3]\), "-", 
                  RowBox[{"2", " ", \(cr[2]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{"2", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/2\), " ", \(cr[0]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/2\), " ", \(cr[2]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/2\), " ", \(v0\^2\), " ", \(cr[2]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/4\), " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              FormBox["\<\"\[Phi]3\"\>",
                                "StandardForm"],
                              Format], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False]}],
                          SequenceForm[ 
                            Format[ "\[Phi]3"], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]]],
                          Editable->False], ")"}], "2"]}], "-", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/2\), " ", \(cr[2]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"2", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(3\/4\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/4\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/4\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}]}]}], ")"}]}], "-", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/8\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ al1], 
                    Format[ al2], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"o", " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(-v0\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"w", " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"-", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}]}]}], ")"}]}]}], ")"}]}],
             "+", 
            RowBox[{\(o\^2\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(cr[0]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"2", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r'"\),
                                Subscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al3], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r'"\),
                                Superscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au1], 
                          Format[ au3]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/2\), " ", \(v0\^2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{"2", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r'"\),
                                Superscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au2], 
                          Format[ au3]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r'"\),
                                Subscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al3], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r'"\),
                                Subscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r'"\),
                                Superscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al3], 
                          Format[ au3]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/2\), " ", \(cr[0]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(w\^2\), " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{\(cr[2]\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/2\), " ", \(cr[2]\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}]}]}], ")"}]}], "-", 
                  RowBox[{\(1\/4\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r'"\),
                                Subscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"s'"\),
                                Subscript[ "s'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          Format[ al3], 
                          Format[ al4], 
                          Format[ au1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r'"\),
                                Superscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"s'"\),
                                Superscript[ "s'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          Format[ au2], 
                          Format[ au3], 
                          Format[ au4]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"v0", " ", "w", " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{\(-2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"r'"\),
                                      Subscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al3], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"r'"\),
                                      Superscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ au1], 
                                Format[ au3]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(3\/8\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au2]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"r'"\),
                                      Subscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al3], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"r'"\),
                                      Superscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1], 
                                Format[ au3]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/4\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}]}]}], ")"}]}], "+", 
                  RowBox[{\(1\/4\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r'"\),
                                Subscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r'"\),
                                Superscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          Format[ al3], 
                          Format[ au1], 
                          Format[ au2], 
                          Format[ au3]],
                        Editable->False], ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
      
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s'"\),
                    Subscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al4]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(-\(1\/2\)\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s'"\),
                          Superscript[ "s'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au3], 
                    Format[ au4]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s'"\),
                          Superscript[ "s'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au3], 
                    Format[ au4]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/24\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"s'"\),
                          Superscript[ "s'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ au3], 
                    Format[ au4]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["\<\
This is the log of the standard multivariate normal density in dim-1 \
dimension.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo51 = \(-\(\(dim - 1\)\/2\)\) Log[2  Pi]\  - \ \(1\/2\) ru[ala] 
          ru[aua]\)], "Input"],

Cell[BoxData[
    RowBox[{\(1\/2\ \((1 - dim)\)\ Log[2\ \[Pi]]\), "-", 
      RowBox[{\(1\/2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ ala]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ aua]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Get the coefficients of the polynomials of ",
  Cell[BoxData[
      \(TraditionalForm\`u\_\(a'\)\)]],
  " from ",
  Cell[BoxData[
      \(TraditionalForm\`log\ \(f(u, w | v0)\) - foo51\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(\(foo52 = \ 
        Collect[CoefficientList[\((logdensityuw - 
                  foo51)\) /. {ru[al_] \[Rule] u}, u], o, 
          tsimpp[CanAll[# /. {au1 \[Rule] aua, au2 \[Rule] aub, 
                    au3 \[Rule] auc, au4 \[Rule] aud, au5 \[Rule] aue, 
                    al1 \[Rule] ala, al2 \[Rule] alb, al3 \[Rule] alc, 
                    al4 \[Rule] ald, 
                    al5 \[Rule] ale}]] &];\)\(\ \ \ \ \ \ \ \ \)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dimensions[foo52]\)], "Input"],

Cell[BoxData[
    \({5}\)], "Output"]
}, Open  ]],

Cell["constant term in terms of u", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo52[\([1]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(-\(v0\^2\/2\)\), "+", \(v0\ w\), "-", \(w\^2\/2\), 
      "-", \(1\/2\ Log[2\ \[Pi]]\), "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          
          RowBox[{\(\(-v0\)\ cr[0]\), "+", \(w\ cr[0]\), "-", \(2\ w\ cr[2]\),
             "-", \(v0\ w\^2\ cr[2]\), "+", \(w\^3\ cr[2]\), "+", 
            RowBox[{"2", " ", "w", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/3\), " ", \(v0\^3\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", "w", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", \(v0\^2\), " ", "w", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/6\), " ", \(w\^3\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", "w", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          
          RowBox[{\(\(-\(1\/2\)\)\ cr[0]\^2\), "-", \(cr[1]\), 
            "-", \(v0\ w\ cr[1]\), "+", \(w\^2\ cr[1]\), 
            "-", \(w\^2\ cr[0]\ cr[2]\), "-", \(2\ w\^2\ cr[2]\^2\), 
            "-", \(1\/2\ w\^4\ cr[2]\^2\), "-", \(3\ w\^2\ cr[3]\), 
            "-", \(v0\ w\^3\ cr[3]\), "+", \(w\^4\ cr[3]\), "+", 
            RowBox[{\((\(-2\)\ cr[0] - 2\ w\^2\ cr[2])\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", \(w\^2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", \(cr[0]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", \(v0\^2\), " ", \(cr[0]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", \(w\^2\), " ", \(cr[0]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", \(w\^2\), " ", \(cr[2]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            
            RowBox[{\(1\/2\), " ", \(v0\^2\), " ", \(w\^2\), " ", \(cr[2]\), 
              " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", \(w\^4\), " ", \(cr[2]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/6\), " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]]],
                    Editable->False], ")"}], "2"]}], "-", 
            RowBox[{\(1\/4\), " ", \(w\^2\), " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]]],
                    Editable->False], ")"}], "2"]}], "+", 
            RowBox[{\((1\/2 - w\^2\/2)\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\((cr[0]\/2 + 1\/2\ w\^2\ cr[2])\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", \(w\^2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\((1\/2 - \(3\ w\^2\)\/4)\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/6\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al1], 
                    Format[ al2], 
                    Format[ al3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/8\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/8\), " ", \(v0\^4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/6\), " ", \(v0\^3\), " ", "w", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/4\), " ", \(w\^2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/24\), " ", \(w\^4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\((\(-\(1\/4\)\) + w\^2\/4)\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/8\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ al1], 
                    Format[ al2], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`u\_\(a'\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo52[\([2]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\((v0\^2\/2 - \(v0\ w\)\/2)\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al1], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\((\(-v0\) + w)\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"br\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "br"], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "-", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"dbr\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"a'"\),
                      Superscript[ "a'"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "dbr"], 
                Format[ aua]],
              Editable->False], "+", 
            RowBox[{"6", " ", "w", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"e\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "e"], 
                    Format[ al1], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\((5\ w + v0\^2\ w - w\^3)\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"w", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                
                RowBox[{\(1\/2\ v0\ cr[0]\), "+", \(1\/2\ v0\ w\^2\ cr[2]\), 
                  "-", 
                  RowBox[{\(3\/4\), " ", "w", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/4\), " ", \(v0\^2\), " ", "w", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/4\), " ", \(w\^3\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/4\), " ", "w", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            
            RowBox[{\((\(-\(\(3\ w\)\/2\)\) - \(v0\^2\ w\)\/2 + w\^3\/2)\), 
              " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"w", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al2], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", "w", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al2], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", "w", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al2], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", "w", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al2], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\((v0\^3\/6 + w\/2 - w\^3\/6)\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", "w", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_\(a'\)\) u\_\(b'\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo52[\([3]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\((\(-v0\) - w)\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", "w", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\((2 - 2\ v0\ w)\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ aub]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{\(cr[0]\), "+", \(w\^2\ cr[2]\), "-", 
                  RowBox[{\(1\/2\), " ", \(v0\^2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/2\), " ", "v0", " ", "w", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{\(3\/8\), " ", "v0", " ", "w", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ aub]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", "v0", " ", "w", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ aub]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\((\(-\(cr[0]\/2\)\) - 1\/2\ w\^2\ cr[2])\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al1], 
                    Format[ al2], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/4\), " ", "v0", " ", "w", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ al1], 
                    Format[ au1], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_\(a'\)\) \(u\_\(b'\)\) u\_\(c'\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo52[\([4]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(-\(1\/6\)\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"c'"\),
                    Superscript[ "c'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ aua], 
              Format[ aub], 
              Format[ auc]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\((\(-v0\) - 2\ w)\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"e\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c'"\),
                          Superscript[ "c'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "e"], 
                    Format[ aua], 
                    Format[ aub], 
                    Format[ auc]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(3\/2\), " ", "w", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c'"\),
                          Superscript[ "c'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ aub], 
                    Format[ auc]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/4\), " ", "w", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c'"\),
                          Superscript[ "c'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ auc]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"w", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c'"\),
                          Superscript[ "c'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ auc]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au1], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", "w", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c'"\),
                          Superscript[ "c'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ auc]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au1], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/3\), " ", "w", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c'"\),
                          Superscript[ "c'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua], 
                    Format[ aub], 
                    Format[ auc]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_\(a'\)\) \(u\_\(b'\)\) \(u\_\(c'\)\) 
        u\_\(d'\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo52[\([5]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(o\^2\), " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{\(-\(1\/2\)\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"d\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a'"\),
                        Superscript[ "a'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "d"], 
                  Format[ aua], 
                  Format[ aub]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"d\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"d'"\),
                        Superscript[ "d'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "d"], 
                  Format[ auc], 
                  Format[ aud]],
                Editable->False], ")"}]}], "+", 
          RowBox[{\(1\/2\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"d\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"d'"\),
                        Superscript[ "d'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "d"], 
                  Format[ auc], 
                  Format[ aud]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a'"\),
                        Superscript[ "a'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  Format[ aua], 
                  Format[ aub]],
                Editable->False], ")"}]}], "-", 
          RowBox[{\(1\/24\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]4\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a'"\),
                        Superscript[ "a'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"c'"\),
                        Superscript[ "c'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"d'"\),
                        Superscript[ "d'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]4"], 
                  Format[ aua], 
                  Format[ aub], 
                  Format[ auc], 
                  Format[ aud]],
                Editable->False], ")"}]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "We now calculate ",
  Cell[BoxData[
      \(TraditionalForm\`log\ \(f(
            w | v0)\) = \ \ \ log\ \(\[Integral]\(f(u, 
                w | v0)\) \[DifferentialD]u\)\)]],
  " as an application of \"logeexppoly\" to foo52. It is denoted by \
logdensityw."
}], "Text"],

Cell[BoxData[
    \(\(foo53 = Collect[foo52/{1, o, o, o, o\^2}, o];\)\)], "Input"],

Cell[BoxData[
    \(RuleUnique[rule53u0, ta0, foo53[\([1]\)]]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[rule53u1, ta1[aua_], foo53[\([2]\)]]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[rule53u2, ta2[aua_, aub_], 
      tsimp[Symmetrize[foo53[\([3]\)], {aua, aub}]]]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[rule53u3, ta3[aua_, aub_, auc_], 
      tsimp[Symmetrize[foo53[\([4]\)], {aua, aub, auc}]]]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[rule53u4, ta4[aua_, aub_, auc_, aud_], 
      tsimp[Symmetrize[foo53[\([5]\)], {aua, aub, auc, aud}]]]\)], "Input"],

Cell[BoxData[
    \(\(foo54 = 
        tgeto2[ApplyRules[\(logeexppoly /. {l1 \[Rule] al1, u1 \[Rule] au1, 
                  l2 \[Rule] al2, u2 \[Rule] au2, l3 \[Rule] al3, 
                  u3 \[Rule] au3, l4 \[Rule] al4, 
                  u4 \[Rule] au4}\) /. {sb[la_] \[Rule] 0}, {rule53u0, 
              rule53u1, rule53u2, rule53u3, rule53u4}]];\)\)], "Input"],

Cell[TextData[{
  "This is ",
  Cell[BoxData[
      \(TraditionalForm\`log\ \(\(f(w | v0)\)\(.\)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(logdensityw = Collect[foo54, {w, o, v0}, tsimpp]\)], "Input"],

Cell[BoxData[
    RowBox[{\(-\(v0\^2\/2\)\), "-", \(1\/2\ Log[2\ \[Pi]]\), "+", 
      RowBox[{\(w\^3\), " ", 
        RowBox[{"(", 
          RowBox[{\(\(-o\^2\)\ v0\ cr[3]\), "+", 
            RowBox[{"o", " ", 
              RowBox[{"(", 
                RowBox[{\(cr[2]\), "-", 
                  RowBox[{\(1\/6\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
      
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"v0", " ", 
              RowBox[{"(", 
                RowBox[{\(-cr[0]\), "-", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"d\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p'"\),
                            Subscript[ "p'"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"p'"\),
                            Superscript[ "p'"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "d"], 
                      Format[ al1], 
                      Format[ au1]],
                    Editable->False]}], ")"}]}], "-", 
            RowBox[{\(1\/3\), " ", \(v0\^3\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", \(w\^4\), " ", 
        RowBox[{"(", 
          RowBox[{\(\(-\(1\/2\)\)\ cr[2]\^2\), "+", \(cr[3]\), "+", 
            RowBox[{\(1\/2\), " ", \(cr[2]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/24\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"w", " ", 
        RowBox[{"(", 
          RowBox[{"v0", "+", 
            RowBox[{"o", " ", 
              RowBox[{"(", 
                RowBox[{\(cr[0]\), "-", \(2\ cr[2]\), "+", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"d\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p'"\),
                            Subscript[ "p'"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"p'"\),
                            Superscript[ "p'"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "d"], 
                      Format[ al1], 
                      Format[ au1]],
                    Editable->False], "+", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/2\), " ", \(v0\^2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{\(o\^2\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(v0\^3\), " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{\(-\(1\/4\)\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/6\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}]}], ")"}]}], "+", 
                  RowBox[{"v0", " ", 
                    RowBox[{"(", 
                      RowBox[{\(-cr[1]\), "+", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al1], 
                                Format[ au1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(3\/8\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al1], 
                                Format[ al2]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al1], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al2], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/4\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al1], 
                                Format[ au1]],
                              Editable->False], ")"}]}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(w\^2\), " ", 
        RowBox[{"(", 
          RowBox[{\(-\(1\/2\)\), "-", \(o\ v0\ cr[2]\), "+", 
            RowBox[{\(o\^2\), " ", 
              RowBox[{"(", 
                
                RowBox[{\(cr[1]\), "-", \(cr[0]\ cr[2]\), 
                  "-", \(2\ cr[2]\^2\), "-", \(3\ cr[3]\), "-", 
                  RowBox[{\(cr[2]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/2\), " ", \(cr[0]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/2\), " ", \(cr[2]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/4\), " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              FormBox["\<\"\[Phi]3\"\>",
                                "StandardForm"],
                              Format], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False]}],
                          SequenceForm[ 
                            Format[ "\[Phi]3"], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]]],
                          Editable->False], ")"}], "2"]}], "-", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(v0\^2\), " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{\(-\(1\/2\)\), " ", \(cr[2]\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/8\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}]}], ")"}]}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ al2]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/4\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/4\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
      
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{\(\(-\(1\/2\)\)\ cr[0]\^2\), "-", \(cr[1]\), "-", 
            RowBox[{\(cr[0]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al2], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", \(cr[0]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/6\), " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]]],
                    Editable->False], ")"}], "2"]}], "+", 
            RowBox[{\(v0\^2\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ al2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/2\), " ", \(cr[0]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ al2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/8\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al1], 
                    Format[ al2], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al3], 
                    Format[ au1], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/8\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al1], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al3], 
                    Format[ au2], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(v0\^4\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(1\/8\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/8\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "-", 
            RowBox[{\(1\/8\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(logdensityw // InputForm\)], "Input"],

Cell["\<\
-v0^2/2 - Log[2*Pi]/2 + w^3*(-(o^2*v0*cr[3]) + 
   o*(cr[2] - tp3[9, 9, 9]/6)) + 
 o*(v0*(-cr[0] - td[al1, au1]) - (v0^3*tp3[9, 9, 9])/3) + 
 o^2*w^4*(-cr[2]^2/2 + cr[3] + (cr[2]*tp3[9, 9, 9])/2 - 
   tp4[9, 9, 9, 9]/24) + 
 w*(v0 + o*(cr[0] - 2*cr[2] + td[al1, au1] + tp3[9, 9, 9]/2 + 
     (v0^2*tp3[9, 9, 9])/2) + 
   o^2*(v0^3*(-(tp3[9, 9, al1]*tp3[9, 9, au1])/4 + 
       tp4[9, 9, 9, 9]/6) + 
     v0*(-cr[1] + (td[al1, au1]*tp3[9, 9, 9])/2 + 
       (3*tp3[9, 9, al1]*tp3[9, 9, au1])/8 - 
       td[au1, au2]*tp3[9, al1, al2] + 
       (tp3[9, al1, au2]*tp3[9, al2, au1])/2 - tp4[9, 9, al1, au1]/
        4))) + w^2*(-1/2 - o*v0*cr[2] + 
   o^2*(cr[1] - cr[0]*cr[2] - 2*cr[2]^2 - 3*cr[3] - 
     cr[2]*td[al1, au1] - td[al1, au2]*td[al2, au1] + 
     (cr[0]*tp3[9, 9, 9])/2 - (cr[2]*tp3[9, 9, 9])/2 - 
     tp3[9, 9, 9]^2/4 - (tp3[9, 9, al1]*tp3[9, 9, au1])/2 + 
     v0^2*(-(cr[2]*tp3[9, 9, 9])/2 + 
       (tp3[9, 9, al1]*tp3[9, 9, au1])/8) + 
     td[au1, au2]*tp3[9, al1, al2] - 
     (tp3[9, al1, au2]*tp3[9, al2, au1])/2 + tp4[9, 9, 9, 9]/4 + 
     tp4[9, 9, al1, au1]/4)) + 
 o^2*(-cr[0]^2/2 - cr[1] - cr[0]*td[al1, au1] + 
   td[al1, au2]*td[al2, au1] - (td[al1, au1]*td[al2, au2])/2 - 
   (cr[0]*tp3[9, 9, 9])/2 + tp3[9, 9, 9]^2/6 + 
   v0^2*(td[al1, al2]*td[au1, au2] - (cr[0]*tp3[9, 9, 9])/2 - 
     (td[al1, au1]*tp3[9, 9, 9])/2) + 
   (tp3[9, 9, al1]*tp3[9, 9, au1])/2 - 
   td[au1, au2]*tp3[9, al1, al2] + 
   (tp3[9, al1, au2]*tp3[9, al2, au1])/2 - 
   (tp3[al1, al2, au2]*tp3[al3, au1, au3])/8 + 
   (tp3[al1, al2, au1]*tp3[al3, au2, au3])/8 + 
   v0^4*((tp3[9, 9, al1]*tp3[9, 9, au1])/8 - tp4[9, 9, 9, 9]/8) - 
   tp4[9, 9, 9, 9]/8 - tp4[9, 9, al1, au1]/4)\
\>", "Output"]
}, Open  ]],

Cell[TextData[{
  "The coefficients of ",
  Cell[BoxData[
      \(TraditionalForm\`w\^i\)]],
  "in ",
  Cell[BoxData[
      \(TraditionalForm\`log\ \(f(w | v0)\)\)]],
  "are shown below."
}], "Text"],

Cell[BoxData[
    \(\(foo55 = 
        Collect[CoefficientList[logdensityw, w], {o, v0}, 
          tsimpp];\)\)], "Input"],

Cell[TextData[{
  "Coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(w\^0\)\(.\)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo55[\([1]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(-\(v0\^2\/2\)\), "-", \(1\/2\ Log[2\ \[Pi]]\), "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"v0", " ", 
              RowBox[{"(", 
                RowBox[{\(-cr[0]\), "-", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"d\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p'"\),
                            Subscript[ "p'"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"p'"\),
                            Superscript[ "p'"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "d"], 
                      Format[ al1], 
                      Format[ au1]],
                    Editable->False]}], ")"}]}], "-", 
            RowBox[{\(1\/3\), " ", \(v0\^3\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{\(\(-\(1\/2\)\)\ cr[0]\^2\), "-", \(cr[1]\), "-", 
            RowBox[{\(cr[0]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al2], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", \(cr[0]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/6\), " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]]],
                    Editable->False], ")"}], "2"]}], "+", 
            RowBox[{\(v0\^2\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ al2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/2\), " ", \(cr[0]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ al2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/8\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al1], 
                    Format[ al2], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al3], 
                    Format[ au1], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/8\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al1], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al3], 
                    Format[ au2], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(v0\^4\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(1\/8\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/8\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "-", 
            RowBox[{\(1\/8\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(w\^1\)\(.\)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo55[\([2]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{"v0", "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{\(cr[0]\), "-", \(2\ cr[2]\), "+", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"d\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\_"p'"\),
                      Subscript[ "p'"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"p'"\),
                      Superscript[ "p'"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "d"], 
                Format[ al1], 
                Format[ au1]],
              Editable->False], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", \(v0\^2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(v0\^3\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(-\(1\/4\)\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/6\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{"v0", " ", 
              RowBox[{"(", 
                RowBox[{\(-cr[1]\), "+", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(3\/8\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ al2]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/4\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}]}]}], ")"}]}]}], 
          ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(w\^2\)\(.\)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo55[\([3]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(-\(1\/2\)\), "-", \(o\ v0\ cr[2]\), "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          
          RowBox[{\(cr[1]\), "-", \(cr[0]\ cr[2]\), "-", \(2\ cr[2]\^2\), 
            "-", \(3\ cr[3]\), "-", 
            RowBox[{\(cr[2]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", \(cr[0]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", \(cr[2]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/4\), " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]]],
                    Editable->False], ")"}], "2"]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(v0\^2\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(-\(1\/2\)\), " ", \(cr[2]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/8\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ al2]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(w\^3\)\(.\)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo55[\([4]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(\(-o\^2\)\ v0\ cr[3]\), "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{\(cr[2]\), "-", 
            RowBox[{\(1\/6\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(w\^4\)\(.\)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo55[\([5]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(o\^2\), " ", 
      RowBox[{"(", 
        RowBox[{\(\(-\(1\/2\)\)\ cr[2]\^2\), "+", \(cr[3]\), "+", 
          RowBox[{\(1\/2\), " ", \(cr[2]\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]]],
                Editable->False], ")"}]}], "-", 
          RowBox[{\(1\/24\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]4\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False]}],
                SequenceForm[ 
                  Format[ "\[Phi]4"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]]],
                Editable->False], ")"}]}]}], ")"}]}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["cumulants of w", "Subsubsection"],

Cell["\<\
Consider the normal density with mean v0+t and variance 1 for w. The log of \
the density is foo60.\
\>", "Text"],

Cell[BoxData[
    \(\(foo60 = \(\(-1\)\/2\) 
            Log[2  Pi] - \(1\/2\) \((w - \((v0 + t)\))\)\^2;\)\)], "Input"],

Cell[TextData[{
  "Then,we define foo61 by  ",
  Cell[BoxData[
      \(TraditionalForm\`e\^\(w\ t\)\ \(f(
            w | v0)\) = \(e\^foo60\) \(\(exp(\ foo61)\)\(.\)\)\)]],
  " This foo61 is a polynomial function of w."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo61 = 
      Collect[w\ t\  + \ logdensityw\  - \ foo60, {w, o}, 
        Simplify]\)], "Input"],

Cell[BoxData[
    RowBox[{\(1\/2\ t\ \((t + 2\ v0)\)\), "+", 
      RowBox[{\(w\^3\), " ", 
        RowBox[{"(", 
          RowBox[{\(\(-o\^2\)\ v0\ cr[3]\), "+", 
            RowBox[{"o", " ", 
              RowBox[{"(", 
                RowBox[{\(cr[2]\), "-", 
                  RowBox[{\(1\/6\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}]}], ")"}]}], "-", 
      
      RowBox[{\(1\/3\), " ", "o", " ", "v0", " ", 
        RowBox[{"(", 
          RowBox[{\(3\ cr[0]\), "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(v0\^2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", \(w\^4\), " ", 
        RowBox[{"(", 
          RowBox[{\(\(-\(1\/2\)\)\ cr[2]\^2\), "+", \(cr[3]\), "+", 
            RowBox[{\(1\/2\), " ", \(cr[2]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/24\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(1\/24\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{\(\(-12\)\ cr[0]\^2\), "-", \(24\ cr[1]\), "+", 
            RowBox[{"24", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"24", " ", \(v0\^2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"12", " ", \(cr[0]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"12", " ", \(v0\^2\), " ", \(cr[0]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"4", " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]]],
                    Editable->False], ")"}], "2"]}], "-", 
            RowBox[{"12", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{\(2\ cr[0]\), "+", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"d\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"q'"\),
                            Subscript[ "q'"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"q'"\),
                            Superscript[ "q'"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "d"], 
                      Format[ al2], 
                      Format[ au2]],
                    Editable->False], "+", 
                  RowBox[{\(v0\^2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{"12", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", \(v0\^4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"24", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ al2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"12", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al1], 
                    Format[ al2], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al3], 
                    Format[ au1], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al1], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al3], 
                    Format[ au2], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"3", " ", \(v0\^4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"6", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(w\^2\), " ", 
        RowBox[{"(", 
          RowBox[{\(\(-o\)\ v0\ cr[2]\), "+", 
            RowBox[{\(1\/8\), " ", \(o\^2\), " ", 
              RowBox[{"(", 
                
                RowBox[{\(8\ cr[1]\), "-", \(8\ cr[0]\ cr[2]\), 
                  "-", \(16\ cr[2]\^2\), "-", \(24\ cr[3]\), "-", 
                  RowBox[{"8", " ", \(cr[2]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{"8", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"4", " ", \(cr[0]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{"4", " ", \(cr[2]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{"4", " ", \(v0\^2\), " ", \(cr[2]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{"2", " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              FormBox["\<\"\[Phi]3\"\>",
                                "StandardForm"],
                              Format], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False]}],
                          SequenceForm[ 
                            Format[ "\[Phi]3"], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]]],
                          Editable->False], ")"}], "2"]}], "-", 
                  RowBox[{"4", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(v0\^2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"8", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ al2]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{"4", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"2", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"2", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
      
      RowBox[{"w", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"o", " ", 
              RowBox[{"(", 
                RowBox[{
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"d\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p'"\),
                            Subscript[ "p'"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"p'"\),
                            Superscript[ "p'"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "d"], 
                      Format[ al1], 
                      Format[ au1]],
                    Editable->False], "+", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      RowBox[{\(2\ cr[0]\), "-", \(4\ cr[2]\), "+", 
                        RowBox[{\((1 + v0\^2)\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}]}], ")"}]}]}], ")"}]}],
             "-", 
            RowBox[{\(1\/24\), " ", \(o\^2\), " ", "v0", " ", 
              RowBox[{"(", 
                RowBox[{\(24\ cr[1]\), "-", 
                  RowBox[{"12", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"3", " ", \((\(-3\) + 2\ v0\^2)\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"24", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ al2]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{"12", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{"4", " ", \(v0\^2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"6", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}]}]}], ")"}]}]}], 
          ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Get the coefficients of ",
  Cell[BoxData[
      \(TraditionalForm\`w\^i\)]],
  "'s for foo61, and store them in foo62 below."
}], "Text"],

Cell[BoxData[
    \(\(foo62 = 
        Collect[CoefficientList[foo61, w], {o, v0}, tsimpp];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[foo62]\)], "Input"],

Cell[BoxData[
    \(5\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo62[\([1]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(t\^2\/2\), "+", \(t\ v0\), "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"v0", " ", 
              RowBox[{"(", 
                RowBox[{\(-cr[0]\), "-", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"d\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p'"\),
                            Subscript[ "p'"],
                            Editable->False],
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\^"p'"\),
                            Superscript[ "p'"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "d"], 
                      Format[ al1], 
                      Format[ au1]],
                    Editable->False]}], ")"}]}], "-", 
            RowBox[{\(1\/3\), " ", \(v0\^3\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{\(\(-\(1\/2\)\)\ cr[0]\^2\), "-", \(cr[1]\), "-", 
            RowBox[{\(cr[0]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al2], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", \(cr[0]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/6\), " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]]],
                    Editable->False], ")"}], "2"]}], "+", 
            RowBox[{\(v0\^2\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ al2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/2\), " ", \(cr[0]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ al2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/8\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al1], 
                    Format[ al2], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al3], 
                    Format[ au1], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/8\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al1], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al3], 
                    Format[ au2], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(v0\^4\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(1\/8\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/8\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "-", 
            RowBox[{\(1\/8\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo62[\([2]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{\(cr[0]\), "-", \(2\ cr[2]\), "+", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"d\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\_"p'"\),
                      Subscript[ "p'"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"p'"\),
                      Superscript[ "p'"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "d"], 
                Format[ al1], 
                Format[ au1]],
              Editable->False], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", \(v0\^2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(v0\^3\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(-\(1\/4\)\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/6\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{"v0", " ", 
              RowBox[{"(", 
                RowBox[{\(-cr[1]\), "+", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(3\/8\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ al2]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/4\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}]}]}], ")"}]}]}], 
          ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo62[\([3]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(\(-o\)\ v0\ cr[2]\), "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          
          RowBox[{\(cr[1]\), "-", \(cr[0]\ cr[2]\), "-", \(2\ cr[2]\^2\), 
            "-", \(3\ cr[3]\), "-", 
            RowBox[{\(cr[2]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", \(cr[0]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", \(cr[2]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/4\), " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]]],
                    Editable->False], ")"}], "2"]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(v0\^2\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(-\(1\/2\)\), " ", \(cr[2]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/8\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ al2]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo62[\([4]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(\(-o\^2\)\ v0\ cr[3]\), "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{\(cr[2]\), "-", 
            RowBox[{\(1\/6\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo62[\([5]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(o\^2\), " ", 
      RowBox[{"(", 
        RowBox[{\(\(-\(1\/2\)\)\ cr[2]\^2\), "+", \(cr[3]\), "+", 
          RowBox[{\(1\/2\), " ", \(cr[2]\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]]],
                Editable->False], ")"}]}], "-", 
          RowBox[{\(1\/24\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]4\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False]}],
                SequenceForm[ 
                  Format[ "\[Phi]4"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]]],
                Editable->False], ")"}]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Apply \"logeexppoly\" to foo62.  We get foo64= ",
  Cell[BoxData[
      \(TraditionalForm\`log \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] e\^\
\(w\ t\)\ \(f(w | v0)\) \[DifferentialD]w\) = \ 
        log \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\ \(e\^foo60\) \(exp(\
\ foo61)\)\ \(\(\[DifferentialD]w\)\(.\)\)\)\)]]
}], "Text"],

Cell[BoxData[
    \(\(foo63 = Simplify[foo62/{1, o, o, o, o\^2}];\)\)], "Input"],

Cell[BoxData[
    \(RuleUnique[rule63u0, ta0, foo63[\([1]\)]]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[rule63u1, ta1[aua_], foo63[\([2]\)]]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[rule63u2, ta2[aua_, aub_], foo63[\([3]\)]]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[rule63u3, ta3[aua_, aub_, auc_], foo63[\([4]\)]]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[rule63u4, ta4[aua_, aub_, auc_, aud_], 
      foo63[\([5]\)]]\)], "Input"],

Cell[BoxData[
    \(\(foo64 = 
        tgeto2[ApplyRules[
            logeexppoly /. {sb[la_] \[Rule] v0 + t}, {rule63u0, rule63u1, 
              rule63u2, rule63u3, rule63u4}]];\)\)], "Input"],

Cell[TextData[{
  "Get the coefficients of ",
  Cell[BoxData[
      \(TraditionalForm\`t\^i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`i = 0, 1, 2, 3, 4, \)]],
  " and multiply ",
  Cell[BoxData[
      \(TraditionalForm\`\(i!\)\)]],
  " so that we get ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\_i\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(foo65 = 
        Collect[CoefficientList[foo64, t]*\ {1, 1, 2, 6, 24}, {o, v0}, 
          tsimpp];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[foo65]\)], "Input"],

Cell[BoxData[
    \(5\)], "Output"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\_0\)]],
  " should be zero."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo65[\([1]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(o\^2\), " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{\(-\(1\/8\)\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"p'"\),
                        Subscript[ "p'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"q'"\),
                        Subscript[ "q'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"q'"\),
                        Superscript[ "q'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  Format[ al1], 
                  Format[ al2], 
                  Format[ au2]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"r'"\),
                        Subscript[ "r'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"p'"\),
                        Superscript[ "p'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"r'"\),
                        Superscript[ "r'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  Format[ al3], 
                  Format[ au1], 
                  Format[ au3]],
                Editable->False], ")"}]}], "+", 
          RowBox[{\(1\/8\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"p'"\),
                        Subscript[ "p'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"q'"\),
                        Subscript[ "q'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"p'"\),
                        Superscript[ "p'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  Format[ al1], 
                  Format[ al2], 
                  Format[ au1]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"r'"\),
                        Subscript[ "r'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"q'"\),
                        Superscript[ "q'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"r'"\),
                        Superscript[ "r'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  Format[ al3], 
                  Format[ au2], 
                  Format[ au3]],
                Editable->False], ")"}]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo65[\([1]\)] = 
      CanAll[% /. {al1 \[Rule] alc, au1 \[Rule] auc, al2 \[Rule] alb, 
            au2 \[Rule] aub}]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Kappa]\_1\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo65[\([2]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{"v0", "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{\(cr[0]\), "+", \(cr[2]\), "+", \(v0\^2\ cr[2]\), "+", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"d\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\_"p'"\),
                      Subscript[ "p'"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"p'"\),
                      Superscript[ "p'"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "d"], 
                Format[ al1], 
                Format[ au1]],
              Editable->False]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{\(v0\^3\ \((2\ cr[2]\^2 + cr[3])\)\), "+", 
            RowBox[{"v0", " ", 
              RowBox[{"(", 
                
                RowBox[{\(cr[1]\), "+", \(2\ cr[0]\ cr[2]\), 
                  "+", \(6\ cr[2]\^2\), "+", \(3\ cr[3]\), "-", 
                  RowBox[{"2", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      RowBox[{\(2\ cr[2]\), "-", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}]}], ")"}]}], "-", 
                  RowBox[{\(cr[2]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(5\/8\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ al2]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/4\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}]}]}], ")"}]}]}], 
          ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Kappa]\_2\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo65[\([3]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{"1", "+", 
      RowBox[{"o", " ", "v0", " ", 
        RowBox[{"(", 
          RowBox[{\(4\ cr[2]\), "-", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[Phi]3\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False]}],
              SequenceForm[ 
                Format[ "\[Phi]3"], 
                SequenceForm[ 
                  Superscript[ "9"]], 
                SequenceForm[ 
                  Superscript[ "9"]], 
                SequenceForm[ 
                  Superscript[ "9"]]],
              Editable->False]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          
          RowBox[{\(2\ cr[1]\), "+", \(4\ cr[0]\ cr[2]\), 
            "+", \(14\ cr[2]\^2\), "+", \(6\ cr[3]\), "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{\(4\ cr[2]\), "-", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]]],
                    Editable->False]}], ")"}]}], "-", 
            RowBox[{"2", " ", \(cr[2]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ al2]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(v0\^2\), " ", 
              RowBox[{"(", 
                RowBox[{\(16\ cr[2]\^2\), "+", \(6\ cr[3]\), "-", 
                  RowBox[{"4", " ", \(cr[2]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}], "2"], "+", 
                  RowBox[{\(1\/4\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Kappa]\_3\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo65[\([4]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{\(6\ cr[2]\), "-", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[Phi]3\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False]}],
              SequenceForm[ 
                Format[ "\[Phi]3"], 
                SequenceForm[ 
                  Superscript[ "9"]], 
                SequenceForm[ 
                  Superscript[ "9"]], 
                SequenceForm[ 
                  Superscript[ "9"]]],
              Editable->False]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", "v0", " ", 
        RowBox[{"(", 
          RowBox[{\(60\ cr[2]\^2\), "+", \(18\ cr[3]\), "-", 
            RowBox[{"18", " ", \(cr[2]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"3", " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]]],
                    Editable->False], ")"}], "2"]}], "-", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[Phi]4\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\^"9"\),
                    Superscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Superscript[ "9"]],
                  Editable->False]}],
              SequenceForm[ 
                Format[ "\[Phi]4"], 
                SequenceForm[ 
                  Superscript[ "9"]], 
                SequenceForm[ 
                  Superscript[ "9"]], 
                SequenceForm[ 
                  Superscript[ "9"]], 
                SequenceForm[ 
                  Superscript[ "9"]]],
              Editable->False]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Kappa]\_4\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo65[\([5]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(o\^2\), " ", 
      RowBox[{"(", 
        RowBox[{\(96\ cr[2]\^2\), "+", \(24\ cr[3]\), "-", 
          RowBox[{"24", " ", \(cr[2]\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]]],
                Editable->False], ")"}]}], "+", 
          RowBox[{"3", " ", 
            SuperscriptBox[
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}], "2"]}], "-", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(cumulantw = Drop[foo65, 1];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cumulantw // InputForm\)], "Input"],

Cell["\<\
{v0 + o*(cr[0] + cr[2] + v0^2*cr[2] + td[al1, au1]) + 
  o^2*(v0^3*(2*cr[2]^2 + cr[3]) + v0*(cr[1] + 2*cr[0]*cr[2] + 
      6*cr[2]^2 + 3*cr[3] - 2*td[al1, au2]*td[al2, au1] + 
      td[al1, au1]*(2*cr[2] - tp3[9, 9, 9]/2) - 
      cr[2]*tp3[9, 9, 9] - (5*tp3[9, 9, al1]*tp3[9, 9, au1])/8 + 
      td[au1, au2]*tp3[9, al1, al2] - 
      (tp3[9, al1, au2]*tp3[9, al2, au1])/2 + tp4[9, 9, al1, au1]/
       4)), 1 + o*v0*(4*cr[2] - tp3[9, 9, 9]) + 
  o^2*(2*cr[1] + 4*cr[0]*cr[2] + 14*cr[2]^2 + 6*cr[3] - 
    2*td[al1, au2]*td[al2, au1] + td[al1, au1]*
     (4*cr[2] - tp3[9, 9, 9]) - 2*cr[2]*tp3[9, 9, 9] - 
    tp3[9, 9, al1]*tp3[9, 9, au1] + 2*td[au1, au2]*
     tp3[9, al1, al2] - tp3[9, al1, au2]*tp3[9, al2, au1] + 
    v0^2*(16*cr[2]^2 + 6*cr[3] - 4*cr[2]*tp3[9, 9, 9] + 
      tp3[9, 9, 9]^2 + (tp3[9, 9, al1]*tp3[9, 9, au1])/4 - 
      tp4[9, 9, 9, 9]/2) + tp4[9, 9, al1, au1]/2), 
 o*(6*cr[2] - tp3[9, 9, 9]) + o^2*v0*(60*cr[2]^2 + 18*cr[3] - 
    18*cr[2]*tp3[9, 9, 9] + 3*tp3[9, 9, 9]^2 - tp4[9, 9, 9, 9]), 
 o^2*(96*cr[2]^2 + 24*cr[3] - 24*cr[2]*tp3[9, 9, 9] + 
   3*tp3[9, 9, 9]^2 - tp4[9, 9, 9, 9])}\
\>", "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["distribution function of w", "Subsection"],

Cell[TextData[{
  "The Cornish-Fisher expansion for the standardized random variable is taken \
from Johnson and Kotz (1994) as shown in \"cfexpx\" below. We first obtain \
the same expansion for nonstandardized variable as shown in \"cfexpw\", and \
apply it to the cumulants of w. This gives the distribution function of w, \
and we obtain ",
  Cell[BoxData[
      \(TraditionalForm\`zformula = \(\[CapitalPhi]\^\(-1\)\)(
          Pr {W \[LessEqual] w | v0})\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]\^\(-1\)\)]],
  " is the quantile function of the standard normal distribution. The same \
expression, but without MathTensor notation, is also given in \"zform\". \
Finally, the scaling by the factor \"tau\" is applied to these results, and \
zc-formula is stored in \"zformulatau\" as well as in \"zformtau\"."
}], "Text"],

Cell[CellGroupData[{

Cell["Cornish-Fisher expansion  (p.66 of Johnson and Kotz 1994).", \
"Subsubsection"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`cfexpx = U(X\_a)\)]],
  " in p.66 of JK94 is for the standardized distribution. We assume the \
cumulants are ",
  Cell[BoxData[
      \(TraditionalForm\`kx1 = 0, kx2 = 1, kx3 = O(n\^\(\(-1\)/2\)), \ 
      kx4 = O(n\^\(-1\)), kx5, 
      kx6, \(\(...\)\(=\)\(\(O(n\^\(\(-3\)/2\))\)\(.\)\)\)\)]],
  "  The following expression is defined by ",
  Cell[BoxData[
      \(TraditionalForm\`Pr {X\  \[LessEqual] \ x}\  = \ \[CapitalPhi](
          cfexpx)\)]],
  ", or ",
  Cell[BoxData[
      \(TraditionalForm\`cfexpx = \(\[CapitalPhi]\^\(-1\)\)(
          Pr {X \[LessEqual] x})\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(cfexpx = 
        x\  - \ \(1\/6\) \((x\^2 - 1)\)\ kx[3] - \(1\/24\) \((x\^3 - 3  x)\) 
            kx[4]\  + \ \(1\/36\) \((4  x\^3 - 7  x)\) kx[3]\^2;\)\)], "Input"],

Cell[TextData[{
  "For w,  the cumulants are ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            
            FormBox[\(kw1 = O(1), 
              kw2 = 1 + O(n\^\(\(-1\)/2\)), \(\(kw3\)\(=\)\)\),
              "TraditionalForm"], \(O(n\^\(\(-1\)/2\))\)}], ",", 
          " ", \(kw4 = \(\(O(n\^\(-1\))\)\(.\)\)\)}], TraditionalForm]]],
  " We first standardize w and apply cfexpx to the standardized w to get ",
  Cell[BoxData[
      \(TraditionalForm\`cfexpw = \(\[CapitalPhi]\^\(-1\)\)(
          Pr {W \[LessEqual] w})\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(rule70 = {x \[Rule] \(w - kw[1]\)\/Sqrt[kw[2]]};\)\)], "Input"],

Cell[BoxData[
    \(\(rule71 = {kx[1] \[Rule] 0, kx[2] \[Rule] 1, 
          kx[3] \[Rule] kw[3]\/kw[2]\^\(3/2\), 
          kx[4] \[Rule] kw[4]\/kw[2]\^2};\)\)], "Input"],

Cell[BoxData[
    \(\(rule72 = {kw[1] \[Rule] aw1, kw[2] \[Rule] 1 + o\ aw2, 
          kw[3] \[Rule] o\ aw3, kw[4] \[Rule] o\^2\ aw4};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rule73 = 
      Simplify[\(Solve[\((x /. rule70)\) \[Equal] x, 
            w]\)[\([1]\)]]\)], "Input"],

Cell[BoxData[
    \({w \[Rule] kw[1] + x\ \@kw[2]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cfexpw = gets2[\(cfexpx /. Join[rule70, rule71]\) /. rule72]\)], "Input"],

Cell[BoxData[
    \(\(-aw1\) + 
      1\/6\ o\ \((aw3\ \((1 - \((aw1 - w)\)\^2)\) + 
            3\ aw2\ \((aw1 - w)\))\) + w + 
      1\/72\ o\^2\ \((27\ aw2\^2\ \((\(-aw1\) + w)\) + 
            6\ aw2\ aw3\ \((\(-3\) + 5\ aw1\^2 - 10\ aw1\ w + 5\ w\^2)\) + 
            3\ aw4\ \((\((aw1 - w)\)\^3 + 3\ \((\(-aw1\) + w)\))\) + 
            2\ aw3\^2\ \((7\ \((aw1 - w)\) + 
                  4\ \((\(-aw1\) + w)\)\^3)\))\)\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Cornish-Fisher expansion of w", "Subsubsection"],

Cell["We apply cfexpw to cumulantw.", "Text"],

Cell[BoxData[
    \(\(aw = 
        Simplify[\((cumulantw - {0, 1, 0, 0})\)/{1, o, o, 
              o\^2}];\)\)], "Input"],

Cell[BoxData[
    \(RuleUnique[rulecumaw1, aw1, aw[\([1]\)]]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[rulecumaw2, aw2, aw[\([2]\)]]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[rulecumaw3, aw3, aw[\([3]\)]]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[rulecumaw4, aw4, aw[\([4]\)]]\)], "Input"],

Cell[BoxData[
    \(func75[exp_, rule_] := tgeto2[ApplyRules[exp, rule]]\)], "Input"],

Cell[BoxData[
    \(\(foo75 = 
        func75[func75[func75[func75[cfexpw, rulecumaw1], rulecumaw2], 
            rulecumaw3], rulecumaw4];\)\)], "Input"],

Cell[TextData[{
  "The following zformula is defined as ",
  Cell[BoxData[
      \(TraditionalForm\`zformula = \(\[CapitalPhi]\^\(-1\)\)(
          Pr {W \[LessEqual] w})\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(zformula = Collect[foo75, {o, w, v0}, tsimpp]\)], "Input"],

Cell[BoxData[
    RowBox[{\(-v0\), "+", "w", "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{\(-cr[0]\), "-", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"d\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\_"p'"\),
                      Subscript[ "p'"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"p'"\),
                      Superscript[ "p'"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "d"], 
                Format[ al1], 
                Format[ au1]],
              Editable->False], "+", 
            RowBox[{\(w\^2\), " ", 
              RowBox[{"(", 
                RowBox[{\(-cr[2]\), "+", 
                  RowBox[{\(1\/6\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "-", 
            RowBox[{\(1\/6\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/3\), " ", \(v0\^2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/6\), " ", "v0", " ", "w", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(v0\^3\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(1\/18\), " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              FormBox["\<\"\[Phi]3\"\>",
                                "StandardForm"],
                              Format], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False]}],
                          SequenceForm[ 
                            Format[ "\[Phi]3"], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]]],
                          Editable->False], ")"}], "2"]}], "+", 
                  RowBox[{\(1\/8\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/8\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{"v0", " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/6\), " ", \(cr[0]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/6\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(5\/72\), " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              FormBox["\<\"\[Phi]3\"\>",
                                "StandardForm"],
                              Format], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False]}],
                          SequenceForm[ 
                            Format[ "\[Phi]3"], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]]],
                          Editable->False], ")"}], "2"]}], "+", 
                  RowBox[{\(1\/8\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/24\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{"v0", " ", \(w\^2\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(-\(1\/6\)\), " ", \(cr[2]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/24\), " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              FormBox["\<\"\[Phi]3\"\>",
                                "StandardForm"],
                              Format], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False]}],
                          SequenceForm[ 
                            Format[ "\[Phi]3"], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]]],
                          Editable->False], ")"}], "2"]}], "+", 
                  RowBox[{\(1\/24\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{\(w\^3\), " ", 
              RowBox[{"(", 
                RowBox[{\(-cr[3]\), "-", 
                  RowBox[{\(1\/3\), " ", \(cr[2]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/72\), " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              FormBox["\<\"\[Phi]3\"\>",
                                "StandardForm"],
                              Format], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False]}],
                          SequenceForm[ 
                            Format[ "\[Phi]3"], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]]],
                          Editable->False], ")"}], "2"]}], "+", 
                  RowBox[{\(1\/24\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{"w", " ", 
              RowBox[{"(", 
                RowBox[{\(-cr[1]\), "+", 
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/3\), " ", \(cr[0]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/6\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(13\/72\), " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              FormBox["\<\"\[Phi]3\"\>",
                                "StandardForm"],
                              Format], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False]}],
                          SequenceForm[ 
                            Format[ "\[Phi]3"], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]]],
                          Editable->False], ")"}], "2"]}], "+", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ al2]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(v0\^2\), " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{\(-\(1\/8\)\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/24\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}]}], ")"}]}], "-", 
                  RowBox[{\(1\/8\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/4\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}]}]}], ")"}]}]}], 
          ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(zformula // InputForm\)], "Input"],

Cell["\<\
-v0 + w + o*(-cr[0] - td[al1, au1] + 
   w^2*(-cr[2] + tp3[9, 9, 9]/6) - tp3[9, 9, 9]/6 - 
   (v0^2*tp3[9, 9, 9])/3 + (v0*w*tp3[9, 9, 9])/6) + 
 o^2*(v0^3*(tp3[9, 9, 9]^2/18 + (tp3[9, 9, al1]*tp3[9, 9, au1])/8 - 
     tp4[9, 9, 9, 9]/8) + v0*(td[al1, au2]*td[al2, au1] - 
     (cr[0]*tp3[9, 9, 9])/6 - (td[al1, au1]*tp3[9, 9, 9])/6 + 
     (5*tp3[9, 9, 9]^2)/72 + (tp3[9, 9, al1]*tp3[9, 9, au1])/8 - 
     tp4[9, 9, 9, 9]/24) + v0*w^2*(-(cr[2]*tp3[9, 9, 9])/6 - 
     tp3[9, 9, 9]^2/24 + tp4[9, 9, 9, 9]/24) + 
   w^3*(-cr[3] - (cr[2]*tp3[9, 9, 9])/3 - tp3[9, 9, 9]^2/72 + 
     tp4[9, 9, 9, 9]/24) + w*(-cr[1] + td[al1, au2]*td[al2, au1] - 
     (cr[0]*tp3[9, 9, 9])/3 + (td[al1, au1]*tp3[9, 9, 9])/6 + 
     (13*tp3[9, 9, 9]^2)/72 + (tp3[9, 9, al1]*tp3[9, 9, au1])/2 - 
     td[au1, au2]*tp3[9, al1, al2] + 
     (tp3[9, al1, au2]*tp3[9, al2, au1])/2 + 
     v0^2*(-(tp3[9, 9, al1]*tp3[9, 9, au1])/8 + 
       tp4[9, 9, 9, 9]/24) - tp4[9, 9, 9, 9]/8 - 
     tp4[9, 9, al1, au1]/4))\
\>", "Output"]
}, Open  ]],

Cell[TextData[{
  "Get the coefficients of ",
  Cell[BoxData[
      \(TraditionalForm\`\(w\^i\) v0\^j\)]],
  " for zformula."
}], "Text"],

Cell[BoxData[
    \(\(foo76 = 
        Collect[CoefficientList[zformula, {w, v0}], o, tsimpp];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dimensions[foo76]\)], "Input"],

Cell[BoxData[
    \({4, 4}\)], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(w\^0\) v0\^0\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo76[\([1, 1]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{"o", " ", 
      RowBox[{"(", 
        RowBox[{\(-cr[0]\), "-", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al1], 
              Format[ au1]],
            Editable->False], "-", 
          RowBox[{\(1\/6\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]]],
                Editable->False], ")"}]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(w\^0\) v0\^1\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo76[\([1, 2]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(-1\), "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/6\), " ", \(cr[0]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/6\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(5\/72\), " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]]],
                    Editable->False], ")"}], "2"]}], "+", 
            RowBox[{\(1\/8\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/24\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(w\^0\) v0\^2\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo76[\([1, 3]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(-\(1\/3\)\), " ", "o", " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"\[Phi]3\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            InterpretationBox[
              InterpretationBox[\(\[Null]\^"9"\),
                Superscript[ "9"],
                Editable->False],
              SequenceForm[ 
                Superscript[ "9"]],
              Editable->False], "\[InvisibleSpace]", 
            InterpretationBox[
              InterpretationBox[\(\[Null]\^"9"\),
                Superscript[ "9"],
                Editable->False],
              SequenceForm[ 
                Superscript[ "9"]],
              Editable->False], "\[InvisibleSpace]", 
            InterpretationBox[
              InterpretationBox[\(\[Null]\^"9"\),
                Superscript[ "9"],
                Editable->False],
              SequenceForm[ 
                Superscript[ "9"]],
              Editable->False]}],
          SequenceForm[ 
            Format[ "\[Phi]3"], 
            SequenceForm[ 
              Superscript[ "9"]], 
            SequenceForm[ 
              Superscript[ "9"]], 
            SequenceForm[ 
              Superscript[ "9"]]],
          Editable->False], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(w\^0\) v0\^3\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo76[\([1, 4]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(o\^2\), " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{\(1\/18\), " ", 
            SuperscriptBox[
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}], "2"]}], "+", 
          RowBox[{\(1\/8\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"p'"\),
                        Subscript[ "p'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  Format[ al1]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"p'"\),
                        Superscript[ "p'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  Format[ au1]],
                Editable->False], ")"}]}], "-", 
          RowBox[{\(1\/8\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]4\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False]}],
                SequenceForm[ 
                  Format[ "\[Phi]4"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]]],
                Editable->False], ")"}]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(w\^1\) v0\^0\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo76[\([2, 1]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{"1", "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{\(-cr[1]\), "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/3\), " ", \(cr[0]\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/6\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(13\/72\), " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[Phi]3\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\^"9"\),
                          Superscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Superscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "\[Phi]3"], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]], 
                      SequenceForm[ 
                        Superscript[ "9"]]],
                    Editable->False], ")"}], "2"]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ al2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/8\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al1], 
                    Format[ au1]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(w\^1\) v0\^1\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo76[\([2, 2]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(1\/6\), " ", "o", " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"\[Phi]3\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            InterpretationBox[
              InterpretationBox[\(\[Null]\^"9"\),
                Superscript[ "9"],
                Editable->False],
              SequenceForm[ 
                Superscript[ "9"]],
              Editable->False], "\[InvisibleSpace]", 
            InterpretationBox[
              InterpretationBox[\(\[Null]\^"9"\),
                Superscript[ "9"],
                Editable->False],
              SequenceForm[ 
                Superscript[ "9"]],
              Editable->False], "\[InvisibleSpace]", 
            InterpretationBox[
              InterpretationBox[\(\[Null]\^"9"\),
                Superscript[ "9"],
                Editable->False],
              SequenceForm[ 
                Superscript[ "9"]],
              Editable->False]}],
          SequenceForm[ 
            Format[ "\[Phi]3"], 
            SequenceForm[ 
              Superscript[ "9"]], 
            SequenceForm[ 
              Superscript[ "9"]], 
            SequenceForm[ 
              Superscript[ "9"]]],
          Editable->False], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(w\^1\) v0\^2\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo76[\([2, 3]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(o\^2\), " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{\(-\(1\/8\)\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\_"p'"\),
                        Subscript[ "p'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  Format[ al1]],
                Editable->False], ")"}], " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"p'"\),
                        Superscript[ "p'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  Format[ au1]],
                Editable->False], ")"}]}], "+", 
          RowBox[{\(1\/24\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]4\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False]}],
                SequenceForm[ 
                  Format[ "\[Phi]4"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]]],
                Editable->False], ")"}]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(w\^1\) v0\^3\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo76[\([2, 4]\)]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(w\^2\) v0\^0\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo76[\([3, 1]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{"o", " ", 
      RowBox[{"(", 
        RowBox[{\(-cr[2]\), "+", 
          RowBox[{\(1\/6\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]]],
                Editable->False], ")"}]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(w\^2\) v0\^1\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo76[\([3, 2]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(o\^2\), " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{\(-\(1\/6\)\), " ", \(cr[2]\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]]],
                Editable->False], ")"}]}], "-", 
          RowBox[{\(1\/24\), " ", 
            SuperscriptBox[
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}], "2"]}], "+", 
          RowBox[{\(1\/24\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]4\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False]}],
                SequenceForm[ 
                  Format[ "\[Phi]4"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]]],
                Editable->False], ")"}]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(w\^2\) v0\^2\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo76[\([3, 3]\)]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(w\^2\) v0\^3\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo76[\([3, 4]\)]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(w\^3\) v0\^0\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo76[\([4, 1]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{\(o\^2\), " ", 
      RowBox[{"(", 
        RowBox[{\(-cr[3]\), "-", 
          RowBox[{\(1\/3\), " ", \(cr[2]\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]3\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False]}],
                SequenceForm[ 
                  Format[ "\[Phi]3"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]]],
                Editable->False], ")"}]}], "-", 
          RowBox[{\(1\/72\), " ", 
            SuperscriptBox[
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}], "2"]}], "+", 
          RowBox[{\(1\/24\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"\[Phi]4\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False], "\[InvisibleSpace]", 
                  InterpretationBox[
                    InterpretationBox[\(\[Null]\^"9"\),
                      Superscript[ "9"],
                      Editable->False],
                    SequenceForm[ 
                      Superscript[ "9"]],
                    Editable->False]}],
                SequenceForm[ 
                  Format[ "\[Phi]4"], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]], 
                  SequenceForm[ 
                    Superscript[ "9"]]],
                Editable->False], ")"}]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(w\^3\) v0\^1\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo76[\([4, 2]\)]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(w\^3\) v0\^2\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo76[\([4, 3]\)]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(w\^3\) v0\^3\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo76[\([4, 4]\)]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["zc-formula using a simplified notation", "Subsubsection"],

Cell["\<\
In the below, the tensor symbols are replaced by regular symbols.\
\>", "Text"],

Cell[BoxData[
    \(RuleUnique[rule80a, td[al1_, au1_], Daa, PairaQ[al1, au1]]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[rule80b, td[al1_, au2_] td[al2_, au1_], Dab2, 
      PairaQ[{al1, al2}, {au1, au2}]]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[rule80c, tp3[9, 9, 9], P999]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[rule80d, tp4[9, 9, 9, 9], P9999]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[rule80e, tp3[9, 9, al1_] tp3[9, 9, au1_], P99a2, 
      PairaQ[al1, au1]]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[rule80f, td[au1_, au2_] tp3[9, al1_, al2_], DabP9ab, 
      PairaQ[{al1, al2}, {au1, au2}]]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[rule80g, tp3[9, al1_, au2_] tp3[9, al2_, au1_], P9ab2, 
      PairaQ[{al1, al2}, {au1, au2}]]\)], "Input"],

Cell[BoxData[
    \(RuleUnique[rule80h, tp4[9, 9, al1_, au1_], P99aa, 
      PairaQ[al1, au1]]\)], "Input"],

Cell[BoxData[
    \(\(rule81 = {cr[0] \[Rule] c0, cr[1] \[Rule] c1, cr[2] \[Rule] c2, 
          cr[3] \[Rule] c3};\)\)], "Input"],

Cell["\<\
The following expression of \"zform\" is equivalent to \"zformula\", but \
without the tensor symbols so that we can use it without MathTensor.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(zform = 
      Collect[ApplyRules[
            zformula, {rule80a, rule80b, rule80c, rule80d, rule80e, rule80f, 
              rule80g, rule80h}] /. rule81, {o, w, v0}]\)], "Input"],

Cell[BoxData[
    \(\(-v0\) + w + 
      o\ \((\(-c0\) - Daa - 
            P999\/6 - \(P999\ v0\^2\)\/3 + \(P999\ v0\ w\)\/6 + \((\(-c2\) + 
                  P999\/6)\)\ w\^2)\) + 
      o\^2\ \((\((Dab2 - \(c0\ P999\)\/6 - \(Daa\ P999\)\/6 + \(5\ \
P999\^2\)\/72 - P9999\/24 + P99a2\/8)\)\ v0 + \((P999\^2\/18 - P9999\/8 + 
                  P99a2\/8)\)\ v0\^3 + \((\(-c1\) + Dab2 - 
                  DabP9ab - \(c0\ P999\)\/3 + \(Daa\ P999\)\/6 + \(13\ \
P999\^2\)\/72 - P9999\/8 + P99a2\/2 - P99aa\/4 + 
                  P9ab2\/2 + \((P9999\/24 - 
                        P99a2\/8)\)\ v0\^2)\)\ w + \((\(-\(\(c2\ \
P999\)\/6\)\) - P999\^2\/24 + 
                  P9999\/24)\)\ v0\ w\^2 + \((\(-c3\) - \(c2\ P999\)\/3 - 
                  P999\^2\/72 + P9999\/24)\)\ w\^3)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(zform // InputForm\)], "Input"],

Cell["\<\
-v0 + w + o*(-c0 - Daa - P999/6 - (P999*v0^2)/3 + (P999*v0*w)/6 + 
   (-c2 + P999/6)*w^2) + 
 o^2*((Dab2 - (c0*P999)/6 - (Daa*P999)/6 + (5*P999^2)/72 - 
     P9999/24 + P99a2/8)*v0 + (P999^2/18 - P9999/8 + P99a2/8)*
    v0^3 + (-c1 + Dab2 - DabP9ab - (c0*P999)/3 + (Daa*P999)/6 + 
     (13*P999^2)/72 - P9999/8 + P99a2/2 - P99aa/4 + P9ab2/2 + 
     (P9999/24 - P99a2/8)*v0^2)*w + 
   (-(c2*P999)/6 - P999^2/24 + P9999/24)*v0*w^2 + 
   (-c3 - (c2*P999)/3 - P999^2/72 + P9999/24)*w^3)\
\>", "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["scaling by the factor \"tau\".", "Subsubsection"],

Cell[TextData[{
  "When scaling the problem by the factor \[Tau], the expression of the \
z-formula changes. First, the ",
  Cell[BoxData[
      \(TraditionalForm\`O(1)\)]],
  " term such as w and v0 are multiplied by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Tau]\^\(-1\)\)\(.\)\)\)]],
  " On the other hand, ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(\(-1\)/2\))\)]],
  " terms such as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\^ijk\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`d\^ab\)]],
  "are multiplied by \[Tau], ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(-1\))\)]],
  "terms such as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\^ijkl\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`e\^abc\)]],
  "are by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\^2\)]],
  "  The cr[r] coefficient for modified signed distance is multiplied by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\^\(r - 1\)\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(rule85a = {w \[Rule] w/tau, v0 \[Rule] v0/tau};\)\)], "Input"],

Cell[BoxData[
    \(\(rule85b = {tp3[ala_, alb_, alc_] \[Rule] tau\ tp3[ala, alb, alc], 
          td[ala_, alb_] \[Rule] tau\ td[ala, alb]};\)\)], "Input"],

Cell[BoxData[
    \(\(rule85c = {tp4[ala_, alb_, alc_, ald_] \[Rule] \(tau\^2\) 
              tp4[ala, alb, alc, ald], 
          te[ala_, alb_, alc_] \[Rule] \(tau\^2\) 
              te[ala, alb, alc]};\)\)], "Input"],

Cell[BoxData[
    \(\(rule85d = {cr[r_] \[Rule] cr[r]\ tau\^\(r - 1\)};\)\)], "Input"],

Cell[BoxData[
    \(\(rule85 = Join[rule85a, rule85b, rule85c, rule85d];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(zformulatau = Collect[zformula /. rule85, {tau, o, w, v0}]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(1\/tau\), 
        RowBox[{"(", 
          RowBox[{\(-v0\), "+", "w", "+", 
            RowBox[{"o", " ", 
              RowBox[{"(", 
                RowBox[{\(-cr[0]\), "+", 
                  RowBox[{\(w\^2\), " ", 
                    RowBox[{"(", 
                      RowBox[{\(-cr[2]\), "+", 
                        RowBox[{\(1\/6\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}]}], ")"}]}], "-", 
                  RowBox[{\(1\/3\), " ", \(v0\^2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/6\), " ", "v0", " ", "w", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{\(o\^2\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(-\(1\/6\)\), " ", "v0", " ", \(cr[0]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"w", " ", 
                    RowBox[{"(", 
                      RowBox[{\(-cr[1]\), "-", 
                        RowBox[{\(1\/3\), " ", \(cr[0]\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(v0\^2\), " ", 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{\(-\(1\/8\)\), " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]3\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\_"p'"\),
                                        Subscript[ "p'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]3"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      Format[ al1]],
                                    Editable->False], ")"}], " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]3\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\^"p'"\),
                                        Superscript[ "p'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]3"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      Format[ au1]],
                                    Editable->False], ")"}]}], "+", 
                              RowBox[{\(1\/24\), " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]4\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]4"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]]],
                                    Editable->False], ")"}]}]}], ")"}]}]}], 
                      ")"}]}], "+", 
                  RowBox[{\(v0\^3\), " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{\(1\/18\), " ", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    FormBox["\<\"\[Phi]3\"\>",
                                      "StandardForm"],
                                    Format], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False]}],
                                SequenceForm[ 
                                  Format[ "\[Phi]3"], 
                                  SequenceForm[ 
                                    Superscript[ "9"]], 
                                  SequenceForm[ 
                                    Superscript[ "9"]], 
                                  SequenceForm[ 
                                    Superscript[ "9"]]],
                                Editable->False], ")"}], "2"]}], "+", 
                        RowBox[{\(1\/8\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/8\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}]}], ")"}]}], "+", 
                  RowBox[{"v0", " ", \(w\^2\), " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{\(-\(1\/6\)\), " ", \(cr[2]\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/24\), " ", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    FormBox["\<\"\[Phi]3\"\>",
                                      "StandardForm"],
                                    Format], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False]}],
                                SequenceForm[ 
                                  Format[ "\[Phi]3"], 
                                  SequenceForm[ 
                                    Superscript[ "9"]], 
                                  SequenceForm[ 
                                    Superscript[ "9"]], 
                                  SequenceForm[ 
                                    Superscript[ "9"]]],
                                Editable->False], ")"}], "2"]}], "+", 
                        RowBox[{\(1\/24\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}]}], ")"}]}], "+", 
                  RowBox[{\(w\^3\), " ", 
                    RowBox[{"(", 
                      RowBox[{\(-cr[3]\), "-", 
                        RowBox[{\(1\/3\), " ", \(cr[2]\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/72\), " ", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    FormBox["\<\"\[Phi]3\"\>",
                                      "StandardForm"],
                                    Format], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False]}],
                                SequenceForm[ 
                                  Format[ "\[Phi]3"], 
                                  SequenceForm[ 
                                    Superscript[ "9"]], 
                                  SequenceForm[ 
                                    Superscript[ "9"]], 
                                  SequenceForm[ 
                                    Superscript[ "9"]]],
                                Editable->False], ")"}], "2"]}], "+", 
                        RowBox[{\(1\/24\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}], "+", 
      RowBox[{"tau", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"o", " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/6\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{\(o\^2\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"v0", " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al1], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al2], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/6\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al1], 
                                Format[ au1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(5\/72\), " ", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    FormBox["\<\"\[Phi]3\"\>",
                                      "StandardForm"],
                                    Format], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False]}],
                                SequenceForm[ 
                                  Format[ "\[Phi]3"], 
                                  SequenceForm[ 
                                    Superscript[ "9"]], 
                                  SequenceForm[ 
                                    Superscript[ "9"]], 
                                  SequenceForm[ 
                                    Superscript[ "9"]]],
                                Editable->False], ")"}], "2"]}], "+", 
                        RowBox[{\(1\/8\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/24\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}]}], ")"}]}], "+", 
                  RowBox[{"w", " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al1], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al2], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/6\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al1], 
                                Format[ au1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(13\/72\), " ", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    FormBox["\<\"\[Phi]3\"\>",
                                      "StandardForm"],
                                    Format], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False]}],
                                SequenceForm[ 
                                  Format[ "\[Phi]3"], 
                                  SequenceForm[ 
                                    Superscript[ "9"]], 
                                  SequenceForm[ 
                                    Superscript[ "9"]], 
                                  SequenceForm[ 
                                    Superscript[ "9"]]],
                                Editable->False], ")"}], "2"]}], "+", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al1], 
                                Format[ al2]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al1], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al2], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/8\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/4\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al1], 
                                Format[ au1]],
                              Editable->False], ")"}]}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(zformulatau // InputForm\)], "Input"],

Cell["\<\
(-v0 + w + o*(-cr[0] + w^2*(-cr[2] + tp3[9, 9, 9]/6) - 
     (v0^2*tp3[9, 9, 9])/3 + (v0*w*tp3[9, 9, 9])/6) + 
   o^2*(-(v0*cr[0]*tp3[9, 9, 9])/6 + 
     w*(-cr[1] - (cr[0]*tp3[9, 9, 9])/3 + 
       v0^2*(-(tp3[9, 9, al1]*tp3[9, 9, au1])/8 + 
         tp4[9, 9, 9, 9]/24)) + v0^3*(tp3[9, 9, 9]^2/18 + 
       (tp3[9, 9, al1]*tp3[9, 9, au1])/8 - tp4[9, 9, 9, 9]/8) + 
     v0*w^2*(-(cr[2]*tp3[9, 9, 9])/6 - tp3[9, 9, 9]^2/24 + 
       tp4[9, 9, 9, 9]/24) + w^3*(-cr[3] - (cr[2]*tp3[9, 9, 9])/3 - 
       tp3[9, 9, 9]^2/72 + tp4[9, 9, 9, 9]/24)))/tau + 
 tau*(o*(-td[al1, au1] - tp3[9, 9, 9]/6) + 
   o^2*(v0*(td[al1, au2]*td[al2, au1] - (td[al1, au1]*tp3[9, 9, 9])/
        6 + (5*tp3[9, 9, 9]^2)/72 + (tp3[9, 9, al1]*tp3[9, 9, au1])/
        8 - tp4[9, 9, 9, 9]/24) + w*(td[al1, au2]*td[al2, au1] + 
       (td[al1, au1]*tp3[9, 9, 9])/6 + (13*tp3[9, 9, 9]^2)/72 + 
       (tp3[9, 9, al1]*tp3[9, 9, au1])/2 - td[au1, au2]*
        tp3[9, al1, al2] + (tp3[9, al1, au2]*tp3[9, al2, au1])/2 - 
       tp4[9, 9, 9, 9]/8 - tp4[9, 9, al1, au1]/4)))\
\>", "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(zformtau = 
      Collect[ApplyRules[
            zformulatau, {rule80a, rule80b, rule80c, rule80d, rule80e, 
              rule80f, rule80g, rule80h}] /. rule81, {tau, o, w, 
          v0}]\)], "Input"],

Cell[BoxData[
    \(tau\ \((o\ \((\(-Daa\) - P999\/6)\) + 
            o\^2\ \((\((Dab2 - \(Daa\ P999\)\/6 + \(5\ P999\^2\)\/72 - 
                        P9999\/24 + P99a2\/8)\)\ v0 + \((Dab2 - 
                        DabP9ab + \(Daa\ P999\)\/6 + \(13\ P999\^2\)\/72 - 
                        P9999\/8 + P99a2\/2 - P99aa\/4 + 
                        P9ab2\/2)\)\ w)\))\) + \(1\/tau\) \((\(-v0\) + w + 
            o\ \((\(-c0\) - \(P999\ v0\^2\)\/3 + \(P999\ v0\ w\)\/6 + \
\((\(-c2\) + P999\/6)\)\ w\^2)\) + 
            o\^2\ \((\(-\(1\/6\)\)\ c0\ P999\ v0 + \((P999\^2\/18 - 
                        P9999\/8 + 
                        P99a2\/8)\)\ v0\^3 + \((\(-c1\) - \(c0\ P999\)\/3 + \
\((P9999\/24 - P99a2\/8)\)\ v0\^2)\)\ w + \((\(-\(\(c2\ P999\)\/6\)\) - 
                        P999\^2\/24 + 
                        P9999\/24)\)\ v0\ w\^2 + \((\(-c3\) - \(c2\ P999\)\/3 \
- P999\^2\/72 + P9999\/24)\)\ w\^3)\))\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(zformtau // InputForm\)], "Input"],

Cell["\<\
tau*(o*(-Daa - P999/6) + 
   o^2*((Dab2 - (Daa*P999)/6 + (5*P999^2)/72 - P9999/24 + P99a2/8)*
      v0 + (Dab2 - DabP9ab + (Daa*P999)/6 + (13*P999^2)/72 - 
       P9999/8 + P99a2/2 - P99aa/4 + P9ab2/2)*w)) + 
 (-v0 + w + o*(-c0 - (P999*v0^2)/3 + (P999*v0*w)/6 + 
     (-c2 + P999/6)*w^2) + o^2*(-(c0*P999*v0)/6 + 
     (P999^2/18 - P9999/8 + P99a2/8)*v0^3 + 
     (-c1 - (c0*P999)/3 + (P9999/24 - P99a2/8)*v0^2)*w + 
     (-(c2*P999)/6 - P999^2/24 + P9999/24)*v0*w^2 + 
     (-c3 - (c2*P999)/3 - P999^2/72 + P9999/24)*w^3))/tau\
\>", "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["local coordinates at the projection", "Subsection"],

Cell[TextData[{
  "We consider a local coordinate \[CapitalDelta]\[Eta] around a point \
\[Eta](u0,0) on the surface, where u0 indicates any specified value of u.  \
This will be used for u0 specifying the projection of y onto the surface. The \
change of variable \[Eta]\[LeftRightArrow]\[CapitalDelta]\[Eta]  is specified \
by  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_a = \(\[Eta]\_a\)(u0, 
            0)\  + \ \(\(B\_a\^b\)(u0)\) \[CapitalDelta]\[Eta]\_b\)]],
  " for each u0.  The expression for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_\(a'\)\)]],
  " is given in \"rule93\", and that for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_9\)]],
  " is in \"rule94\". The surface is expressed as ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Eta]\_dim = \(-\ 
              d\&^\^\(a' b'\)\) \(\[CapitalDelta]\[Eta]\_\(a'\)\) \
\[CapitalDelta]\[Eta]\_\(b'\) - \ \(e\&^\^\(a' b' 
                  c'\)\) \(\[CapitalDelta]\[Eta]\_\(a'\)\) \(\[CapitalDelta]\
\[Eta]\_\(b'\)\) \[CapitalDelta]\[Eta]\_\(c'\)\)]],
  ", where the coefficients are shown in foo101 and foo102. Next,  the \
expression for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]\^2\( \[Phi](\[Eta])\)\)\(\ \)\)\/\(\
\[PartialD]\ \[Eta]\_p \[PartialD]\ \[Eta]\_q\)\( | \_\(\[Eta] = \[Eta](u0) + 
                B\[CapitalDelta]\[Eta]\)\)\ \(\(B\_p\^a\)(u0)\) \(\(B\_q\^b\)(
            u0)\)\)]],
  " is obtained and stored in foo114[ua,ub]. This is equated with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\&^\^ab + \(\[Phi]\&^\^abc\) \[CapitalDelta]\
\[Eta]\_c + \(1\/2\) \(\[Phi]\&^\^abcd\) \(\[CapitalDelta]\[Eta]\_c\) \
\[CapitalDelta]\[Eta]\_d\)]],
  ", and the coefficients  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\&^\^ab\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\&^\^abc\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\&^\^abcd\)]],
  " are obtained in foo121. The inverse of the metric=",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\&^\_\(a' b'\) = \((\[Phi]\&^\^\(a' \
b'\))\)\^\(-1\)\)]],
  "is in rule131, which is used for ",
  Cell[BoxData[
      \(TraditionalForm\`foo132 = \(\[Phi]\&^\_\(a' b'\)\) 
          d\&^\^\(a' b'\)\)]],
  " . These conversion rules are summarized in \"rulesproj\". zc-formula \
evaluated at \[Eta](u0,0) is shown in zformulau0, and that for scaling tau is \
in zformulatauu0."
}], "Text"],

Cell[CellGroupData[{

Cell["the expression for the surface in the local coordinates", \
"Subsubsection"],

Cell[TextData[{
  "We use ",
  Cell[BoxData[
      \(TraditionalForm\`u0\_\(a'\)\)]],
  "for the ",
  Cell[BoxData[
      \(TraditionalForm\`u\_\(a'\)\)]],
  "-coordinate of the projection. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[ru0, "\<u0\>", {{1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"u0\"\) defined"\)], "Message"]
}, Open  ]],

Cell[TextData[{
  "Define local coordinates at the projection, and denote ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Eta]\_a\)]],
  ". The local coordinate ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Eta]\_a\)]],
  " is in the ",
  Cell[BoxData[
      \(TraditionalForm\`B\^a\)]],
  "direction. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[re, "\<\[CapitalDelta]\[Eta]\>", {{1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"\\[CapitalDelta]\\[Eta]\"\) defined"\)], "Message"]
}, Open  ]],

Cell[TextData[{
  "First, separate the type-a and 9 indices in the local parametrization at \
the projection. ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_a\)]],
  " in foo90 indicates the projection point, whereas foo90 itself indicates \
the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_a\)]],
  "-coordinates for a general point."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(se[la] + \ tB[la, ub]\ re[lb]\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"\[Eta]\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\_"a"\),
                Subscript[ "a"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ "\[Eta]"], 
          Format[ la]],
        Editable->False], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b"\),
                    Subscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ lb]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ la], 
              Format[ ub]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo90 = CanAll[sepa[se[la] + \ tB[la, ub]\ re[lb], lb]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"\[Eta]\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\_"a"\),
                Subscript[ "a"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ "\[Eta]"], 
          Format[ la]],
        Editable->False], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ la], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a"\),
                    Subscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ la], 
              Format[ au1]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["foo91 is foo90 for a=a'.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo91 = ApplyRules[foo90 /. {la \[Rule] ala}, rule1]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ ala], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["foo92 is foo90 for a=9.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo92 = ApplyRules[foo90 /. {la \[Rule] \(-9\)}, rule2]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Then, ",
  Cell[BoxData[
      \(TraditionalForm\`B\^a\)]],
  " is expanded by its expression. ",
  Cell[BoxData[
      \(TraditionalForm\`u\_\(a'\)\)]],
  "is now substituted by ",
  Cell[BoxData[
      \(TraditionalForm\`u0\_\(a'\)\)]],
  " to change the origin to the projection. Here we obtain ",
  Cell[BoxData[
      \(TraditionalForm\`foo93 = \[Eta]\_\(a'\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`foo94 = \[Eta]\_9\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo93 = 
      ApplyRules[foo91, {rule3, rule4, rule15, rule16}] /. 
        ru \[Rule] ru0\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"2", " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ ala], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ ala], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ ala], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ ala], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ala], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule93, se[ala_], foo93, IndexaQ[ala]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo94 = 
      ApplyRules[foo92, {rule3, rule4, rule15, rule16}] /. 
        ru \[Rule] ru0\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          InterpretationBox[
            InterpretationBox[\(\[Null]\_"9"\),
              Subscript[ "9"],
              Editable->False],
            SequenceForm[ 
              Subscript[ "9"]],
            Editable->False]}],
        SequenceForm[ 
          Format[ "\[CapitalDelta]\[Eta]"], 
          SequenceForm[ 
            Subscript[ "9"]]],
        Editable->False], "-", 
      RowBox[{"2", " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(3\/8\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule94, se[\(-9\)], foo94]\)], "Input"],

Cell[TextData[{
  "We will equate foo93 with foo95, and foo94 with foo96 below to derive the \
expression of the surface in the local coordinates. foo95 and foo96 define \
the surface with the origin at 0. First we consider ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_\(a'\)\)]],
  "direction."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo95 = tsimpp[ApplyRules[se[ala], rule1]]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          FormBox["\<\"u\"\>",
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\_"a'"\),
              Subscript[ "a'"],
              Editable->False],
            "StandardForm"],
          Format]}],
      SequenceForm[ 
        Format[ "u"], 
        Format[ ala]],
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Thus, ",
  Cell[BoxData[
      \(TraditionalForm\`u\_\(a'\)\)]],
  "= foo93 as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Eta]\_a\)]],
  ". We make it rule95."
}], "Text"],

Cell[BoxData[
    \(RuleUnique[rule95, ru[ala_], foo93]\)], "Input"],

Cell[TextData[{
  "Consider ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_9\)]],
  "direction."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo96 = ApplyRules[se[\(-9\)], rule2]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(-o\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u"], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Using the rule95, we get an expression of foo96 in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Eta]\_a\)]],
  "'s."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo97 = tgeto2[ApplyRules[foo96, rule95]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      TagBox[
                        FormBox[
                          InterpretationBox[\(\[Null]\_"p'"\),
                            Subscript[ "p'"],
                            Editable->False],
                          "StandardForm"],
                        Format]}],
                    SequenceForm[ 
                      Format[ "\[CapitalDelta]\[Eta]"], 
                      Format[ al1]],
                    Editable->False], ")"}]}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(-4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al3], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"4", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al3], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"e\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "e"], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"e\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "e"], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"e\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "e"], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"e\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "e"], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al3], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al3], 
                    Format[ au2]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Equate foo94\[Equal]foo97 to solve the expression of ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Eta]\_9\)]],
  " in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Eta]\_\(a'\)\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(foo98 = 
        CoefficientList[tsimpp[foo94 - foo97], re[\(-9\)]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[foo98]\)], "Input"],

Cell[BoxData[
    \(2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo98[\([1]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo98[\([2]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{"1", "+", 
      RowBox[{"4", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(3\/8\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al3], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/4\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The following foo99 gives an expression of ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Eta]\_9\)]],
  "in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Eta]\_\(a'\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo99 = \ 
      Collect[tgets2[\(-x\)/y, x, foo98[\([1]\)], y, 
          foo98[\([2]\)]], {re[al1] re[al2] re[al3], re[al1] re[al2], 
          ru0[al3]}]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(-o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(-o\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(-3\), " ", \(o\^2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"e\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r'"\),
                                Superscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "e"], 
                          Format[ au1], 
                          Format[ au2], 
                          Format[ au3]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r'"\),
                                Superscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au3]],
                        Editable->False], ")"}]}]}], ")"}]}]}], 
          ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "get the coefficients of ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[CapitalDelta]\[Eta]\_\(a'\)\), " ", 
          FormBox[\(\[CapitalDelta]\[Eta]\_\(b'\)\),
            "TraditionalForm"]}], TraditionalForm]]],
  " and  ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[CapitalDelta]\[Eta]\_\(a'\)\), " ", 
          
          FormBox[\(\(\[CapitalDelta]\[Eta]\_\(b'\)\) \[CapitalDelta]\[Eta]\_\
\(c'\)\),
            "TraditionalForm"]}], TraditionalForm]]],
  "  for ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Eta]\_9\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo100 = 
      Collect[CoefficientList[foo99 /. re[ala_] \[Rule] x, 
            x] /. {au1 \[Rule] aua, au2 \[Rule] aub, au3 \[Rule] auc, 
            au4 \[Rule] aud, al1 \[Rule] ala, al2 \[Rule] alb, 
            al3 \[Rule] alc, al4 \[Rule] ald}, o, tsimpp]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
        RowBox[{
          RowBox[{\(-o\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    FormBox["\<\"d\"\>",
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"a'"\),
                        Superscript[ "a'"],
                        Editable->False],
                      "StandardForm"],
                    Format], "\[InvisibleSpace]", 
                  TagBox[
                    FormBox[
                      InterpretationBox[\(\[Null]\^"b'"\),
                        Superscript[ "b'"],
                        Editable->False],
                      "StandardForm"],
                    Format]}],
                SequenceForm[ 
                  Format[ "d"], 
                  Format[ aua], 
                  Format[ aub]],
                Editable->False], ")"}]}], "+", 
          RowBox[{\(o\^2\), " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(-3\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u0\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p'"\),
                              Subscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u0"], 
                        Format[ al1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"e\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a'"\),
                              Superscript[ "a'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b'"\),
                              Superscript[ "b'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "e"], 
                        Format[ au1], 
                        Format[ aua], 
                        Format[ aub]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u0\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p'"\),
                              Subscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u0"], 
                        Format[ al1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"d\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a'"\),
                              Superscript[ "a'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b'"\),
                              Superscript[ "b'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "d"], 
                        Format[ aua], 
                        Format[ aub]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ au1]],
                      Editable->False], ")"}]}]}], ")"}]}]}], ",", 
        RowBox[{\(-o\^2\), " ", 
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"e\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"a'"\),
                      Superscript[ "a'"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"b'"\),
                      Superscript[ "b'"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"c'"\),
                      Superscript[ "c'"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "e"], 
                Format[ aua], 
                Format[ aub], 
                Format[ auc]],
              Editable->False], ")"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "This is ",
  Cell[BoxData[
      \(TraditionalForm\`d\^\(a' b'\)\)]],
  " at the projection. We denote it  ",
  Cell[BoxData[
      \(TraditionalForm\`d\&^\^\(a' b'\)\)]],
  "=foo101."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo101 = 
      Collect[Simplify[\(-foo100[\([3]\)]\)/o], {ru0[al1], o}, 
        tsimp]\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"d\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"a'"\),
                Superscript[ "a'"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"b'"\),
                Superscript[ "b'"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ "d"], 
          Format[ aua], 
          Format[ aub]],
        Editable->False], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"e\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "e"], 
                    Format[ au1], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule101, td[aua, aub], foo101]\)], "Input"],

Cell[TextData[{
  "This is ",
  Cell[BoxData[
      \(TraditionalForm\`e\^\(a' b' c'\)\)]],
  " at the projection. We denote it ",
  Cell[BoxData[
      \(TraditionalForm\`e\&^\^\(a' b' c'\)\)]],
  " = foo102."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo102 = Simplify[\(-foo100[\([4]\)]\)/o\^2]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          FormBox["\<\"e\"\>",
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"a'"\),
              Superscript[ "a'"],
              Editable->False],
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"b'"\),
              Superscript[ "b'"],
              Editable->False],
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"c'"\),
              Superscript[ "c'"],
              Editable->False],
            "StandardForm"],
          Format]}],
      SequenceForm[ 
        Format[ "e"], 
        Format[ aua], 
        Format[ aub], 
        Format[ auc]],
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now the surface is expressed in the local coordinates as ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Eta]\_9 = \(-\ 
              d\&^\^\(a' b'\)\) \(\[CapitalDelta]\[Eta]\_\(a'\)\) \
\[CapitalDelta]\[Eta]\_\(b'\) - \ \(e\&^\^\(a' b' 
                  c'\)\) \(\[CapitalDelta]\[Eta]\_\(a'\)\) \(\[CapitalDelta]\
\[Eta]\_\(b'\)\) \[CapitalDelta]\[Eta]\_\(c'\)\)]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["the expressions for the potential derivatives", "Subsubsection"],

Cell["the metric", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[tp2, "\<\[Phi]2\>", {{2, 1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"\\[Phi]2\"\) assigned"\)], "Message"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"\\[Phi]2\"\) defined"\)], "Message"]
}, Open  ]],

Cell["the inverse of the metric", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[tr2, "\<i\[Phi]2\>", {{2, 1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"i\\[Phi]2\"\) assigned"\)], "Message"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"i\\[Phi]2\"\) defined"\)], "Message"]
}, Open  ]],

Cell[TextData[{
  "phi2eta=",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]\^2\( \[Phi](\[Eta])\)\)\(\ \)\)\/\(\
\[PartialD]\ \[Eta]\_a \[PartialD]\ \[Eta]\_b\)\)]],
  " is derived earlier."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(phi2eta\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"Kdelta\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"a"\),
                Superscript[ "a"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"b"\),
                Superscript[ "b"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ Kdelta], 
          Format[ ua], 
          Format[ ub]],
        Editable->False], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ u1], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p"\),
                    Subscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q"\),
                    Subscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ l2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p"\),
                    Superscript[ "p"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q"\),
                    Superscript[ "q"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ u1], 
              Format[ u2], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "foo110=phi2eta but ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_p\)]],
  "is separated into ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_\(p'\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_9\)]],
  " in the summation."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo110 = CanAll[sepa[sepa[phi2eta, l1], l2]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"Kdelta\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"a"\),
                Superscript[ "a"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"b"\),
                Superscript[ "b"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ Kdelta], 
          Format[ ua], 
          Format[ ub]],
        Editable->False], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au1], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        SuperscriptBox[
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[Eta]\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\_"9"\),
                    Subscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Subscript[ "9"]],
                  Editable->False]}],
              SequenceForm[ 
                Format[ "\[Eta]"], 
                SequenceForm[ 
                  Subscript[ "9"]]],
              Editable->False], ")"}], "2"], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Eta]"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ au1], 
              Format[ au2], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "foo111=foo110 but ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_\(p'\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_9\)]],
  " are substituted by their expressions in the local coordinates."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo111 = tgeto2[ApplyRules[foo110, {rule93, rule94}]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"Kdelta\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"a"\),
                Superscript[ "a"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"b"\),
                Superscript[ "b"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ Kdelta], 
          Format[ ua], 
          Format[ ub]],
        Editable->False], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au1], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au1], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(-2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au2], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au2], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\_"9"\),
                          Subscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Subscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "\[CapitalDelta]\[Eta]"], 
                      SequenceForm[ 
                        Subscript[ "9"]]],
                    Editable->False], ")"}], "2"], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a"\),
                          Superscript[ "a"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b"\),
                          Superscript[ "b"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ ua], 
                    Format[ ub]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "foo112=",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]\^2\( \[Phi](\[Eta])\)\)\(\ \)\)\/\(\
\[PartialD]\ \[Eta]\_a \[PartialD]\ \[Eta]\_b\)\( | \_\(\[Eta] = \[Eta](u0) + 
                B\[CapitalDelta]\[Eta]\)\)\ \(\(B\_a\^c\)(u0)\) \(\(B\_b\^d\)(
            u0)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo112 = foo111\ tB[la, uc] tB[lb, ud]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"B\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"a"\),
                  Subscript[ "a"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"c"\),
                  Superscript[ "c"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "B"], 
            Format[ la], 
            Format[ uc]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"B\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"b"\),
                  Subscript[ "b"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"d"\),
                  Superscript[ "d"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "B"], 
            Format[ lb], 
            Format[ ud]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        RowBox[{
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ ua], 
              Format[ ub]],
            Editable->False], "+", 
          RowBox[{"o", " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\_"9"\),
                            Subscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Subscript[ "9"]],
                          Editable->False]}],
                      SequenceForm[ 
                        Format[ "\[CapitalDelta]\[Eta]"], 
                        SequenceForm[ 
                          Subscript[ "9"]]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p'"\),
                              Subscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[CapitalDelta]\[Eta]"], 
                        Format[ al1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        Format[ au1], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u0\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p'"\),
                              Subscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u0"], 
                        Format[ al1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        Format[ au1], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}]}], ")"}]}], "+", 
          RowBox[{\(o\^2\), " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(-2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p'"\),
                              Subscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[CapitalDelta]\[Eta]"], 
                        Format[ al1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u0\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u0"], 
                        Format[ al2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"d\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "d"], 
                        Format[ au1], 
                        Format[ au2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u0\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p'"\),
                              Subscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u0"], 
                        Format[ al1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u0\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u0"], 
                        Format[ al2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"d\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "d"], 
                        Format[ au1], 
                        Format[ au2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\_"9"\),
                            Subscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Subscript[ "9"]],
                          Editable->False]}],
                      SequenceForm[ 
                        Format[ "\[CapitalDelta]\[Eta]"], 
                        SequenceForm[ 
                          Subscript[ "9"]]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u0\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p'"\),
                              Subscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u0"], 
                        Format[ al1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ au1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{"2", " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\_"9"\),
                            Subscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Subscript[ "9"]],
                          Editable->False]}],
                      SequenceForm[ 
                        Format[ "\[CapitalDelta]\[Eta]"], 
                        SequenceForm[ 
                          Subscript[ "9"]]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u0\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p'"\),
                              Subscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u0"], 
                        Format[ al1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"d\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "d"], 
                        Format[ al2], 
                        Format[ au1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        Format[ au2], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\_"9"\),
                            Subscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Subscript[ "9"]],
                          Editable->False]}],
                      SequenceForm[ 
                        Format[ "\[CapitalDelta]\[Eta]"], 
                        SequenceForm[ 
                          Subscript[ "9"]]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u0\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p'"\),
                              Subscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u0"], 
                        Format[ al1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ al2], 
                        Format[ au1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        Format[ au2], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(1\/2\), " ", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\_"9"\),
                              Subscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Subscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[CapitalDelta]\[Eta]"], 
                          SequenceForm[ 
                            Subscript[ "9"]]],
                        Editable->False], ")"}], "2"], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]4\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]4"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\_"9"\),
                            Subscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Subscript[ "9"]],
                          Editable->False]}],
                      SequenceForm[ 
                        Format[ "\[CapitalDelta]\[Eta]"], 
                        SequenceForm[ 
                          Subscript[ "9"]]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p'"\),
                              Subscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[CapitalDelta]\[Eta]"], 
                        Format[ al1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]4\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]4"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ au1], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\_"9"\),
                            Subscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Subscript[ "9"]],
                          Editable->False]}],
                      SequenceForm[ 
                        Format[ "\[CapitalDelta]\[Eta]"], 
                        SequenceForm[ 
                          Subscript[ "9"]]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u0\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p'"\),
                              Subscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u0"], 
                        Format[ al1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]4\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]4"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ au1], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p'"\),
                              Subscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[CapitalDelta]\[Eta]"], 
                        Format[ al1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[CapitalDelta]\[Eta]"], 
                        Format[ al2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]4\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]4"], 
                        Format[ au1], 
                        Format[ au2], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p'"\),
                              Subscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[CapitalDelta]\[Eta]"], 
                        Format[ al1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u0\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u0"], 
                        Format[ al2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]4\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]4"], 
                        Format[ au1], 
                        Format[ au2], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u0\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"p'"\),
                              Subscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u0"], 
                        Format[ al1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"u0\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "u0"], 
                        Format[ al2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]4\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"a"\),
                              Superscript[ "a"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"b"\),
                              Superscript[ "b"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]4"], 
                        Format[ au1], 
                        Format[ au2], 
                        Format[ ua], 
                        Format[ ub]],
                      Editable->False], ")"}]}]}], ")"}]}]}], 
        ")"}]}]], "Output"]
}, Open  ]],

Cell["\<\
Separate the regular indices a and b for the summation into type-a indexes \
and 9's.\
\>", "Text"],

Cell[BoxData[
    \(\(foo113 = CanAll[sepa[sepa[foo112, la], lb]];\)\)], "Input"],

Cell[TextData[{
  "foo114[ua,ub]=",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]\^2\( \[Phi](\[Eta])\)\)\(\ \)\)\/\(\
\[PartialD]\ \[Eta]\_p \[PartialD]\ \[Eta]\_q\)\( | \_\(\[Eta] = \[Eta](u0) + 
                B\[CapitalDelta]\[Eta]\)\)\ \(\(B\_p\^a\)(u0)\) \(\(B\_q\^b\)(
            u0)\)\)]],
  " is the same as foo112, but the subscripts are changed. In the below, we \
substitute ",
  Cell[BoxData[
      \(TraditionalForm\`B\^a\)]],
  "'s by their expressions at the projection."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo114[ua_, ub_] = foo113 /. {uc \[Rule] ua, ud \[Rule] ub}\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al1], 
              Format[ ua]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al1], 
              Format[ ub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"Kdelta\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ Kdelta], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al1], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ ub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al1], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al1], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al2], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al2], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al1], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al3], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al3], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al3], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al3], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s'"\),
                    Subscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al4], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s'"\),
                    Superscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au3], 
              Format[ au4]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s'"\),
                    Subscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al4], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s'"\),
                    Superscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au3], 
              Format[ au4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s'"\),
                    Subscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al4], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s'"\),
                    Superscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au2], 
              Format[ au3], 
              Format[ au4]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s'"\),
                    Subscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ al4], 
              Format[ au1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s'"\),
                    Superscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au2], 
              Format[ au3], 
              Format[ au4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        SuperscriptBox[
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\_"9"\),
                    Subscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Subscript[ "9"]],
                  Editable->False]}],
              SequenceForm[ 
                Format[ "\[CapitalDelta]\[Eta]"], 
                SequenceForm[ 
                  Subscript[ "9"]]],
              Editable->False], ")"}], "2"], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        SuperscriptBox[
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\_"9"\),
                    Subscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Subscript[ "9"]],
                  Editable->False]}],
              SequenceForm[ 
                Format[ "\[CapitalDelta]\[Eta]"], 
                SequenceForm[ 
                  Subscript[ "9"]]],
              Editable->False], ")"}], "2"], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al1], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        SuperscriptBox[
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\_"9"\),
                    Subscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Subscript[ "9"]],
                  Editable->False]}],
              SequenceForm[ 
                Format[ "\[CapitalDelta]\[Eta]"], 
                SequenceForm[ 
                  Subscript[ "9"]]],
              Editable->False], ")"}], "2"], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al1], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        SuperscriptBox[
          RowBox[{"(", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                InterpretationBox[
                  InterpretationBox[\(\[Null]\_"9"\),
                    Subscript[ "9"],
                    Editable->False],
                  SequenceForm[ 
                    Subscript[ "9"]],
                  Editable->False]}],
              SequenceForm[ 
                Format[ "\[CapitalDelta]\[Eta]"], 
                SequenceForm[ 
                  Subscript[ "9"]]],
              Editable->False], ")"}], "2"], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al1], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              SequenceForm[ 
                Subscript[ "9"]], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\_"9"\),
                  Subscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Subscript[ "9"]],
                Editable->False]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              SequenceForm[ 
                Subscript[ "9"]]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al2], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s'"\),
                    Subscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al4], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s'"\),
                    Superscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3], 
              Format[ au4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[CapitalDelta]\[Eta]"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s'"\),
                    Subscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al4], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s'"\),
                    Superscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3], 
              Format[ au4]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a"\),
                    Superscript[ "a"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al3], 
              Format[ ua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"B\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"s'"\),
                    Subscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b"\),
                    Superscript[ "b"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "B"], 
              Format[ al4], 
              Format[ ub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"s'"\),
                    Superscript[ "s'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ au1], 
              Format[ au2], 
              Format[ au3], 
              Format[ au4]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["foo115=foo114[aua,aub]", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo115 = 
      tgeto2[ApplyRules[foo114[aua, aub], {rule3, rule4, rule15, rule16}] /. 
          ru \[Rule] ru0]\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"Kdelta\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"a'"\),
                Superscript[ "a'"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"b'"\),
                Superscript[ "b'"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ Kdelta], 
          Format[ aua], 
          Format[ aub]],
        Editable->False], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au1], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au1], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"4", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au2], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ aub]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au2], 
                    Format[ aub]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au2], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ aub]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au2], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au2], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au2], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au2], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\_"9"\),
                          Subscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Subscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "\[CapitalDelta]\[Eta]"], 
                      SequenceForm[ 
                        Subscript[ "9"]]],
                    Editable->False], ")"}], "2"], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["check if foo115 is consistent with ph2bu obtained earlier.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tsimpp[
      tsimp[foo115 /. {re[la_] \[Rule] 0, ru0 \[Rule] ru}] - 
        phi2bu]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell["foo116=foo114[9,aua]", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo116 = 
      tgeto2[ApplyRules[foo114[9, aua], {rule3, rule4, rule15, rule16}] /. 
          ru \[Rule] ru0]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(-2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au2], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au2], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"4", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au2], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au2], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au2], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al3], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au1], 
                    Format[ au3], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al3], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au1], 
                    Format[ au3], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al3], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au1], 
                    Format[ au3], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al3], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au1], 
                    Format[ au3], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al3], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au2], 
                    Format[ au3], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al3], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au2], 
                    Format[ au3], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\_"9"\),
                          Subscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Subscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "\[CapitalDelta]\[Eta]"], 
                      SequenceForm[ 
                        Subscript[ "9"]]],
                    Editable->False], ")"}], "2"], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ aua]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["foo117=foo114[9,9]", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo117 = 
      tgeto2[ApplyRules[foo114[9, 9], {rule3, rule4, rule15, rule16}] /. 
          ru \[Rule] ru0]\)], "Input"],

Cell[BoxData[
    RowBox[{"1", "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(-2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(3\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"6", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au3]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al3], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"4", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al3], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al3], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al3], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al3], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"4", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al3], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au2], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al3], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au2], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                          "StandardForm"],
                        Format], "\[InvisibleSpace]", 
                      InterpretationBox[
                        InterpretationBox[\(\[Null]\_"9"\),
                          Subscript[ "9"],
                          Editable->False],
                        SequenceForm[ 
                          Subscript[ "9"]],
                        Editable->False]}],
                    SequenceForm[ 
                      Format[ "\[CapitalDelta]\[Eta]"], 
                      SequenceForm[ 
                        Subscript[ "9"]]],
                    Editable->False], ")"}], "2"], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\_"9"\),
                        Subscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Subscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    SequenceForm[ 
                      Subscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[CapitalDelta]\[Eta]\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[CapitalDelta]\[Eta]"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now obtain the coefficients in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Eta]\_a\)]],
  " for foo115,foo116,foo117."
}], "Text"],

Cell[BoxData[
    \(\(goo118 = {{1, 1/o, 2/o\^2}, {1/o, 1/o\^2, 2/o\^3}, {2/o\^2, 2/o\^3, 
            4/o\^4}};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(goo118 // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", \(1\/o\), \(2\/o\^2\)},
            {\(1\/o\), \(1\/o\^2\), \(2\/o\^3\)},
            {\(2\/o\^2\), \(2\/o\^3\), \(4\/o\^4\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(foo118 = 
        Collect[CoefficientList[
              foo115 /. {re[\(-9\)] \[Rule] D9, re[ala_] \[Rule] DA}, {DA, 
                D9}]\ *\ goo118, o, 
          tsimpp[CanAll[# /. {au1 \[Rule] auc, au2 \[Rule] aud, 
                    au3 \[Rule] aue, au4 \[Rule] auf, au5 \[Rule] aug, 
                    al1 \[Rule] alc, al2 \[Rule] ald, al3 \[Rule] ale, 
                    al4 \[Rule] alf, al5 \[Rule] alg}]] &];\)\)], "Input"],

Cell[BoxData[
    \("Symmetries may be inconsistent."\)], "Print"]
}, Open  ]],

Cell[BoxData[
    \(\(foo119 = 
        Collect[CoefficientList[
              foo116 /. {re[\(-9\)] \[Rule] D9, re[ala_] \[Rule] DA}, {DA, 
                D9}]*goo118, o, 
          tsimpp[CanAll[# /. {au1 \[Rule] auc, au2 \[Rule] aud, 
                    au3 \[Rule] aue, au4 \[Rule] auf, au5 \[Rule] aug, 
                    al1 \[Rule] alc, al2 \[Rule] ald, al3 \[Rule] ale, 
                    al4 \[Rule] alf, al5 \[Rule] alg}]] &];\)\)], "Input"],

Cell[BoxData[
    \(\(foo120 = 
        Collect[CoefficientList[
              foo117 /. {re[\(-9\)] \[Rule] D9, re[ala_] \[Rule] DA}, {DA, 
                D9}]*goo118, o, 
          tsimpp[CanAll[# /. {au1 \[Rule] auc, au2 \[Rule] aud, 
                    au3 \[Rule] aue, au4 \[Rule] auf, au5 \[Rule] aug, 
                    al1 \[Rule] alc, al2 \[Rule] ald, al3 \[Rule] ale, 
                    al4 \[Rule] alf, al5 \[Rule] alg}]] &];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dimensions[foo118]\)], "Input"],

Cell[BoxData[
    \({3, 3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dimensions[foo119]\)], "Input"],

Cell[BoxData[
    \({3, 3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dimensions[foo120]\)], "Input"],

Cell[BoxData[
    \({3, 3}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(foo121 = {foo118, foo119, foo120};\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Geometric quantities at the projection", "Subsubsection"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Phi]\&^\^\(a' b'\)\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo121[\([1, 1, 1]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"Kdelta\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"a'"\),
                Superscript[ "a'"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"b'"\),
                Superscript[ "b'"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ Kdelta], 
          Format[ aua], 
          Format[ aub]],
        Editable->False], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au1], 
              Format[ aua], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"4", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au2], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ aub]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au2], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au2], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ au1], 
                    Format[ au2], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule121Pab, tp2[aua_, aub_], 
      foo121[\([1, 1, 1]\)]]\)], "Input"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Phi]\&^\^\(9  a'\)\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo121[\([2, 1, 1]\)]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule121P9a, tp2[9, aua_], foo121[\([2, 1, 1]\)]]\)], "Input"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Phi]\&^\^99\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo121[\([3, 1, 1]\)]\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule121P99, tp2[9, 9], foo121[\([3, 1, 1]\)]]\)], "Input"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Phi]\&^\^\(a' b' c'\)\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo121[\([1, 2, 1]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"\[Phi]3\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"a'"\),
                Superscript[ "a'"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"b'"\),
                Superscript[ "b'"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"c'"\),
                Superscript[ "c'"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ "\[Phi]3"], 
          Format[ aua], 
          Format[ aub], 
          Format[ auc]],
        Editable->False], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(-2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c'"\),
                          Superscript[ "c'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ auc]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ aub]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c'"\),
                          Superscript[ "c'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua], 
                    Format[ auc]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c'"\),
                          Superscript[ "c'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aub], 
                    Format[ auc]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"c'"\),
                          Superscript[ "c'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ au1], 
                    Format[ aua], 
                    Format[ aub], 
                    Format[ auc]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule121Pabc, tp3[aua_, aub_, auc_], 
      foo121[\([1, 2, 1]\)]]\)], "Input"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Phi]\&^\^\(9  a' b'\)\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo121[\([1, 1, 2]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"\[Phi]3\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          InterpretationBox[
            InterpretationBox[\(\[Null]\^"9"\),
              Superscript[ "9"],
              Editable->False],
            SequenceForm[ 
              Superscript[ "9"]],
            Editable->False], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"a'"\),
                Superscript[ "a'"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"b'"\),
                Superscript[ "b'"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ "\[Phi]3"], 
          SequenceForm[ 
            Superscript[ "9"]], 
          Format[ aua], 
          Format[ aub]],
        Editable->False], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(-2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ aub]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au2], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ au2], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"b'"\),
                          Superscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ aua], 
                    Format[ aub]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((foo121[\([2, 2, 1]\)] /. auc \[Rule] aub)\) - 
      foo121[\([1, 1, 2]\)]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule121P9ab, tp3[9, aua_, aub_], 
      foo121[\([1, 1, 2]\)]]\)], "Input"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Phi]\&^\^\(99  a'\)\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo121[\([2, 1, 2]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"\[Phi]3\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          InterpretationBox[
            InterpretationBox[\(\[Null]\^"9"\),
              Superscript[ "9"],
              Editable->False],
            SequenceForm[ 
              Superscript[ "9"]],
            Editable->False], "\[InvisibleSpace]", 
          InterpretationBox[
            InterpretationBox[\(\[Null]\^"9"\),
              Superscript[ "9"],
              Editable->False],
            SequenceForm[ 
              Superscript[ "9"]],
            Editable->False], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"a'"\),
                Superscript[ "a'"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ "\[Phi]3"], 
          SequenceForm[ 
            Superscript[ "9"]], 
          SequenceForm[ 
            Superscript[ "9"]], 
          Format[ aua]],
        Editable->False], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(-2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"4", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au2], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au2], 
                    Format[ aua]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"a'"\),
                          Superscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1], 
                    Format[ aua]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((foo121[\([3, 2, 1]\)] /. auc \[Rule] aua)\) - 
      foo121[\([2, 1, 2]\)]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule121P99a, tp3[9, 9, aua_], 
      foo121[\([2, 1, 2]\)]]\)], "Input"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Phi]\&^\^999\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo121[\([3, 1, 2]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"\[Phi]3\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          InterpretationBox[
            InterpretationBox[\(\[Null]\^"9"\),
              Superscript[ "9"],
              Editable->False],
            SequenceForm[ 
              Superscript[ "9"]],
            Editable->False], "\[InvisibleSpace]", 
          InterpretationBox[
            InterpretationBox[\(\[Null]\^"9"\),
              Superscript[ "9"],
              Editable->False],
            SequenceForm[ 
              Superscript[ "9"]],
            Editable->False], "\[InvisibleSpace]", 
          InterpretationBox[
            InterpretationBox[\(\[Null]\^"9"\),
              Superscript[ "9"],
              Editable->False],
            SequenceForm[ 
              Superscript[ "9"]],
            Editable->False]}],
        SequenceForm[ 
          Format[ "\[Phi]3"], 
          SequenceForm[ 
            Superscript[ "9"]], 
          SequenceForm[ 
            Superscript[ "9"]], 
          SequenceForm[ 
            Superscript[ "9"]]],
        Editable->False], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(-\(3\/2\)\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"6", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ al2], 
                    Format[ au1]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ au1]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule121P999, tp3[9, 9, 9], foo121[\([3, 1, 2]\)]]\)], "Input"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Phi]\&^\^\(a' b' c' d'\)\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo121[\([1, 3, 1]\)]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          FormBox["\<\"\[Phi]4\"\>",
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"a'"\),
              Superscript[ "a'"],
              Editable->False],
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"b'"\),
              Superscript[ "b'"],
              Editable->False],
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"c'"\),
              Superscript[ "c'"],
              Editable->False],
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"d'"\),
              Superscript[ "d'"],
              Editable->False],
            "StandardForm"],
          Format]}],
      SequenceForm[ 
        Format[ "\[Phi]4"], 
        Format[ aua], 
        Format[ aub], 
        Format[ auc], 
        Format[ aud]],
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule121Pabcd, tp4[aua_, aub_, auc_, aud_], 
      foo121[\([1, 3, 1]\)]]\)], "Input"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Phi]\&^\^\(9  a' b' c'\)\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo121[\([1, 2, 2]\)]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          FormBox["\<\"\[Phi]4\"\>",
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        InterpretationBox[
          InterpretationBox[\(\[Null]\^"9"\),
            Superscript[ "9"],
            Editable->False],
          SequenceForm[ 
            Superscript[ "9"]],
          Editable->False], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"a'"\),
              Superscript[ "a'"],
              Editable->False],
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"b'"\),
              Superscript[ "b'"],
              Editable->False],
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"c'"\),
              Superscript[ "c'"],
              Editable->False],
            "StandardForm"],
          Format]}],
      SequenceForm[ 
        Format[ "\[Phi]4"], 
        SequenceForm[ 
          Superscript[ "9"]], 
        Format[ aua], 
        Format[ aub], 
        Format[ auc]],
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo121[\([2, 3, 1]\)] /. {auc \[Rule] aub, aud \[Rule] auc}\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          FormBox["\<\"\[Phi]4\"\>",
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        InterpretationBox[
          InterpretationBox[\(\[Null]\^"9"\),
            Superscript[ "9"],
            Editable->False],
          SequenceForm[ 
            Superscript[ "9"]],
          Editable->False], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"a'"\),
              Superscript[ "a'"],
              Editable->False],
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"b'"\),
              Superscript[ "b'"],
              Editable->False],
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"c'"\),
              Superscript[ "c'"],
              Editable->False],
            "StandardForm"],
          Format]}],
      SequenceForm[ 
        Format[ "\[Phi]4"], 
        SequenceForm[ 
          Superscript[ "9"]], 
        Format[ aua], 
        Format[ aub], 
        Format[ auc]],
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule121P9abc, tp4[9, aua_, aub_, auc_], 
      foo121[\([1, 2, 2]\)]]\)], "Input"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Phi]\&^\^\(99  a' b'\)\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo121[\([1, 1, 3]\)]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          FormBox["\<\"\[Phi]4\"\>",
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        InterpretationBox[
          InterpretationBox[\(\[Null]\^"9"\),
            Superscript[ "9"],
            Editable->False],
          SequenceForm[ 
            Superscript[ "9"]],
          Editable->False], "\[InvisibleSpace]", 
        InterpretationBox[
          InterpretationBox[\(\[Null]\^"9"\),
            Superscript[ "9"],
            Editable->False],
          SequenceForm[ 
            Superscript[ "9"]],
          Editable->False], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"a'"\),
              Superscript[ "a'"],
              Editable->False],
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"b'"\),
              Superscript[ "b'"],
              Editable->False],
            "StandardForm"],
          Format]}],
      SequenceForm[ 
        Format[ "\[Phi]4"], 
        SequenceForm[ 
          Superscript[ "9"]], 
        SequenceForm[ 
          Superscript[ "9"]], 
        Format[ aua], 
        Format[ aub]],
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo121[\([2, 2, 2]\)] /. {auc \[Rule] aub}\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          FormBox["\<\"\[Phi]4\"\>",
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        InterpretationBox[
          InterpretationBox[\(\[Null]\^"9"\),
            Superscript[ "9"],
            Editable->False],
          SequenceForm[ 
            Superscript[ "9"]],
          Editable->False], "\[InvisibleSpace]", 
        InterpretationBox[
          InterpretationBox[\(\[Null]\^"9"\),
            Superscript[ "9"],
            Editable->False],
          SequenceForm[ 
            Superscript[ "9"]],
          Editable->False], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"a'"\),
              Superscript[ "a'"],
              Editable->False],
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"b'"\),
              Superscript[ "b'"],
              Editable->False],
            "StandardForm"],
          Format]}],
      SequenceForm[ 
        Format[ "\[Phi]4"], 
        SequenceForm[ 
          Superscript[ "9"]], 
        SequenceForm[ 
          Superscript[ "9"]], 
        Format[ aua], 
        Format[ aub]],
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo121[\([3, 3, 1]\)] /. {auc \[Rule] aua, aud \[Rule] aub}\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          FormBox["\<\"\[Phi]4\"\>",
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        InterpretationBox[
          InterpretationBox[\(\[Null]\^"9"\),
            Superscript[ "9"],
            Editable->False],
          SequenceForm[ 
            Superscript[ "9"]],
          Editable->False], "\[InvisibleSpace]", 
        InterpretationBox[
          InterpretationBox[\(\[Null]\^"9"\),
            Superscript[ "9"],
            Editable->False],
          SequenceForm[ 
            Superscript[ "9"]],
          Editable->False], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"a'"\),
              Superscript[ "a'"],
              Editable->False],
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"b'"\),
              Superscript[ "b'"],
              Editable->False],
            "StandardForm"],
          Format]}],
      SequenceForm[ 
        Format[ "\[Phi]4"], 
        SequenceForm[ 
          Superscript[ "9"]], 
        SequenceForm[ 
          Superscript[ "9"]], 
        Format[ aua], 
        Format[ aub]],
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule121Pabcd, tp4[9, 9, aua_, aub_], 
      foo121[\([1, 1, 3]\)]]\)], "Input"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Phi]\&^\^\(999  a'\)\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo121[\([2, 1, 3]\)]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          FormBox["\<\"\[Phi]4\"\>",
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        InterpretationBox[
          InterpretationBox[\(\[Null]\^"9"\),
            Superscript[ "9"],
            Editable->False],
          SequenceForm[ 
            Superscript[ "9"]],
          Editable->False], "\[InvisibleSpace]", 
        InterpretationBox[
          InterpretationBox[\(\[Null]\^"9"\),
            Superscript[ "9"],
            Editable->False],
          SequenceForm[ 
            Superscript[ "9"]],
          Editable->False], "\[InvisibleSpace]", 
        InterpretationBox[
          InterpretationBox[\(\[Null]\^"9"\),
            Superscript[ "9"],
            Editable->False],
          SequenceForm[ 
            Superscript[ "9"]],
          Editable->False], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"a'"\),
              Superscript[ "a'"],
              Editable->False],
            "StandardForm"],
          Format]}],
      SequenceForm[ 
        Format[ "\[Phi]4"], 
        SequenceForm[ 
          Superscript[ "9"]], 
        SequenceForm[ 
          Superscript[ "9"]], 
        SequenceForm[ 
          Superscript[ "9"]], 
        Format[ aua]],
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo121[\([3, 2, 2]\)] /. auc \[Rule] aua\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          FormBox["\<\"\[Phi]4\"\>",
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        InterpretationBox[
          InterpretationBox[\(\[Null]\^"9"\),
            Superscript[ "9"],
            Editable->False],
          SequenceForm[ 
            Superscript[ "9"]],
          Editable->False], "\[InvisibleSpace]", 
        InterpretationBox[
          InterpretationBox[\(\[Null]\^"9"\),
            Superscript[ "9"],
            Editable->False],
          SequenceForm[ 
            Superscript[ "9"]],
          Editable->False], "\[InvisibleSpace]", 
        InterpretationBox[
          InterpretationBox[\(\[Null]\^"9"\),
            Superscript[ "9"],
            Editable->False],
          SequenceForm[ 
            Superscript[ "9"]],
          Editable->False], "\[InvisibleSpace]", 
        TagBox[
          FormBox[
            InterpretationBox[\(\[Null]\^"a'"\),
              Superscript[ "a'"],
              Editable->False],
            "StandardForm"],
          Format]}],
      SequenceForm[ 
        Format[ "\[Phi]4"], 
        SequenceForm[ 
          Superscript[ "9"]], 
        SequenceForm[ 
          Superscript[ "9"]], 
        SequenceForm[ 
          Superscript[ "9"]], 
        Format[ aua]],
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule121P999a, tp4[9, 9, 9, aua_], 
      foo121[\([2, 1, 3]\)]]\)], "Input"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Phi]\&^\^9999\)]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo121[\([3, 1, 3]\)]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          FormBox["\<\"\[Phi]4\"\>",
            "StandardForm"],
          Format], "\[InvisibleSpace]", 
        InterpretationBox[
          InterpretationBox[\(\[Null]\^"9"\),
            Superscript[ "9"],
            Editable->False],
          SequenceForm[ 
            Superscript[ "9"]],
          Editable->False], "\[InvisibleSpace]", 
        InterpretationBox[
          InterpretationBox[\(\[Null]\^"9"\),
            Superscript[ "9"],
            Editable->False],
          SequenceForm[ 
            Superscript[ "9"]],
          Editable->False], "\[InvisibleSpace]", 
        InterpretationBox[
          InterpretationBox[\(\[Null]\^"9"\),
            Superscript[ "9"],
            Editable->False],
          SequenceForm[ 
            Superscript[ "9"]],
          Editable->False], "\[InvisibleSpace]", 
        InterpretationBox[
          InterpretationBox[\(\[Null]\^"9"\),
            Superscript[ "9"],
            Editable->False],
          SequenceForm[ 
            Superscript[ "9"]],
          Editable->False]}],
      SequenceForm[ 
        Format[ "\[Phi]4"], 
        SequenceForm[ 
          Superscript[ "9"]], 
        SequenceForm[ 
          Superscript[ "9"]], 
        SequenceForm[ 
          Superscript[ "9"]], 
        SequenceForm[ 
          Superscript[ "9"]]],
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule121P9999, tp4[9, 9, 9, 9], 
      foo121[\([3, 1, 3]\)]]\)], "Input"],

Cell["zero terms", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({foo121[\([1, 3, 2]\)], foo121[\([1, 2, 3]\)], 
      foo121[\([1, 3, 3]\)]}\)], "Input"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({foo121[\([2, 3, 2]\)], foo121[\([2, 2, 3]\)], 
      foo121[\([2, 3, 3]\)]}\)], "Input"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({foo121[\([3, 3, 2]\)], foo121[\([3, 2, 3]\)], 
      foo121[\([3, 3, 3]\)]}\)], "Input"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "A=",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\&^\^\(a' b'\) - \[Delta]\^\(a' b'\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[t125, "\<A\>", {{2, 1}, 1}]\)], "Input"],

Cell[BoxData[
    \(PermWeight::"sym" \(\(:\)\(\ \)\) 
      "Symmetries of \!\(\"A\"\) assigned"\)], "Message"],

Cell[BoxData[
    \(PermWeight::"def" \(\(:\)\(\ \)\) 
      "Object \!\(\"A\"\) defined"\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo125 = 
      ApplyRules[tp2[aua, aub], rule121Pab] - Kdelta[aua, aub]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"4", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au2], 
              Format[ aub]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ aub]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2], 
              Format[ aua]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ aua]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au2], 
              Format[ aub]],
            Editable->False], ")"}]}], "-", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ aua], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ au1], 
              Format[ aua], 
              Format[ aub]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", \(o\^2\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]4\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"a'"\),
                    Superscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"b'"\),
                    Superscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]4"], 
              Format[ au1], 
              Format[ au2], 
              Format[ aua], 
              Format[ aub]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule125, t125[aua_, aub_], foo125]\)], "Input"],

Cell[TextData[{
  "foo130=",
  Cell[BoxData[
      \(TraditionalForm\`A\^2\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo130 = 
      tgeto2[ApplyRules[t125[aua, auc] Kdelta[alc, ald] t125[aud, aub], 
            rule125]] /. {aua \[Rule] ala, aub \[Rule] alb}\)], "Input"],

Cell[BoxData[
    RowBox[{\(o\^2\), " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"u0\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"p'"\),
                  Subscript[ "p'"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "u0"], 
            Format[ al1]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"u0\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"q'"\),
                  Subscript[ "q'"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "u0"], 
            Format[ al2]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"\[Phi]3\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"r'"\),
                  Subscript[ "r'"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"a'"\),
                  Subscript[ "a'"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"p'"\),
                  Superscript[ "p'"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "\[Phi]3"], 
            Format[ al3], 
            Format[ ala], 
            Format[ au1]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"\[Phi]3\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"b'"\),
                  Subscript[ "b'"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"q'"\),
                  Superscript[ "q'"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"r'"\),
                  Superscript[ "r'"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "\[Phi]3"], 
            Format[ alb], 
            Format[ au2], 
            Format[ au3]],
          Editable->False], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "foo131=",
  Cell[BoxData[
      \(TraditionalForm\`\((I + A)\)\^\(-1\) = I - A + A\^2\)]],
  "=the inverse of the metric=",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\&^\_\(a' b'\) = \((\[Phi]\&^\^\(a' \
b'\))\)\^\(-1\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo131 = 
      Collect[Kdelta[ala, alb] - ApplyRules[t125[ala, alb], rule125] + 
          foo130, o, tsimpp]\)], "Input"],

Cell[BoxData[
    \("Symmetries may be inconsistent."\)], "Print"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"Kdelta\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\_"a'"\),
                Subscript[ "a'"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\_"b'"\),
                Subscript[ "b'"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ Kdelta], 
          Format[ ala], 
          Format[ alb]],
        Editable->False], "-", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"a'"\),
                    Subscript[ "a'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"b'"\),
                    Subscript[ "b'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ ala], 
              Format[ alb], 
              Format[ au1]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(-4\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"a'"\),
                          Subscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ ala], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"b'"\),
                          Subscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ alb], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"a'"\),
                          Subscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"b'"\),
                          Subscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ ala], 
                    Format[ alb]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"b'"\),
                          Subscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ alb], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"a'"\),
                          Subscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ ala], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{"2", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"d\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"a'"\),
                          Subscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "d"], 
                    Format[ ala], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"b'"\),
                          Subscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    Format[ alb], 
                    Format[ au2]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"r'"\),
                          Subscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"a'"\),
                          Subscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ al3], 
                    Format[ ala], 
                    Format[ au1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"b'"\),
                          Subscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"r'"\),
                          Superscript[ "r'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    Format[ alb], 
                    Format[ au2], 
                    Format[ au3]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"q'"\),
                          Subscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al2]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]4\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"a'"\),
                          Subscript[ "a'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"b'"\),
                          Subscript[ "b'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"p'"\),
                          Superscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\^"q'"\),
                          Superscript[ "q'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "\[Phi]4"], 
                    Format[ ala], 
                    Format[ alb], 
                    Format[ au1], 
                    Format[ au2]],
                  Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule131, tr2[ala_, alb_], foo131]\)], "Input"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`foo132 = \(i\[Phi]2\_\(a' b'\)\) 
          d\&^\^\(a' b'\)\)]],
  " substitutes ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\_\(a' b'\)\) d\^\(a' b'\)\)]],
  "at the projection."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tr2[ala, alb] td[aua, aub]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"d\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"a'"\),
                  Superscript[ "a'"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\^"b'"\),
                  Superscript[ "b'"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "d"], 
            Format[ aua], 
            Format[ aub]],
          Editable->False], ")"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{
            TagBox[
              FormBox["\<\"i\[Phi]2\"\>",
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"a'"\),
                  Subscript[ "a'"],
                  Editable->False],
                "StandardForm"],
              Format], "\[InvisibleSpace]", 
            TagBox[
              FormBox[
                InterpretationBox[\(\[Null]\_"b'"\),
                  Subscript[ "b'"],
                  Editable->False],
                "StandardForm"],
              Format]}],
          SequenceForm[ 
            Format[ "i\[Phi]2"], 
            Format[ ala], 
            Format[ alb]],
          Editable->False], ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo132 = 
      tsimpp[tgeto2[
            ApplyRules[o\ tr2[ala, alb] td[aua, aub], {rule101, rule131}]]/
          o]\)], "Input"],

Cell[BoxData[
    RowBox[{
      InterpretationBox[
        RowBox[{
          TagBox[
            FormBox["\<\"d\"\>",
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\_"p'"\),
                Subscript[ "p'"],
                Editable->False],
              "StandardForm"],
            Format], "\[InvisibleSpace]", 
          TagBox[
            FormBox[
              InterpretationBox[\(\[Null]\^"p'"\),
                Superscript[ "p'"],
                Editable->False],
              "StandardForm"],
            Format]}],
        SequenceForm[ 
          Format[ "d"], 
          Format[ al1], 
          Format[ au1]],
        Editable->False], "+", 
      RowBox[{"3", " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"e\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "e"], 
              Format[ al2], 
              Format[ au1], 
              Format[ au2]],
            Editable->False], ")"}]}], "+", 
      RowBox[{\(1\/2\), " ", "o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ al2], 
              Format[ au2]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              InterpretationBox[
                InterpretationBox[\(\[Null]\^"9"\),
                  Superscript[ "9"],
                  Editable->False],
                SequenceForm[ 
                  Superscript[ "9"]],
                Editable->False], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              SequenceForm[ 
                Superscript[ "9"]], 
              SequenceForm[ 
                Superscript[ "9"]], 
              Format[ au1]],
            Editable->False], ")"}]}], "-", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"u0\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"p'"\),
                    Subscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "u0"], 
              Format[ al1]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"d\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"q'"\),
                    Superscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"r'"\),
                    Superscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "d"], 
              Format[ au2], 
              Format[ au3]],
            Editable->False], ")"}], " ", 
        RowBox[{"(", 
          InterpretationBox[
            RowBox[{
              TagBox[
                FormBox["\<\"\[Phi]3\"\>",
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"q'"\),
                    Subscript[ "q'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\_"r'"\),
                    Subscript[ "r'"],
                    Editable->False],
                  "StandardForm"],
                Format], "\[InvisibleSpace]", 
              TagBox[
                FormBox[
                  InterpretationBox[\(\[Null]\^"p'"\),
                    Superscript[ "p'"],
                    Editable->False],
                  "StandardForm"],
                Format]}],
            SequenceForm[ 
              Format[ "\[Phi]3"], 
              Format[ al2], 
              Format[ al3], 
              Format[ au1]],
            Editable->False], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(RuleUnique[rule132, td[ala_, aua_], foo132, 
      PairaQ[ala, aua]]\)], "Input"],

Cell[TextData[{
  "Here we summarize the substitution rules for the projection for the \
derivatives. Here only discuss ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(\(-1\)/2\))\)]],
  "terms. This includes ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\^999, \ d\^\(a' a'\)\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(rulesproj = {rule121P999, rule132};\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["zc-formula", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(zformulau0 = 
      Collect[tgeto2[ApplyRules[zformula, rulesproj]], {o, ru0[al1], w, 
          v0}]\)], "Input"],

Cell[BoxData[
    RowBox[{\(-v0\), "+", "w", "+", 
      RowBox[{"o", " ", 
        RowBox[{"(", 
          RowBox[{\(-cr[0]\), "-", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  FormBox["\<\"d\"\>",
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\_"p'"\),
                      Subscript[ "p'"],
                      Editable->False],
                    "StandardForm"],
                  Format], "\[InvisibleSpace]", 
                TagBox[
                  FormBox[
                    InterpretationBox[\(\[Null]\^"p'"\),
                      Superscript[ "p'"],
                      Editable->False],
                    "StandardForm"],
                  Format]}],
              SequenceForm[ 
                Format[ "d"], 
                Format[ al1], 
                Format[ au1]],
              Editable->False], "+", 
            RowBox[{\(w\^2\), " ", 
              RowBox[{"(", 
                RowBox[{\(-cr[2]\), "+", 
                  RowBox[{\(1\/6\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "-", 
            RowBox[{\(1\/6\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "-", 
            RowBox[{\(1\/3\), " ", \(v0\^2\), " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}], "+", 
            RowBox[{\(1\/6\), " ", "v0", " ", "w", " ", 
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"\[Phi]3\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False], "\[InvisibleSpace]", 
                    InterpretationBox[
                      InterpretationBox[\(\[Null]\^"9"\),
                        Superscript[ "9"],
                        Editable->False],
                      SequenceForm[ 
                        Superscript[ "9"]],
                      Editable->False]}],
                  SequenceForm[ 
                    Format[ "\[Phi]3"], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]], 
                    SequenceForm[ 
                      Superscript[ "9"]]],
                  Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{\(o\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(v0\^3\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(1\/18\), " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              FormBox["\<\"\[Phi]3\"\>",
                                "StandardForm"],
                              Format], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False]}],
                          SequenceForm[ 
                            Format[ "\[Phi]3"], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]]],
                          Editable->False], ")"}], "2"]}], "+", 
                  RowBox[{\(1\/8\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/8\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{"v0", " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/6\), " ", \(cr[0]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/6\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(5\/72\), " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              FormBox["\<\"\[Phi]3\"\>",
                                "StandardForm"],
                              Format], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False]}],
                          SequenceForm[ 
                            Format[ "\[Phi]3"], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]]],
                          Editable->False], ")"}], "2"]}], "+", 
                  RowBox[{\(1\/8\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/24\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{"v0", " ", \(w\^2\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(-\(1\/6\)\), " ", \(cr[2]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/24\), " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              FormBox["\<\"\[Phi]3\"\>",
                                "StandardForm"],
                              Format], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False]}],
                          SequenceForm[ 
                            Format[ "\[Phi]3"], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]]],
                          Editable->False], ")"}], "2"]}], "+", 
                  RowBox[{\(1\/24\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{\(w\^3\), " ", 
              RowBox[{"(", 
                RowBox[{\(-cr[3]\), "-", 
                  RowBox[{\(1\/3\), " ", \(cr[2]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/72\), " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              FormBox["\<\"\[Phi]3\"\>",
                                "StandardForm"],
                              Format], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False]}],
                          SequenceForm[ 
                            Format[ "\[Phi]3"], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]]],
                          Editable->False], ")"}], "2"]}], "+", 
                  RowBox[{\(1\/24\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{
              RowBox[{"(", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      FormBox["\<\"u0\"\>",
                        "StandardForm"],
                      Format], "\[InvisibleSpace]", 
                    TagBox[
                      FormBox[
                        InterpretationBox[\(\[Null]\_"p'"\),
                          Subscript[ "p'"],
                          Editable->False],
                        "StandardForm"],
                      Format]}],
                  SequenceForm[ 
                    Format[ "u0"], 
                    Format[ al1]],
                  Editable->False], ")"}], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(-3\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"e\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "e"], 
                          Format[ al2], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al2], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/4\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au2]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"r'"\),
                                Superscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au2], 
                          Format[ au3]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"r'"\),
                                Subscript[ "r'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          Format[ al2], 
                          Format[ al3], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(v0\^2\), " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al2], 
                                Format[ au1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au2]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al2], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/3\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}]}], ")"}]}], "+", 
                  RowBox[{"v0", " ", "w", " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{\(-\(1\/4\)\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al2], 
                                Format[ au1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au2]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al2], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/6\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}]}], ")"}]}], "+", 
                  RowBox[{\(w\^2\), " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{\(-\(1\/4\)\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al2], 
                                Format[ au1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au2]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al2], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/6\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}]}], ")"}]}], "-", 
                  RowBox[{\(1\/6\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{"w", " ", 
              RowBox[{"(", 
                RowBox[{\(-cr[1]\), "+", 
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/3\), " ", \(cr[0]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/6\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(13\/72\), " ", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              FormBox["\<\"\[Phi]3\"\>",
                                "StandardForm"],
                              Format], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False], "\[InvisibleSpace]", 
                            InterpretationBox[
                              InterpretationBox[\(\[Null]\^"9"\),
                                Superscript[ "9"],
                                Editable->False],
                              SequenceForm[ 
                                Superscript[ "9"]],
                              Editable->False]}],
                          SequenceForm[ 
                            Format[ "\[Phi]3"], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]], 
                            SequenceForm[ 
                              Superscript[ "9"]]],
                          Editable->False], ")"}], "2"]}], "+", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ au1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ al2]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"q'"\),
                                Superscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ au2]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"q'"\),
                                Subscript[ "q'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al2], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(v0\^2\), " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{\(-\(1\/8\)\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/24\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}]}], ")"}]}], "-", 
                  RowBox[{\(1\/8\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/4\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]4\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "\[Phi]4"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}]}]}], ")"}]}]}], 
          ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(zformulatauu0 = 
      Collect[tgeto2[ApplyRules[zformulatau, rulesproj]], {tau, o, ru0[al1], 
          w, v0}]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(1\/tau\), 
        RowBox[{"(", 
          RowBox[{\(-v0\), "+", "w", "+", 
            RowBox[{"o", " ", 
              RowBox[{"(", 
                RowBox[{\(-cr[0]\), "+", 
                  RowBox[{\(w\^2\), " ", 
                    RowBox[{"(", 
                      RowBox[{\(-cr[2]\), "+", 
                        RowBox[{\(1\/6\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}]}], ")"}]}], "-", 
                  RowBox[{\(1\/3\), " ", \(v0\^2\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{\(1\/6\), " ", "v0", " ", "w", " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{\(o\^2\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(-\(1\/6\)\), " ", "v0", " ", \(cr[0]\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}], "+", 
                  RowBox[{"w", " ", 
                    RowBox[{"(", 
                      RowBox[{\(-cr[1]\), "-", 
                        RowBox[{\(1\/3\), " ", \(cr[0]\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(v0\^2\), " ", 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{\(-\(1\/8\)\), " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]3\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\_"p'"\),
                                        Subscript[ "p'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]3"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      Format[ al1]],
                                    Editable->False], ")"}], " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]3\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\^"p'"\),
                                        Superscript[ "p'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]3"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      Format[ au1]],
                                    Editable->False], ")"}]}], "+", 
                              RowBox[{\(1\/24\), " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]4\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]4"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]]],
                                    Editable->False], ")"}]}]}], ")"}]}]}], 
                      ")"}]}], "+", 
                  RowBox[{\(v0\^3\), " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{\(1\/18\), " ", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    FormBox["\<\"\[Phi]3\"\>",
                                      "StandardForm"],
                                    Format], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False]}],
                                SequenceForm[ 
                                  Format[ "\[Phi]3"], 
                                  SequenceForm[ 
                                    Superscript[ "9"]], 
                                  SequenceForm[ 
                                    Superscript[ "9"]], 
                                  SequenceForm[ 
                                    Superscript[ "9"]]],
                                Editable->False], ")"}], "2"]}], "+", 
                        RowBox[{\(1\/8\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/8\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}]}], ")"}]}], "+", 
                  RowBox[{"v0", " ", \(w\^2\), " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{\(-\(1\/6\)\), " ", \(cr[2]\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/24\), " ", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    FormBox["\<\"\[Phi]3\"\>",
                                      "StandardForm"],
                                    Format], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False]}],
                                SequenceForm[ 
                                  Format[ "\[Phi]3"], 
                                  SequenceForm[ 
                                    Superscript[ "9"]], 
                                  SequenceForm[ 
                                    Superscript[ "9"]], 
                                  SequenceForm[ 
                                    Superscript[ "9"]]],
                                Editable->False], ")"}], "2"]}], "+", 
                        RowBox[{\(1\/24\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}]}], ")"}]}], "+", 
                  RowBox[{\(w\^3\), " ", 
                    RowBox[{"(", 
                      RowBox[{\(-cr[3]\), "-", 
                        RowBox[{\(1\/3\), " ", \(cr[2]\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/72\), " ", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    FormBox["\<\"\[Phi]3\"\>",
                                      "StandardForm"],
                                    Format], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False]}],
                                SequenceForm[ 
                                  Format[ "\[Phi]3"], 
                                  SequenceForm[ 
                                    Superscript[ "9"]], 
                                  SequenceForm[ 
                                    Superscript[ "9"]], 
                                  SequenceForm[ 
                                    Superscript[ "9"]]],
                                Editable->False], ")"}], "2"]}], "+", 
                        RowBox[{\(1\/24\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}]}], ")"}]}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"u0\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "u0"], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{\(v0\^2\), " ", 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{\(1\/2\), " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]3\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]3"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]]],
                                    Editable->False], ")"}], " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]3\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\^"p'"\),
                                        Superscript[ "p'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]3"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      Format[ au1]],
                                    Editable->False], ")"}]}], "-", 
                              RowBox[{"2", " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"d\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\_"q'"\),
                                        Subscript[ "q'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\^"p'"\),
                                        Superscript[ "p'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "d"], 
                                      Format[ al2], 
                                      Format[ au1]],
                                    Editable->False], ")"}], " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]3\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\^"q'"\),
                                        Superscript[ "q'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]3"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      Format[ au2]],
                                    Editable->False], ")"}]}], "+", 
                              RowBox[{
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]3\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\^"q'"\),
                                        Superscript[ "q'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]3"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      Format[ au2]],
                                    Editable->False], ")"}], " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]3\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\_"q'"\),
                                        Subscript[ "q'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\^"p'"\),
                                        Superscript[ "p'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]3"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      Format[ al2], 
                                      Format[ au1]],
                                    Editable->False], ")"}]}], "-", 
                              RowBox[{\(1\/3\), " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]4\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\^"p'"\),
                                        Superscript[ "p'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]4"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      Format[ au1]],
                                    Editable->False], ")"}]}]}], ")"}]}], "+",
                         
                        RowBox[{"v0", " ", "w", " ", 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{\(-\(1\/4\)\), " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]3\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]3"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]]],
                                    Editable->False], ")"}], " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]3\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\^"p'"\),
                                        Superscript[ "p'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]3"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      Format[ au1]],
                                    Editable->False], ")"}]}], "+", 
                              RowBox[{
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"d\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\_"q'"\),
                                        Subscript[ "q'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\^"p'"\),
                                        Superscript[ "p'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "d"], 
                                      Format[ al2], 
                                      Format[ au1]],
                                    Editable->False], ")"}], " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]3\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\^"q'"\),
                                        Superscript[ "q'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]3"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      Format[ au2]],
                                    Editable->False], ")"}]}], "-", 
                              RowBox[{\(1\/2\), " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]3\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\^"q'"\),
                                        Superscript[ "q'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]3"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      Format[ au2]],
                                    Editable->False], ")"}], " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]3\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\_"q'"\),
                                        Subscript[ "q'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\^"p'"\),
                                        Superscript[ "p'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]3"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      Format[ al2], 
                                      Format[ au1]],
                                    Editable->False], ")"}]}], "+", 
                              RowBox[{\(1\/6\), " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]4\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\^"p'"\),
                                        Superscript[ "p'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]4"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      Format[ au1]],
                                    Editable->False], ")"}]}]}], ")"}]}], "+",
                         
                        RowBox[{\(w\^2\), " ", 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{\(-\(1\/4\)\), " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]3\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]3"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]]],
                                    Editable->False], ")"}], " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]3\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\^"p'"\),
                                        Superscript[ "p'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]3"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      Format[ au1]],
                                    Editable->False], ")"}]}], "+", 
                              RowBox[{
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"d\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\_"q'"\),
                                        Subscript[ "q'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\^"p'"\),
                                        Superscript[ "p'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "d"], 
                                      Format[ al2], 
                                      Format[ au1]],
                                    Editable->False], ")"}], " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]3\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\^"q'"\),
                                        Superscript[ "q'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]3"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      Format[ au2]],
                                    Editable->False], ")"}]}], "-", 
                              RowBox[{\(1\/2\), " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]3\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\^"q'"\),
                                        Superscript[ "q'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]3"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      Format[ au2]],
                                    Editable->False], ")"}], " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]3\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\_"q'"\),
                                        Subscript[ "q'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\^"p'"\),
                                        Superscript[ "p'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]3"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      Format[ al2], 
                                      Format[ au1]],
                                    Editable->False], ")"}]}], "+", 
                              RowBox[{\(1\/6\), " ", 
                                RowBox[{"(", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        FormBox["\<\"\[Phi]4\"\>",
                                        "StandardForm"],
                                        Format], "\[InvisibleSpace]", 
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      InterpretationBox[
                                        InterpretationBox[\(\[Null]\^"9"\),
                                        Superscript[ "9"],
                                        Editable->False],
                                        SequenceForm[ 
                                        Superscript[ "9"]],
                                        Editable->False], "\[InvisibleSpace]",
                                       
                                      TagBox[
                                        FormBox[
                                        InterpretationBox[\(\[Null]\^"p'"\),
                                        Superscript[ "p'"],
                                        Editable->False],
                                        "StandardForm"],
                                        Format]}],
                                    SequenceForm[ 
                                      Format[ "\[Phi]4"], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      SequenceForm[ 
                                        Superscript[ "9"]], 
                                      Format[ au1]],
                                    Editable->False], ")"}]}]}], ")"}]}]}], 
                      ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"tau", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"o", " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"d\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\^"p'"\),
                                Superscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "d"], 
                          Format[ al1], 
                          Format[ au1]],
                        Editable->False], ")"}]}], "-", 
                  RowBox[{\(1\/6\), " ", 
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"\[Phi]3\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False], "\[InvisibleSpace]", 
                          InterpretationBox[
                            InterpretationBox[\(\[Null]\^"9"\),
                              Superscript[ "9"],
                              Editable->False],
                            SequenceForm[ 
                              Superscript[ "9"]],
                            Editable->False]}],
                        SequenceForm[ 
                          Format[ "\[Phi]3"], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]], 
                          SequenceForm[ 
                            Superscript[ "9"]]],
                        Editable->False], ")"}]}]}], ")"}]}], "+", 
            RowBox[{\(o\^2\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"v0", " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al1], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al2], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/6\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al1], 
                                Format[ au1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(5\/72\), " ", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    FormBox["\<\"\[Phi]3\"\>",
                                      "StandardForm"],
                                    Format], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False]}],
                                SequenceForm[ 
                                  Format[ "\[Phi]3"], 
                                  SequenceForm[ 
                                    Superscript[ "9"]], 
                                  SequenceForm[ 
                                    Superscript[ "9"]], 
                                  SequenceForm[ 
                                    Superscript[ "9"]]],
                                Editable->False], ")"}], "2"]}], "+", 
                        RowBox[{\(1\/8\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/24\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}]}], ")"}]}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            FormBox["\<\"u0\"\>",
                              "StandardForm"],
                            Format], "\[InvisibleSpace]", 
                          TagBox[
                            FormBox[
                              InterpretationBox[\(\[Null]\_"p'"\),
                                Subscript[ "p'"],
                                Editable->False],
                              "StandardForm"],
                            Format]}],
                        SequenceForm[ 
                          Format[ "u0"], 
                          Format[ al1]],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{\(-3\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"e\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "e"], 
                                Format[ al2], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al2], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/4\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al2], 
                                Format[ au1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au2]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al2], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"r'"\),
                                      Superscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ au2], 
                                Format[ au3]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"r'"\),
                                      Subscript[ "r'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                Format[ al2], 
                                Format[ al3], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/6\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}]}], ")"}]}], "+", 
                  RowBox[{"w", " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al1], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al2], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/6\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ al1], 
                                Format[ au1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(13\/72\), " ", 
                          SuperscriptBox[
                            RowBox[{"(", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    FormBox["\<\"\[Phi]3\"\>",
                                      "StandardForm"],
                                    Format], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False], "\[InvisibleSpace]", 
                                  InterpretationBox[
                                    InterpretationBox[\(\[Null]\^"9"\),
                                      Superscript[ "9"],
                                      Editable->False],
                                    SequenceForm[ 
                                      Superscript[ "9"]],
                                    Editable->False]}],
                                SequenceForm[ 
                                  Format[ "\[Phi]3"], 
                                  SequenceForm[ 
                                    Superscript[ "9"]], 
                                  SequenceForm[ 
                                    Superscript[ "9"]], 
                                  SequenceForm[ 
                                    Superscript[ "9"]]],
                                Editable->False], ")"}], "2"]}], "+", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al1]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"d\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "d"], 
                                Format[ au1], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al1], 
                                Format[ al2]],
                              Editable->False], ")"}]}], "+", 
                        RowBox[{\(1\/2\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"q'"\),
                                      Superscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al1], 
                                Format[ au2]],
                              Editable->False], ")"}], " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]3\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"q'"\),
                                      Subscript[ "q'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]3"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al2], 
                                Format[ au1]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/8\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]]],
                              Editable->False], ")"}]}], "-", 
                        RowBox[{\(1\/4\), " ", 
                          RowBox[{"(", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  FormBox["\<\"\[Phi]4\"\>",
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                InterpretationBox[
                                  InterpretationBox[\(\[Null]\^"9"\),
                                    Superscript[ "9"],
                                    Editable->False],
                                  SequenceForm[ 
                                    Superscript[ "9"]],
                                  Editable->False], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\_"p'"\),
                                      Subscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format], "\[InvisibleSpace]", 
                                TagBox[
                                  FormBox[
                                    InterpretationBox[\(\[Null]\^"p'"\),
                                      Superscript[ "p'"],
                                      Editable->False],
                                    "StandardForm"],
                                  Format]}],
                              SequenceForm[ 
                                Format[ "\[Phi]4"], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                SequenceForm[ 
                                  Superscript[ "9"]], 
                                Format[ al1], 
                                Format[ au1]],
                              Editable->False], ")"}]}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(InputForm[zformulatauu0]\)], "Input"],

Cell["\<\
(-v0 + w + o*(-cr[0] + w^2*(-cr[2] + tp3[9, 9, 9]/6) - 
     (v0^2*tp3[9, 9, 9])/3 + (v0*w*tp3[9, 9, 9])/6) + 
   o^2*(-(v0*cr[0]*tp3[9, 9, 9])/6 + 
     w*(-cr[1] - (cr[0]*tp3[9, 9, 9])/3 + 
       v0^2*(-(tp3[9, 9, al1]*tp3[9, 9, au1])/8 + 
         tp4[9, 9, 9, 9]/24)) + v0^3*(tp3[9, 9, 9]^2/18 + 
       (tp3[9, 9, al1]*tp3[9, 9, au1])/8 - tp4[9, 9, 9, 9]/8) + 
     v0*w^2*(-(cr[2]*tp3[9, 9, 9])/6 - tp3[9, 9, 9]^2/24 + 
       tp4[9, 9, 9, 9]/24) + w^3*(-cr[3] - (cr[2]*tp3[9, 9, 9])/3 - 
       tp3[9, 9, 9]^2/72 + tp4[9, 9, 9, 9]/24) + 
     ru0[al1]*(v0^2*((tp3[9, 9, 9]*tp3[9, 9, au1])/2 - 
         2*td[al2, au1]*tp3[9, 9, au2] + tp3[9, 9, au2]*
          tp3[9, al2, au1] - tp4[9, 9, 9, au1]/3) + 
       v0*w*(-(tp3[9, 9, 9]*tp3[9, 9, au1])/4 + 
         td[al2, au1]*tp3[9, 9, au2] - 
         (tp3[9, 9, au2]*tp3[9, al2, au1])/2 + tp4[9, 9, 9, au1]/
          6) + w^2*(-(tp3[9, 9, 9]*tp3[9, 9, au1])/4 + 
         td[al2, au1]*tp3[9, 9, au2] - 
         (tp3[9, 9, au2]*tp3[9, al2, au1])/2 + tp4[9, 9, 9, au1]/
          6))))/tau + tau*(o*(-td[al1, au1] - tp3[9, 9, 9]/6) + 
   o^2*(v0*(td[al1, au2]*td[al2, au1] - (td[al1, au1]*tp3[9, 9, 9])/
        6 + (5*tp3[9, 9, 9]^2)/72 + (tp3[9, 9, al1]*tp3[9, 9, au1])/
        8 - tp4[9, 9, 9, 9]/24) + ru0[al1]*(-3*te[al2, au1, au2] - 
       (td[al2, au2]*tp3[9, 9, au1])/2 + 
       (tp3[9, 9, 9]*tp3[9, 9, au1])/4 - td[al2, au1]*
        tp3[9, 9, au2] + (tp3[9, 9, au2]*tp3[9, al2, au1])/2 + 
       td[au2, au3]*tp3[al2, al3, au1] - tp4[9, 9, 9, au1]/6) + 
     w*(td[al1, au2]*td[al2, au1] + (td[al1, au1]*tp3[9, 9, 9])/6 + 
       (13*tp3[9, 9, 9]^2)/72 + (tp3[9, 9, al1]*tp3[9, 9, au1])/2 - 
       td[au1, au2]*tp3[9, al1, al2] + 
       (tp3[9, al1, au2]*tp3[9, al2, au1])/2 - tp4[9, 9, 9, 9]/8 - 
       tp4[9, 9, al1, au1]/4)))\
\>", "Output"]
}, Open  ]],

Cell[TextData[{
  "We confirm that zformula depends on ",
  Cell[BoxData[
      \(TraditionalForm\`u0\_\(a'\)\)]],
  "only linearly, and the term is only ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(O(n\^\(-1\))\)\(.\)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Collect[Coefficient[zformulatauu0, ru0[al1]], {o, tau}]\)], "Input"],

Cell[BoxData[
    RowBox[{\(o\^2\), " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{"tau", " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(-3\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"e\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "e"], 
                        Format[ al2], 
                        Format[ au1], 
                        Format[ au2]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"d\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "d"], 
                        Format[ al2], 
                        Format[ au2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ au1]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(1\/4\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ au1]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"d\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "d"], 
                        Format[ al2], 
                        Format[ au1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ au2]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(1\/2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ au2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ al2], 
                        Format[ au1]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"d\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"r'"\),
                              Superscript[ "r'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "d"], 
                        Format[ au2], 
                        Format[ au3]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"r'"\),
                              Subscript[ "r'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        Format[ al2], 
                        Format[ al3], 
                        Format[ au1]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{\(1\/6\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]4\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]4"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ au1]],
                      Editable->False], ")"}]}]}], ")"}]}], "+", 
          RowBox[{\(1\/tau\), 
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(1\/2\), " ", \(v0\^2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ au1]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{\(1\/4\), " ", "v0", " ", "w", " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ au1]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{\(1\/4\), " ", \(w\^2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ au1]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{"2", " ", \(v0\^2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"d\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "d"], 
                        Format[ al2], 
                        Format[ au1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ au2]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{"v0", " ", "w", " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"d\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "d"], 
                        Format[ al2], 
                        Format[ au1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ au2]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(w\^2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"d\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "d"], 
                        Format[ al2], 
                        Format[ au1]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ au2]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(v0\^2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ au2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ al2], 
                        Format[ au1]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{\(1\/2\), " ", "v0", " ", "w", " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ au2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ al2], 
                        Format[ au1]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{\(1\/2\), " ", \(w\^2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"q'"\),
                              Superscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ au2]],
                      Editable->False], ")"}], " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]3\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\_"q'"\),
                              Subscript[ "q'"],
                              Editable->False],
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]3"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ al2], 
                        Format[ au1]],
                      Editable->False], ")"}]}], "-", 
                RowBox[{\(1\/3\), " ", \(v0\^2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]4\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]4"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ au1]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(1\/6\), " ", "v0", " ", "w", " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]4\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]4"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ au1]],
                      Editable->False], ")"}]}], "+", 
                RowBox[{\(1\/6\), " ", \(w\^2\), " ", 
                  RowBox[{"(", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          FormBox["\<\"\[Phi]4\"\>",
                            "StandardForm"],
                          Format], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        InterpretationBox[
                          InterpretationBox[\(\[Null]\^"9"\),
                            Superscript[ "9"],
                            Editable->False],
                          SequenceForm[ 
                            Superscript[ "9"]],
                          Editable->False], "\[InvisibleSpace]", 
                        TagBox[
                          FormBox[
                            InterpretationBox[\(\[Null]\^"p'"\),
                              Superscript[ "p'"],
                              Editable->False],
                            "StandardForm"],
                          Format]}],
                      SequenceForm[ 
                        Format[ "\[Phi]4"], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        SequenceForm[ 
                          Superscript[ "9"]], 
                        Format[ au1]],
                      Editable->False], ")"}]}]}], ")"}]}]}], 
        ")"}]}]], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Bootstrap Methods", "Subsubtitle"],

Cell["\<\
In this part, the asymptotic accuracies of several bootstrap methods are \
discussed. We use the zc-formula obtained in the previous part.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Startup", "Section"],

Cell[TextData[{
  "This section initializes the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session."
}], "Text"],

Cell[CellGroupData[{

Cell["packages", "Subsubsection"],

Cell[BoxData[
    \(<< \ Statistics`ContinuousDistributions`\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["error messages", "Subsubsection"],

Cell[BoxData[
    \(Off[General::spell1]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["distribution functions", "Subsubsection"],

Cell[BoxData[{
    \(gammadist[x_, m_, \[Alpha]_] := 
      PDF[GammaDistribution[m, \[Alpha]], x]\), "\n", 
    \(Gammadist[x_, m_, \[Alpha]_] := 
      CDF[GammaDistribution[m, \[Alpha]], x]\), "\n", 
    \(f[x_] := PDF[NormalDistribution[0, 1], x]\), "\n", 
    \(F[x_] := CDF[NormalDistribution[0, 1], x]\), "\n", 
    \(Q[x_] := Quantile[NormalDistribution[0, 1], x]\), "\n", 
    \(Chidist[x_, {di_, nc_}] := 
      CDF[NoncentralChiSquareDistribution[di, nc], x]\)}], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Asymptotic Analysis of Bootstrap Methods", "Section"],

Cell["\<\
This section calculates the distribution functions of several bootstrap \
methods for showing their asymptotic accuracies in terms of the unbiasedness \
of hypothesis testing of the region R. The calculations are based on the \
zc-formula obtained in the previous part. We first define a pivot statistic \
and shows its third-order accuracy. The bootstrap probability is first-order \
accurate, the double bootstrap is second-order accurate, and the two-level \
bootstrap is second-order accurate.\
\>", "Text"],

Cell[CellGroupData[{

Cell["preliminary", "Subsection"],

Cell[TextData[{
  "The zc-formula is given in zc[w,cc,v0,tau]=zformtau=",
  Cell[BoxData[
      \(TraditionalForm\`\(z\_c\)(w; v0, tau) = \(\[CapitalPhi]\^\(-1\)\)[
          Pr {W \[LessEqual] w; v0, tau}]\)]],
  ", where cc={c0,c1,c2,c3} specifies the modified signed distance w. The \
signed distance v is expressed in terms of w by  ",
  Cell[BoxData[
      \(TraditionalForm\`v = w - \[Sum]\+\(r = 0\)\%3\( c\_r\) w\^r\)]],
  ", or in the inverse series ",
  Cell[BoxData[
      \(TraditionalForm\`w = v - \[Sum]\+\(r = 0\)\%3\( cb\_r\) v\^r\)]],
  ". We write the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`cb\_0 = cb0, \ cb\_1 = cb1, \)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`c\_0 = c0, \ c\_1 = c1\)]],
  ", etc. The rule to calculate {c0,c1,c2,c3} in terms of {cb0,cb1,cb2,cb3} \
is given in \"rulecc2cb\" or in cb2cc function. The function zq2cc[exp] \
calculates the {c0,c1,c2,c3} from the polynomial of w in terms of v."
}], "Text"],

Cell[CellGroupData[{

Cell["simplification functions", "Subsubsection"],

Cell[TextData[{
  "Ignore ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(\(-3\)/2\))\)]],
  " terms for scalar"
}], "Text"],

Cell[BoxData[
    \(geto2[exp_] := 
      Sum[Simplify[Coefficient[exp, o, i]] o\^i, {i, \(-1\), 2}]\)], "Input"],

Cell[TextData[{
  "Series expansion for scalar ignoring ",
  Cell[BoxData[
      \(TraditionalForm\`\(O(n\^\(\(-3\)/2\))\)\ \(\(terms\)\(.\)\)\)]]
}], "Text"],

Cell[BoxData[
    \(gets2[exp_] := geto2[Series[exp, {o, 0, 2}]]\)], "Input"],

Cell[BoxData[
    \(geto[exp_, n_] := 
      Sum[Simplify[Coefficient[exp, o, i]] o\^i, {i, \(-1\), n}]\)], "Input"],

Cell[BoxData[
    \(gets[exp_, n_] := geto[Series[exp, {o, 0, n}], n]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["zc-formula", "Subsubsection"],

Cell[TextData[{
  "zc[w,cc,v0,tau]=zformtau is ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\_c\)(w; v0, tau) = \(\[CapitalPhi]\^\(-1\)\)[
          Pr {W \[LessEqual] w; v0, tau}]\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`u0\_\(a'\)\)]],
  "is assumed zero. The coefficients cc={c0,c1,c2,c3} specify the modified \
signed distance w. We do not need to use the more general zformulatauu0 in \
which ",
  Cell[BoxData[
      \(TraditionalForm\`u0\_\(a'\) \[NotEqual] 0\)]],
  ", because the u0 terms contribute only ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(\(-3\)/2\))\)]],
  " in our calculation below."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(zc[w_, {c0_, c1_, c2_, c3_}, v0_, tau_] = 
      tau*\((o*\((\(-Daa\) - P999/6)\) + 
              o^2*\((\((Dab2 - \((Daa*P999)\)/6 + \((5*P999^2)\)/72 - 
                          P9999/24 + P99a2/8)\)*
                      v0 + \((Dab2 - 
                          DabP9ab + \((Daa*P999)\)/6 + \((13*P999^2)\)/72 - 
                          P9999/8 + P99a2/2 - P99aa/4 + P9ab2/2)\)*
                      w)\))\) + \((\(-v0\) + w + 
              o*\((\(-c0\) - \((P999*v0^2)\)/3 + \((P999*v0*w)\)/
                      6 + \((\(-c2\) + P999/6)\)*w^2)\) + 
              o^2*\((\(-\((c0*P999*v0)\)\)/
                      6 + \((P999^2/18 - P9999/8 + P99a2/8)\)*
                      v0^3 + \((\(-c1\) - \((c0*P999)\)/
                            3 + \((P9999/24 - P99a2/8)\)*v0^2)\)*
                      w + \((\(-\((c2*P999)\)\)/6 - P999^2/24 + P9999/24)\)*
                      v0*w^2 + \((\(-c3\) - \((c2*P999)\)/3 - P999^2/72 + 
                          P9999/24)\)*w^3)\))\)/tau\)], "Input"],

Cell[BoxData[
    \(tau\ \((o\ \((\(-Daa\) - P999\/6)\) + 
            o\^2\ \((\((Dab2 - \(Daa\ P999\)\/6 + \(5\ P999\^2\)\/72 - 
                        P9999\/24 + P99a2\/8)\)\ v0 + \((Dab2 - 
                        DabP9ab + \(Daa\ P999\)\/6 + \(13\ P999\^2\)\/72 - 
                        P9999\/8 + P99a2\/2 - P99aa\/4 + 
                        P9ab2\/2)\)\ w)\))\) + \(1\/tau\) \((\(-v0\) + w + 
            o\ \((\(-c0\) - \(P999\ v0\^2\)\/3 + \(P999\ v0\ w\)\/6 + \
\((\(-c2\) + P999\/6)\)\ w\^2)\) + 
            o\^2\ \((\(-\(1\/6\)\)\ c0\ P999\ v0 + \((P999\^2\/18 - 
                        P9999\/8 + 
                        P99a2\/8)\)\ v0\^3 + \((\(-c1\) - \(c0\ P999\)\/3 + \
\((P9999\/24 - P99a2\/8)\)\ v0\^2)\)\ w + \((\(-\(\(c2\ P999\)\/6\)\) - 
                        P999\^2\/24 + 
                        P9999\/24)\)\ v0\ w\^2 + \((\(-c3\) - \(c2\ P999\)\/3 \
- P999\^2\/72 + P9999\/24)\)\ w\^3)\))\)\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["modified signed distance", "Subsubsection"],

Cell["{c0,c1,c2,c3} are represented by {cb0,cb1,cb2,cb3}", "Text"],

Cell[BoxData[
    \(\(rulecc2cb = {c0 \[Rule] cb0, c1 \[Rule] cb1 - 2\ cb0\ \ cb2, 
          c2 \[Rule] cb2, c3 \[Rule] \(-2\)\ cb2\^2 + cb3};\)\)], "Input"],

Cell[BoxData[
    \(coef2cb[coef_] := 
      Expand[Simplify[\((coef - {0, 1, 0, 0})\)/{o, o\^2, o, 
              o\^2}]]\)], "Input"],

Cell[BoxData[
    \(\(cb2cc[{cb0_, cb1_, cb2_, cb3_}] := 
        Expand[Simplify[{cb0, cb1 - 2\ cb0\ cb2, 
              cb2, \(-2\)\ cb2\^2 + cb3}]];\)\)], "Input"],

Cell[BoxData[
    \(zq2cc[exp_] := 
      cb2cc[coef2cb[PadRight[CoefficientList[exp, v], 4]]]\)], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["the pivot and some existing bootstrap methods", "Subsection"],

Cell[TextData[{
  "The pivot is defined as z8[v]=",
  Cell[BoxData[
      \(TraditionalForm\`\(z\&^\_\[Infinity]\)(0, 
          v) = \(-\(\(\[CapitalPhi]\^\(-1\)\)(
            Pr {V \[GreaterEqual] v; v0 = 0))\)\)\)]],
  "=zc[v,{0,0,0,0},0,1]. ",
  Cell[BoxData[
      \(TraditionalForm\`cb\_r\)]],
  "'s and ",
  Cell[BoxData[
      \(TraditionalForm\`c\_r\)]],
  "'s are in cbz8 and ccz8 respectively for z8[v].  We define zq[v]=",
  Cell[BoxData[
      \(TraditionalForm\`\(z\&^\_q\)(0, v)\)]],
  "=z8[v] + q0 + q1 v + q2 ",
  Cell[BoxData[
      \(TraditionalForm\`v\^2\)]],
  "+ q3 ",
  Cell[BoxData[
      \(TraditionalForm\`v\^3\)]],
  ", where the coefficients qq={q0,q1,q2,q3} specify the zq[v]. zq2qq \
calculates qq from any z-value. ",
  Cell[BoxData[
      \(TraditionalForm\`cb\_r\)]],
  "'s and ",
  Cell[BoxData[
      \(TraditionalForm\`c\_r\)]],
  "'s are in cbzq and cczq respectively for zq[v]. The distribution function \
of zq is obtained as ",
  Cell[BoxData[
      \(TraditionalForm\`Pr {zq[V] \[LessEqual] w; v0, tau}\)]],
  "=\[CapitalPhi]{zfzq[w,{q0,q1,q2,q3},v0,tau]}. We observe that \
zfzq[w,{0,0,0,0},0,1]=w, and thus ",
  "the distribution function of z8 under v0=0 is Pr{Z8\[LessEqual]w;0,1)=\
\[CapitalPhi](w)."
}], "Text"],

Cell[TextData[{
  "The bootstrap probability is ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Alpha]\&~\_1\)(0, v, tau1) = 
        Pr {V \[LessEqual] 0; \ v0 = v, tau1}\)]],
  " for y=\[Eta](0,v), and the corresponding z-value is z1[v,tau1]=",
  Cell[BoxData[
      \(TraditionalForm\`\(z\&~\_1\)(0, v, 
          tau1) = \(-\(\(\[CapitalPhi]\^\(-1\)\)(\(\[Alpha]\&~\_1\)(0, v, 
              tau1))\)\)\)]],
  "=-zc[0,{0,0,0,0},v,tau1]. For tau1=1, we define ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(z\&^\_0\)\(=\)\)\)]],
  "z0[v]=z1[v,1], which can be regarded as another w. For general tau1, \
w1=tau1 z1[v,tau1] is regarded as another w with ",
  Cell[BoxData[
      \(TraditionalForm\`cb\_r\)]],
  "'s being cbw1 and ",
  Cell[BoxData[
      \(TraditionalForm\`c\_r\)]],
  "'s being ccw1, and the distribution function is expressed as ",
  Cell[BoxData[
      \(TraditionalForm\`Pr {W1 \[LessEqual] w; \ v0, tau} = \[CapitalPhi](
          zfw1)\)]],
  ". For tau=1 and tau1=1, we have ",
  Cell[BoxData[
      \(TraditionalForm\`Pr {Z\&^\_0 \[LessEqual] w; v0, 
            tau = 1} = \[CapitalPhi] {zfz0[w, v0]}\)]],
  ", which becomes ",
  Cell[BoxData[
      \(TraditionalForm\`zfz0[w, 0] = w + O(n\^\(\(-1\)/2\))\)]],
  " under v0=0, showing the first-order accuracy of z0[v]."
}], "Text"],

Cell[TextData[{
  "The z-value of the double bootstrap probability is ",
  Cell[BoxData[
      \(TraditionalForm\`zd[
          v] = \(-\(\[CapitalPhi]\^\(-1\)\)[
            Pr {Z\&^\_0 \[LessEqual] \(z\&^\_0\)(v); v0 = 0}]\)\)]],
  ", and we observe that z8[v]=zd[v], showing the double bootstrap \
asymptotically equivalent to the third-order accurate pivot statistic up to \
",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(-1\))\)]],
  " terms."
}], "Text"],

Cell[TextData[{
  "The ABC formula is given in abcformula[v,ac]. The z-value of the two-level \
bootstrap method is calculated in za[v]. Its ",
  Cell[BoxData[
      \(TraditionalForm\`q\_i\)]],
  "'s are in qqza. The distribution function of za[v]  under tau=1 is \
Pr{za[V]\[LessEqual]w;v0,1}=\[CapitalPhi][zfzq[w,qqza,v0,1]]. This becomes ",
  Cell[BoxData[
      \(TraditionalForm\`w + O(n\^\(-1\))\)]],
  " for v0=0, showing the second-order accuracy of the two-level bootstrap."
}], "Text"],

Cell[CellGroupData[{

Cell["pivot statistic", "Subsubsection"],

Cell[TextData[{
  "We define ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Alpha]\&^\_\[Infinity]\)(0, v) = 
        Pr {V \[GreaterEqual] v; v0 = 0)\)]],
  ", and the corresponding z-value ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\&^\_\[Infinity]\)(0, 
          v) = \(-\(\(\(\[CapitalPhi]\^\(-1\)\)(\(\[Alpha]\&^\_\[Infinity]\)(
                0, v))\)\(.\)\)\)\)]],
  " We denote this z-value as z8[v]=zc[v,{0,0,0,0},0,1]."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(z8[v_] = Collect[zc[v, {0, 0, 0, 0}, 0, 1], {o, v}]\)], "Input"],

Cell[BoxData[
    \(v + o\ \((\(-Daa\) - P999\/6 + \(P999\ v\^2\)\/6)\) + 
      o\^2\ \((\((Dab2 - DabP9ab + \(Daa\ P999\)\/6 + \(13\ P999\^2\)\/72 - 
                  P9999\/8 + P99a2\/2 - P99aa\/4 + 
                  P9ab2\/2)\)\ v + \((\(-\(P999\^2\/72\)\) + 
                  P9999\/24)\)\ v\^3)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cbz8 = coef2cb[CoefficientList[z8[v], v]]\)], "Input"],

Cell[BoxData[
    \({\(-Daa\) - P999\/6, 
      Dab2 - DabP9ab + \(Daa\ P999\)\/6 + \(13\ P999\^2\)\/72 - P9999\/8 + 
        P99a2\/2 - P99aa\/4 + P9ab2\/2, 
      P999\/6, \(-\(P999\^2\/72\)\) + P9999\/24}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ccz8 = cb2cc[cbz8]\)], "Input"],

Cell[BoxData[
    \({\(-Daa\) - P999\/6, 
      Dab2 - DabP9ab + \(Daa\ P999\)\/2 + \(17\ P999\^2\)\/72 - P9999\/8 + 
        P99a2\/2 - P99aa\/4 + P9ab2\/2, 
      P999\/6, \(-\(\(5\ P999\^2\)\/72\)\) + P9999\/24}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We slightly alter z8[v] and denoted zq[v]=",
  Cell[BoxData[
      \(TraditionalForm\`\(z\&^\_q\)(0, v)\)]],
  " below. "
}], "Text"],

Cell[BoxData[
    \(\(zq[v_, {q0_, q1_, q2_, q3_}] = 
        z8[v]\  + \ o\ q0 + \ \(o\^2\) q1\ v\  + 
          o\ q2\ v\^2\  + \ \(o\^2\) q3\ v\^3;\)\)], "Input"],

Cell[TextData[{
  "Here we define a function to collect ",
  Cell[BoxData[
      \(TraditionalForm\`q\_i\)]],
  "'s for later use"
}], "Text"],

Cell[BoxData[
    \(zq2qq[zz_] := 
      Expand[Simplify[
          PadRight[CoefficientList[zz - z8[v], v], 4]/{o, o\^2, o, 
              o\^2}]]\)], "Input"],

Cell["check if this is correct.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(zq2qq[zq[v, {q0, q1, q2, q3}]]\)], "Input"],

Cell[BoxData[
    \({q0, q1, q2, q3}\)], "Output"]
}, Open  ]],

Cell["\<\
Now we continue to calculate the distribution function of zq[v]\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cbzq = coef2cb[CoefficientList[zq[v, {q0, q1, q2, q3}], v]]\)], "Input"],

Cell[BoxData[
    \({\(-Daa\) - P999\/6 + q0, 
      Dab2 - DabP9ab + \(Daa\ P999\)\/6 + \(13\ P999\^2\)\/72 - P9999\/8 + 
        P99a2\/2 - P99aa\/4 + P9ab2\/2 + q1, 
      P999\/6 + q2, \(-\(P999\^2\/72\)\) + P9999\/24 + q3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cczq = cb2cc[cbzq]\)], "Input"],

Cell[BoxData[
    \({\(-Daa\) - P999\/6 + q0, 
      Dab2 - DabP9ab + \(Daa\ P999\)\/2 + \(17\ P999\^2\)\/72 - P9999\/8 + 
        P99a2\/2 - P99aa\/4 + P9ab2\/2 - \(P999\ q0\)\/3 + q1 + 
        2\ Daa\ q2 + \(P999\ q2\)\/3 - 2\ q0\ q2, 
      P999\/6 + q2, \(-\(\(5\ P999\^2\)\/72\)\) + 
        P9999\/24 - \(2\ P999\ q2\)\/3 - 2\ q2\^2 + q3}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The distribution function of zq is obtained here. ",
  Cell[BoxData[
      \(TraditionalForm\`Pr {zq[V] \[LessEqual] w; v0, tau}\)]],
  "=\[CapitalPhi]{zfzq[w,{q0,q1,q2,q3},v0,tau]}."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(zfzq[w_, {q0_, q1_, q2_, q3_}, v0_, tau_] = 
      Collect[zc[w, cczq, v0, tau], {o, w, v0}, Expand]\)], "Input"],

Cell[BoxData[
    \(\(-\(v0\/tau\)\) + w\/tau + 
      o\ \((Daa\/tau + P999\/\(6\ tau\) - q0\/tau - 
            Daa\ tau - \(P999\ tau\)\/6 - \(P999\ v0\^2\)\/\(3\ tau\) + \
\(P999\ v0\ w\)\/\(6\ tau\) - \(q2\ w\^2\)\/tau)\) + 
      o\^2\ \((\((\(Daa\ P999\)\/\(6\ tau\) + 
                  P999\^2\/\(36\ tau\) - \(P999\ q0\)\/\(6\ tau\) + 
                  Dab2\ tau - \(Daa\ P999\ tau\)\/6 + \(5\ P999\^2\ tau\)\/72 \
- \(P9999\ tau\)\/24 + \(P99a2\ tau\)\/8)\)\ v0 + \((P999\^2\/\(18\ tau\) - 
                  P9999\/\(8\ tau\) + 
                  P99a2\/\(8\ tau\))\)\ v0\^3 + \((\(-\(Dab2\/tau\)\) + 
                  DabP9ab\/tau - \(Daa\ P999\)\/\(6\ tau\) - \(13\ \
P999\^2\)\/\(72\ tau\) + P9999\/\(8\ tau\) - P99a2\/\(2\ tau\) + 
                  P99aa\/\(4\ tau\) - P9ab2\/\(2\ tau\) - 
                  q1\/tau - \(2\ Daa\ q2\)\/tau - \(P999\ q2\)\/\(3\ tau\) + \
\(2\ q0\ q2\)\/tau + Dab2\ tau - 
                  DabP9ab\ tau + \(Daa\ P999\ tau\)\/6 + \(13\ P999\^2\ tau\)\
\/72 - \(P9999\ tau\)\/8 + \(P99a2\ tau\)\/2 - \(P99aa\ tau\)\/4 + \(P9ab2\ \
tau\)\/2 + \((P9999\/\(24\ tau\) - 
                        P99a2\/\(8\ tau\))\)\ v0\^2)\)\ w + \((\(-\(\(5\ P999\
\^2\)\/\(72\ tau\)\)\) + 
                  P9999\/\(24\ tau\) - \(P999\ q2\)\/\(6\ tau\))\)\ v0\ w\^2 \
+ \((\(P999\ q2\)\/\(3\ tau\) + \(2\ q2\^2\)\/tau - 
                  q3\/tau)\)\ w\^3)\)\)], "Output"]
}, Open  ]],

Cell["For tau=1, zfzq becomes", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(zfzq[w, {q0, q1, q2, q3}, v0, 1]\)], "Input"],

Cell[BoxData[
    \(\(-v0\) + w + 
      o\ \((\(-q0\) - \(P999\ v0\^2\)\/3 + \(P999\ v0\ w\)\/6 - q2\ w\^2)\) + 
      o\^2\ \((\((Dab2 + \(7\ P999\^2\)\/72 - P9999\/24 + 
                  P99a2\/8 - \(P999\ q0\)\/6)\)\ v0 + \((P999\^2\/18 - 
                  P9999\/8 + P99a2\/8)\)\ v0\^3 + \((\(-q1\) - 
                  2\ Daa\ q2 - \(P999\ q2\)\/3 + 
                  2\ q0\ q2 + \((P9999\/24 - 
                        P99a2\/8)\)\ v0\^2)\)\ w + \((\(-\(\(5\ P999\^2\)\/72\
\)\) + P9999\/24 - \(P999\ q2\)\/6)\)\ v0\ w\^2 + \((\(P999\ q2\)\/3 + 
                  2\ q2\^2 - q3)\)\ w\^3)\)\)], "Output"]
}, Open  ]],

Cell["When v0=0, tau=1,  zfzq becomes", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(zfzq[w, {q0, q1, q2, q3}, 0, 1]\)], "Input"],

Cell[BoxData[
    \(w + o\ \((\(-q0\) - q2\ w\^2)\) + 
      o\^2\ \((\((\(-q1\) - 2\ Daa\ q2 - \(P999\ q2\)\/3 + 
                  2\ q0\ q2)\)\ w + \((\(P999\ q2\)\/3 + 2\ q2\^2 - 
                  q3)\)\ w\^3)\)\)], "Output"]
}, Open  ]],

Cell["\<\
In particular, the distribution function of z8 under v0=0 is \
Pr{Z8\[LessEqual]w;0,1)=\[CapitalPhi](w).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(zfzq[w, {0, 0, 0, 0}, 0, 1]\)], "Input"],

Cell[BoxData[
    \(w\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["bootstrap probability", "Subsubsection"],

Cell[TextData[{
  "We define ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Alpha]\&~\_1\)(0, v, tau1) = 
        Pr \(\({V \[LessEqual] 0; \ v0 = v, tau1}\)\(.\)\)\)]],
  " This is the bootstrap probability for y=\[Eta](0,v).  The z-value is ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\&~\_1\)(0, v, 
          tau1) = \(-\(\(\[CapitalPhi]\^\(-1\)\)(\(\[Alpha]\&~\_1\)(0, v, 
              tau1))\)\)\)]],
  ". This becomes z1[v,tau1]=-zc[0,{0,0,0,0},v,tau1]. For a general \
y=\[Eta](u,v) with u\[NotEqual]0, the expression changes only by the linear \
term in u and the difference is only ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(O(n\^\(-1\))\)\(.\)\)\)]],
  " "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(z1[v_, tau1_] = 
      Collect[\(-zc[0, {0, 0, 0, 0}, v, tau1]\), {tau1, o, v}, 
        Expand]\)], "Input"],

Cell[BoxData[
    \(tau1\ \((o\ \((Daa + P999\/6)\) + 
            o\^2\ \((\(-Dab2\) + \(Daa\ P999\)\/6 - \(5\ P999\^2\)\/72 + 
                  P9999\/24 - 
                  P99a2\/8)\)\ v)\) + \(v + 1\/3\ o\ P999\ v\^2 + o\^2\ \
\((\(-\(P999\^2\/18\)\) + P9999\/8 - P99a2\/8)\)\ v\^3\)\/tau1\)], "Output"]
}, Open  ]],

Cell["The following w1=tau1 z1[v,tau1] is regarded as another w.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(w1[v_, tau1_] = Collect[tau1\ z1[v, tau1], {o, v, tau1}]\)], "Input"],

Cell[BoxData[
    \(v + o\ \((\((Daa + P999\/6)\)\ tau1\^2 + \(P999\ v\^2\)\/3)\) + 
      o\^2\ \((\((\(-Dab2\) + \(Daa\ P999\)\/6 - \(5\ P999\^2\)\/72 + 
                  P9999\/24 - 
                  P99a2\/8)\)\ tau1\^2\ v + \((\(-\(P999\^2\/18\)\) + 
                  P9999\/8 - P99a2\/8)\)\ v\^3)\)\)], "Output"]
}, Open  ]],

Cell["\<\
Here we obtain the coefficients cc for w1. The scale tau1 is specified \
instead of tau.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cbw1 = coef2cb[CoefficientList[w1[v, tau1], v]]\)], "Input"],

Cell[BoxData[
    \({Daa\ tau1\^2 + \(P999\ tau1\^2\)\/6, \(-Dab2\)\ tau1\^2 + 
        1\/6\ Daa\ P999\ tau1\^2 - \(5\ P999\^2\ tau1\^2\)\/72 + \(P9999\ \
tau1\^2\)\/24 - \(P99a2\ tau1\^2\)\/8, 
      P999\/3, \(-\(P999\^2\/18\)\) + P9999\/8 - P99a2\/8}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ccw1 = cb2cc[cbw1]\)], "Input"],

Cell[BoxData[
    \({Daa\ tau1\^2 + \(P999\ tau1\^2\)\/6, \(-Dab2\)\ tau1\^2 - 
        1\/2\ Daa\ P999\ tau1\^2 - \(13\ P999\^2\ tau1\^2\)\/72 + \(P9999\ \
tau1\^2\)\/24 - \(P99a2\ tau1\^2\)\/8, 
      P999\/3, \(-\(\(5\ P999\^2\)\/18\)\) + P9999\/8 - P99a2\/8}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The distribution function of w1 under v0 and scale tau is  ",
  Cell[BoxData[
      \(TraditionalForm\`Pr {W1 \[LessEqual] w; \ v0, tau} = \[CapitalPhi](
          zfw1)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(zfw1[w_, tau1_, v0_, tau_] = 
      Collect[zc[w, ccw1, v0, tau], {o, w, tau1, v0, tau}, Expand]\)], "Input"],

Cell[BoxData[
    \(\(-\(v0\/tau\)\) + w\/tau + 
      o\ \((\((\(-Daa\) - 
                  P999\/6)\)\ tau + \(\((\(-Daa\) - P999\/6)\)\ \
tau1\^2\)\/tau - \(P999\ v0\^2\)\/\(3\ tau\) + \(P999\ v0\ w\)\/\(6\ tau\) - \
\(P999\ w\^2\)\/\(6\ tau\))\) + 
      o\^2\ \((\((Dab2 - \(Daa\ P999\)\/6 + \(5\ P999\^2\)\/72 - P9999\/24 + 
                  P99a2\/8)\)\ tau\ v0 + \(\((\(-\(\(Daa\ P999\)\/6\)\) - \
P999\^2\/36)\)\ tau1\^2\ v0\)\/tau + \(\((P999\^2\/18 - P9999\/8 + \
P99a2\/8)\)\ v0\^3\)\/tau + \((\((Dab2 - 
                        DabP9ab + \(Daa\ P999\)\/6 + \(13\ P999\^2\)\/72 - 
                        P9999\/8 + P99a2\/2 - P99aa\/4 + 
                        P9ab2\/2)\)\ tau + \(\((Dab2 + \(Daa\ P999\)\/6 + \
P999\^2\/8 - P9999\/24 + P99a2\/8)\)\ tau1\^2\)\/tau + \(\((P9999\/24 - P99a2\
\/8)\)\ v0\^2\)\/tau)\)\ w + \(\((\(-\(\(7\ P999\^2\)\/72\)\) + P9999\/24)\)\ \
v0\ w\^2\)\/tau + \(\((\(11\ P999\^2\)\/72 - P9999\/12 + P99a2\/8)\)\ \
w\^3\)\/tau)\)\)], "Output"]
}, Open  ]],

Cell["\<\
We can use the function zq2cc to obtain ccw1 directly from w1[v].\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(zq2cc[w1[v, tau1]] - ccw1\)], "Input"],

Cell[BoxData[
    \({0, 0, 0, 0}\)], "Output"]
}, Open  ]],

Cell["We can do the same as above in another way though zq.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(qqw1 = zq2qq[w1[v, tau1]]\)], "Input"],

Cell[BoxData[
    \({Daa + P999\/6 + Daa\ tau1\^2 + \(P999\ tau1\^2\)\/6, \(-Dab2\) + 
        DabP9ab - \(Daa\ P999\)\/6 - \(13\ P999\^2\)\/72 + P9999\/8 - 
        P99a2\/2 + P99aa\/4 - P9ab2\/2 - Dab2\ tau1\^2 + 
        1\/6\ Daa\ P999\ tau1\^2 - \(5\ P999\^2\ tau1\^2\)\/72 + \(P9999\ \
tau1\^2\)\/24 - \(P99a2\ tau1\^2\)\/8, 
      P999\/6, \(-\(P999\^2\/24\)\) + P9999\/12 - P99a2\/8}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Collect[zfzq[w, qqw1, v0, tau], {o, w, tau1, v0, tau}, Expand] - 
      zfw1[w, tau1, v0, tau]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The usual bootstrap probability is defined from  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Alpha]\&~\_1\)(0, v, tau)\)]],
  " with tau=1. We denote it as ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Alpha]\&^\_0\)(0, v) = \(\[Alpha]\&~\_1\)(0, v, 
          1)\)]],
  ". The corresponding z-value is denoted by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(z\&^\_0\)(0, v)\)\(.\)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(z0[v_] = z1[v, 1]\)], "Input"],

Cell[BoxData[
    \(o\ \((Daa + P999\/6)\) + v + 
      o\^2\ \((\(-Dab2\) + \(Daa\ P999\)\/6 - \(5\ P999\^2\)\/72 + 
            P9999\/24 - P99a2\/8)\)\ v + 1\/3\ o\ P999\ v\^2 + 
      o\^2\ \((\(-\(P999\^2\/18\)\) + P9999\/8 - 
            P99a2\/8)\)\ v\^3\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The distribution function of ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\&^\_0\)(u, v)\)]],
  " is denoted by ",
  Cell[BoxData[
      \(TraditionalForm\`Pr {Z\&^\_0 \[LessEqual] w; v0, 
            tau = 1} = \[CapitalPhi] {zfz0[w, v0]}\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(zfz0[w_, v0_] = Collect[zfw1[w, 1, v0, 1], {o, w, v0}]\)], "Input"],

Cell[BoxData[
    \(\(-v0\) + w + 
      o\ \((\(-2\)\ Daa - 
            P999\/3 - \(P999\ v0\^2\)\/3 + \(P999\ v0\ w\)\/6 - \(P999\ \
w\^2\)\/6)\) + 
      o\^2\ \((\((Dab2 - \(Daa\ P999\)\/3 + P999\^2\/24 - P9999\/24 + 
                  P99a2\/8)\)\ v0 + \((P999\^2\/18 - P9999\/8 + 
                  P99a2\/8)\)\ v0\^3 + \((2\ Dab2 - 
                  DabP9ab + \(Daa\ P999\)\/3 + \(11\ P999\^2\)\/36 - 
                  P9999\/6 + \(5\ P99a2\)\/8 - P99aa\/4 + 
                  P9ab2\/2 + \((P9999\/24 - 
                        P99a2\/8)\)\ v0\^2)\)\ w + \((\(-\(\(7\ P999\^2\)\/72\
\)\) + P9999\/24)\)\ v0\ w\^2 + \((\(11\ P999\^2\)\/72 - P9999\/12 + 
                  P99a2\/8)\)\ w\^3)\)\)], "Output"]
}, Open  ]],

Cell["Under v0=0, zfz0 becomes", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(zfz0[w, 0]\)], "Input"],

Cell[BoxData[
    \(w + o\ \((\(-2\)\ Daa - P999\/3 - \(P999\ w\^2\)\/6)\) + 
      o\^2\ \((\((2\ Dab2 - 
                  DabP9ab + \(Daa\ P999\)\/3 + \(11\ P999\^2\)\/36 - 
                  P9999\/6 + \(5\ P99a2\)\/8 - P99aa\/4 + 
                  P9ab2\/2)\)\ w + \((\(11\ P999\^2\)\/72 - P9999\/12 + 
                  P99a2\/8)\)\ w\^3)\)\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["double bootstrap", "Subsubsection"],

Cell[TextData[{
  "The z-value of the double bootstrap probability is ",
  Cell[BoxData[
      \(TraditionalForm\`zd[
          v] = \(-\(\(\(\[CapitalPhi]\^\(-1\)\)[
              Pr {Z\&^\_0 \[LessEqual] \(z\&^\_0\)(v); 
                  v0 = 0}]\)\(.\)\)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(zd[v_] = Collect[geto2[zfz0[z0[v], 0]], {o, v}]\)], "Input"],

Cell[BoxData[
    \(v + o\ \((\(-Daa\) - P999\/6 + \(P999\ v\^2\)\/6)\) + 
      o\^2\ \((\((Dab2 - DabP9ab + \(Daa\ P999\)\/6 + \(13\ P999\^2\)\/72 - 
                  P9999\/8 + P99a2\/2 - P99aa\/4 + 
                  P9ab2\/2)\)\ v + \((\(-\(P999\^2\/72\)\) + 
                  P9999\/24)\)\ v\^3)\)\)], "Output"]
}, Open  ]],

Cell["This is equivalent to the pivot z8[v]", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(z8[v] - zd[v]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["two-level bootstrap", "Subsubsection"],

Cell["\<\
The ABC conversion formula of Efron (1987) and DiCiccio and Efron (1992) is\
\>", "Text"],

Cell[BoxData[
    \(\(abcformula[v_, 
          ac_] = \(z0[v] - z0[0]\)\/\(1 - ac \((z0[v] - z0[0])\)\) - 
          z0[0];\)\)], "Input"],

Cell["The acceleration constant \"ac\" is", "Text"],

Cell[BoxData[
    \(\(ac = \(-\(1\/6\)\) o\ P999;\)\)], "Input"],

Cell["\<\
The z-value of the bootstrap probability around the projection is\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(z0[0]\)], "Input"],

Cell[BoxData[
    \(o\ \((Daa + P999\/6)\)\)], "Output"]
}, Open  ]],

Cell["Thus the ABC formula, denoted za[v] here, becomes", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(za[v_] = gets2[abcformula[v, ac]]\)], "Input"],

Cell[BoxData[
    \(v - 
      1\/72\ o\^2\ v\ \((72\ Dab2 - 12\ Daa\ P999 + 5\ P999\^2 - 3\ P9999 + 
            9\ P99a2 + 10\ P999\^2\ v\^2 - 9\ P9999\ v\^2 + 
            9\ P99a2\ v\^2)\) + 
      1\/6\ o\ \((\(-6\)\ Daa + P999\ \((\(-1\) + v\^2)\))\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`q\_i\)]],
  "'s are obtained by"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(qqza = zq2qq[za[v]]\)], "Input"],

Cell[BoxData[
    \({0, \(-2\)\ Dab2 + DabP9ab - P999\^2\/4 + P9999\/6 - \(5\ P99a2\)\/8 + 
        P99aa\/4 - P9ab2\/2, 
      0, \(-\(P999\^2\/8\)\) + P9999\/12 - P99a2\/8}\)], "Output"]
}, Open  ]],

Cell["\<\
The distribution function of za[v]  under tau=1 is \
Pr{za[V]\[LessEqual]w;v0,1}=\[CapitalPhi][zfzq[w,qqza,v0,1]]\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Collect[zfzq[w, qqza, v0, 1], {o, w, v0}, Expand]\)], "Input"],

Cell[BoxData[
    \(\(-v0\) + w + 
      o\ \((\(-\(\(P999\ v0\^2\)\/3\)\) + \(P999\ v0\ w\)\/6)\) + 
      o\^2\ \((\((Dab2 + \(7\ P999\^2\)\/72 - P9999\/24 + 
                  P99a2\/8)\)\ v0 + \((P999\^2\/18 - P9999\/8 + 
                  P99a2\/8)\)\ v0\^3 + \((2\ Dab2 - DabP9ab + P999\^2\/4 - 
                  P9999\/6 + \(5\ P99a2\)\/8 - P99aa\/4 + 
                  P9ab2\/2 + \((P9999\/24 - 
                        P99a2\/8)\)\ v0\^2)\)\ w + \((\(-\(\(5\ P999\^2\)\/72\
\)\) + P9999\/24)\)\ v0\ w\^2 + \((P999\^2\/8 - P9999\/12 + 
                  P99a2\/8)\)\ w\^3)\)\)], "Output"]
}, Open  ]],

Cell["Under v0=0, tau=1, it becomes", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Collect[zfzq[w, qqza, 0, 1], {o, w}, Expand]\)], "Input"],

Cell[BoxData[
    \(w + 
      o\^2\ \((\((2\ Dab2 - DabP9ab + P999\^2\/4 - 
                  P9999\/6 + \(5\ P99a2\)\/8 - P99aa\/4 + 
                  P9ab2\/2)\)\ w + \((P999\^2\/8 - P9999\/12 + 
                  P99a2\/8)\)\ w\^3)\)\)], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["multistep-multiscale bootstrap method", "Subsection"],

Cell["\<\
Here we calculate the asymptotic accuracy of the three-step multiscale \
bootstrap method.\
\>", "Text"],

Cell[TextData[{
  "The pivot z8[v] is generalized to define  ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\&^\_\[Infinity]\)(0, v, v0, 
          tau) = \(z8[v, v0, tau] = zc[v, {0, 0, 0, 0}, v0, tau]\)\)]],
  ", which reduces to z8[v,0,1]=z8[v]. We standardize z8[v,v0,tau] by \
w8[v,v0,tau]=z8[v,v0,tau]*isz8 + v0, where ",
  Cell[BoxData[
      \(TraditionalForm\`isz8 = 
        tau - \(1\/6\) P999\ tau\ v0\  + \ \(1\/36\) \(P999\^2\) 
            tau\ v0\^2\)]],
  ", so that ",
  Cell[BoxData[
      \(TraditionalForm\`w8[v, v0, tau] = v + O(n\^\(\(-1\)/2\))\)]],
  ".  The distribution function is ",
  Cell[BoxData[
      \(TraditionalForm\`Pr {W8 \[LessEqual] w; v0, 
            tau} = \[CapitalPhi] \(\({zfz8[w, v0, tau]}\)\(.\)\)\)]],
  " We show ",
  Cell[BoxData[
      \(TraditionalForm\`Pr {z8[V, v0, tau] \[LessEqual] w; v0, 
            tau} = \(Pr {W8\  \[LessEqual] \ w\ isz8\  + \ v0; v0, 
              tau} = \(\[CapitalPhi] {zfw8[w\ isz8 + v0]} = \[CapitalPhi](
              w)\)\)\)]],
  ". \nWe obtain the inverse function of z8[v,v0,tau]=z in terms of v so that \
v8[z,v0,tau]=v is defined."
}], "Text"],

Cell[TextData[{
  "Let func[z]=(az+b) + rem[z], where rem[z]=",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(i = 0\)\%m c[\([i + 1]\)]\ z\^i\)]],
  "is of order ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(O(n\^\(\(-1\)/2\))\)\(\ \)\(.\)\)\)]],
  " We would like to calculate intfz=",
  Cell[BoxData[
      \(TraditionalForm\`Q[\[Integral]\_\(-\[Infinity]\)\%\[Infinity] F[
              func[z]] f[z] \[DifferentialD]z]\)]],
  ", where f, F, and Q are, respectively, the density, the distribution, and \
quantile functions of the standard normal distribution. Let us define ",
  Cell[BoxData[
      \(intxfg[a, b, 
          n] = \(\@\(1 + a\^2\)\/f[
                b\/\@\(1 + a\^2\)]\) \(\[Integral]\_\(-\[Infinity]\)\%\
\[Infinity]\( x\^n\) f[a\ x + b] f[x] \[DifferentialD]x\)\)]],
  ". Then we will show that  intfz=ddint[a,b,d,z]=",
  Cell[BoxData[
      \(TraditionalForm\`b\/\@\(1 + a\^2\) + \[Sum]\+\(i = 0\)\%\(2  m + \
1\)d[\([i + 1]\)] 
            intxfg[a, b, i]\/\@\(1 + a\^2\) + \(1\/2\) \(b\/\@\(1 + a\^2\)\) \
\((\[Sum]\+\(i = 0\)\%\(2  m + 1\)d[\([i + 1]\)] intxfg[a, b, i]\/\@\(1 + \
a\^2\))\)\^2\)]],
  ", where d=func2dd[a,b,rem,z] calculates the coefficients of the expansion \
",
  Cell[BoxData[
      \(TraditionalForm\`rem[
            z] - \(1\/2\) \((a\ z + 
                b)\)\ rem[z]\^2 = \[Sum]\+\(i = 0\)\%\(2  m + 1\)d[\([i + 
                  1]\)]\ z\^i\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Using ddint function defined above, we will calculate ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(z2[v0, tau1, tau2]\), "=", 
          
          FormBox[\(\(\[CapitalPhi]\^\(-1\)\)[\[Integral]\_\(-\[Infinity]\)\%\
\[Infinity]\( \[CapitalPhi](z1[v, tau2])\) 
                  f[v, v0, tau1] \[DifferentialD]v]\),
            "TraditionalForm"]}], TraditionalForm]]],
  "  =",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalPhi]\^\(-1\)\)[\[Integral]\_\(-\[Infinity]\
\)\%\[Infinity]\( \[CapitalPhi](z1[v8[z, v0, tau1], tau2])\) 
            f[z] \[DifferentialD]z]\)]],
  ". This is the z-value of the twostep-multiscale bootstrap probability. "
}], "Text"],

Cell[TextData[{
  "Similarly we will calculate the z-value of the threestep-multiscale \
bootstrap probability defined by \n",
  Cell[BoxData[
      FormBox[
        RowBox[{\(z3[v0, tau1, tau2, tau3]\), "=", 
          
          FormBox[\(\(\[CapitalPhi]\^\(-1\)\)[\[Integral]\_\(-\[Infinity]\)\%\
\[Infinity]\( \[CapitalPhi](z2[v, tau2, tau3])\) 
                  f[v, v0, tau1] \[DifferentialD]v]\),
            "TraditionalForm"]}], TraditionalForm]]],
  "  =",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalPhi]\^\(-1\)\)[\[Integral]\_\(-\[Infinity]\
\)\%\[Infinity]\( \[CapitalPhi](z2[v8[z, v0, tau1], tau2, tau3])\) 
            f[z] \[DifferentialD]z]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "The six geometric quantities ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\_1,  ... , \[Gamma]\_6\)]],
  " are denoted by G1,...,G6 here. The scaling parameter ",
  Cell[BoxData[
      \(TraditionalForm\`s\_1,  ... , s\_4\)]],
  " are denoted by S1,...,S4 here. We define Z3G and Z8G in terms of \
G1,...,G6, S1,...,S4, and will show that Z3G=z3[v,tau1,tau2,tau3] and \
Z8G=z8[v]."
}], "Text"],

Cell[CellGroupData[{

Cell["a generalization of the pivot", "Subsubsection"],

Cell[TextData[{
  "We define a generalization of the pivot by ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\&^\_\[Infinity]\)(0, v, v0, 
          tau) = \(z8[v, v0, tau] = zc[v, {0, 0, 0, 0}, v0, tau]\)\)]],
  ". We use z8 in the analysis of the multistep bootstrap."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(z8[v_, v0_, tau_] = 
      Collect[zc[v, {0, 0, 0, 0}, v0, tau], {tau, v, o, v0}]\)], "Input"],

Cell[BoxData[
    \(tau\ \((o\ \((\(-Daa\) - P999\/6)\) + 
            o\^2\ \((Dab2 - 
                  DabP9ab + \(Daa\ P999\)\/6 + \(13\ P999\^2\)\/72 - 
                  P9999\/8 + P99a2\/2 - P99aa\/4 + P9ab2\/2)\)\ v + 
            o\^2\ \((Dab2 - \(Daa\ P999\)\/6 + \(5\ P999\^2\)\/72 - 
                  P9999\/24 + 
                  P99a2\/8)\)\ v0)\) + \(1\/tau\) \((o\^2\ \
\((\(-\(P999\^2\/72\)\) + P9999\/24)\)\ v\^3 - v0 - 1\/3\ o\ P999\ v0\^2 + 
            o\^2\ \((P999\^2\/18 - P9999\/8 + P99a2\/8)\)\ v0\^3 + 
            v\^2\ \((\(o\ P999\)\/6 + 
                  o\^2\ \((\(-\(P999\^2\/24\)\) + P9999\/24)\)\ v0)\) + 
            v\ \((1 + \(o\ P999\ v0\)\/6 + 
                  o\^2\ \((P9999\/24 - P99a2\/8)\)\ v0\^2)\))\)\)], "Output"]
}, Open  ]],

Cell["This reduces to the pivot when v0=0, tau=1.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[z8[v, 0, 1] - z8[v]]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell["\<\
We standardize z8[v,v0,tau] so that it can be regarded as w with proper \
coefficients. First, we find the rescaling factor.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(scz8 = \(1\/tau\) \((1 + o\ P999\/6\ v0)\)\)], "Input"],

Cell[BoxData[
    \(\(1 + \(o\ P999\ v0\)\/6\)\/tau\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(isz8 = gets2[1/scz8]\)], "Input"],

Cell[BoxData[
    \(tau - 1\/6\ o\ P999\ tau\ v0 + 
      1\/36\ o\^2\ P999\^2\ tau\ v0\^2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The standardization of z8[v,v0,tau] up to ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^\(\(-1\)/2\))\)]],
  " term is denoted w8[v,v0,tau]=z8[v,v0,tau]*isz8 + v0."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(w8[v_, v0_, tau_] = 
      Collect[geto2[z8[v, v0, tau]\ isz8 + v0], {o, v, tau, v0}]\)], "Input"],

Cell[BoxData[
    \(v + 
      o\ \((\((\(-Daa\) - 
                  P999\/6)\)\ tau\^2 + \(P999\ v\^2\)\/6 - \(P999\ \
v0\^2\)\/6)\) + 
      o\^2\ \((\((\(-\(P999\^2\/72\)\) + 
                  P9999\/24)\)\ v\^3 + \((Dab2 + \(7\ P999\^2\)\/72 - 
                  P9999\/24 + 
                  P99a2\/8)\)\ tau\^2\ v0 + \((\(-\(\(5\ P999\^2\)\/72\)\) + 
                  P9999\/24)\)\ v\^2\ v0 + \((P999\^2\/12 - P9999\/8 + 
                  P99a2\/8)\)\ v0\^3 + 
            v\ \((\((Dab2 - 
                        DabP9ab + \(Daa\ P999\)\/6 + \(13\ P999\^2\)\/72 - 
                        P9999\/8 + P99a2\/2 - P99aa\/4 + 
                        P9ab2\/2)\)\ tau\^2 + \((P9999\/24 - 
                        P99a2\/8)\)\ v0\^2)\))\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(qqw8 = Collect[zq2qq[w8[v, v0, tau]], o, Simplify]\)], "Input"],

Cell[BoxData[
    \({1\/6\ \((\(-6\)\ Daa\ \((\(-1\) + tau\^2)\) - 
              P999\ \((\(-1\) + tau\^2 + v0\^2)\))\) + 
        1\/72\ o\ v0\ \((72\ Dab2\ tau\^2 - 3\ P9999\ tau\^2 + 
              9\ P99a2\ tau\^2 - 9\ P9999\ v0\^2 + 9\ P99a2\ v0\^2 + 
              P999\^2\ \((7\ tau\^2 + 6\ v0\^2)\))\), 
      1\/72\ \((\(-12\)\ Daa\ P999 - 13\ P999\^2 + 9\ P9999 - 36\ P99a2 + 
            18\ P99aa - 36\ P9ab2 + 12\ Daa\ P999\ tau\^2 + 
            13\ P999\^2\ tau\^2 - 9\ P9999\ tau\^2 + 36\ P99a2\ tau\^2 - 
            18\ P99aa\ tau\^2 + 36\ P9ab2\ tau\^2 + 
            72\ Dab2\ \((\(-1\) + tau\^2)\) - 
            72\ DabP9ab\ \((\(-1\) + tau\^2)\) + 3\ P9999\ v0\^2 - 
            9\ P99a2\ v0\^2)\), 
      1\/72\ o\ \((\(-5\)\ P999\^2\ v0 + 3\ P9999\ v0)\), 0}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Then the distribution function of W8=w8[V,v0,tau] is ",
  Cell[BoxData[
      \(TraditionalForm\`Pr {W8 \[LessEqual] w; v0, 
            tau} = \[CapitalPhi] \(\({zfz8[w, v0, tau]}\)\(.\)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(zfw8[w_, v0_, tau_] = 
      Simplify[geto2[zfzq[w, qqw8, v0, tau]]]\)], "Input"],

Cell[BoxData[
    \(\(-\(\(\((6 + o\ P999\ v0)\)\ \((v0 - 
                w)\)\)\/\(6\ tau\)\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Then, ",
  Cell[BoxData[
      \(TraditionalForm\`Pr {z8[V, v0, tau] \[LessEqual] w; v0, 
            tau} = \(Pr {W8\  \[LessEqual] \ w\ isz8\  + \ v0; v0, 
              tau} = \[CapitalPhi] {zfw8[w\ isz8 + v0]}\)\)]],
  ". The following equation implies that  ",
  Cell[BoxData[
      \(TraditionalForm\`Pr {z8[V, v0, tau] \[LessEqual] w; v0, 
            tau} = \[CapitalPhi](w)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(geto2[zfw8[w\ isz8 + v0, v0, tau]]\)], "Input"],

Cell[BoxData[
    \(w\)], "Output"]
}, Open  ]],

Cell["\<\
We obtain the inverse function of z8[v,v0,tau]=z in terms of v so that \
v8[z,v0,tau]=v by applying the inversion formula of the modified signed \
distance to w8. We use v8-function in the following section.\
\>", "Text"],

Cell[BoxData[
    \(\(ccw8 = Collect[zq2cc[w8[v, v0, tau]], o, Simplify];\)\)], "Input"],

Cell[BoxData[
    \(\(ccw8o = ccw8\ *\ {o, o\^2, o, o\^2};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(v8[z_, v0_, tau_] = 
      geto2[\((w - geto2[Sum[ccw8o[\([i]\)] w\^\(i - 1\), {i, 4}]])\) /. 
          w \[Rule] z\ isz8 + v0]\)], "Input"],

Cell[BoxData[
    \(v0 + tau\ z - 
      1\/72\ o\^2\ tau\ \((36\ Daa\ P999\ tau\ v0 + 24\ P999\^2\ tau\ v0 - 
            12\ P9999\ tau\ v0 + 45\ P99a2\ tau\ v0 - 18\ P99aa\ tau\ v0 + 
            36\ P9ab2\ tau\ v0 + 36\ Daa\ P999\ tau\^2\ z + 
            17\ P999\^2\ tau\^2\ z - 9\ P9999\ tau\^2\ z + 
            36\ P99a2\ tau\^2\ z - 18\ P99aa\ tau\^2\ z + 
            36\ P9ab2\ tau\^2\ z - 27\ P999\^2\ v0\^2\ z + 
            18\ P9999\ v0\^2\ z - 9\ P99a2\ v0\^2\ z - 
            24\ P999\^2\ tau\ v0\ z\^2 + 12\ P9999\ tau\ v0\ z\^2 - 
            5\ P999\^2\ tau\^2\ z\^3 + 3\ P9999\ tau\^2\ z\^3 - 
            72\ DabP9ab\ tau\ \((v0 + tau\ z)\) + 
            72\ Dab2\ tau\ \((2\ v0 + tau\ z)\))\) + 
      1\/6\ o\ tau\ \((6\ Daa\ tau + 
            P999\ \((tau - 3\ v0\ z - tau\ z\^2)\))\)\)], "Output"]
}, Open  ]],

Cell["Check if z8[v8[z]]=z and v8[z8[v]]=v", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(geto2[z8[v8[z, v0, tau], v0, tau]]\)], "Input"],

Cell[BoxData[
    \(z\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(geto2[v8[z8[v, v0, tau], v0, tau]]\)], "Input"],

Cell[BoxData[
    \(v\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["some useful formula for normal integration", "Subsubsection"],

Cell[TextData[{
  "The normal distribution function \[CapitalPhi][x], the quantile function \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalPhi]\^\(-1\)\)[p]\)]],
  ",  and the normal density function \[Phi][x]."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({F[x], Q[p], f[x]}\)], "Input"],

Cell[BoxData[
    \({1\/2\ \((1 + Erf[x\/\@2])\), \@2\ InverseErf[
          0, \(-1\) + 
            2\ p], \[ExponentialE]\^\(-\(x\^2\/2\)\)\/\@\(2\ \[Pi]\)}\)], \
"Output"]
}, Open  ]],

Cell["First, we will calculate the following intxfp[a,b]", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(intxfp[a_, b_] = 
      FullSimplify[\[Integral]\_\(-\[Infinity]\)\%\[Infinity] F[a\ x + b] 
            f[x] \[DifferentialD]x, 
        a\[Epsilon]Reals\  \[And] \ b \[Element] Reals]\)], "Input"],

Cell[BoxData[
    FractionBox[
      RowBox[{
        SubsuperscriptBox["\[Integral]", 
          InterpretationBox[\(-\[Infinity]\),
            DirectedInfinity[ -1]], 
          InterpretationBox["\[Infinity]",
            DirectedInfinity[ 
            1]]], \(\(\[ExponentialE]\^\(-\(x\^2\/2\)\)\ \((1 + 
                Erf[\(b + a\ x\)\/\@2])\)\) \[DifferentialD]x\)}], \(2\ \@\(2\
\ \[Pi]\)\)]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " does not calculate intxfp, so we consider change of variables. First \
rewrite intxfp as follows."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\[Integral]\_\(\
-\[Infinity]\)\%\(a\ x1 + b\)f[x1] 
            f[x2] \[DifferentialD]x2 \[DifferentialD]x1\), 
      a\[Epsilon]Reals\  \[And] \ b \[Element] Reals]\)], "Input"],

Cell[BoxData[
    FractionBox[
      RowBox[{
        SubsuperscriptBox["\[Integral]", 
          InterpretationBox[\(-\[Infinity]\),
            DirectedInfinity[ -1]], 
          InterpretationBox["\[Infinity]",
            DirectedInfinity[ 
            1]]], \(\(\[ExponentialE]\^\(-\(x1\^2\/2\)\)\ \((1 + 
                Erf[\(b + a\ x1\)\/\@2])\)\) \[DifferentialD]x1\)}], \(2\ \
\@\(2\ \[Pi]\)\)]], "Output"]
}, Open  ]],

Cell["Then, {x1,x2} is transformed to {y1,y2}.", "Text"],

Cell[BoxData[
    \(\(foo1 = {x1 \[Rule] \(-\(\(\(-y1\) + a\ y2\)\/\@\(1 + a\^2\)\)\), 
          x2 \[Rule] \(-\(\(\(-a\)\ y1 - 
                    y2\)\/\@\(1 + a\^2\)\)\)};\)\)], "Input"],

Cell["The range of the integration is now expressed as", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo2 = 
      FullSimplify[x2\  \[LessEqual] \ a\ x1 + b /. foo1, 
        a\[Epsilon]Reals\  \[And] \ b \[Element] Reals]\)], "Input"],

Cell[BoxData[
    \(\@\(1 + a\^2\)\ y2 \[LessEqual] b\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(Now\ we\ get\ the\ integration\ intxfp[a, 
          b] = \[Integral]\_\(-\[Infinity]\)\%\[Infinity] F[a\ x + b] 
          f[x] \[DifferentialD]x\)], "Text"],

Cell[BoxData[
    \(\(intxfp[a_, b_] = F[b\/\@\(1 + a\^2\)];\)\)], "Input"],

Cell[BoxData[
    \(The\ following\ intx2f[
          n] = \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( x\^\(2  n\)\) 
          f[x] \[DifferentialD]x\ gives\ \(\(\(\((2  
                      n)\)!\)\/\((\(2\^n\) \(n!\))\)\)\(.\)\)\)], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(intx2f[n_] = 
      FullSimplify[\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( x\^\(2  n\)\) 
            f[x] \[DifferentialD]x, 
        n \[GreaterEqual] 0 \[And] n \[Element] Integers]\)], "Input"],

Cell[BoxData[
    \(\(2\^n\ Gamma[1\/2 + n]\)\/\@\[Pi]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[intxf[n], {n, 10}]\)], "Input"],

Cell[BoxData[
    \({intxf[1], intxf[2], intxf[3], intxf[4], intxf[5], intxf[6], intxf[7], 
      intxf[8], intxf[9], intxf[10]}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(The\ following\ intxfg[a, b, 
          n] = \(\@\(1 + a\^2\)\/f[
              b\/\@\(1 + a\^2\)]\) \(\[Integral]\_\(-\[Infinity]\)\%\
\[Infinity]\( x\^n\) f[a\ x + b] 
            f[x] \[DifferentialD]x\ will\ be\ used\ repeatedly . \ 
              This\ may\ be\ obtained\ \ by\ using\ the\ integration\ by\ \
parts\ and\ intx2f[n]\), \ 
    but\ Mathematica\ does\ it\ \(\(automatically\)\(.\)\)\)], "Text"],

Cell[BoxData[
    \(\(foo5 = \(\@\(1 + a\^2\)\/f[
                b\/\@\(1 + a\^2\)]\) \(\[Integral]\_\(-\[Infinity]\)\%\
\[Infinity]\( x\^n\) f[a\ x + b] f[x] \[DifferentialD]x\);\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(intxfg[a_, b_, n_] = 
      Simplify[foo5, 
        n \[GreaterEqual] 0 \[And] \ n \[Element] Integers \[And] \ 
          a\  \[Element] \ Reals\  \[And] \ b\  \[Element] Reals]\)], "Input"],

Cell[BoxData[
    \(\(1\/\@\[Pi]\) \((2\^\(1\/2\ \((\(-3\) + n)\)\)\ \((1 + a\^2)\)\^\(1\/2\
\ \((\(-1\) - n)\)\)\ \((2\ \((\(-1\) + \((\(-1\))\)\^n)\)\ a\ b\ Gamma[
                  1 + n\/2]\ Hypergeometric1F1[1\/2 - n\/2, 
                  3\/2, \(a\^2\ b\^2\)\/\(\(-2\) - 2\ a\^2\)] + \@2\ \((1 + \
\((\(-1\))\)\^n)\)\ \@\(1 + a\^2\)\ Gamma[\(1 + n\)\/2]\ \
Hypergeometric1F1[\(-\(n\/2\)\), 
                  1\/2, \(a\^2\ b\^2\)\/\(\(-2\) - 2\ a\^2\)])\))\)\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[Table[intxfg[a, b, n], {n, 0, 10}]]\)], "Input"],

Cell[BoxData[
    \({1, \(-\(\(a\ b\)\/\(1 + 
              a\^2\)\)\), \(1 + a\^2\ \((1 + b\^2)\)\)\/\((1 + a\^2)\)\^2, \
\(-\(\(a\ b\ \((3 + 
                  a\^2\ \((3 + 
                        b\^2)\))\)\)\/\((1 + a\^2)\)\^3\)\), \(3 + 6\ a\^2\ \
\((1 + b\^2)\) + a\^4\ \((3 + 6\ b\^2 + b\^4)\)\)\/\((1 + a\^2)\)\^4, \
\(-\(\(a\ b\ \((15 + 10\ a\^2\ \((3 + b\^2)\) + 
                  a\^4\ \((15 + 10\ b\^2 + 
                        b\^4)\))\)\)\/\((1 + a\^2)\)\^5\)\), \(15 + 45\ a\^2\ \
\((1 + b\^2)\) + 15\ a\^4\ \((3 + 6\ b\^2 + b\^4)\) + a\^6\ \((15 + 45\ b\^2 \
+ 15\ b\^4 + b\^6)\)\)\/\((1 + a\^2)\)\^6, \(-\(\(a\ b\ \((105 + 
                  105\ a\^2\ \((3 + b\^2)\) + 
                  21\ a\^4\ \((15 + 10\ b\^2 + b\^4)\) + 
                  a\^6\ \((105 + 105\ b\^2 + 21\ b\^4 + 
                        b\^6)\))\)\)\/\((1 + a\^2)\)\^7\)\), \(1\/\((1 + \
a\^2)\)\^8\) \((105 + 420\ a\^2\ \((1 + b\^2)\) + 
            210\ a\^4\ \((3 + 6\ b\^2 + b\^4)\) + 
            28\ a\^6\ \((15 + 45\ b\^2 + 15\ b\^4 + b\^6)\) + 
            a\^8\ \((105 + 420\ b\^2 + 210\ b\^4 + 28\ b\^6 + 
                  b\^8)\))\), \(-\(\(1\/\((1 + a\^2)\)\^9\) \((a\ b\ \((945 + 
                  1260\ a\^2\ \((3 + b\^2)\) + 
                  378\ a\^4\ \((15 + 10\ b\^2 + b\^4)\) + 
                  36\ a\^6\ \((105 + 105\ b\^2 + 21\ b\^4 + b\^6)\) + 
                  a\^8\ \((945 + 1260\ b\^2 + 378\ b\^4 + 36\ b\^6 + 
                        b\^8)\))\))\)\)\), \(1\/\((1 + a\^2)\)\^10\) \((945\ \
\((1 + a\^2)\)\^5 + 4725\ a\^2\ \((1 + a\^2)\)\^4\ b\^2 + 
            3150\ a\^4\ \((1 + a\^2)\)\^3\ b\^4 + 
            630\ a\^6\ \((1 + a\^2)\)\^2\ b\^6 + 
            45\ a\^8\ \((1 + a\^2)\)\ b\^8 + a\^10\ b\^10)\)}\)], "Output"]
}, Open  ]],

Cell["Finally we consider some asymptotic expansions.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(foo7 = gets2[\(F[x + o\ y]\  - \ F[x]\)\/f[x]]\)], "Input"],

Cell[BoxData[
    \(o\ y - 1\/2\ o\^2\ x\ y\^2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Thus, F[x+oy] = F[x] + f[x] (",
  Cell[BoxData[
      \(o\ y - 1\/2\ o\^2\ x\ y\^2\)]],
  ")=F[x] + f[x] * expandF[x+oy,x], where x=Coefficient[x+oy,o,0]."
}], "Text"],

Cell[BoxData[
    \(expandF[exp_, x_] := 
      gets2[\((exp - x)\) - 1\/2\ \((exp - x)\)\^2\ x]\)], "Input"],

Cell["Next, note that ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[
      gets2[F[x + o\ y\  + \ \(1\/2\) o\^2\ x\ y\^2]] - \((F[x] + 
            f[x]\ o\ y)\)]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Thus,  Q[F[x]+f[x] o y] = ",
  Cell[BoxData[
      \(x + o\ y\  + \ \(1\/2\) o\^2\ x\ y\^2\)]],
  "=expandQ[x,y]."
}], "Text"],

Cell[BoxData[
    \(expandQ[x_, y_] := gets2[x + \ y\  + \ 1\/2\ x\ y\^2]\)], "Input"],

Cell[TextData[{
  "Combining these asymptotic expansions, we obtain the following \
integration. Let func[z]=(az+b) + rem[z], where rem[z]=",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(i = 0\)\%m c[\([i + 1]\)]\ z\^i\)]],
  "is of order ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(O(n\^\(\(-1\)/2\))\)\(\ \)\(.\)\)\)]],
  " We would like to calculate intfz=Q[",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity] F[
            func[z]] f[z] \[DifferentialD]z\)]],
  "."
}], "Text"],

Cell[TextData[{
  "The integrand F[func[z]]f[z] is  expandF[func[z],az+b]f[z] =  ",
  Cell[BoxData[
      \(TraditionalForm\`F[a\ z + b] f[z] + 
        f[a\ z + b] 
          f[z]\ \((rem[z] - \(1\/2\) \((a\ z + b)\)\ rem[z]\^2)\)\)]],
  " . We denote ",
  Cell[BoxData[
      \(TraditionalForm\`rem[
            z] - \(1\/2\) \((a\ z + 
                b)\)\ rem[z]\^2 = \[Sum]\+\(i = 0\)\%\(2  m + 1\)d[\([i + 
                  1]\)]\ z\^i\)]],
  ". The coefficients d's are obtained from a,b, and c's."
}], "Text"],

Cell[BoxData[
    \(func2dd[a_, b_, rem_, z_] := 
      Collect[CoefficientList[gets2[rem - \(1\/2\) \((a\ z + b)\) rem\^2], 
          z], o, Simplify]\)], "Input"],

Cell[TextData[{
  "Now the integration is intfz=Q[",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\((F[
                a\ z + b] + 
              f[a\ z + 
                    b] \(\[Sum]\+\(i = 0\)\%\(2  m + 1\)d[\([i + 
                          1]\)]\ z\^i\))\) f[z] \[DifferentialD]z\)]],
  ". Since ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity] F[
              a\ z + b] f[z] \[DifferentialD]z = F[b\/\@\(1 + a\^2\)]\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( z\^n\) 
            f[a\ z + b] f[z] \[DifferentialD]z = 
        f[b\/\@\(1 + a\^2\)] intxfg[a, b, n]\/\@\(1 + a\^2\)\)]],
  ", we obtain \n",
  Cell[BoxData[
      \(TraditionalForm\`intfz = 
        Q[F[b\/\@\(1 + a\^2\)] + 
            f[b\/\@\(1 + a\^2\)] \(\[Sum]\+\(i = 0\)\%\(2  m + 1\)d[\([i + 
                        1]\)] intxfg[a, b, i]\/\@\(1 + a\^2\)\)]\)]],
  ". Using expandQ, this becomes intfz=",
  Cell[BoxData[
      \(TraditionalForm\`b\/\@\(1 + a\^2\) + \[Sum]\+\(i = 0\)\%\(2  m + \
1\)d[\([i + 1]\)] 
            intxfg[a, b, i]\/\@\(1 + a\^2\) + \(1\/2\) \(b\/\@\(1 + a\^2\)\) \
\((\[Sum]\+\(i = 0\)\%\(2  m + 1\)d[\([i + 1]\)] intxfg[a, b, i]\/\@\(1 + \
a\^2\))\)\^2\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(dd2int[a_, b_, dd_, z_] := 
      Module[{intg}, 
        intg = \[Sum]\+\(i = 1\)\%\(Length[dd]\)dd[\([i]\)] 
              intxfg[a, b, i - 1]\/\@\(1 + a\^2\); \ 
        gets2[\(b\/\@\(1 + a\^2\)\) \((1 + \(1\/2\) intg\^2)\) + 
            intg]]\)], "Input"],

Cell["\<\
Now, the integration function may be written as \
intfz=dd2int[a,b,func2dd[a,b,rem,z],z];\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["two-step multiscale bootstrap", "Subsubsection"],

Cell[TextData[{
  "In the below, we will calculate ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(z2[v0, tau1, tau2]\), "=", 
          
          FormBox[\(\(\[CapitalPhi]\^\(-1\)\)[\[Integral]\_\(-\[Infinity]\)\%\
\[Infinity]\( \[CapitalPhi](z1[v, tau2])\) 
                  f[v, v0, tau1] \[DifferentialD]v]\),
            "TraditionalForm"]}], TraditionalForm]]],
  "  =",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalPhi]\^\(-1\)\)[\[Integral]\_\(-\[Infinity]\
\)\%\[Infinity]\( \[CapitalPhi](z1[v8[z, v0, tau1], tau2])\) 
            f[z] \[DifferentialD]z]\)]],
  "."
}], "Text"],

Cell["\<\
z1v8=z1[v8[z,v0,tau1],tau2]. This is regarded as a polynomial of z, and then \
intfz will be applied to z1v8.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(z1v8 = geto2[z1[v8[z, v0, tau1], tau2]]\)], "Input"],

Cell[BoxData[
    \(\(v0 + tau1\ z\)\/tau2 + \(o\ \((6\ Daa\ \((tau1\^2 + tau2\^2)\) + P999\
\ \((tau2\^2 + 2\ v0\^2 + tau1\ v0\ z + tau1\^2\ \((1 + z\^2)\))\))\)\)\/\(6\ \
tau2\) + o\^2\ \((\(-\(1\/72\)\)\ \((72\ Dab2 - 12\ Daa\ P999 + 5\ P999\^2 - 
                  3\ P9999 + 9\ P99a2)\)\ tau2\ \((v0 + 
                  tau1\ z)\) - \(1\/\(72\ tau2\)\) \((\((4\ P999\^2 - 
                        9\ P9999 + 9\ P99a2)\)\ \((v0 + tau1\ z)\)\^3 + 
                  tau1\ \((36\ Daa\ P999\ tau1\ v0 + 24\ P999\^2\ tau1\ v0 - 
                        12\ P9999\ tau1\ v0 + 45\ P99a2\ tau1\ v0 - 
                        18\ P99aa\ tau1\ v0 + 36\ P9ab2\ tau1\ v0 + 
                        36\ Daa\ P999\ tau1\^2\ z + 17\ P999\^2\ tau1\^2\ z - 
                        9\ P9999\ tau1\^2\ z + 36\ P99a2\ tau1\^2\ z - 
                        18\ P99aa\ tau1\^2\ z + 36\ P9ab2\ tau1\^2\ z - 
                        27\ P999\^2\ v0\^2\ z + 18\ P9999\ v0\^2\ z - 
                        9\ P99a2\ v0\^2\ z - 24\ P999\^2\ tau1\ v0\ z\^2 + 
                        12\ P9999\ tau1\ v0\ z\^2 - 
                        5\ P999\^2\ tau1\^2\ z\^3 + 3\ P9999\ tau1\^2\ z\^3 - 
                        72\ DabP9ab\ tau1\ \((v0 + tau1\ z)\) + 
                        72\ Dab2\ tau1\ \((2\ v0 + tau1\ z)\))\) + 
                  8\ P999\ tau1\ \((v0 + tau1\ z)\)\ \((\(-6\)\ Daa\ tau1 + 
                        P999\ \((3\ v0\ z + 
                              tau1\ \((\(-1\) + 
                                    z\^2)\))\))\))\))\)\)], "Output"]
}, Open  ]],

Cell["foo11 is the O(1) term ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(z1v8o0 = Coefficient[z1v8, o, 0]\)], "Input"],

Cell[BoxData[
    \(\(v0 + tau1\ z\)\/tau2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(z1v8ab = CoefficientList[z1v8o0, z]\)], "Input"],

Cell[BoxData[
    \({v0\/tau2, tau1\/tau2}\)], "Output"]
}, Open  ]],

Cell["\<\
We may make replacements b\[Rule]z1v8ab[[1]], a\[Rule]z1v8ab[[2]]  later for \
the normal integration with intfxg[a,b,n], i.e., z1v8o0=az+b.\
\>", "Text"],

Cell["Get the dd coefficients and store them in z1v8dd", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(z1v8dd = 
      Collect[func2dd[z1v8ab[\([2]\)], z1v8ab[\([1]\)], z1v8 - z1v8o0, z], o, 
        Simplify[#, tau1 > 0 \[And] tau2 > 0] &]\)], "Input"],

Cell[BoxData[
    \({\(o\ \((6\ Daa\ \((tau1\^2 + tau2\^2)\) + P999\ \((tau1\^2 + tau2\^2 + \
2\ v0\^2)\))\)\)\/\(6\ tau2\) - \(1\/\(72\ tau2\^3\)\) \((o\^2\ v0\ \((36\ \
Daa\^2\ \((tau1\^2 + tau2\^2)\)\^2 + 
                  12\ Daa\ P999\ \((tau1\^2 + tau2\^2)\)\ \((tau1\^2 + 
                        2\ v0\^2)\) + 
                  3\ tau2\^2\ \((\(-24\)\ DabP9ab\ tau1\^2 - 
                        4\ P9999\ tau1\^2 + 15\ P99a2\ tau1\^2 - 
                        6\ P99aa\ tau1\^2 + 12\ P9ab2\ tau1\^2 - 
                        P9999\ tau2\^2 + 3\ P99a2\ tau2\^2 + 
                        24\ Dab2\ \((2\ tau1\^2 + tau2\^2)\) - 
                        3\ P9999\ v0\^2 + 3\ P99a2\ v0\^2)\) + 
                  P999\^2\ \((tau1\^4 + 6\ tau2\^4 + 8\ tau2\^2\ v0\^2 + 
                        4\ v0\^4 + 
                        2\ tau1\^2\ \((9\ tau2\^2 + 
                              2\ v0\^2)\))\))\))\), \(o\ P999\ tau1\ \
v0\)\/\(6\ tau2\) - \(1\/\(72\ tau2\^3\)\) \((o\^2\ tau1\ \((36\ Daa\^2\ \
\((tau1\^2 + tau2\^2)\)\^2 + 
                  12\ Daa\ P999\ \((tau1\^2 + tau2\^2)\)\ \((tau1\^2 + 
                        3\ v0\^2)\) + 
                  3\ tau2\^2\ \((\(-24\)\ DabP9ab\ tau1\^2 - 
                        3\ P9999\ tau1\^2 + 12\ P99a2\ tau1\^2 - 
                        6\ P99aa\ tau1\^2 + 12\ P9ab2\ tau1\^2 - 
                        P9999\ tau2\^2 + 3\ P99a2\ tau2\^2 + 
                        24\ Dab2\ \((tau1\^2 + tau2\^2)\) - 3\ P9999\ v0\^2 + 
                        6\ P99a2\ v0\^2)\) + 
                  P999\^2\ \((tau1\^4 + 6\ tau2\^4 + 15\ tau2\^2\ v0\^2 + 
                        8\ v0\^4 + 
                        tau1\^2\ \((11\ tau2\^2 + 
                              6\ v0\^2)\))\))\))\), \(o\ P999\ tau1\^2\)\/\(6\
\ tau2\) - \(1\/\(72\ tau2\^3\)\) \((o\^2\ tau1\^2\ v0\ \((3\ \((\(-5\)\ \
P9999 + 9\ P99a2)\)\ tau2\^2 + 24\ Daa\ P999\ \((tau1\^2 + tau2\^2)\) + 
                  P999\^2\ \((4\ tau1\^2 + 24\ tau2\^2 + 
                        9\ v0\^2)\))\))\), \(-\(\(1\/\(72\ tau2\^3\)\) \
\((o\^2\ tau1\^3\ \((3\ \((\(-2\)\ P9999 + 3\ P99a2)\)\ tau2\^2 + 
                  12\ Daa\ P999\ \((tau1\^2 + tau2\^2)\) + 
                  P999\^2\ \((2\ tau1\^2 + 9\ tau2\^2 + 
                        7\ v0\^2)\))\))\)\)\), \(-\(\(o\^2\ P999\^2\ tau1\^4\ \
v0\)\/\(24\ tau2\^3\)\)\), \(-\(\(o\^2\ P999\^2\ tau1\^5\)\/\(72\ tau2\^3\)\)\
\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[z1v8dd]\)], "Input"],

Cell[BoxData[
    \(6\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now the integration is ",
  Cell[BoxData[
      \(TraditionalForm\`z2[v0, tau1, tau2]\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalPhi]\^\(-1\)\)[\[Integral]\_\(-\[Infinity]\
\)\%\[Infinity]\( \[CapitalPhi](z1v8)\) f[z] \[DifferentialD]z]\)]],
  ". ."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(z2[v0_, tau1_, tau2_] = 
      Collect[dd2int[z1v8ab[\([2]\)], z1v8ab[\([1]\)], z1v8dd, z], o, 
        FullSimplify[#, tau1 > 0 \[And] tau2 > 0] &]\)], "Input"],

Cell[BoxData[
    \(v0\/\@\(tau1\^2 + tau2\^2\) + \(1\/\(72\ \((tau1\^2 + tau2\^2)\)\^\(9/2\
\)\)\) \((o\^2\ \((\(-72\)\ Dab2\ \((tau1\^2 + tau2\^2)\)\^5\ v0 + \((tau1\^2 \
+ tau2\^2)\)\ \((\((12\ Daa\ P999 - 5\ P999\^2 + 3\ P9999 - 
                            9\ P99a2)\)\ tau1\^8 + 
                      3\ \((24\ DabP9ab + 8\ Daa\ P999 - 7\ P999\^2 + 
                            5\ P9999 - 21\ P99a2 + 6\ P99aa - 
                            12\ P9ab2)\)\ tau1\^6\ tau2\^2 + \((144\ DabP9ab \
+ 24\ Daa\ P999 - 73\ P999\^2 + 42\ P9999 - 135\ P99a2 + 36\ P99aa - 
                            72\ P9ab2)\)\ tau1\^4\ tau2\^4 + 
                      3\ \((24\ DabP9ab + 8\ \((Daa - 2\ P999)\)\ P999 + 
                            11\ P9999 + 
                            6\ \((\(-5\)\ P99a2 + P99aa - 
                                  2\ P9ab2)\))\)\ tau1\^2\ tau2\^6 + \((12\ \
Daa\ P999 - 5\ P999\^2 + 3\ P9999 - 
                            9\ P99a2)\)\ tau2\^8)\)\ v0 - \((\((4\ P999\^2 - 
                            9\ P9999 + 9\ P99a2)\)\ tau1\^8 + 
                      3\ \((7\ P999\^2 - 11\ P9999 + 
                            9\ P99a2)\)\ tau1\^6\ tau2\^2 + \((17\ P999\^2 - 
                            42\ P9999 + 27\ P99a2)\)\ tau1\^4\ tau2\^4 + 
                      3\ \((4\ P999\^2 - 9\ P9999 + 
                            6\ P99a2)\)\ tau1\^2\ tau2\^6 + \((4\ P999\^2 - 
                            9\ P9999 + 
                            9\ P99a2)\)\ tau2\^8)\)\ v0\^3)\))\) + \(1\/\(6\ \
\((tau1\^2 + tau2\^2)\)\^\(5/2\)\)\) \((o\ \((6\ Daa\ \((tau1\^2 + tau2\^2)\)\
\^3 + P999\ \((tau1\^6 + 4\ tau1\^4\ tau2\^2 + 4\ tau1\^2\ tau2\^4 + 
                      tau2\^6 + \((2\ tau1\^4 + 3\ tau1\^2\ tau2\^2 + 
                            2\ tau2\^4)\)\ v0\^2)\))\))\)\)], "Output"]
}, Open  ]],

Cell["Check if z2 reduces to z1 when one of the scales is zero", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[Limit[z2[v, tau1, tau2], tau2 \[Rule] 0] - z1[v, tau1], 
      tau1 > 0]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[Limit[z2[v, tau1, tau2], tau1 \[Rule] 0] - z1[v, tau2], 
      tau2 > 0]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["three-step multiscale bootstrap", "Subsubsection"],

Cell[TextData[{
  "In the below, we will calculate ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(z3[v0, tau1, tau2, tau3]\), "=", 
          
          FormBox[\(\(\[CapitalPhi]\^\(-1\)\)[\[Integral]\_\(-\[Infinity]\)\%\
\[Infinity]\( \[CapitalPhi](z2[v, tau2, tau3])\) 
                  f[v, v0, tau1] \[DifferentialD]v]\),
            "TraditionalForm"]}], TraditionalForm]]],
  "  =",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalPhi]\^\(-1\)\)[\[Integral]\_\(-\[Infinity]\
\)\%\[Infinity]\( \[CapitalPhi](z2[v8[z, v0, tau1], tau2, tau3])\) 
            f[z] \[DifferentialD]z]\)]],
  "."
}], "Text"],

Cell["\<\
z2v8=z2[v8[z,v0,tau1],tau2,tau3]. This is regarded as a polynomial of z, and \
then intfz will be applied to z2v8.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(z2v8 = geto2[z2[v8[z, v0, tau1], tau2, tau3]]\)], "Input"],

Cell[BoxData[
    \(\(v0 + tau1\ z\)\/\@\(tau2\^2 + tau3\^2\) + \(1\/\(6\ \((tau2\^2 + tau3\
\^2)\)\^\(5/2\)\)\) \((o\ \((6\ Daa\ \((tau2\^2 + tau3\^2)\)\^3 + 
                P999\ \((tau2\^6 + 4\ tau2\^4\ tau3\^2 + 
                      4\ tau2\^2\ tau3\^4 + 
                      tau3\^6 + \((2\ tau2\^4 + 3\ tau2\^2\ tau3\^2 + 
                            2\ tau3\^4)\)\ \((v0 + tau1\ z)\)\^2)\) + 
                tau1\ \((tau2\^2 + tau3\^2)\)\^2\ \((6\ Daa\ tau1 + 
                      P999\ \((tau1 - 3\ v0\ z - 
                            tau1\ z\^2)\))\))\))\) + \(1\/\(72\ \((tau2\^2 + \
tau3\^2)\)\^\(9/2\)\)\) \((o\^2\ \((\(-72\)\ Dab2\ \((tau2\^2 + tau3\^2)\)\^5\
\ \((v0 + tau1\ z)\) + \((tau2\^2 + 
                      tau3\^2)\)\ \((12\ Daa\ P999\ \((tau2\^2 + \
tau3\^2)\)\^2\ \((tau2\^4 + tau3\^4)\) - 
                      P999\^2\ \((5\ tau2\^8 + 21\ tau2\^6\ tau3\^2 + 
                            73\ tau2\^4\ tau3\^4 + 48\ tau2\^2\ tau3\^6 + 
                            5\ tau3\^8)\) + 
                      3\ \((tau2\^2 + 
                            tau3\^2)\)\ \((P9999\ \((tau2\^6 + 
                                  4\ tau2\^4\ tau3\^2 + 
                                  10\ tau2\^2\ tau3\^4 + tau3\^6)\) - 
                            3\ \((\(-2\)\ \((4\ DabP9ab + P99aa - 
                                        2\ P9ab2)\)\ tau2\^2\ tau3\^2\ \
\((tau2\^2 + tau3\^2)\) + P99a2\ \((tau2\^6 + 6\ tau2\^4\ tau3\^2 + 
                                        9\ tau2\^2\ tau3\^4 + 
                                        tau3\^6)\))\))\))\)\ \((v0 + 
                      tau1\ z)\) - \((\((4\ P999\^2 - 9\ P9999 + 
                            9\ P99a2)\)\ tau2\^8 + 
                      3\ \((7\ P999\^2 - 11\ P9999 + 
                            9\ P99a2)\)\ tau2\^6\ tau3\^2 + \((17\ P999\^2 - 
                            42\ P9999 + 27\ P99a2)\)\ tau2\^4\ tau3\^4 + 
                      3\ \((4\ P999\^2 - 9\ P9999 + 
                            6\ P99a2)\)\ tau2\^2\ tau3\^6 + \((4\ P999\^2 - 
                            9\ P9999 + 
                            9\ P99a2)\)\ tau3\^8)\)\ \((v0 + tau1\ z)\)\^3 - 
                tau1\ \((tau2\^2 + tau3\^2)\)\^4\ \((36\ Daa\ P999\ tau1\ v0 \
+ 24\ P999\^2\ tau1\ v0 - 12\ P9999\ tau1\ v0 + 45\ P99a2\ tau1\ v0 - 
                      18\ P99aa\ tau1\ v0 + 36\ P9ab2\ tau1\ v0 + 
                      36\ Daa\ P999\ tau1\^2\ z + 17\ P999\^2\ tau1\^2\ z - 
                      9\ P9999\ tau1\^2\ z + 36\ P99a2\ tau1\^2\ z - 
                      18\ P99aa\ tau1\^2\ z + 36\ P9ab2\ tau1\^2\ z - 
                      27\ P999\^2\ v0\^2\ z + 18\ P9999\ v0\^2\ z - 
                      9\ P99a2\ v0\^2\ z - 24\ P999\^2\ tau1\ v0\ z\^2 + 
                      12\ P9999\ tau1\ v0\ z\^2 - 5\ P999\^2\ tau1\^2\ z\^3 + 
                      3\ P9999\ tau1\^2\ z\^3 - 
                      72\ DabP9ab\ tau1\ \((v0 + tau1\ z)\) + 
                      72\ Dab2\ tau1\ \((2\ v0 + tau1\ z)\))\) + 
                4\ P999\ tau1\ \((tau2\^2 + tau3\^2)\)\^2\ \((2\ tau2\^4 + 
                      3\ tau2\^2\ tau3\^2 + 2\ tau3\^4)\)\ \((v0 + 
                      tau1\ z)\)\ \((6\ Daa\ tau1 + 
                      P999\ \((tau1 - 3\ v0\ z - 
                            tau1\ z\^2)\))\))\))\)\)], "Output"]
}, Open  ]],

Cell["foo11 is the O(1) term ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(z2v8o0 = Coefficient[z2v8, o, 0]\)], "Input"],

Cell[BoxData[
    \(\(v0 + tau1\ z\)\/\@\(tau2\^2 + tau3\^2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(z2v8ab = CoefficientList[z2v8o0, z]\)], "Input"],

Cell[BoxData[
    \({v0\/\@\(tau2\^2 + tau3\^2\), 
      tau1\/\@\(tau2\^2 + tau3\^2\)}\)], "Output"]
}, Open  ]],

Cell["\<\
We may make replacements b\[Rule]z2v8ab[[1]], a\[Rule]z2v8ab[[2]]  later for \
the normal integration with intfxg[a,b,n], i.e., z2v8o0=az+b.\
\>", "Text"],

Cell["Get the dd coefficients and store them in z2v8dd", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(z2v8dd = 
      Collect[func2dd[z2v8ab[\([2]\)], z2v8ab[\([1]\)], z2v8 - z2v8o0, z], o, 
        FullSimplify[#, 
            tau1 > 0 \[And] tau2 > 0 \[And] tau3 > 0] &]\)], "Input"],

Cell[BoxData[
    \({\(1\/\(6\ \((tau2\^2 + tau3\^2)\)\^\(5/2\)\)\) \((o\ \((6\ Daa\ \
\((tau2\^2 + tau3\^2)\)\^2\ \((tau1\^2 + tau2\^2 + tau3\^2)\) + 
                  P999\ \((tau2\^2 + tau3\^2)\)\ \((tau2\^4 + 
                        3\ tau2\^2\ tau3\^2 + tau3\^4 + 
                        tau1\^2\ \((tau2\^2 + tau3\^2)\))\) + 
                  P999\ \((2\ tau2\^4 + 3\ tau2\^2\ tau3\^2 + 
                        2\ tau3\^4)\)\ v0\^2)\))\) - \((o\^2\ v0\ \((36\ \
Daa\^2\ \((tau2\^2 + tau3\^2)\)\^4\ \((tau1\^2 + tau2\^2 + tau3\^2)\)\^2 + 
                  3\ \((tau2\^2 + tau3\^2)\)\^2\ \((24\ Dab2\ \((tau2\^2 + \
tau3\^2)\)\^3\ \((2\ tau1\^2 + tau2\^2 + tau3\^2)\) - \((tau2\^2 + 
                              tau3\^2)\)\ \((\((24\ DabP9ab + 4\ P9999 - 
                                    15\ P99a2 + 6\ P99aa - 
                                    12\ P9ab2)\)\ tau1\^2\ tau2\^4 + \((P9999 \
- 3\ P99a2)\)\ tau2\^6 + 2\ tau2\^2\ \((\((24\ DabP9ab + 4\ P9999 - 
                                        15\ P99a2 + 6\ P99aa - 
                                        12\ P9ab2)\)\ tau1\^2 + \((12\ \
DabP9ab + 2\ P9999 - 9\ P99a2 + 3\ P99aa - 
                                        6\ P9ab2)\)\ tau2\^2)\)\ tau3\^2 + \
\((\((24\ DabP9ab + 4\ P9999 - 15\ P99a2 + 6\ P99aa - 
                                        12\ P9ab2)\)\ tau1\^2 + \((24\ \
DabP9ab + 10\ P9999 - 27\ P99a2 + 6\ P99aa - 
                                        12\ P9ab2)\)\ tau2\^2)\)\ tau3\^4 + \
\((P9999 - 3\ P99a2)\)\ tau3\^6)\) - \((3\ \((P9999 - P99a2)\)\ tau2\^6 + 
                              2\ \((4\ P9999 - 
                                    3\ P99a2)\)\ tau2\^4\ tau3\^2 + 
                              3\ \((2\ P9999 - P99a2)\)\ tau2\^2\ tau3\^4 + 
                              3\ \((P9999 - P99a2)\)\ tau3\^6)\)\ v0\^2)\) + 
                  P999\^2\ \((\((tau2\^2 + tau3\^2)\)\^2\ \((6\ tau2\^8 + 
                              27\ tau2\^6\ tau3\^2 + 84\ tau2\^4\ tau3\^4 + 
                              54\ tau2\^2\ tau3\^6 + 6\ tau3\^8 + 
                              tau1\^4\ \((tau2\^2 + tau3\^2)\)\^2 + 
                              6\ tau1\^2\ \((tau2\^2 + 
                                    tau3\^2)\)\ \((3\ tau2\^4 + 
                                    7\ tau2\^2\ tau3\^2 + 
                                    3\ tau3\^4)\))\) + \((tau2\^2 + 
                              tau3\^2)\)\ \((8\ tau2\^8 + 
                              39\ tau2\^6\ tau3\^2 + 43\ tau2\^4\ tau3\^4 + 
                              30\ tau2\^2\ tau3\^6 + 8\ tau3\^8 + 
                              2\ tau1\^2\ \((tau2\^2 + 
                                    tau3\^2)\)\ \((2\ tau2\^4 + 
                                    3\ tau2\^2\ tau3\^2 + 
                                    2\ tau3\^4)\))\)\ v0\^2 + \((2\ tau2\^4 + \
3\ tau2\^2\ tau3\^2 + 2\ tau3\^4)\)\^2\ v0\^4)\) + 
                  12\ Daa\ P999\ \((tau2\^2 + tau3\^2)\)\^2\ \((tau1\^2 + 
                        tau2\^2 + 
                        tau3\^2)\)\ \((tau1\^2\ \((tau2\^2 + tau3\^2)\)\^2 + 
                        2\ tau3\^4\ v0\^2 + 
                        3\ tau2\^2\ tau3\^2\ \((tau3\^2 + v0\^2)\) + 
                        tau2\^4\ \((3\ tau3\^2 + 
                              2\ v0\^2)\))\))\))\)/\((72\ \((tau2\^2 + \
tau3\^2)\)\^\(11/2\))\), \(o\ P999\ tau1\ \((tau2\^4 + tau3\^4)\)\ v0\)\/\(6\ \
\((tau2\^2 + tau3\^2)\)\^\(5/2\)\) - \((o\^2\ tau1\ \((36\ Daa\^2\ \((tau2\^2 \
+ tau3\^2)\)\^4\ \((tau1\^2 + tau2\^2 + tau3\^2)\)\^2 + 
                  12\ Daa\ P999\ \((tau2\^2 + tau3\^2)\)\^2\ \((tau1\^2 + 
                        tau2\^2 + 
                        tau3\^2)\)\ \((3\ tau2\^2\ tau3\^2\ \((tau2\^2 + 
                              tau3\^2)\) + 
                        tau1\^2\ \((tau2\^2 + tau3\^2)\)\^2 + 
                        3\ \((tau2\^4 + tau2\^2\ tau3\^2 + 
                              tau3\^4)\)\ v0\^2)\) + 
                  3\ \((tau2\^2 + tau3\^2)\)\^2\ \((24\ Dab2\ \((tau2\^2 + \
tau3\^2)\)\^3\ \((tau1\^2 + tau2\^2 + tau3\^2)\) - \((tau2\^2 + 
                              tau3\^2)\)\ \((3\ \((8\ DabP9ab + P9999 - 
                                    4\ P99a2 + 2\ P99aa - 
                                    4\ P9ab2)\)\ tau1\^2\ tau2\^4 + \((P9999 \
- 3\ P99a2)\)\ tau2\^6 + 2\ tau2\^2\ \((3\ \((8\ DabP9ab + P9999 - 4\ P99a2 + 
                                        2\ P99aa - 
                                        4\ P9ab2)\)\ tau1\^2 + \((12\ DabP9ab \
+ 2\ P9999 - 9\ P99a2 + 3\ P99aa - 
                                        6\ P9ab2)\)\ tau2\^2)\)\ tau3\^2 + \
\((3\ \((8\ DabP9ab + P9999 - 4\ P99a2 + 2\ P99aa - 
                                        4\ P9ab2)\)\ tau1\^2 + \((24\ DabP9ab \
+ 10\ P9999 - 27\ P99a2 + 6\ P99aa - 
                                        12\ P9ab2)\)\ tau2\^2)\)\ tau3\^4 + \
\((P9999 - 3\ P99a2)\)\ tau3\^6)\) - 
                        3\ \((\((P9999 - 2\ P99a2)\)\ tau2\^6 + \((2\ P9999 - 
                                    3\ P99a2)\)\ tau2\^4\ tau3\^2 + \((P9999 \
- 2\ P99a2)\)\ tau3\^6)\)\ v0\^2)\) + 
                  P999\^2\ \((\((tau2\^2 + tau3\^2)\)\^2\ \((6\ tau2\^8 + 
                              27\ tau2\^6\ tau3\^2 + 84\ tau2\^4\ tau3\^4 + 
                              54\ tau2\^2\ tau3\^6 + 6\ tau3\^8 + 
                              tau1\^4\ \((tau2\^2 + tau3\^2)\)\^2 + 
                              tau1\^2\ \((tau2\^2 + 
                                    tau3\^2)\)\ \((11\ tau2\^4 + 
                                    28\ tau2\^2\ tau3\^2 + 
                                    11\ tau3\^4)\))\) + 
                        3\ \((tau2\^2 + tau3\^2)\)\ \((5\ tau2\^8 + 
                              21\ tau2\^6\ tau3\^2 + 13\ tau2\^4\ tau3\^4 + 
                              12\ tau2\^2\ tau3\^6 + 5\ tau3\^8 + 
                              2\ tau1\^2\ \((tau2\^6 + 2\ tau2\^4\ tau3\^2 + 
                                    2\ tau2\^2\ tau3\^4 + 
                                    tau3\^6)\))\)\ v0\^2 + \((8\ tau2\^8 + 
                              18\ tau2\^6\ tau3\^2 + 25\ tau2\^4\ tau3\^4 + 
                              18\ tau2\^2\ tau3\^6 + 
                              8\ tau3\^8)\)\ v0\^4)\))\))\)/\((72\ \((tau2\^2 \
+ tau3\^2)\)\^\(11/2\))\), \(o\ P999\ tau1\^2\ \((tau2\^4 + tau2\^2\ tau3\^2 \
+ tau3\^4)\)\)\/\(6\ \((tau2\^2 + tau3\^2)\)\^\(5/2\)\) + \((o\^2\ tau1\^2\ \
v0\ \((\(-\((tau2\^2 + tau3\^2)\)\)\ \((4\ P999\ \((6\ Daa + 
                              P999)\)\ tau1\^2\ tau2\^6 + 
                        3\ \((8\ P999\ \((Daa + P999)\) - 5\ P9999 + 
                              9\ P99a2)\)\ tau2\^8 + 
                        3\ tau2\^4\ \((2\ P999\ \((6\ Daa + 
                                    P999)\)\ tau1\^2 + \((20\ Daa\ P999 + 
                                    31\ P999\^2 - 17\ P9999 + 
                                    27\ P99a2)\)\ tau2\^2)\)\ tau3\^2 + 
                        3\ tau2\^2\ \((2\ P999\ \((6\ Daa + 
                                    P999)\)\ tau1\^2 + 
                              3\ \((8\ Daa\ P999 + 9\ P999\^2 - 6\ P9999 + 
                                    9\ P99a2)\)\ tau2\^2)\)\ tau3\^4 + \((4\ \
P999\ \((6\ Daa + P999)\)\ tau1\^2 + 
                              3\ \((20\ Daa\ P999 + 22\ P999\^2 - 11\ P9999 + 
                                    18\ P99a2)\)\ tau2\^2)\)\ tau3\^6 + 
                        3\ \((8\ P999\ \((Daa + P999)\) - 5\ P9999 + 
                              9\ P99a2)\)\ tau3\^8)\) - 
                  P999\^2\ \((9\ tau2\^8 + 16\ tau2\^6\ tau3\^2 + 
                        24\ tau2\^4\ tau3\^4 + 16\ tau2\^2\ tau3\^6 + 
                        9\ tau3\^8)\)\ v0\^2)\))\)/\((72\ \((tau2\^2 + \
tau3\^2)\)\^\(11/2\))\), \((o\^2\ tau1\^3\ \((\(-\((tau2\^2 + 
                        tau3\^2)\)\)\ \((12\ Daa\ P999\ \((tau2\^2 + 
                            tau3\^2)\)\ \((tau1\^2 + tau2\^2 + 
                            tau3\^2)\)\ \((tau2\^2 - tau2\ tau3 + 
                            tau3\^2)\)\ \((tau2\^2 + tau2\ tau3 + 
                            tau3\^2)\) - 
                      3\ \((tau2\^2 + 
                            tau3\^2)\)\ \((P9999\ \((tau2\^2 + 
                                  2\ tau3\^2)\)\ \((2\ tau2\^4 + 
                                  tau2\^2\ tau3\^2 + tau3\^4)\) - 
                            3\ P99a2\ \((tau2\^6 + 2\ tau2\^4\ tau3\^2 + 
                                  tau2\^2\ tau3\^4 + tau3\^6)\))\) + 
                      P999\^2\ \((9\ tau2\^8 + 37\ tau2\^6\ tau3\^2 + 
                            37\ tau2\^4\ tau3\^4 + 28\ tau2\^2\ tau3\^6 + 
                            9\ tau3\^8 + 
                            2\ tau1\^2\ \((tau2\^6 + 2\ tau2\^4\ tau3\^2 + 
                                  2\ tau2\^2\ tau3\^4 + tau3\^6)\))\))\) - 
                P999\^2\ \((7\ tau2\^8 + 12\ tau2\^6\ tau3\^2 + 
                      20\ tau2\^4\ tau3\^4 + 12\ tau2\^2\ tau3\^6 + 
                      7\ tau3\^8)\)\ v0\^2)\))\)/\((72\ \((tau2\^2 + tau3\^2)\
\)\^\(11/2\))\), \(-\(\(o\^2\ P999\^2\ tau1\^4\ \((3\ tau2\^8 + 
                  4\ tau2\^6\ tau3\^2 + 7\ tau2\^4\ tau3\^4 + 
                  4\ tau2\^2\ tau3\^6 + 
                  3\ tau3\^8)\)\ v0\)\/\(72\ \((tau2\^2 + \
tau3\^2)\)\^\(11/2\)\)\)\), \(-\(\(o\^2\ P999\^2\ tau1\^5\ \((tau2\^4 + \
tau2\^2\ tau3\^2 + tau3\^4)\)\^2\)\/\(72\ \((tau2\^2 + tau3\^2)\)\^\(11/2\)\)\
\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[z2v8dd]\)], "Input"],

Cell[BoxData[
    \(6\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now the integration is ",
  Cell[BoxData[
      \(TraditionalForm\`z3[v0, tau1, tau2, tau3]\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalPhi]\^\(-1\)\)[\[Integral]\_\(-\[Infinity]\
\)\%\[Infinity]\( \[CapitalPhi](z2v8)\) f[z] \[DifferentialD]z]\)]],
  ". ."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(z3[v0_, tau1_, tau2_, tau3_] = 
      Collect[dd2int[z2v8ab[\([2]\)], z2v8ab[\([1]\)], z2v8dd, z], o, 
        FullSimplify[#, 
            tau1 > 0 \[And] tau2 > 0 \[And] tau3 > 0] &]\)], "Input"],

Cell[BoxData[
    \(v0\/\@\(tau1\^2 + tau2\^2 + tau3\^2\) + \((o\ \((\((tau1\^2 + tau2\^2 + 
                      tau3\^2)\)\ \((6\ Daa\ \((tau1\^2 + tau2\^2 + \
tau3\^2)\)\^2 + P999\ \((tau1\^4 + tau2\^4 + 3\ tau2\^2\ tau3\^2 + tau3\^4 + 
                            3\ tau1\^2\ \((tau2\^2 + tau3\^2)\))\))\) + 
                P999\ \((2\ tau1\^4 + 2\ tau2\^4 + 3\ tau2\^2\ tau3\^2 + 
                      2\ tau3\^4 + 
                      3\ tau1\^2\ \((tau2\^2 + 
                            tau3\^2)\))\)\ v0\^2)\))\)/\((6\ \((tau1\^2 + \
tau2\^2 + tau3\^2)\)\^\(5/2\))\) + \((o\^2\ \((\(-72\)\ Dab2\ \((tau1\^2 + \
tau2\^2 + tau3\^2)\)\^5\ v0 + \((tau1\^2 + tau2\^2 + 
                      tau3\^2)\)\ \((12\ Daa\ P999\ \((tau1\^2 + tau2\^2 + \
tau3\^2)\)\^2\ \((tau1\^4 + tau2\^4 + tau3\^4)\) + 
                      P999\^2\ \((\(-5\)\ tau1\^8 - 21\ tau1\^6\ tau2\^2 - 
                            73\ tau1\^4\ tau2\^4 - 48\ tau1\^2\ tau2\^6 - 
                            5\ tau2\^8 - 
                            3\ \((7\ tau1\^6 + 40\ tau1\^4\ tau2\^2 + 
                                  49\ tau1\^2\ tau2\^4 + 
                                  7\ tau2\^6)\)\ tau3\^2 - \((73\ tau1\^4 + 
                                  174\ tau1\^2\ tau2\^2 + 
                                  73\ tau2\^4)\)\ tau3\^4 - 
                            48\ \((tau1\^2 + tau2\^2)\)\ tau3\^6 - 
                            5\ tau3\^8)\) + 
                      3\ \((tau1\^2 + tau2\^2 + 
                            tau3\^2)\)\ \((\(-3\)\ P99a2\ \((tau1\^6 + 
                                  6\ tau1\^4\ tau2\^2 + 9\ tau1\^2\ tau2\^4 + 
                                  tau2\^6)\) - 
                            18\ P99a2\ \((tau1\^4 + 3\ tau1\^2\ tau2\^2 + 
                                  tau2\^4)\)\ tau3\^2 - 
                            27\ P99a2\ \((tau1\^2 + tau2\^2)\)\ tau3\^4 - 
                            3\ P99a2\ tau3\^6 + 
                            6\ \((4\ DabP9ab + P99aa - 
                                  2\ P9ab2)\)\ \((tau1\^2 + tau2\^2 + 
                                  tau3\^2)\)\ \((tau1\^2\ tau2\^2 + \
\((tau1\^2 + tau2\^2)\)\ tau3\^2)\) + 
                            P9999\ \((tau1\^6 + tau2\^6 + 
                                  4\ tau2\^4\ tau3\^2 + 
                                  10\ tau2\^2\ tau3\^4 + tau3\^6 + 
                                  4\ tau1\^4\ \((tau2\^2 + tau3\^2)\) + 
                                  2\ tau1\^2\ \((5\ tau2\^4 + 
                                        9\ tau2\^2\ tau3\^2 + 
                                        5\ tau3\^4)\))\))\))\)\ v0 - \
\((P999\^2\ \((4\ tau1\^8 + 4\ tau2\^8 + 21\ tau2\^6\ tau3\^2 + 
                            17\ tau2\^4\ tau3\^4 + 12\ tau2\^2\ tau3\^6 + 
                            4\ tau3\^8 + 
                            21\ tau1\^6\ \((tau2\^2 + tau3\^2)\) + 
                            tau1\^4\ \((17\ tau2\^4 + 48\ tau2\^2\ tau3\^2 + 
                                  17\ tau3\^4)\) + 
                            3\ tau1\^2\ \((4\ tau2\^6 + 
                                  13\ tau2\^4\ tau3\^2 + 
                                  10\ tau2\^2\ tau3\^4 + 4\ tau3\^6)\))\) - 
                      3\ \((tau1\^2 + tau2\^2 + 
                            tau3\^2)\)\ \((\(-3\)\ P99a2\ \((tau1\^6 + 
                                  2\ tau1\^4\ tau2\^2 + tau1\^2\ tau2\^4 + 
                                  tau2\^6)\) - 
                            6\ P99a2\ \((tau1\^4 + tau1\^2\ tau2\^2 + 
                                  tau2\^4)\)\ tau3\^2 - 
                            3\ P99a2\ \((tau1\^2 + tau2\^2)\)\ tau3\^4 - 
                            3\ P99a2\ tau3\^6 + 
                            P9999\ \((3\ tau1\^6 + 3\ tau2\^6 + 
                                  8\ tau2\^4\ tau3\^2 + 6\ tau2\^2\ tau3\^4 + 
                                  3\ tau3\^6 + 
                                  8\ tau1\^4\ \((tau2\^2 + tau3\^2)\) + 
                                  6\ tau1\^2\ \((tau2\^2 + \
tau3\^2)\)\^2)\))\))\)\ v0\^3)\))\)/\((72\ \((tau1\^2 + tau2\^2 + \
tau3\^2)\)\^\(9/2\))\)\)], "Output"]
}, Open  ]],

Cell["Check if z3 reduces to z2 when one of the scales is zero", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[
      Limit[z3[v, tau1, tau2, tau3], tau3 \[Rule] 0] - z2[v, tau1, tau2], 
      tau1 > 0 \[And] tau2 > 0]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[
      Limit[z3[v, tau1, tau2, tau3], tau2 \[Rule] 0] - z2[v, tau1, tau3], 
      tau1 > 0 \[And] tau3 > 0]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[
      Limit[z3[v, tau1, tau2, tau3], tau1 \[Rule] 0] - z2[v, tau2, tau3], 
      tau2 > 0 \[And] tau3 > 0]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(z3[v, tau1, tau2, tau3] // InputForm\)], "Input"],

Cell["\<\
v/Sqrt[tau1^2 + tau2^2 + tau3^2] + 
 (o*((tau1^2 + tau2^2 + tau3^2)*(6*Daa*(tau1^2 + tau2^2 + tau3^2)^2 + 
      P999*(tau1^4 + tau2^4 + 3*tau2^2*tau3^2 + tau3^4 + 
        3*tau1^2*(tau2^2 + tau3^2))) + 
    P999*(2*tau1^4 + 2*tau2^4 + 3*tau2^2*tau3^2 + 2*tau3^4 + 
      3*tau1^2*(tau2^2 + tau3^2))*v^2))/
  (6*(tau1^2 + tau2^2 + tau3^2)^(5/2)) + 
 (o^2*(-72*Dab2*(tau1^2 + tau2^2 + tau3^2)^5*v + 
    (tau1^2 + tau2^2 + tau3^2)*(12*Daa*P999*(tau1^2 + tau2^2 + tau3^2)^2*
       (tau1^4 + tau2^4 + tau3^4) + P999^2*(-5*tau1^8 - 
        21*tau1^6*tau2^2 - 73*tau1^4*tau2^4 - 48*tau1^2*tau2^6 - 
        5*tau2^8 - 3*(7*tau1^6 + 40*tau1^4*tau2^2 + 49*tau1^2*tau2^4 + 
          7*tau2^6)*tau3^2 - (73*tau1^4 + 174*tau1^2*tau2^2 + 73*tau2^4)*
         tau3^4 - 48*(tau1^2 + tau2^2)*tau3^6 - 5*tau3^8) + 
      3*(tau1^2 + tau2^2 + tau3^2)*(-3*P99a2*(tau1^6 + 6*tau1^4*tau2^2 + 
          9*tau1^2*tau2^4 + tau2^6) - 18*P99a2*(tau1^4 + 
          3*tau1^2*tau2^2 + tau2^4)*tau3^2 - 27*P99a2*(tau1^2 + tau2^2)*
         tau3^4 - 3*P99a2*tau3^6 + 6*(4*DabP9ab + P99aa - 2*P9ab2)*
         (tau1^2 + tau2^2 + tau3^2)*(tau1^2*tau2^2 + (tau1^2 + tau2^2)*
           tau3^2) + P9999*(tau1^6 + tau2^6 + 4*tau2^4*tau3^2 + 
          10*tau2^2*tau3^4 + tau3^6 + 4*tau1^4*(tau2^2 + tau3^2) + 
          2*tau1^2*(5*tau2^4 + 9*tau2^2*tau3^2 + 5*tau3^4))))*v - 
    (P999^2*(4*tau1^8 + 4*tau2^8 + 21*tau2^6*tau3^2 + 17*tau2^4*tau3^4 + 
        12*tau2^2*tau3^6 + 4*tau3^8 + 21*tau1^6*(tau2^2 + tau3^2) + 
        tau1^4*(17*tau2^4 + 48*tau2^2*tau3^2 + 17*tau3^4) + 
        3*tau1^2*(4*tau2^6 + 13*tau2^4*tau3^2 + 10*tau2^2*tau3^4 + 
          4*tau3^6)) - 3*(tau1^2 + tau2^2 + tau3^2)*
       (-3*P99a2*(tau1^6 + 2*tau1^4*tau2^2 + tau1^2*tau2^4 + tau2^6) - 
        6*P99a2*(tau1^4 + tau1^2*tau2^2 + tau2^4)*tau3^2 - 
        3*P99a2*(tau1^2 + tau2^2)*tau3^4 - 3*P99a2*tau3^6 + 
        P9999*(3*tau1^6 + 3*tau2^6 + 8*tau2^4*tau3^2 + 6*tau2^2*tau3^4 + 
          3*tau3^6 + 8*tau1^4*(tau2^2 + tau3^2) + 
          6*tau1^2*(tau2^2 + tau3^2)^2)))*v^3))/
  (72*(tau1^2 + tau2^2 + tau3^2)^(9/2))\
\>", "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["simplifying z3 and z8", "Subsubsection"],

Cell["We define six geometric quantities;", "Text"],

Cell[BoxData[
    \(\(GG = {G1 \[Rule] 
            v0 + 1\/3\ o\ P999\ v0\^2 + 
              o\^2\ \((\(-\(P999\^2\/18\)\) + P9999\/8 - P99a2\/8)\)\ v0\^3, 
          G2 \[Rule] 
            o\ \((\(-Daa\) - P999\/6)\)\ v0 + 
              o\^2\ \((Dab2 - \(Daa\ P999\)\/2 + P999\^2\/72 - P9999\/24 + 
                    P99a2\/8)\)\ v0\^2, 
          G3 \[Rule] \(-\(1\/6\)\)\ o\ P999\ v0 + 
              o\^2\ \((P999\^2\/9 - P9999\/8 + P99a2\/4)\)\ v0\^2, 
          G4 \[Rule] 
            o\^2\ \((\(-DabP9ab\) + \(Daa\ P999\)\/3 + \(2\ P999\^2\)\/9 - 
                  P9999\/6 + P99a2\/2 - P99aa\/4 + P9ab2\/2)\)\ v0\^2, 
          G5 \[Rule] 
            o\^2\ \((\(-\(P999\^2\/8\)\) + P9999\/12 - P99a2\/8)\)\ v0\^2, 
          G6 \[Rule] 
            o\^2\ \((\(-\(P999\^2\/8\)\) + P9999\/24 - 
                  P99a2\/8)\)\ v0\^2};\)\)], "Input"],

Cell["\<\
We also define four scale parameters (but there are only three degrees of \
freedom among them).\
\>", "Text"],

Cell[BoxData[
    \(\(SS = {S1 \[Rule] 1\/\@\(tau1\^2 + tau2\^2 + tau3\^2\), 
          S2 \[Rule] \(tau1\^2\ tau2\^2 + tau1\^2\ tau3\^2 + tau2\^2\ tau3\^2\
\)\/\((tau1\^2 + tau2\^2 + tau3\^2)\)\^2, 
          S3 \[Rule] \(tau1\^2\ tau2\^2\ tau3\^2 + tau2\^4\ tau3\^2 + tau1\^4\
\ \((tau2\^2 + tau3\^2)\)\)\/\((tau1\^2 + tau2\^2 + tau3\^2)\)\^3, 
          S4 \[Rule] \(tau1\^2\ tau2\^2\ tau3\^2\)\/\((tau1\^2 + tau2\^2 + \
tau3\^2)\)\^3};\)\)], "Input"],

Cell["The pivot z8[v0,1] is denoted by Z8G", "Text"],

Cell[BoxData[
    \(\(z8G = \(G2 + G3\^2\/2 + G4 + G5\)\/G1 + 
          G1\ \((1 + G3 + 4\ G3\^2 + G6)\);\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[gets2[z8G /. GG] - z8[v0]]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell["\<\
The three-step multiscale z-value z3[v0,tau1,tau2,tau3] is denoted by Z3G\
\>", "Text"],

Cell[BoxData[
    \(\(Z3G = 
        G1\ S1\ \((1 + G3\ S2 + 4\ G3\^2\ S2\^2 + G5\ S3 + 
                G6\ S4)\) - \(G2 + G3\ S2 + G4\ S2 + 7\ G3\^2\ S2\^2 + 3\ G5\ \
S3 + 3\ G6\ S4\)\/\(G1\ S1\);\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[
      gets2[Z3G /. Join[GG, SS]] - z3[v0, tau1, tau2, tau3]]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
ScreenStyleEnvironment->"Presentation",
WindowSize->{810, 651},
WindowMargins->{{47, Automatic}, {Automatic, 1}},
SpellingDictionaries->{"CorrectWords"->{
  "multiscale", "Hidetoshi", "Shimodaira", "Ookayama", "Meguro", "shimo", 
    "titech", "Multiscale", "cumulant", "cumulants", "unbiasedness", "zc", 
    "cc", "zformtau", "zq", "cbzq", "cczq", "zfzq", "zd", "abcformula", "za", 
    "qqza"}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 69, 0, 45, "Text"],
Cell[1777, 52, 242, 9, 220, "Text"],

Cell[CellGroupData[{
Cell[2044, 65, 64, 0, 81, "Subtitle"],
Cell[2111, 67, 371, 9, 70, "Text"],
Cell[2485, 78, 779, 26, 95, "Text"],
Cell[3267, 106, 243, 8, 70, "Text"],

Cell[CellGroupData[{
Cell[3535, 118, 58, 0, 68, "Subsubtitle"],
Cell[3596, 120, 429, 7, 120, "Text"],

Cell[CellGroupData[{
Cell[4050, 131, 26, 0, 72, "Section"],
Cell[4079, 133, 128, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[4232, 142, 33, 0, 57, "Subsubsection"],
Cell[4268, 144, 73, 1, 38, "Input"],

Cell[CellGroupData[{
Cell[4366, 149, 61, 1, 38, "Input"],
Cell[4430, 152, 75, 1, 70, "Print"],
Cell[4508, 155, 39, 1, 70, "Print"],
Cell[4550, 158, 90, 1, 70, "Print"],
Cell[4643, 161, 87, 1, 70, "Print"],
Cell[4733, 164, 78, 1, 70, "Print"],
Cell[4814, 167, 75, 1, 70, "Print"],
Cell[4892, 170, 83, 1, 70, "Print"],
Cell[4978, 173, 90, 1, 70, "Print"],
Cell[5071, 176, 77, 1, 70, "Print"],
Cell[5151, 179, 79, 1, 70, "Print"],
Cell[5233, 182, 81, 1, 70, "Print"],
Cell[5317, 185, 139, 3, 70, "Print"],
Cell[5459, 190, 243, 4, 70, "Print"],
Cell[5705, 196, 227, 4, 70, "Print"],
Cell[5935, 202, 101, 2, 70, "Print"],
Cell[6039, 206, 76, 1, 70, "Print"],
Cell[6118, 209, 47, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[6214, 216, 39, 0, 35, "Subsubsection"],
Cell[6256, 218, 53, 1, 38, "Input"],
Cell[6312, 221, 52, 1, 38, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6401, 227, 47, 0, 35, "Subsubsection"],
Cell[6451, 229, 483, 9, 176, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6983, 244, 38, 0, 72, "Section"],
Cell[7024, 246, 186, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[7235, 254, 73, 0, 68, "Subsection"],
Cell[7311, 256, 968, 29, 120, "Text"],

Cell[CellGroupData[{
Cell[8304, 289, 101, 2, 57, "Subsubsection"],
Cell[8408, 293, 278, 5, 57, "Text"],

Cell[CellGroupData[{
Cell[8711, 302, 220, 4, 56, "Input"],
Cell[8934, 308, 68, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9039, 314, 58, 1, 38, "Input"],
Cell[9100, 317, 106, 2, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[9255, 325, 39, 0, 35, "Subsubsection"],
Cell[9297, 327, 250, 11, 45, "Text"],

Cell[CellGroupData[{
Cell[9572, 342, 68, 1, 38, "Input"],
Cell[9643, 345, 104, 2, 70, "Message"],
Cell[9750, 349, 104, 2, 26, "Message"]
}, Open  ]],
Cell[9869, 354, 248, 11, 45, "Text"],

Cell[CellGroupData[{
Cell[10142, 369, 68, 1, 38, "Input"],
Cell[10213, 372, 104, 2, 70, "Message"]
}, Open  ]],
Cell[10332, 377, 198, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[10555, 387, 69, 1, 38, "Input"],
Cell[10627, 390, 105, 2, 70, "Message"],
Cell[10735, 394, 105, 2, 26, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10877, 401, 70, 1, 38, "Input"],
Cell[10950, 404, 105, 2, 70, "Message"],
Cell[11058, 408, 105, 2, 26, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11200, 415, 73, 1, 38, "Input"],
Cell[11276, 418, 113, 2, 70, "Message"],
Cell[11392, 422, 105, 2, 70, "Message"],
Cell[11500, 426, 113, 2, 26, "Message"],
Cell[11616, 430, 105, 2, 26, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11758, 437, 76, 1, 38, "Input"],
Cell[11837, 440, 105, 2, 70, "Message"],
Cell[11945, 444, 105, 2, 26, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12087, 451, 62, 1, 38, "Input"],
Cell[12152, 454, 113, 2, 70, "Message"],
Cell[12268, 458, 113, 2, 26, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12418, 465, 79, 1, 38, "Input"],
Cell[12500, 468, 105, 2, 70, "Message"],
Cell[12608, 472, 105, 2, 26, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12750, 479, 66, 1, 38, "Input"],
Cell[12819, 482, 113, 2, 70, "Message"],
Cell[12935, 486, 113, 2, 26, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13085, 493, 85, 1, 38, "Input"],
Cell[13173, 496, 105, 2, 70, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13315, 503, 74, 1, 38, "Input"],
Cell[13392, 506, 113, 2, 70, "Message"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[13554, 514, 70, 0, 35, "Subsubsection"],
Cell[13627, 516, 568, 14, 95, "Text"],
Cell[14198, 532, 68, 1, 38, "Input"],
Cell[14269, 535, 148, 3, 61, "Input"],
Cell[14420, 540, 199, 4, 84, "Input"],
Cell[14622, 546, 304, 11, 45, "Text"],
Cell[14929, 559, 66, 1, 38, "Input"],
Cell[14998, 562, 84, 1, 38, "Input"],
Cell[15085, 565, 82, 1, 38, "Input"],
Cell[15170, 568, 115, 2, 61, "Input"],
Cell[15288, 572, 105, 2, 61, "Input"],
Cell[15396, 576, 139, 2, 84, "Input"],
Cell[15538, 580, 126, 2, 61, "Input"],
Cell[15667, 584, 198, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[15890, 594, 84, 1, 38, "Input"],
Cell[15977, 597, 44, 1, 70, "Output"]
}, Open  ]],
Cell[16036, 601, 139, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[16200, 610, 66, 1, 38, "Input"],
Cell[16269, 613, 44, 1, 70, "Output"]
}, Open  ]],
Cell[16328, 617, 145, 2, 40, "Text"],

Cell[CellGroupData[{
Cell[16498, 623, 64, 1, 40, "Input"],
Cell[16565, 626, 40, 1, 70, "Output"]
}, Open  ]],
Cell[16620, 630, 162, 2, 40, "Text"],

Cell[CellGroupData[{
Cell[16807, 636, 70, 1, 40, "Input"],
Cell[16880, 639, 40, 1, 70, "Output"]
}, Open  ]],
Cell[16935, 643, 156, 2, 39, "Text"],

Cell[CellGroupData[{
Cell[17116, 649, 77, 1, 38, "Input"],
Cell[17196, 652, 40, 1, 70, "Output"]
}, Open  ]],
Cell[17251, 656, 516, 16, 70, "Text"],

Cell[CellGroupData[{
Cell[17792, 676, 59, 1, 38, "Input"],
Cell[17854, 679, 1935, 63, 70, "Output"]
}, Open  ]],
Cell[19804, 745, 131, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[19960, 754, 56, 1, 38, "Input"],
Cell[20019, 757, 1671, 53, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21727, 815, 48, 1, 38, "Input"],
Cell[21778, 818, 707, 25, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22522, 848, 45, 1, 38, "Input"],
Cell[22570, 851, 707, 25, 70, "Output"]
}, Open  ]],
Cell[23292, 879, 159, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[23476, 887, 82, 1, 38, "Input"],
Cell[23561, 890, 3563, 115, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27161, 1010, 56, 1, 38, "Input"],
Cell[27220, 1013, 3045, 95, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30302, 1113, 48, 1, 38, "Input"],
Cell[30353, 1116, 1401, 43, 70, "Output"]
}, Open  ]],
Cell[31769, 1162, 181, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[31975, 1171, 111, 2, 61, "Input"],
Cell[32089, 1175, 5191, 167, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37317, 1347, 56, 1, 38, "Input"],
Cell[37376, 1350, 4410, 137, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41823, 1492, 48, 1, 38, "Input"],
Cell[41874, 1495, 1944, 59, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[43879, 1561, 82, 1, 68, "Subsection"],
Cell[43964, 1564, 1261, 42, 120, "Text"],

Cell[CellGroupData[{
Cell[45250, 1610, 43, 0, 57, "Subsubsection"],
Cell[45296, 1612, 170, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[45491, 1619, 230, 4, 85, "Input"],
Cell[45724, 1625, 9982, 305, 70, "Output"]
}, Open  ]],
Cell[55721, 1933, 71, 0, 45, "Text"],
Cell[55795, 1935, 65, 1, 38, "Input"],
Cell[55863, 1938, 27, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[55915, 1942, 58, 1, 38, "Input"],
Cell[55976, 1945, 253, 6, 70, "Output"]
}, Open  ]],
Cell[56244, 1954, 224, 8, 45, "Text"],
Cell[56471, 1964, 103, 2, 54, "Input"],

Cell[CellGroupData[{
Cell[56599, 1970, 102, 2, 40, "Input"],
Cell[56704, 1974, 40889, 1061, 70, "Output"]
}, Open  ]],
Cell[97608, 3038, 179, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[97812, 3047, 59, 1, 38, "Input"],
Cell[97874, 3050, 32627, 968, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[130538, 4023, 48, 1, 38, "Input"],
Cell[130589, 4026, 16021, 474, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[146647, 4505, 52, 1, 38, "Input"],
Cell[146702, 4508, 16021, 474, 70, "Output"]
}, Open  ]],
Cell[162738, 4985, 28, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[162791, 4989, 62, 1, 38, "Input"],
Cell[162856, 4992, 241, 6, 70, "Output"]
}, Open  ]],
Cell[163112, 5001, 160, 5, 45, "Text"],
Cell[163275, 5008, 69, 1, 38, "Input"],
Cell[163347, 5011, 83, 1, 40, "Input"],

Cell[CellGroupData[{
Cell[163455, 5016, 121, 3, 63, "Input"],
Cell[163579, 5021, 13812, 355, 70, "Output"]
}, Open  ]],
Cell[177406, 5379, 44, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[177475, 5383, 59, 1, 38, "Input"],
Cell[177537, 5386, 13831, 355, 70, "Output"]
}, Open  ]],
Cell[191383, 5744, 139, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[191547, 5751, 104, 2, 38, "Input"],
Cell[191654, 5755, 10924, 279, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[202627, 6040, 56, 0, 35, "Subsubsection"],
Cell[202686, 6042, 415, 14, 70, "Text"],

Cell[CellGroupData[{
Cell[203126, 6060, 82, 1, 38, "Input"],
Cell[203211, 6063, 16382, 485, 70, "Output"]
}, Open  ]],
Cell[219608, 6551, 105, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[219738, 6558, 62, 1, 38, "Input"],
Cell[219803, 6561, 39252, 1195, 70, "Output"]
}, Open  ]],
Cell[259070, 7759, 66, 1, 38, "Input"],
Cell[259139, 7762, 225, 8, 45, "Text"],
Cell[259367, 7772, 104, 2, 54, "Input"],

Cell[CellGroupData[{
Cell[259496, 7778, 104, 2, 40, "Input"],
Cell[259603, 7782, 284055, 7346, 70, "Output"]
}, Open  ]],
Cell[543673, 15131, 181, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[543879, 15140, 60, 1, 38, "Input"],
Cell[543942, 15143, 148456, 4465, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[692435, 19613, 48, 1, 38, "Input"],
Cell[692486, 19616, 110000, 3321, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[802523, 22942, 53, 1, 38, "Input"],
Cell[802579, 22945, 110000, 3321, 70, "Output"]
}, Open  ]],
Cell[912594, 26269, 162, 5, 45, "Text"],
Cell[912759, 26276, 72, 1, 38, "Input"],
Cell[912834, 26279, 87, 1, 40, "Input"],

Cell[CellGroupData[{
Cell[912946, 26284, 123, 3, 63, "Input"],
Cell[913072, 26289, 64571, 1657, 70, "Output"]
}, Open  ]],
Cell[977658, 27949, 54, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[977737, 27953, 58, 1, 38, "Input"],
Cell[977798, 27956, 64590, 1657, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1042425, 29618, 55, 1, 38, "Input"],
Cell[1042483, 29621, 911, 19, 70, "Output"]
}, Open  ]],
Cell[1043409, 29643, 139, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[1043573, 29650, 148, 3, 84, "Input"],
Cell[1043724, 29655, 57988, 1395, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1101749, 31055, 122, 2, 38, "Input"],
Cell[1101874, 31059, 54989, 1319, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1156936, 32386, 37, 0, 72, "Section"],
Cell[1156976, 32388, 675, 10, 170, "Text"],

Cell[CellGroupData[{
Cell[1157676, 32402, 39, 0, 68, "Subsection"],
Cell[1157718, 32404, 594, 15, 95, "Text"],

Cell[CellGroupData[{
Cell[1158337, 32423, 49, 0, 57, "Subsubsection"],
Cell[1158389, 32425, 76, 0, 45, "Text"],
Cell[1158468, 32427, 81, 1, 38, "Input"],
Cell[1158552, 32430, 113, 2, 63, "Input"],
Cell[1158668, 32434, 111, 2, 40, "Input"],
Cell[1158782, 32438, 63, 0, 45, "Text"],
Cell[1158848, 32440, 778, 14, 314, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[1159663, 32459, 39, 0, 35, "Subsubsection"],
Cell[1159705, 32461, 163, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[1159893, 32470, 75, 1, 38, "Input"],
Cell[1159971, 32473, 112, 2, 70, "Message"]
}, Open  ]],
Cell[1160098, 32478, 159, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[1160282, 32486, 73, 1, 38, "Input"],
Cell[1160358, 32489, 110, 2, 70, "Message"]
}, Open  ]],
Cell[1160483, 32494, 297, 7, 56, "Text"],

Cell[CellGroupData[{
Cell[1160805, 32505, 81, 1, 38, "Input"],
Cell[1160889, 32508, 111, 2, 70, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1161037, 32515, 62, 1, 38, "Input"],
Cell[1161102, 32518, 119, 2, 70, "Message"]
}, Open  ]],
Cell[1161236, 32523, 320, 7, 56, "Text"],

Cell[CellGroupData[{
Cell[1161581, 32534, 84, 1, 38, "Input"],
Cell[1161668, 32537, 111, 2, 70, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1161816, 32544, 66, 1, 38, "Input"],
Cell[1161885, 32547, 119, 2, 70, "Message"]
}, Open  ]],
Cell[1162019, 32552, 305, 7, 53, "Text"],

Cell[CellGroupData[{
Cell[1162349, 32563, 81, 1, 38, "Input"],
Cell[1162433, 32566, 111, 2, 70, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1162581, 32573, 62, 1, 38, "Input"],
Cell[1162646, 32576, 119, 2, 70, "Message"]
}, Open  ]],
Cell[1162780, 32581, 330, 7, 53, "Text"],

Cell[CellGroupData[{
Cell[1163135, 32592, 84, 1, 38, "Input"],
Cell[1163222, 32595, 111, 2, 70, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1163370, 32602, 66, 1, 38, "Input"],
Cell[1163439, 32605, 119, 2, 70, "Message"]
}, Open  ]],
Cell[1163573, 32610, 131, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[1163729, 32618, 68, 1, 38, "Input"],
Cell[1163800, 32621, 104, 2, 70, "Message"]
}, Open  ]],
Cell[1163919, 32626, 295, 11, 51, "Text"],

Cell[CellGroupData[{
Cell[1164239, 32641, 70, 1, 38, "Input"],
Cell[1164312, 32644, 105, 2, 70, "Message"]
}, Open  ]],
Cell[1164432, 32649, 336, 11, 55, "Text"],

Cell[CellGroupData[{
Cell[1164793, 32664, 73, 1, 38, "Input"],
Cell[1164869, 32667, 113, 2, 70, "Message"],
Cell[1164985, 32671, 105, 2, 70, "Message"]
}, Open  ]],
Cell[1165105, 32676, 201, 7, 45, "Text"],

Cell[CellGroupData[{
Cell[1165331, 32687, 75, 1, 38, "Input"],
Cell[1165409, 32690, 114, 2, 70, "Message"],
Cell[1165526, 32694, 106, 2, 70, "Message"]
}, Open  ]],
Cell[1165647, 32699, 354, 12, 55, "Text"],

Cell[CellGroupData[{
Cell[1166026, 32715, 76, 1, 38, "Input"],
Cell[1166105, 32718, 105, 2, 70, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1166247, 32725, 62, 1, 38, "Input"],
Cell[1166312, 32728, 113, 2, 70, "Message"]
}, Open  ]],
Cell[1166440, 32733, 372, 12, 55, "Text"],

Cell[CellGroupData[{
Cell[1166837, 32749, 79, 1, 38, "Input"],
Cell[1166919, 32752, 105, 2, 70, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1167061, 32759, 66, 1, 38, "Input"],
Cell[1167130, 32762, 113, 2, 70, "Message"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1167292, 32770, 56, 0, 35, "Subsubsection"],
Cell[1167351, 32772, 71, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[1167447, 32778, 79, 1, 38, "Input"],
Cell[1167529, 32781, 1259, 38, 70, "Output"]
}, Open  ]],
Cell[1168803, 32822, 1054, 28, 129, "Text"],
Cell[1169860, 32852, 348, 10, 56, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1170257, 32868, 83, 2, 68, "Subsection"],
Cell[1170343, 32872, 176, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[1170544, 32880, 35, 0, 57, "Subsubsection"],
Cell[1170582, 32882, 1015, 24, 106, "Text"],
Cell[1171600, 32908, 216, 4, 122, "Input"],

Cell[CellGroupData[{
Cell[1171841, 32916, 61, 1, 38, "Input"],
Cell[1171905, 32919, 7185, 214, 70, "Output"]
}, Open  ]],
Cell[1179105, 33136, 897, 20, 112, "Text"],
Cell[1180005, 33158, 240, 4, 122, "Input"],

Cell[CellGroupData[{
Cell[1180270, 33166, 71, 1, 38, "Input"],
Cell[1180344, 33169, 7167, 214, 70, "Output"]
}, Open  ]],
Cell[1187526, 33386, 905, 23, 92, "Text"],

Cell[CellGroupData[{
Cell[1188456, 33413, 67, 1, 38, "Input"],
Cell[1188526, 33416, 5242, 158, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1193805, 33579, 63, 1, 38, "Input"],
Cell[1193871, 33582, 114, 2, 70, "Message"],
Cell[1193988, 33586, 106, 2, 70, "Message"]
}, Open  ]],
Cell[1194109, 33591, 75, 1, 38, "Input"],
Cell[1194187, 33594, 357, 12, 56, "Text"],

Cell[CellGroupData[{
Cell[1194569, 33610, 274, 7, 130, "Input"],
Cell[1194846, 33619, 9940, 266, 70, "Output"]
}, Open  ]],
Cell[1204801, 33888, 506, 15, 57, "Text"],

Cell[CellGroupData[{
Cell[1205332, 33907, 76, 1, 38, "Input"],
Cell[1205411, 33910, 14140, 371, 70, "Output"]
}, Open  ]],
Cell[1219566, 34284, 653, 14, 78, "Text"],

Cell[CellGroupData[{
Cell[1220244, 34302, 299, 5, 130, "Input"],
Cell[1220546, 34309, 9866, 246, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1230449, 34560, 105, 2, 40, "Input"],
Cell[1230557, 34564, 8030, 217, 70, "Output"]
}, Open  ]],
Cell[1238602, 34784, 88, 1, 38, "Input"],
Cell[1238693, 34787, 121, 2, 61, "Input"],
Cell[1238817, 34791, 429, 11, 53, "Text"],

Cell[CellGroupData[{
Cell[1239271, 34806, 69, 1, 38, "Input"],
Cell[1239343, 34809, 1138, 35, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1240518, 34849, 73, 1, 38, "Input"],
Cell[1240594, 34852, 6008, 180, 70, "Output"]
}, Open  ]],
Cell[1246617, 35035, 787, 14, 78, "Text"],

Cell[CellGroupData[{
Cell[1247429, 35053, 231, 4, 136, "Input"],
Cell[1247663, 35059, 9000, 268, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1256712, 35333, 31, 0, 35, "Subsubsection"],
Cell[1256746, 35335, 126, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[1256897, 35342, 161, 4, 130, "Input"],
Cell[1257061, 35348, 8089, 242, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1265187, 35595, 52, 1, 38, "Input"],
Cell[1265242, 35598, 159, 4, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1265462, 35609, 83, 2, 68, "Subsection"],
Cell[1265548, 35613, 146, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[1265719, 35620, 35, 0, 57, "Subsubsection"],
Cell[1265757, 35622, 502, 13, 73, "Text"],

Cell[CellGroupData[{
Cell[1266284, 35639, 272, 5, 136, "Input"],
Cell[1266559, 35646, 10122, 306, 70, "Output"]
}, Open  ]],
Cell[1276696, 35955, 228, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[1276949, 35965, 232, 4, 103, "Input"],
Cell[1277184, 35971, 6945, 193, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1284166, 36169, 191, 4, 103, "Input"],
Cell[1284360, 36175, 3551, 102, 70, "Output"]
}, Open  ]],
Cell[1287926, 36280, 181, 5, 45, "Text"],
Cell[1288110, 36287, 107, 2, 61, "Input"],
Cell[1288220, 36291, 60, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[1288305, 36295, 125, 3, 84, "Input"],
Cell[1288433, 36300, 4572, 139, 70, "Output"]
}, Open  ]],
Cell[1293020, 36442, 188, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[1293233, 36451, 75, 1, 38, "Input"],
Cell[1293311, 36454, 6773, 205, 70, "Output"]
}, Open  ]],
Cell[1300099, 36662, 1138, 31, 141, "Text"],

Cell[CellGroupData[{
Cell[1301262, 36697, 112, 2, 54, "Input"],
Cell[1301377, 36701, 6622, 193, 70, "Output"]
}, Open  ]],
Cell[1308014, 36897, 804, 22, 78, "Text"],

Cell[CellGroupData[{
Cell[1308843, 36923, 75, 1, 38, "Input"],
Cell[1308921, 36926, 114, 2, 70, "Message"],
Cell[1309038, 36930, 106, 2, 70, "Message"]
}, Open  ]],
Cell[1309159, 36935, 114, 2, 38, "Input"],
Cell[1309276, 36939, 185, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[1309486, 36949, 281, 5, 159, "Input"],
Cell[1309770, 36956, 11171, 333, 70, "Output"]
}, Open  ]],
Cell[1320956, 37292, 342, 10, 70, "Text"],

Cell[CellGroupData[{
Cell[1321323, 37306, 61, 1, 38, "Input"],
Cell[1321387, 37309, 12361, 370, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1333785, 37684, 157, 3, 54, "Input"],
Cell[1333945, 37689, 2573, 74, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1336555, 37768, 84, 1, 38, "Input"],
Cell[1336642, 37771, 11299, 342, 70, "Output"]
}, Open  ]],
Cell[1347956, 38116, 823, 19, 120, "Text"],

Cell[CellGroupData[{
Cell[1348804, 38139, 124, 3, 40, "Input"],
Cell[1348931, 38144, 5936, 164, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1354904, 38313, 328, 6, 153, "Input"],
Cell[1355235, 38321, 56813, 1690, 70, "Output"]
}, Open  ]],
Cell[1412063, 40014, 568, 14, 76, "Text"],
Cell[1412634, 40030, 91, 1, 38, "Input"],

Cell[CellGroupData[{
Cell[1412750, 40035, 287, 5, 107, "Input"],
Cell[1413040, 40042, 65362, 1520, 70, "Output"]
}, Open  ]],
Cell[1478417, 41565, 96, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[1478538, 41571, 170, 3, 61, "Input"],
Cell[1478711, 41576, 2971, 80, 70, "Output"]
}, Open  ]],
Cell[1481697, 41659, 150, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[1481872, 41668, 47, 1, 38, "Input"],
Cell[1481922, 41671, 17340, 440, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1499299, 42116, 47, 1, 38, "Input"],
Cell[1499349, 42119, 38, 1, 70, "Output"]
}, Open  ]],
Cell[1499402, 42123, 203, 8, 45, "Text"],

Cell[CellGroupData[{
Cell[1499630, 42135, 90, 1, 38, "Input"],
Cell[1499723, 42138, 11176, 333, 70, "Output"]
}, Open  ]],
Cell[1510914, 42474, 45, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[1510984, 42478, 141, 3, 84, "Input"],
Cell[1511128, 42483, 47056, 1115, 70, "Output"]
}, Open  ]],
Cell[1558199, 43601, 186, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[1558410, 43609, 90, 1, 38, "Input"],
Cell[1558503, 43612, 2363, 69, 70, "Output"]
}, Open  ]],
Cell[1560881, 43684, 93, 1, 38, "Input"],

Cell[CellGroupData[{
Cell[1560999, 43689, 118, 3, 38, "Input"],
Cell[1561120, 43694, 1991, 55, 70, "Output"]
}, Open  ]],
Cell[1563126, 43752, 83, 1, 38, "Input"],

Cell[CellGroupData[{
Cell[1563234, 43757, 140, 3, 61, "Input"],
Cell[1563377, 43762, 2939, 85, 70, "Output"]
}, Open  ]],
Cell[1566331, 43850, 105, 2, 38, "Input"],

Cell[CellGroupData[{
Cell[1566461, 43856, 164, 4, 107, "Input"],
Cell[1566628, 43862, 5742, 141, 70, "Output"]
}, Open  ]],
Cell[1572385, 44006, 89, 1, 38, "Input"],

Cell[CellGroupData[{
Cell[1572499, 44011, 179, 5, 130, "Input"],
Cell[1572681, 44018, 11376, 257, 70, "Output"]
}, Open  ]],
Cell[1584072, 44278, 79, 1, 38, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[1584188, 44284, 31, 0, 35, "Subsubsection"],
Cell[1584222, 44286, 152, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[1584399, 44295, 154, 4, 107, "Input"],
Cell[1584556, 44301, 19889, 591, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1604482, 44897, 53, 1, 38, "Input"],
Cell[1604538, 44900, 393, 9, 70, "Output"]
}, Open  ]],
Cell[1604946, 44912, 199, 8, 45, "Text"],

Cell[CellGroupData[{
Cell[1605170, 44924, 283, 5, 107, "Input"],
Cell[1605456, 44931, 14447, 347, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1619964, 45285, 40, 0, 68, "Subsection"],
Cell[1620007, 45287, 159, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[1620191, 45296, 61, 0, 57, "Subsubsection"],
Cell[1620255, 45298, 113, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[1620393, 45305, 43, 1, 38, "Input"],
Cell[1620439, 45308, 1259, 38, 70, "Output"]
}, Open  ]],
Cell[1621713, 45349, 136, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[1621874, 45356, 75, 1, 38, "Input"],
Cell[1621952, 45359, 8938, 268, 70, "Output"]
}, Open  ]],
Cell[1630905, 45630, 143, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[1631073, 45637, 39, 1, 38, "Input"],
Cell[1631115, 45640, 8089, 242, 70, "Output"]
}, Open  ]],
Cell[1639219, 45885, 126, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[1639370, 45892, 40, 1, 38, "Input"],
Cell[1639413, 45895, 19889, 591, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1659351, 46492, 31, 0, 35, "Subsubsection"],
Cell[1659385, 46494, 187, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[1659597, 46502, 134, 3, 61, "Input"],
Cell[1659734, 46507, 41694, 1079, 70, "Output"]
}, Open  ]],
Cell[1701443, 47589, 71, 2, 45, "Text"],
Cell[1701517, 47593, 67, 1, 38, "Input"],

Cell[CellGroupData[{
Cell[1701609, 47598, 57, 1, 38, "Input"],
Cell[1701669, 47601, 635, 13, 70, "Output"]
}, Open  ]],
Cell[1702319, 47617, 238, 6, 56, "Text"],

Cell[CellGroupData[{
Cell[1702582, 47627, 76, 1, 38, "Input"],
Cell[1702661, 47630, 5242, 158, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1707940, 47793, 51, 1, 38, "Input"],
Cell[1707994, 47796, 113, 3, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1708192, 47808, 125, 5, 52, "Subsubtitle"],
Cell[1708320, 47815, 954, 23, 145, "Text"],

Cell[CellGroupData[{
Cell[1709299, 47842, 26, 0, 72, "Section"],
Cell[1709328, 47844, 128, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[1709481, 47853, 33, 0, 57, "Subsubsection"],
Cell[1709517, 47855, 73, 1, 38, "Input"],

Cell[CellGroupData[{
Cell[1709615, 47860, 61, 1, 38, "Input"],
Cell[1709679, 47863, 75, 1, 70, "Print"],
Cell[1709757, 47866, 39, 1, 70, "Print"],
Cell[1709799, 47869, 90, 1, 70, "Print"],
Cell[1709892, 47872, 87, 1, 70, "Print"],
Cell[1709982, 47875, 78, 1, 70, "Print"],
Cell[1710063, 47878, 75, 1, 70, "Print"],
Cell[1710141, 47881, 83, 1, 70, "Print"],
Cell[1710227, 47884, 90, 1, 70, "Print"],
Cell[1710320, 47887, 77, 1, 70, "Print"],
Cell[1710400, 47890, 79, 1, 70, "Print"],
Cell[1710482, 47893, 81, 1, 70, "Print"],
Cell[1710566, 47896, 139, 3, 70, "Print"],
Cell[1710708, 47901, 243, 4, 70, "Print"],
Cell[1710954, 47907, 227, 4, 70, "Print"],
Cell[1711184, 47913, 101, 2, 70, "Print"],
Cell[1711288, 47917, 76, 1, 70, "Print"],
Cell[1711367, 47920, 47, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1711463, 47927, 39, 0, 35, "Subsubsection"],
Cell[1711505, 47929, 53, 1, 38, "Input"],
Cell[1711561, 47932, 52, 1, 38, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[1711650, 47938, 47, 0, 35, "Subsubsection"],
Cell[1711700, 47940, 483, 9, 176, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1712232, 47955, 37, 0, 72, "Section"],
Cell[1712272, 47957, 118, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[1712415, 47964, 112, 3, 93, "Subsection"],
Cell[1712530, 47969, 1028, 29, 145, "Text"],

Cell[CellGroupData[{
Cell[1713583, 48002, 39, 0, 57, "Subsubsection"],
Cell[1713625, 48004, 248, 11, 45, "Text"],

Cell[CellGroupData[{
Cell[1713898, 48019, 68, 1, 38, "Input"],
Cell[1713969, 48022, 104, 2, 70, "Message"]
}, Open  ]],
Cell[1714088, 48027, 198, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[1714311, 48037, 69, 1, 38, "Input"],
Cell[1714383, 48040, 105, 2, 70, "Message"],
Cell[1714491, 48044, 105, 2, 26, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1714633, 48051, 70, 1, 38, "Input"],
Cell[1714706, 48054, 105, 2, 70, "Message"],
Cell[1714814, 48058, 105, 2, 26, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1714956, 48065, 73, 1, 38, "Input"],
Cell[1715032, 48068, 113, 2, 70, "Message"],
Cell[1715148, 48072, 105, 2, 70, "Message"],
Cell[1715256, 48076, 113, 2, 26, "Message"],
Cell[1715372, 48080, 105, 2, 26, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1715514, 48087, 76, 1, 38, "Input"],
Cell[1715593, 48090, 105, 2, 70, "Message"],
Cell[1715701, 48094, 105, 2, 26, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1715843, 48101, 62, 1, 38, "Input"],
Cell[1715908, 48104, 113, 2, 70, "Message"],
Cell[1716024, 48108, 113, 2, 26, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1716174, 48115, 79, 1, 38, "Input"],
Cell[1716256, 48118, 105, 2, 70, "Message"],
Cell[1716364, 48122, 105, 2, 26, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1716506, 48129, 66, 1, 38, "Input"],
Cell[1716575, 48132, 113, 2, 70, "Message"],
Cell[1716691, 48136, 113, 2, 26, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1716841, 48143, 85, 1, 38, "Input"],
Cell[1716929, 48146, 105, 2, 70, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1717071, 48153, 74, 1, 38, "Input"],
Cell[1717148, 48156, 113, 2, 70, "Message"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1717310, 48164, 40, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[1717375, 48168, 1183, 21, 498, "Input"],
Cell[1718561, 48191, 64590, 1657, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1783212, 49855, 64, 0, 68, "Subsection"],
Cell[1783279, 49857, 350, 7, 81, "Text"],

Cell[CellGroupData[{
Cell[1783654, 49868, 39, 0, 57, "Subsubsection"],
Cell[1783696, 49870, 163, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[1783884, 49879, 75, 1, 38, "Input"],
Cell[1783962, 49882, 112, 2, 70, "Message"]
}, Open  ]],
Cell[1784089, 49887, 159, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[1784273, 49895, 73, 1, 38, "Input"],
Cell[1784349, 49898, 110, 2, 70, "Message"]
}, Open  ]],
Cell[1784474, 49903, 131, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[1784630, 49911, 68, 1, 38, "Input"],
Cell[1784701, 49914, 104, 2, 70, "Message"]
}, Open  ]],
Cell[1784820, 49919, 297, 7, 56, "Text"],

Cell[CellGroupData[{
Cell[1785142, 49930, 81, 1, 38, "Input"],
Cell[1785226, 49933, 111, 2, 70, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1785374, 49940, 62, 1, 38, "Input"],
Cell[1785439, 49943, 119, 2, 70, "Message"]
}, Open  ]],
Cell[1785573, 49948, 320, 7, 56, "Text"],

Cell[CellGroupData[{
Cell[1785918, 49959, 84, 1, 38, "Input"],
Cell[1786005, 49962, 111, 2, 70, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1786153, 49969, 66, 1, 38, "Input"],
Cell[1786222, 49972, 119, 2, 70, "Message"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1786390, 49980, 40, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[1786455, 49984, 835, 14, 337, "Input"],
Cell[1787293, 50000, 35914, 1073, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1823256, 51079, 36, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[1823317, 51083, 174, 5, 61, "Input"],
Cell[1823494, 51090, 5242, 158, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1828809, 51256, 35, 0, 72, "Section"],
Cell[1828847, 51258, 689, 15, 120, "Text"],

Cell[CellGroupData[{
Cell[1829561, 51277, 33, 0, 68, "Subsection"],
Cell[1829597, 51279, 60, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[1829682, 51283, 32, 0, 57, "Subsubsection"],
Cell[1829717, 51285, 267, 5, 70, "Text"],
Cell[1829987, 51292, 46, 1, 38, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[1830070, 51298, 49, 0, 35, "Subsubsection"],
Cell[1830122, 51300, 45, 0, 45, "Text"],
Cell[1830170, 51302, 86, 1, 38, "Input"],
Cell[1830259, 51305, 91, 1, 38, "Input"],
Cell[1830353, 51308, 37, 0, 45, "Text"],
Cell[1830393, 51310, 165, 4, 107, "Input"],
Cell[1830561, 51316, 56, 0, 45, "Text"],
Cell[1830620, 51318, 174, 3, 61, "Input"],
Cell[1830797, 51323, 38, 0, 45, "Text"],
Cell[1830838, 51325, 277, 6, 130, "Input"],
Cell[1831118, 51333, 127, 5, 45, "Text"],
Cell[1831248, 51340, 113, 2, 40, "Input"],
Cell[1831364, 51344, 128, 5, 45, "Text"],
Cell[1831495, 51351, 111, 2, 40, "Input"],
Cell[1831609, 51355, 158, 4, 45, "Text"],
Cell[1831770, 51361, 77, 1, 38, "Input"],
Cell[1831850, 51364, 159, 4, 45, "Text"],
Cell[1832012, 51370, 380, 8, 153, "Input"],
Cell[1832395, 51380, 256, 6, 85, "Input"],
Cell[1832654, 51388, 385, 7, 155, "Input"],
Cell[1833042, 51397, 105, 3, 45, "Text"],
Cell[1833150, 51402, 203, 4, 84, "Input"],
Cell[1833356, 51408, 63, 0, 45, "Text"],
Cell[1833422, 51410, 778, 14, 291, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[1834237, 51429, 39, 0, 35, "Subsubsection"],
Cell[1834279, 51431, 355, 11, 70, "Text"],

Cell[CellGroupData[{
Cell[1834659, 51446, 68, 1, 38, "Input"],
Cell[1834730, 51449, 104, 2, 70, "Message"]
}, Open  ]],
Cell[1834849, 51454, 188, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[1835062, 51463, 71, 1, 38, "Input"],
Cell[1835136, 51466, 112, 2, 70, "Message"],
Cell[1835251, 51470, 104, 2, 70, "Message"]
}, Open  ]],
Cell[1835370, 51475, 147, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[1835542, 51483, 74, 1, 38, "Input"],
Cell[1835619, 51486, 104, 2, 70, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1835760, 51493, 61, 1, 38, "Input"],
Cell[1835824, 51496, 112, 2, 70, "Message"]
}, Open  ]],
Cell[1835951, 51501, 294, 8, 78, "Text"],

Cell[CellGroupData[{
Cell[1836270, 51513, 71, 1, 38, "Input"],
Cell[1836344, 51516, 104, 2, 70, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1836485, 51523, 44, 1, 38, "Input"],
Cell[1836532, 51526, 708, 25, 70, "Output"]
}, Open  ]],
Cell[1837255, 51554, 375, 8, 58, "Text"],

Cell[CellGroupData[{
Cell[1837655, 51566, 77, 1, 38, "Input"],
Cell[1837735, 51569, 118, 2, 70, "Message"],
Cell[1837856, 51573, 110, 2, 70, "Message"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1838027, 51582, 63, 0, 68, "Subsection"],
Cell[1838093, 51584, 2195, 54, 241, "Text"],

Cell[CellGroupData[{
Cell[1840313, 51642, 39, 0, 57, "Subsubsection"],
Cell[1840355, 51644, 45, 0, 45, "Text"],
Cell[1840403, 51646, 107, 2, 38, "Input"],
Cell[1840513, 51650, 171, 3, 85, "Input"],
Cell[1840687, 51655, 183, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[1840895, 51665, 75, 1, 38, "Input"],
Cell[1840973, 51668, 1406, 45, 70, "Output"]
}, Open  ]],
Cell[1842394, 51716, 218, 4, 39, "Text"],

Cell[CellGroupData[{
Cell[1842637, 51724, 78, 1, 38, "Input"],
Cell[1842718, 51727, 5039, 153, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1847806, 51886, 40, 0, 35, "Subsubsection"],
Cell[1847849, 51888, 134, 2, 53, "Text"],

Cell[CellGroupData[{
Cell[1848008, 51894, 66, 1, 38, "Input"],
Cell[1848077, 51897, 719, 25, 70, "Output"]
}, Open  ]],
Cell[1848811, 51925, 128, 2, 53, "Text"],

Cell[CellGroupData[{
Cell[1848964, 51931, 66, 1, 38, "Input"],
Cell[1849033, 51934, 3897, 117, 70, "Output"]
}, Open  ]],
Cell[1852945, 52054, 53, 0, 45, "Text"],
Cell[1853001, 52056, 113, 2, 38, "Input"],
Cell[1853117, 52060, 88, 1, 38, "Input"],
Cell[1853208, 52063, 34, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[1853267, 52067, 73, 1, 38, "Input"],
Cell[1853343, 52070, 719, 25, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1854099, 52100, 76, 1, 38, "Input"],
Cell[1854178, 52103, 3897, 117, 70, "Output"]
}, Open  ]],
Cell[1858090, 52223, 376, 9, 58, "Text"],
Cell[1858469, 52234, 469, 11, 56, "Text"],

Cell[CellGroupData[{
Cell[1858963, 52249, 40, 1, 38, "Input"],
Cell[1859006, 52252, 5242, 158, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1864285, 52415, 67, 1, 38, "Input"],
Cell[1864355, 52418, 12287, 359, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1876679, 52782, 78, 1, 38, "Input"],
Cell[1876760, 52785, 9707, 260, 70, "Output"]
}, Open  ]],
Cell[1886482, 53048, 580, 13, 83, "Text"],

Cell[CellGroupData[{
Cell[1887087, 53065, 64, 1, 38, "Input"],
Cell[1887154, 53068, 12432, 315, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1899623, 53388, 62, 1, 38, "Input"],
Cell[1899688, 53391, 63387, 1865, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1963112, 55261, 79, 1, 38, "Input"],
Cell[1963194, 55264, 20908, 544, 70, "Output"]
}, Open  ]],
Cell[1984117, 55811, 61, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[1984203, 55815, 179, 3, 85, "Input"],
Cell[1984385, 55820, 13731, 343, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1998153, 56168, 160, 4, 84, "Input"],
Cell[1998316, 56174, 15713, 460, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2014066, 56639, 178, 4, 62, "Input"],
Cell[2014247, 56645, 22249, 577, 70, "Output"]
}, Open  ]],
Cell[2036511, 57225, 148, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[2036684, 57232, 47, 1, 38, "Input"],
Cell[2036734, 57235, 81, 1, 70, "Print"],
Cell[2036818, 57238, 81, 1, 70, "Print"],
Cell[2036902, 57241, 81, 1, 70, "Print"],
Cell[2036986, 57244, 81, 1, 70, "Print"],
Cell[2037070, 57247, 81, 1, 70, "Print"],
Cell[2037154, 57250, 81, 1, 70, "Print"],
Cell[2037238, 57253, 81, 1, 70, "Print"],
Cell[2037322, 57256, 81, 1, 70, "Print"],
Cell[2037406, 57259, 81, 1, 70, "Print"],
Cell[2037490, 57262, 18129, 541, 70, "Output"]
}, Open  ]],
Cell[2055634, 57806, 48, 1, 38, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2055719, 57812, 42, 0, 35, "Subsubsection"],
Cell[2055764, 57814, 453, 12, 70, "Text"],

Cell[CellGroupData[{
Cell[2056242, 57830, 75, 1, 38, "Input"],
Cell[2056320, 57833, 106, 2, 70, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2056463, 57840, 78, 1, 38, "Input"],
Cell[2056544, 57843, 114, 2, 70, "Message"],
Cell[2056661, 57847, 106, 2, 70, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2056804, 57854, 135, 3, 40, "Input"],
Cell[2056942, 57859, 3878, 117, 70, "Output"]
}, Open  ]],
Cell[2060835, 57979, 84, 1, 38, "Input"],

Cell[CellGroupData[{
Cell[2060944, 57984, 72, 1, 38, "Input"],
Cell[2061019, 57987, 106, 2, 70, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2061162, 57994, 75, 1, 38, "Input"],
Cell[2061240, 57997, 114, 2, 70, "Message"],
Cell[2061357, 58001, 106, 2, 70, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2061500, 58008, 129, 3, 40, "Input"],
Cell[2061632, 58013, 3310, 101, 70, "Output"]
}, Open  ]],
Cell[2064957, 58117, 72, 1, 38, "Input"],
Cell[2065032, 58120, 544, 16, 58, "Text"],

Cell[CellGroupData[{
Cell[2065601, 58140, 62, 1, 38, "Input"],
Cell[2065666, 58143, 12488, 316, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2078191, 58464, 62, 1, 38, "Input"],
Cell[2078256, 58467, 64315, 1881, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2142608, 60353, 91, 1, 38, "Input"],
Cell[2142702, 60356, 32988, 839, 70, "Output"]
}, Open  ]],
Cell[2175705, 61198, 463, 13, 58, "Text"],

Cell[CellGroupData[{
Cell[2176193, 61215, 60, 1, 38, "Input"],
Cell[2176256, 61218, 12544, 317, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2188837, 61540, 62, 1, 38, "Input"],
Cell[2188902, 61543, 45039, 1307, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2233978, 62855, 91, 1, 38, "Input"],
Cell[2234072, 62858, 27314, 694, 70, "Output"]
}, Open  ]],
Cell[2261401, 63555, 179, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[2261605, 63563, 170, 3, 63, "Input"],
Cell[2261778, 63568, 18303, 488, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2280118, 64061, 175, 3, 85, "Input"],
Cell[2280296, 64066, 14515, 376, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2294848, 64447, 86, 1, 38, "Input"],
Cell[2294937, 64450, 3302, 90, 70, "Output"]
}, Open  ]],
Cell[2298254, 64543, 130, 2, 61, "Input"],

Cell[CellGroupData[{
Cell[2298409, 64549, 82, 1, 38, "Input"],
Cell[2298494, 64552, 2131, 57, 70, "Output"]
}, Open  ]],
Cell[2300640, 64612, 104, 2, 38, "Input"],

Cell[CellGroupData[{
Cell[2300769, 64618, 137, 3, 61, "Input"],
Cell[2300909, 64623, 17885, 445, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2318831, 65073, 89, 1, 38, "Input"],
Cell[2318923, 65076, 23501, 675, 70, "Output"]
}, Open  ]],
Cell[2342439, 65754, 142, 2, 61, "Input"],

Cell[CellGroupData[{
Cell[2342606, 65760, 141, 3, 61, "Input"],
Cell[2342750, 65765, 20350, 462, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2363137, 66232, 89, 1, 38, "Input"],
Cell[2363229, 66235, 23682, 680, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2386948, 66920, 49, 1, 38, "Input"],
Cell[2387000, 66923, 10800, 307, 70, "Output"]
}, Open  ]],
Cell[2397815, 67233, 116, 2, 38, "Input"],

Cell[CellGroupData[{
Cell[2397956, 67239, 67, 1, 38, "Input"],
Cell[2398026, 67242, 10800, 307, 70, "Output"]
}, Open  ]],
Cell[2408841, 67552, 209, 8, 45, "Text"],

Cell[CellGroupData[{
Cell[2409075, 67564, 38, 1, 38, "Input"],
Cell[2409116, 67567, 3878, 117, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2413031, 67689, 107, 2, 38, "Input"],
Cell[2413141, 67693, 46745, 1176, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2459923, 68874, 54, 1, 38, "Input"],
Cell[2459980, 68877, 25770, 760, 70, "Output"]
}, Open  ]],
Cell[2485765, 69640, 85, 1, 38, "Input"],

Cell[CellGroupData[{
Cell[2485875, 69645, 63, 1, 38, "Input"],
Cell[2485941, 69648, 25770, 760, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2511748, 70413, 38, 1, 38, "Input"],
Cell[2511789, 70416, 3310, 101, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2515136, 70522, 107, 2, 38, "Input"],
Cell[2515246, 70526, 21534, 545, 70, "Output"]
}, Open  ]],
Cell[2536795, 71074, 73, 1, 38, "Input"],

Cell[CellGroupData[{
Cell[2536893, 71079, 66, 1, 38, "Input"],
Cell[2536962, 71082, 18608, 542, 70, "Output"]
}, Open  ]],
Cell[2555585, 71627, 153, 3, 45, "Text"],
Cell[2555741, 71632, 545, 16, 58, "Text"],

Cell[CellGroupData[{
Cell[2556311, 71652, 62, 1, 38, "Input"],
Cell[2556376, 71655, 12488, 316, 70, "Output"]
}, Open  ]],
Cell[2568879, 71974, 67, 1, 38, "Input"],

Cell[CellGroupData[{
Cell[2568971, 71979, 101, 2, 38, "Input"],
Cell[2569075, 71983, 35, 1, 70, "Output"]
}, Open  ]],
Cell[2569125, 71987, 464, 13, 58, "Text"],

Cell[CellGroupData[{
Cell[2569614, 72004, 60, 1, 38, "Input"],
Cell[2569677, 72007, 12544, 317, 70, "Output"]
}, Open  ]],
Cell[2582236, 72327, 67, 1, 38, "Input"],

Cell[CellGroupData[{
Cell[2582328, 72332, 101, 2, 38, "Input"],
Cell[2582432, 72336, 7896, 200, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2590365, 72541, 46, 1, 38, "Input"],
Cell[2590414, 72544, 35, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2590498, 72551, 48, 0, 35, "Subsubsection"],
Cell[2590549, 72553, 169, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[2590743, 72563, 61, 1, 38, "Input"],
Cell[2590807, 72566, 1478, 46, 70, "Output"]
}, Open  ]],
Cell[2592300, 72615, 118, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[2592443, 72624, 126, 3, 38, "Input"],
Cell[2592572, 72629, 27338, 805, 70, "Output"]
}, Open  ]],
Cell[2619925, 73437, 82, 1, 38, "Input"],
Cell[2620010, 73440, 115, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[2620150, 73449, 140, 4, 38, "Input"],
Cell[2620293, 73455, 23671, 694, 70, "Output"]
}, Open  ]],
Cell[2643979, 74152, 70, 1, 38, "Input"],
Cell[2644052, 74155, 66, 1, 38, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2644167, 74162, 41, 0, 68, "Subsection"],
Cell[2644211, 74164, 1032, 30, 100, "Text"],

Cell[CellGroupData[{
Cell[2645268, 74198, 33, 0, 57, "Subsubsection"],
Cell[2645304, 74200, 484, 14, 50, "Text"],
Cell[2645791, 74216, 1624, 44, 95, "Text"],
Cell[2647418, 74262, 346, 11, 54, "Text"],

Cell[CellGroupData[{
Cell[2647789, 74277, 68, 1, 38, "Input"],
Cell[2647860, 74280, 33040, 961, 70, "Output"]
}, Open  ]],
Cell[2680915, 75244, 343, 11, 54, "Text"],

Cell[CellGroupData[{
Cell[2681283, 75259, 68, 1, 38, "Input"],
Cell[2681354, 75262, 24506, 710, 70, "Output"]
}, Open  ]],
Cell[2705875, 75975, 338, 11, 50, "Text"],

Cell[CellGroupData[{
Cell[2706238, 75990, 59, 1, 38, "Input"],
Cell[2706300, 75993, 25770, 760, 70, "Output"]
}, Open  ]],
Cell[2732085, 76756, 335, 11, 50, "Text"],

Cell[CellGroupData[{
Cell[2732445, 76771, 59, 1, 38, "Input"],
Cell[2732507, 76774, 18608, 542, 70, "Output"]
}, Open  ]],
Cell[2751130, 77319, 85, 1, 46, "Text"],

Cell[CellGroupData[{
Cell[2751240, 77324, 80, 1, 38, "Input"],
Cell[2751323, 77327, 22045, 652, 70, "Output"]
}, Open  ]],
Cell[2773383, 77982, 131, 4, 48, "Text"],

Cell[CellGroupData[{
Cell[2773539, 77990, 81, 1, 38, "Input"],
Cell[2773623, 77993, 12249, 359, 70, "Output"]
}, Open  ]],
Cell[2785887, 78355, 293, 10, 48, "Text"],

Cell[CellGroupData[{
Cell[2786205, 78369, 118, 3, 38, "Input"],
Cell[2786326, 78374, 35396, 1033, 70, "Output"]
}, Open  ]],
Cell[2821737, 79410, 472, 16, 55, "Text"],
Cell[2822212, 79428, 326, 10, 48, "Text"],
Cell[2822541, 79440, 34, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[2822600, 79444, 72, 1, 38, "Input"],
Cell[2822675, 79447, 32598, 952, 70, "Output"]
}, Open  ]],
Cell[2855288, 80402, 88, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[2855401, 80407, 136, 3, 38, "Input"],
Cell[2855540, 80412, 6509, 187, 70, "Output"]
}, Open  ]],
Cell[2862064, 80602, 91, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[2862180, 80607, 74, 1, 40, "Input"],
Cell[2862257, 80610, 3595, 109, 70, "Output"]
}, Open  ]],
Cell[2865867, 80722, 226, 7, 48, "Text"],

Cell[CellGroupData[{
Cell[2866118, 80733, 128, 3, 54, "Input"],
Cell[2866249, 80738, 64100, 1596, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2930386, 82339, 93, 1, 38, "Input"],
Cell[2930482, 82342, 54314, 1179, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2984845, 83527, 51, 0, 35, "Subsubsection"],
Cell[2984899, 83529, 122, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[2985046, 83537, 52, 1, 38, "Input"],
Cell[2985101, 83540, 41694, 1079, 70, "Output"]
}, Open  ]],
Cell[3026810, 84622, 267, 8, 45, "Text"],
Cell[3027080, 84632, 79, 1, 38, "Input"],

Cell[CellGroupData[{
Cell[3027184, 84637, 80, 1, 38, "Input"],
Cell[3027267, 84640, 27943, 815, 70, "Output"]
}, Open  ]],
Cell[3055225, 85458, 64, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[3055314, 85464, 157, 4, 130, "Input"],
Cell[3055474, 85470, 93189, 2632, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3148700, 88107, 159, 4, 107, "Input"],
Cell[3148862, 88113, 146197, 4177, 70, "Output"]
}, Open  ]],
Cell[3295074, 92293, 56, 0, 45, "Text"],
Cell[3295133, 92295, 174, 3, 61, "Input"],

Cell[CellGroupData[{
Cell[3295332, 92302, 53, 1, 38, "Input"],
Cell[3295388, 92305, 207276, 4355, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3502701, 96665, 49, 1, 38, "Input"],
Cell[3502753, 96668, 2832, 53, 70, "Output"]
}, Open  ]],
Cell[3505600, 96724, 97, 2, 45, "Text"],
Cell[3505700, 96728, 412, 7, 153, "Input"],

Cell[CellGroupData[{
Cell[3506137, 96739, 50, 1, 38, "Input"],
Cell[3506190, 96742, 40, 1, 70, "Output"]
}, Open  ]],
Cell[3506245, 96746, 51, 1, 38, "Input"],
Cell[3506299, 96749, 96, 4, 45, "Text"],
Cell[3506398, 96755, 78, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[3506501, 96760, 50, 1, 38, "Input"],
Cell[3506554, 96763, 19758, 476, 70, "Output"]
}, Open  ]],
Cell[3526327, 97242, 78, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[3526430, 97247, 64, 1, 38, "Input"],
Cell[3526497, 97250, 7664, 190, 70, "Output"]
}, Open  ]],
Cell[3534176, 97443, 78, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[3534279, 97448, 50, 1, 38, "Input"],
Cell[3534332, 97451, 16328, 394, 70, "Output"]
}, Open  ]],
Cell[3550675, 97848, 78, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[3550778, 97853, 50, 1, 38, "Input"],
Cell[3550831, 97856, 1340, 38, 70, "Output"]
}, Open  ]],
Cell[3552186, 97897, 78, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[3552289, 97902, 50, 1, 38, "Input"],
Cell[3552342, 97905, 1677, 47, 70, "Output"]
}, Open  ]],
Cell[3554034, 97955, 96, 4, 45, "Text"],
Cell[3554133, 97961, 78, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[3554236, 97966, 50, 1, 38, "Input"],
Cell[3554289, 97969, 4795, 122, 70, "Output"]
}, Open  ]],
Cell[3559099, 98094, 78, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[3559202, 98099, 64, 1, 38, "Input"],
Cell[3559269, 98102, 41481, 984, 70, "Output"]
}, Open  ]],
Cell[3600765, 99089, 78, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[3600868, 99094, 50, 1, 38, "Input"],
Cell[3600921, 99097, 35, 1, 70, "Output"]
}, Open  ]],
Cell[3600971, 99101, 78, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[3601074, 99106, 50, 1, 38, "Input"],
Cell[3601127, 99109, 10284, 259, 70, "Output"]
}, Open  ]],
Cell[3611426, 99371, 78, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[3611529, 99376, 50, 1, 38, "Input"],
Cell[3611582, 99379, 35, 1, 70, "Output"]
}, Open  ]],
Cell[3611632, 99383, 96, 4, 45, "Text"],
Cell[3611731, 99389, 78, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[3611834, 99394, 50, 1, 38, "Input"],
Cell[3611887, 99397, 15364, 384, 70, "Output"]
}, Open  ]],
Cell[3627266, 99784, 78, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[3627369, 99789, 64, 1, 38, "Input"],
Cell[3627436, 99792, 15347, 376, 70, "Output"]
}, Open  ]],
Cell[3642798, 100171, 78, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[3642901, 100176, 50, 1, 38, "Input"],
Cell[3642954, 100179, 35, 1, 70, "Output"]
}, Open  ]],
Cell[3643004, 100183, 78, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[3643107, 100188, 50, 1, 38, "Input"],
Cell[3643160, 100191, 35, 1, 70, "Output"]
}, Open  ]],
Cell[3643210, 100195, 78, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[3643313, 100200, 50, 1, 38, "Input"],
Cell[3643366, 100203, 35, 1, 70, "Output"]
}, Open  ]],
Cell[3643416, 100207, 96, 4, 45, "Text"],
Cell[3643515, 100213, 78, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[3643618, 100218, 50, 1, 38, "Input"],
Cell[3643671, 100221, 2461, 71, 70, "Output"]
}, Open  ]],
Cell[3646147, 100295, 78, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[3646250, 100300, 64, 1, 38, "Input"],
Cell[3646317, 100303, 13494, 348, 70, "Output"]
}, Open  ]],
Cell[3659826, 100654, 78, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[3659929, 100659, 50, 1, 38, "Input"],
Cell[3659982, 100662, 35, 1, 70, "Output"]
}, Open  ]],
Cell[3660032, 100666, 78, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[3660135, 100671, 50, 1, 38, "Input"],
Cell[3660188, 100674, 35, 1, 70, "Output"]
}, Open  ]],
Cell[3660238, 100678, 78, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[3660341, 100683, 50, 1, 38, "Input"],
Cell[3660394, 100686, 35, 1, 70, "Output"]
}, Open  ]],
Cell[3660444, 100690, 96, 4, 45, "Text"],
Cell[3660543, 100696, 78, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[3660646, 100701, 50, 1, 38, "Input"],
Cell[3660699, 100704, 6153, 161, 70, "Output"]
}, Open  ]],
Cell[3666867, 100868, 78, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[3666970, 100873, 64, 1, 38, "Input"],
Cell[3667037, 100876, 35, 1, 70, "Output"]
}, Open  ]],
Cell[3667087, 100880, 78, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[3667190, 100885, 50, 1, 38, "Input"],
Cell[3667243, 100888, 35, 1, 70, "Output"]
}, Open  ]],
Cell[3667293, 100892, 78, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[3667396, 100897, 50, 1, 38, "Input"],
Cell[3667449, 100900, 35, 1, 70, "Output"]
}, Open  ]],
Cell[3667499, 100904, 78, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[3667602, 100909, 50, 1, 38, "Input"],
Cell[3667655, 100912, 35, 1, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3667763, 100921, 94, 4, 72, "Section"],
Cell[3667860, 100927, 709, 15, 120, "Text"],

Cell[CellGroupData[{
Cell[3668594, 100946, 48, 0, 68, "Subsection"],
Cell[3668645, 100948, 2027, 46, 273, "Text"],

Cell[CellGroupData[{
Cell[3670697, 100998, 78, 0, 57, "Subsubsection"],
Cell[3670778, 101000, 58, 0, 45, "Text"],
Cell[3670839, 101002, 64, 1, 40, "Input"],

Cell[CellGroupData[{
Cell[3670928, 101007, 155, 3, 40, "Input"],
Cell[3671086, 101012, 111, 2, 70, "Output"]
}, Open  ]],
Cell[3671212, 101017, 86, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[3671323, 101023, 107, 2, 40, "Input"],
Cell[3671433, 101027, 107, 2, 70, "Output"]
}, Open  ]],
Cell[3671555, 101032, 95, 2, 45, "Text"],
Cell[3671653, 101036, 239, 6, 107, "Input"],

Cell[CellGroupData[{
Cell[3671917, 101046, 140, 3, 40, "Input"],
Cell[3672060, 101051, 113, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3672210, 101058, 92, 1, 38, "Input"],
Cell[3672305, 101061, 176, 3, 70, "Output"]
}, Open  ]],
Cell[3672496, 101067, 99, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[3672620, 101073, 103, 2, 38, "Input"],
Cell[3672726, 101077, 203, 4, 70, "Output"]
}, Open  ]],
Cell[3672944, 101084, 75, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[3673044, 101088, 80, 1, 38, "Input"],
Cell[3673127, 101091, 35, 1, 70, "Output"]
}, Open  ]],
Cell[3673177, 101095, 137, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[3673339, 101103, 134, 3, 66, "Input"],
Cell[3673476, 101108, 888, 27, 70, "Output"]
}, Open  ]],
Cell[3674379, 101138, 528, 11, 95, "Text"],
Cell[3674910, 101151, 299, 8, 48, "Text"],

Cell[CellGroupData[{
Cell[3675234, 101163, 72, 1, 38, "Input"],
Cell[3675309, 101166, 106, 2, 70, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3675452, 101173, 84, 1, 40, "Input"],
Cell[3675539, 101176, 1333, 40, 70, "Output"]
}, Open  ]],
Cell[3676887, 101219, 174, 5, 48, "Text"],

Cell[CellGroupData[{
Cell[3677086, 101228, 101, 2, 54, "Input"],
Cell[3677190, 101232, 1646, 43, 70, "Output"]
}, Open  ]],
Cell[3678851, 101278, 196, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[3679072, 101287, 70, 1, 38, "Input"],
Cell[3679145, 101290, 105, 2, 70, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3679287, 101297, 86, 1, 40, "Input"],
Cell[3679376, 101300, 1350, 40, 70, "Output"]
}, Open  ]],
Cell[3680741, 101343, 64, 1, 38, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3680842, 101349, 46, 0, 35, "Subsubsection"],
Cell[3680891, 101351, 183, 4, 70, "Text"],
Cell[3681077, 101357, 128, 3, 38, "Input"],
Cell[3681208, 101362, 85, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[3681318, 101368, 187, 4, 84, "Input"],
Cell[3681508, 101374, 227360, 4709, 70, "Output"]
}, Open  ]],
Cell[3908883, 106086, 105, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[3909013, 106093, 117, 2, 54, "Input"],
Cell[3909133, 106097, 1274, 38, 70, "Output"]
}, Open  ]],
Cell[3910422, 106138, 226, 8, 45, "Text"],
Cell[3910651, 106148, 471, 8, 153, "Input"],

Cell[CellGroupData[{
Cell[3911147, 106160, 50, 1, 38, "Input"],
Cell[3911200, 106163, 37, 1, 70, "Output"]
}, Open  ]],
Cell[3911252, 106167, 43, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[3911320, 106171, 47, 1, 38, "Input"],
Cell[3911370, 106174, 52985, 1252, 70, "Output"]
}, Open  ]],
Cell[3964370, 107429, 103, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[3964498, 107437, 47, 1, 38, "Input"],
Cell[3964548, 107440, 38837, 929, 70, "Output"]
}, Open  ]],
Cell[4003400, 108372, 117, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[4003542, 108380, 47, 1, 38, "Input"],
Cell[4003592, 108383, 28754, 689, 70, "Output"]
}, Open  ]],
Cell[4032361, 109075, 131, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[4032517, 109083, 47, 1, 38, "Input"],
Cell[4032567, 109086, 15493, 384, 70, "Output"]
}, Open  ]],
Cell[4048075, 109473, 154, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[4048254, 109482, 47, 1, 38, "Input"],
Cell[4048304, 109485, 6153, 161, 70, "Output"]
}, Open  ]],
Cell[4054472, 109649, 292, 8, 70, "Text"],
Cell[4054767, 109659, 82, 1, 40, "Input"],
Cell[4054852, 109662, 74, 1, 38, "Input"],
Cell[4054929, 109665, 80, 1, 38, "Input"],
Cell[4055012, 109668, 124, 2, 61, "Input"],
Cell[4055139, 109672, 135, 2, 61, "Input"],
Cell[4055277, 109676, 146, 2, 61, "Input"],
Cell[4055426, 109680, 369, 6, 153, "Input"],
Cell[4055798, 109688, 114, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[4055937, 109696, 81, 1, 38, "Input"],
Cell[4056021, 109699, 107293, 2301, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4163351, 112005, 57, 1, 38, "Input"],
Cell[4163411, 112008, 1706, 36, 70, "Output"]
}, Open  ]],
Cell[4165132, 112047, 199, 8, 45, "Text"],
Cell[4165334, 112057, 123, 3, 38, "Input"],
Cell[4165460, 112062, 111, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[4165596, 112070, 47, 1, 38, "Input"],
Cell[4165646, 112073, 42890, 1000, 70, "Output"]
}, Open  ]],
Cell[4208551, 113076, 111, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[4208687, 113084, 47, 1, 38, "Input"],
Cell[4208737, 113087, 25272, 550, 70, "Output"]
}, Open  ]],
Cell[4234024, 113640, 111, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[4234160, 113648, 47, 1, 38, "Input"],
Cell[4234210, 113651, 26206, 613, 70, "Output"]
}, Open  ]],
Cell[4260431, 114267, 111, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[4260567, 114275, 47, 1, 38, "Input"],
Cell[4260617, 114278, 1768, 42, 70, "Output"]
}, Open  ]],
Cell[4262400, 114323, 111, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[4262536, 114331, 47, 1, 38, "Input"],
Cell[4262586, 114334, 3616, 88, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[4266251, 114428, 39, 0, 35, "Subsubsection"],
Cell[4266293, 114430, 123, 3, 45, "Text"],
Cell[4266419, 114435, 120, 2, 54, "Input"],
Cell[4266542, 114439, 232, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[4266799, 114449, 118, 3, 38, "Input"],
Cell[4266920, 114454, 95089, 2126, 70, "Output"]
}, Open  ]],
Cell[4362024, 116583, 157, 5, 45, "Text"],
Cell[4362184, 116590, 106, 2, 38, "Input"],

Cell[CellGroupData[{
Cell[4362315, 116596, 46, 1, 38, "Input"],
Cell[4362364, 116599, 35, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4362436, 116605, 47, 1, 38, "Input"],
Cell[4362486, 116608, 42870, 1000, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4405393, 117613, 47, 1, 38, "Input"],
Cell[4405443, 117616, 25261, 550, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4430741, 118171, 47, 1, 38, "Input"],
Cell[4430791, 118174, 26191, 613, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4457019, 118792, 47, 1, 38, "Input"],
Cell[4457069, 118795, 1768, 42, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4458874, 118842, 47, 1, 38, "Input"],
Cell[4458924, 118845, 3616, 88, 70, "Output"]
}, Open  ]],
Cell[4462555, 118936, 352, 7, 45, "Text"],
Cell[4462910, 118945, 80, 1, 40, "Input"],
Cell[4462993, 118948, 74, 1, 38, "Input"],
Cell[4463070, 118951, 80, 1, 38, "Input"],
Cell[4463153, 118954, 86, 1, 38, "Input"],
Cell[4463242, 118957, 92, 1, 38, "Input"],
Cell[4463337, 118960, 105, 2, 38, "Input"],
Cell[4463445, 118964, 194, 4, 61, "Input"],
Cell[4463642, 118970, 341, 14, 45, "Text"],
Cell[4463986, 118986, 136, 3, 61, "Input"],

Cell[CellGroupData[{
Cell[4464147, 118993, 46, 1, 38, "Input"],
Cell[4464196, 118996, 35, 1, 70, "Output"]
}, Open  ]],
Cell[4464246, 119000, 106, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[4464377, 119008, 47, 1, 38, "Input"],
Cell[4464427, 119011, 5411, 141, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4469875, 119157, 151, 3, 38, "Input"],
Cell[4470029, 119162, 35, 1, 70, "Output"]
}, Open  ]],
Cell[4470079, 119166, 76, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[4470180, 119171, 47, 1, 38, "Input"],
Cell[4470230, 119174, 20902, 447, 70, "Output"]
}, Open  ]],
Cell[4491147, 119624, 76, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[4491248, 119629, 47, 1, 38, "Input"],
Cell[4491298, 119632, 28142, 651, 70, "Output"]
}, Open  ]],
Cell[4519455, 120286, 76, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[4519556, 120291, 47, 1, 38, "Input"],
Cell[4519606, 120294, 6759, 165, 70, "Output"]
}, Open  ]],
Cell[4526380, 120462, 76, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[4526481, 120467, 47, 1, 38, "Input"],
Cell[4526531, 120470, 4993, 125, 70, "Output"]
}, Open  ]],
Cell[4531539, 120598, 64, 1, 38, "Input"],

Cell[CellGroupData[{
Cell[4531628, 120603, 55, 1, 38, "Input"],
Cell[4531686, 120606, 1139, 21, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4532886, 120634, 48, 0, 68, "Subsection"],
Cell[4532937, 120636, 859, 16, 170, "Text"],

Cell[CellGroupData[{
Cell[4533821, 120656, 85, 1, 57, "Subsubsection"],
Cell[4533909, 120659, 655, 18, 95, "Text"],
Cell[4534567, 120679, 189, 3, 54, "Input"],
Cell[4534759, 120684, 575, 16, 70, "Text"],
Cell[4535337, 120702, 85, 1, 57, "Input"],
Cell[4535425, 120705, 171, 3, 57, "Input"],
Cell[4535599, 120710, 150, 2, 40, "Input"],

Cell[CellGroupData[{
Cell[4535774, 120716, 123, 3, 38, "Input"],
Cell[4535900, 120721, 64, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4536001, 120727, 93, 1, 38, "Input"],
Cell[4536097, 120730, 439, 8, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[4536585, 120744, 54, 0, 35, "Subsubsection"],
Cell[4536642, 120746, 45, 0, 45, "Text"],
Cell[4536690, 120748, 123, 3, 40, "Input"],
Cell[4536816, 120753, 73, 1, 38, "Input"],
Cell[4536892, 120756, 73, 1, 38, "Input"],
Cell[4536968, 120759, 73, 1, 38, "Input"],
Cell[4537044, 120762, 73, 1, 38, "Input"],
Cell[4537120, 120765, 85, 1, 38, "Input"],
Cell[4537208, 120768, 154, 3, 61, "Input"],
Cell[4537365, 120773, 193, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[4537583, 120783, 78, 1, 38, "Input"],
Cell[4537664, 120786, 73508, 1539, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4611209, 122330, 54, 1, 38, "Input"],
Cell[4611266, 122333, 1009, 19, 70, "Output"]
}, Open  ]],
Cell[4612290, 122355, 137, 5, 45, "Text"],
Cell[4612430, 122362, 109, 2, 38, "Input"],

Cell[CellGroupData[{
Cell[4612564, 122368, 50, 1, 38, "Input"],
Cell[4612617, 122371, 40, 1, 70, "Output"]
}, Open  ]],
Cell[4612672, 122375, 79, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[4612776, 122380, 50, 1, 38, "Input"],
Cell[4612829, 122383, 2484, 66, 70, "Output"]
}, Open  ]],
Cell[4615328, 122452, 79, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[4615432, 122457, 50, 1, 38, "Input"],
Cell[4615485, 122460, 13264, 318, 70, "Output"]
}, Open  ]],
Cell[4628764, 122781, 79, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[4628868, 122786, 50, 1, 38, "Input"],
Cell[4628921, 122789, 1340, 38, 70, "Output"]
}, Open  ]],
Cell[4630276, 122830, 79, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[4630380, 122835, 50, 1, 38, "Input"],
Cell[4630433, 122838, 6566, 162, 70, "Output"]
}, Open  ]],
Cell[4637014, 123003, 79, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[4637118, 123008, 50, 1, 38, "Input"],
Cell[4637171, 123011, 20580, 496, 70, "Output"]
}, Open  ]],
Cell[4657766, 123510, 79, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[4657870, 123515, 50, 1, 38, "Input"],
Cell[4657923, 123518, 1335, 38, 70, "Output"]
}, Open  ]],
Cell[4659273, 123559, 79, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[4659377, 123564, 50, 1, 38, "Input"],
Cell[4659430, 123567, 4928, 123, 70, "Output"]
}, Open  ]],
Cell[4664373, 123693, 79, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[4664477, 123698, 50, 1, 38, "Input"],
Cell[4664530, 123701, 35, 1, 70, "Output"]
}, Open  ]],
Cell[4664580, 123705, 79, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[4664684, 123710, 50, 1, 38, "Input"],
Cell[4664737, 123713, 1641, 41, 70, "Output"]
}, Open  ]],
Cell[4666393, 123757, 79, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[4666497, 123762, 50, 1, 38, "Input"],
Cell[4666550, 123765, 5215, 127, 70, "Output"]
}, Open  ]],
Cell[4671780, 123895, 79, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[4671884, 123900, 50, 1, 38, "Input"],
Cell[4671937, 123903, 35, 1, 70, "Output"]
}, Open  ]],
Cell[4671987, 123907, 79, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[4672091, 123912, 50, 1, 38, "Input"],
Cell[4672144, 123915, 35, 1, 70, "Output"]
}, Open  ]],
Cell[4672194, 123919, 79, 1, 41, "Text"],

Cell[CellGroupData[{
Cell[4672298, 123924, 50, 1, 38, "Input"],
Cell[4672351, 123927, 5227, 127, 70, "Output"]
}, Open  ]],
Cell[4677593, 124057, 79, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[4677697, 124062, 50, 1, 38, "Input"],
Cell[4677750, 124065, 35, 1, 70, "Output"]
}, Open  ]],
Cell[4677800, 124069, 79, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[4677904, 124074, 50, 1, 38, "Input"],
Cell[4677957, 124077, 35, 1, 70, "Output"]
}, Open  ]],
Cell[4678007, 124081, 79, 1, 39, "Text"],

Cell[CellGroupData[{
Cell[4678111, 124086, 50, 1, 38, "Input"],
Cell[4678164, 124089, 35, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[4678248, 124096, 63, 0, 35, "Subsubsection"],
Cell[4678314, 124098, 89, 2, 45, "Text"],
Cell[4678406, 124102, 91, 1, 38, "Input"],
Cell[4678500, 124105, 128, 2, 61, "Input"],
Cell[4678631, 124109, 72, 1, 38, "Input"],
Cell[4678706, 124112, 76, 1, 38, "Input"],
Cell[4678785, 124115, 117, 2, 61, "Input"],
Cell[4678905, 124119, 135, 2, 61, "Input"],
Cell[4679043, 124123, 137, 2, 61, "Input"],
Cell[4679183, 124127, 107, 2, 38, "Input"],
Cell[4679293, 124131, 130, 2, 38, "Input"],
Cell[4679426, 124135, 167, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[4679618, 124142, 201, 4, 107, "Input"],
Cell[4679822, 124148, 795, 14, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4680654, 124167, 51, 1, 38, "Input"],
Cell[4680708, 124170, 508, 10, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[4681265, 124186, 55, 0, 35, "Subsubsection"],
Cell[4681323, 124188, 986, 33, 95, "Text"],
Cell[4682312, 124223, 84, 1, 38, "Input"],
Cell[4682399, 124226, 156, 2, 61, "Input"],
Cell[4682558, 124230, 220, 4, 64, "Input"],
Cell[4682781, 124236, 86, 1, 40, "Input"],
Cell[4682870, 124239, 87, 1, 38, "Input"],

Cell[CellGroupData[{
Cell[4682982, 124244, 91, 1, 38, "Input"],
Cell[4683076, 124247, 83400, 1565, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4766513, 125817, 57, 1, 38, "Input"],
Cell[4766573, 125820, 1067, 19, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4767677, 125844, 223, 5, 107, "Input"],
Cell[4767903, 125851, 943, 15, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4768883, 125871, 54, 1, 38, "Input"],
Cell[4768940, 125874, 553, 11, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4769554, 125892, 57, 0, 68, "Subsection"],
Cell[4769614, 125894, 2412, 54, 261, "Text"],

Cell[CellGroupData[{
Cell[4772051, 125952, 82, 1, 57, "Subsubsection"],
Cell[4772136, 125955, 203, 8, 45, "Text"],

Cell[CellGroupData[{
Cell[4772364, 125967, 70, 1, 38, "Input"],
Cell[4772437, 125970, 105, 2, 70, "Message"]
}, Open  ]],
Cell[4772557, 125975, 343, 11, 45, "Text"],

Cell[CellGroupData[{
Cell[4772925, 125990, 88, 1, 38, "Input"],
Cell[4773016, 125993, 126, 2, 70, "Message"]
}, Open  ]],
Cell[4773157, 125998, 359, 10, 70, "Text"],

Cell[CellGroupData[{
Cell[4773541, 126012, 62, 1, 38, "Input"],
Cell[4773606, 126015, 2025, 63, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4775668, 126083, 88, 1, 38, "Input"],
Cell[4775759, 126086, 3650, 110, 70, "Output"]
}, Open  ]],
Cell[4779424, 126199, 40, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[4779489, 126203, 85, 1, 38, "Input"],
Cell[4779577, 126206, 4643, 138, 70, "Output"]
}, Open  ]],
Cell[4784235, 126347, 39, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[4784299, 126351, 88, 1, 38, "Input"],
Cell[4784390, 126354, 8276, 247, 70, "Output"]
}, Open  ]],
Cell[4792681, 126604, 481, 17, 70, "Text"],

Cell[CellGroupData[{
Cell[4793187, 126625, 124, 3, 38, "Input"],
Cell[4793314, 126630, 34875, 1021, 70, "Output"]
}, Open  ]],
Cell[4828204, 127654, 82, 1, 38, "Input"],

Cell[CellGroupData[{
Cell[4828311, 127659, 124, 3, 38, "Input"],
Cell[4828438, 127664, 33366, 978, 70, "Output"]
}, Open  ]],
Cell[4861819, 128645, 70, 1, 38, "Input"],
Cell[4861892, 128648, 314, 7, 70, "Text"],

Cell[CellGroupData[{
Cell[4862231, 128659, 75, 1, 38, "Input"],
Cell[4862309, 128662, 468, 17, 70, "Output"]
}, Open  ]],
Cell[4862792, 128682, 222, 8, 45, "Text"],
Cell[4863017, 128692, 68, 1, 38, "Input"],
Cell[4863088, 128695, 113, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[4863226, 128704, 70, 1, 38, "Input"],
Cell[4863299, 128707, 5039, 153, 70, "Output"]
}, Open  ]],
Cell[4868353, 128863, 172, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[4868550, 128872, 74, 1, 38, "Input"],
Cell[4868627, 128875, 39752, 1003, 70, "Output"]
}, Open  ]],
Cell[4908394, 129881, 258, 8, 45, "Text"],
Cell[4908655, 129891, 105, 2, 38, "Input"],

Cell[CellGroupData[{
Cell[4908785, 129897, 46, 1, 38, "Input"],
Cell[4908834, 129900, 35, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4908906, 129906, 47, 1, 38, "Input"],
Cell[4908956, 129909, 8268, 242, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4917261, 130156, 47, 1, 38, "Input"],
Cell[4917311, 130159, 28290, 827, 70, "Output"]
}, Open  ]],
Cell[4945616, 130989, 247, 8, 45, "Text"],

Cell[CellGroupData[{
Cell[4945888, 131001, 189, 4, 61, "Input"],
Cell[4946080, 131007, 10856, 276, 70, "Output"]
}, Open  ]],
Cell[4956951, 131286, 595, 19, 45, "Text"],

Cell[CellGroupData[{
Cell[4957571, 131309, 295, 5, 107, "Input"],
Cell[4957869, 131316, 8373, 202, 70, "Output"]
}, Open  ]],
Cell[4966257, 131521, 215, 8, 45, "Text"],

Cell[CellGroupData[{
Cell[4966497, 131533, 121, 3, 38, "Input"],
Cell[4966621, 131538, 5417, 145, 70, "Output"]
}, Open  ]],
Cell[4972053, 131686, 74, 1, 38, "Input"],
Cell[4972130, 131689, 222, 8, 45, "Text"],

Cell[CellGroupData[{
Cell[4972377, 131701, 77, 1, 40, "Input"],
Cell[4972457, 131704, 956, 33, 70, "Output"]
}, Open  ]],
Cell[4973428, 131740, 419, 9, 45, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4973884, 131754, 70, 0, 35, "Subsubsection"],
Cell[4973957, 131756, 26, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[4974008, 131760, 78, 1, 38, "Input"],
Cell[4974089, 131763, 119, 2, 70, "Message"],
Cell[4974211, 131767, 111, 2, 70, "Message"]
}, Open  ]],
Cell[4974337, 131772, 41, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[4974403, 131776, 79, 1, 38, "Input"],
Cell[4974485, 131779, 120, 2, 70, "Message"],
Cell[4974608, 131783, 112, 2, 70, "Message"]
}, Open  ]],
Cell[4974735, 131788, 213, 6, 56, "Text"],

Cell[CellGroupData[{
Cell[4974973, 131798, 40, 1, 38, "Input"],
Cell[4975016, 131801, 5242, 158, 70, "Output"]
}, Open  ]],
Cell[4980273, 131962, 283, 11, 45, "Text"],

Cell[CellGroupData[{
Cell[4980581, 131977, 77, 1, 38, "Input"],
Cell[4980661, 131980, 12287, 359, 70, "Output"]
}, Open  ]],
Cell[4992963, 132342, 247, 8, 45, "Text"],

Cell[CellGroupData[{
Cell[4993235, 132354, 86, 1, 38, "Input"],
Cell[4993324, 132357, 46752, 1167, 70, "Output"]
}, Open  ]],
Cell[5040091, 133527, 314, 7, 56, "Text"],

Cell[CellGroupData[{
Cell[5040430, 133538, 71, 1, 38, "Input"],
Cell[5040504, 133541, 53099, 1222, 70, "Output"]
}, Open  ]],
Cell[5093618, 134766, 109, 3, 45, "Text"],
Cell[5093730, 134771, 81, 1, 38, "Input"],
Cell[5093814, 134774, 512, 12, 83, "Text"],

Cell[CellGroupData[{
Cell[5094351, 134790, 92, 1, 38, "Input"],
Cell[5094446, 134793, 270747, 7861, 70, "Output"]
}, Open  ]],
Cell[5365208, 142657, 38, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[5365271, 142661, 146, 3, 107, "Input"],
Cell[5365420, 142666, 74054, 1848, 70, "Output"]
}, Open  ]],
Cell[5439489, 144517, 74, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[5439588, 144521, 118, 3, 38, "Input"],
Cell[5439709, 144526, 35, 1, 70, "Output"]
}, Open  ]],
Cell[5439759, 144530, 36, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[5439820, 144534, 144, 3, 84, "Input"],
Cell[5439967, 144539, 91084, 2254, 70, "Output"]
}, Open  ]],
Cell[5531066, 146796, 34, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[5531125, 146800, 142, 3, 84, "Input"],
Cell[5531270, 146805, 71400, 1756, 70, "Output"]
}, Open  ]],
Cell[5602685, 148564, 175, 5, 45, "Text"],
Cell[5602863, 148571, 127, 2, 40, "Input"],

Cell[CellGroupData[{
Cell[5603015, 148577, 53, 1, 38, "Input"],
Cell[5603071, 148580, 324, 8, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5603432, 148593, 461, 8, 176, "Input"],
Cell[5603896, 148603, 66, 1, 70, "Print"]
}, Open  ]],
Cell[5603977, 148607, 457, 8, 176, "Input"],
Cell[5604437, 148617, 457, 8, 176, "Input"],

Cell[CellGroupData[{
Cell[5604919, 148629, 51, 1, 38, "Input"],
Cell[5604973, 148632, 40, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5605050, 148638, 51, 1, 38, "Input"],
Cell[5605104, 148641, 40, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5605181, 148647, 51, 1, 38, "Input"],
Cell[5605235, 148650, 40, 1, 70, "Output"]
}, Open  ]],
Cell[5605290, 148654, 71, 1, 38, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5605398, 148660, 63, 0, 35, "Subsubsection"],
Cell[5605464, 148662, 85, 1, 41, "Text"],

Cell[CellGroupData[{
Cell[5605574, 148667, 54, 1, 38, "Input"],
Cell[5605631, 148670, 20930, 544, 70, "Output"]
}, Open  ]],
Cell[5626576, 149217, 102, 2, 38, "Input"],
Cell[5626681, 149221, 85, 1, 41, "Text"],

Cell[CellGroupData[{
Cell[5626791, 149226, 54, 1, 38, "Input"],
Cell[5626848, 149229, 35, 1, 70, "Output"]
}, Open  ]],
Cell[5626898, 149233, 92, 1, 38, "Input"],
Cell[5626993, 149236, 78, 1, 41, "Text"],

Cell[CellGroupData[{
Cell[5627096, 149241, 54, 1, 38, "Input"],
Cell[5627153, 149244, 35, 1, 70, "Output"]
}, Open  ]],
Cell[5627203, 149248, 89, 1, 38, "Input"],
Cell[5627295, 149251, 88, 1, 41, "Text"],

Cell[CellGroupData[{
Cell[5627408, 149256, 54, 1, 38, "Input"],
Cell[5627465, 149259, 13160, 338, 70, "Output"]
}, Open  ]],
Cell[5640640, 149600, 109, 2, 38, "Input"],
Cell[5640752, 149604, 88, 1, 41, "Text"],

Cell[CellGroupData[{
Cell[5640865, 149609, 54, 1, 38, "Input"],
Cell[5640922, 149612, 20561, 519, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5661520, 150136, 110, 2, 38, "Input"],
Cell[5661633, 150140, 35, 1, 70, "Output"]
}, Open  ]],
Cell[5661683, 150144, 106, 2, 38, "Input"],
Cell[5661792, 150148, 86, 1, 41, "Text"],

Cell[CellGroupData[{
Cell[5661903, 150153, 54, 1, 38, "Input"],
Cell[5661960, 150156, 17667, 444, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5679664, 150605, 110, 2, 38, "Input"],
Cell[5679777, 150609, 35, 1, 70, "Output"]
}, Open  ]],
Cell[5679827, 150613, 103, 2, 38, "Input"],
Cell[5679933, 150617, 79, 1, 41, "Text"],

Cell[CellGroupData[{
Cell[5680037, 150622, 54, 1, 38, "Input"],
Cell[5680094, 150625, 14667, 367, 70, "Output"]
}, Open  ]],
Cell[5694776, 150995, 93, 1, 38, "Input"],
Cell[5694872, 150998, 91, 1, 41, "Text"],

Cell[CellGroupData[{
Cell[5694988, 151003, 54, 1, 38, "Input"],
Cell[5695045, 151006, 1211, 41, 70, "Output"]
}, Open  ]],
Cell[5696271, 151050, 116, 2, 61, "Input"],
Cell[5696390, 151054, 91, 1, 41, "Text"],

Cell[CellGroupData[{
Cell[5696506, 151059, 54, 1, 38, "Input"],
Cell[5696563, 151062, 1263, 42, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5697863, 151109, 92, 1, 38, "Input"],
Cell[5697958, 151112, 1263, 42, 70, "Output"]
}, Open  ]],
Cell[5699236, 151157, 113, 2, 38, "Input"],
Cell[5699352, 151161, 89, 1, 41, "Text"],

Cell[CellGroupData[{
Cell[5699466, 151166, 54, 1, 38, "Input"],
Cell[5699523, 151169, 1315, 43, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5700875, 151217, 75, 1, 38, "Input"],
Cell[5700953, 151220, 1315, 43, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5702305, 151268, 92, 1, 38, "Input"],
Cell[5702400, 151271, 1315, 43, 70, "Output"]
}, Open  ]],
Cell[5703730, 151317, 110, 2, 38, "Input"],
Cell[5703843, 151321, 87, 1, 41, "Text"],

Cell[CellGroupData[{
Cell[5703955, 151326, 54, 1, 38, "Input"],
Cell[5704012, 151329, 1367, 44, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5705416, 151378, 73, 1, 38, "Input"],
Cell[5705492, 151381, 1367, 44, 70, "Output"]
}, Open  ]],
Cell[5706874, 151428, 107, 2, 38, "Input"],
Cell[5706984, 151432, 80, 1, 41, "Text"],

Cell[CellGroupData[{
Cell[5707089, 151437, 54, 1, 38, "Input"],
Cell[5707146, 151440, 1419, 45, 70, "Output"]
}, Open  ]],
Cell[5708580, 151488, 104, 2, 38, "Input"],
Cell[5708687, 151492, 26, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[5708738, 151496, 109, 2, 38, "Input"],
Cell[5708850, 151500, 43, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5708930, 151506, 109, 2, 38, "Input"],
Cell[5709042, 151510, 43, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5709122, 151516, 109, 2, 38, "Input"],
Cell[5709234, 151520, 43, 1, 70, "Output"]
}, Open  ]],
Cell[5709292, 151524, 123, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[5709440, 151532, 73, 1, 38, "Input"],
Cell[5709516, 151535, 112, 2, 70, "Message"],
Cell[5709631, 151539, 104, 2, 70, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5709772, 151546, 105, 2, 38, "Input"],
Cell[5709880, 151550, 17398, 516, 70, "Output"]
}, Open  ]],
Cell[5727293, 152069, 78, 1, 38, "Input"],
Cell[5727374, 152072, 90, 4, 45, "Text"],

Cell[CellGroupData[{
Cell[5727489, 152080, 175, 3, 84, "Input"],
Cell[5727667, 152085, 3354, 105, 70, "Output"]
}, Open  ]],
Cell[5731036, 152193, 266, 9, 45, "Text"],

Cell[CellGroupData[{
Cell[5731327, 152206, 143, 3, 84, "Input"],
Cell[5731473, 152211, 66, 1, 70, "Print"],
Cell[5731542, 152214, 25066, 649, 70, "Output"]
}, Open  ]],
Cell[5756623, 152866, 77, 1, 38, "Input"],
Cell[5756703, 152869, 258, 8, 45, "Text"],

Cell[CellGroupData[{
Cell[5756986, 152881, 59, 1, 38, "Input"],
Cell[5757048, 152884, 1687, 53, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5758772, 152942, 152, 4, 107, "Input"],
Cell[5758927, 152948, 8006, 239, 70, "Output"]
}, Open  ]],
Cell[5766948, 153190, 101, 2, 38, "Input"],
Cell[5767052, 153194, 306, 9, 70, "Text"],
Cell[5767361, 153205, 72, 1, 38, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5767470, 153211, 35, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[5767530, 153215, 134, 3, 61, "Input"],
Cell[5767667, 153220, 135202, 2748, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5902906, 155973, 145, 3, 61, "Input"],
Cell[5903054, 155978, 154146, 2833, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6057237, 158816, 57, 1, 38, "Input"],
Cell[6057297, 158819, 1829, 33, 70, "Output"]
}, Open  ]],
Cell[6059141, 158855, 239, 7, 45, "Text"],

Cell[CellGroupData[{
Cell[6059405, 158866, 88, 1, 38, "Input"],
Cell[6059496, 158869, 54092, 1189, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[6113673, 160067, 40, 0, 52, "Subsubtitle"],
Cell[6113716, 160069, 162, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[6113903, 160076, 26, 0, 72, "Section"],
Cell[6113932, 160078, 128, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[6114085, 160087, 33, 0, 57, "Subsubsection"],
Cell[6114121, 160089, 73, 1, 38, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6114231, 160095, 39, 0, 35, "Subsubsection"],
Cell[6114273, 160097, 53, 1, 38, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6114363, 160103, 47, 0, 35, "Subsubsection"],
Cell[6114413, 160105, 483, 9, 153, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6114945, 160120, 59, 0, 72, "Section"],
Cell[6115007, 160122, 521, 8, 120, "Text"],

Cell[CellGroupData[{
Cell[6115553, 160134, 33, 0, 68, "Subsection"],
Cell[6115589, 160136, 973, 21, 145, "Text"],

Cell[CellGroupData[{
Cell[6116587, 160161, 49, 0, 57, "Subsubsection"],
Cell[6116639, 160163, 127, 5, 45, "Text"],
Cell[6116769, 160170, 113, 2, 40, "Input"],
Cell[6116885, 160174, 158, 4, 45, "Text"],
Cell[6117046, 160180, 77, 1, 38, "Input"],
Cell[6117126, 160183, 116, 2, 40, "Input"],
Cell[6117245, 160187, 82, 1, 38, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6117364, 160193, 35, 0, 35, "Subsubsection"],
Cell[6117402, 160195, 645, 17, 95, "Text"],

Cell[CellGroupData[{
Cell[6118072, 160216, 1029, 17, 314, "Input"],
Cell[6119104, 160235, 943, 15, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[6120096, 160256, 49, 0, 35, "Subsubsection"],
Cell[6120148, 160258, 66, 0, 45, "Text"],
Cell[6120217, 160260, 158, 2, 40, "Input"],
Cell[6120378, 160264, 135, 3, 40, "Input"],
Cell[6120516, 160269, 166, 3, 62, "Input"],
Cell[6120685, 160274, 107, 2, 38, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6120841, 160282, 67, 0, 68, "Subsection"],
Cell[6120911, 160284, 1259, 36, 170, "Text"],
Cell[6122173, 160322, 1309, 32, 170, "Text"],
Cell[6123485, 160356, 464, 12, 95, "Text"],
Cell[6123952, 160370, 496, 10, 95, "Text"],

Cell[CellGroupData[{
Cell[6124473, 160384, 40, 0, 57, "Subsubsection"],
Cell[6124516, 160386, 448, 11, 70, "Text"],

Cell[CellGroupData[{
Cell[6124989, 160401, 84, 1, 38, "Input"],
Cell[6125076, 160404, 319, 5, 152, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6125432, 160414, 74, 1, 38, "Input"],
Cell[6125509, 160417, 221, 4, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6125767, 160426, 51, 1, 38, "Input"],
Cell[6125821, 160429, 228, 4, 102, "Output"]
}, Open  ]],
Cell[6126064, 160436, 152, 5, 45, "Text"],
Cell[6126219, 160443, 165, 3, 40, "Input"],
Cell[6126387, 160448, 142, 5, 45, "Text"],
Cell[6126532, 160455, 160, 4, 62, "Input"],
Cell[6126695, 160461, 41, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[6126761, 160465, 63, 1, 38, "Input"],
Cell[6126827, 160468, 50, 1, 38, "Output"]
}, Open  ]],
Cell[6126892, 160472, 87, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[6127004, 160478, 92, 1, 38, "Input"],
Cell[6127099, 160481, 241, 4, 144, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6127377, 160490, 51, 1, 38, "Input"],
Cell[6127431, 160493, 359, 6, 143, "Output"]
}, Open  ]],
Cell[6127805, 160502, 214, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[6128044, 160511, 133, 2, 61, "Input"],
Cell[6128180, 160515, 1403, 23, 419, "Output"]
}, Open  ]],
Cell[6129598, 160541, 39, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[6129662, 160545, 65, 1, 38, "Input"],
Cell[6129730, 160548, 613, 10, 193, "Output"]
}, Open  ]],
Cell[6130358, 160561, 47, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[6130430, 160565, 64, 1, 38, "Input"],
Cell[6130497, 160568, 230, 4, 79, "Output"]
}, Open  ]],
Cell[6130742, 160575, 128, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[6130895, 160582, 60, 1, 38, "Input"],
Cell[6130958, 160585, 35, 1, 38, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[6131042, 160592, 46, 0, 35, "Subsubsection"],
Cell[6131091, 160594, 689, 16, 95, "Text"],

Cell[CellGroupData[{
Cell[6131805, 160614, 129, 3, 38, "Input"],
Cell[6131937, 160619, 310, 5, 117, "Output"]
}, Open  ]],
Cell[6132262, 160627, 74, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[6132361, 160631, 89, 1, 38, "Input"],
Cell[6132453, 160634, 321, 5, 152, "Output"]
}, Open  ]],
Cell[6132789, 160642, 112, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[6132926, 160649, 80, 1, 38, "Input"],
Cell[6133009, 160652, 268, 4, 147, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6133314, 160661, 51, 1, 38, "Input"],
Cell[6133368, 160664, 276, 4, 147, "Output"]
}, Open  ]],
Cell[6133659, 160671, 211, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[6133895, 160681, 129, 2, 61, "Input"],
Cell[6134027, 160685, 988, 16, 475, "Output"]
}, Open  ]],
Cell[6135030, 160704, 89, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[6135144, 160710, 58, 1, 38, "Input"],
Cell[6135205, 160713, 46, 1, 38, "Output"]
}, Open  ]],
Cell[6135266, 160717, 69, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[6135360, 160721, 58, 1, 38, "Input"],
Cell[6135421, 160724, 405, 6, 192, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6135863, 160735, 127, 2, 61, "Input"],
Cell[6135993, 160739, 35, 1, 38, "Output"]
}, Open  ]],
Cell[6136043, 160743, 429, 11, 70, "Text"],

Cell[CellGroupData[{
Cell[6136497, 160758, 50, 1, 38, "Input"],
Cell[6136550, 160761, 275, 5, 105, "Output"]
}, Open  ]],
Cell[6136840, 160769, 283, 9, 45, "Text"],

Cell[CellGroupData[{
Cell[6137148, 160782, 87, 1, 38, "Input"],
Cell[6137238, 160785, 716, 13, 244, "Output"]
}, Open  ]],
Cell[6137969, 160801, 40, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[6138034, 160805, 43, 1, 38, "Input"],
Cell[6138080, 160808, 361, 6, 152, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[6138490, 160820, 41, 0, 35, "Subsubsection"],
Cell[6138534, 160822, 276, 7, 45, "Text"],

Cell[CellGroupData[{
Cell[6138835, 160833, 80, 1, 38, "Input"],
Cell[6138918, 160836, 319, 5, 152, "Output"]
}, Open  ]],
Cell[6139252, 160844, 53, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[6139330, 160848, 46, 1, 38, "Input"],
Cell[6139379, 160851, 35, 1, 38, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[6139463, 160858, 44, 0, 35, "Subsubsection"],
Cell[6139510, 160860, 99, 2, 45, "Text"],
Cell[6139612, 160864, 139, 3, 57, "Input"],
Cell[6139754, 160869, 51, 0, 45, "Text"],
Cell[6139808, 160871, 64, 1, 54, "Input"],
Cell[6139875, 160874, 89, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[6139989, 160880, 38, 1, 38, "Input"],
Cell[6140030, 160883, 56, 1, 54, "Output"]
}, Open  ]],
Cell[6140101, 160887, 65, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[6140191, 160891, 66, 1, 38, "Input"],
Cell[6140260, 160894, 270, 5, 95, "Output"]
}, Open  ]],
Cell[6140545, 160902, 124, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[6140694, 160911, 52, 1, 38, "Input"],
Cell[6140749, 160914, 188, 3, 102, "Output"]
}, Open  ]],
Cell[6140952, 160920, 137, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[6141114, 160927, 82, 1, 38, "Input"],
Cell[6141199, 160930, 598, 10, 244, "Output"]
}, Open  ]],
Cell[6141812, 160943, 45, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[6141882, 160947, 77, 1, 38, "Input"],
Cell[6141962, 160950, 252, 5, 105, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6142275, 160962, 59, 0, 68, "Subsection"],
Cell[6142337, 160964, 114, 3, 45, "Text"],
Cell[6142454, 160969, 1134, 26, 173, "Text"],
Cell[6143591, 160997, 1424, 33, 225, "Text"],
Cell[6145018, 161032, 691, 16, 70, "Text"],
Cell[6145712, 161050, 690, 17, 95, "Text"],
Cell[6146405, 161069, 419, 10, 95, "Text"],

Cell[CellGroupData[{
Cell[6146849, 161083, 54, 0, 57, "Subsubsection"],
Cell[6146906, 161085, 282, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[6147213, 161095, 114, 2, 38, "Input"],
Cell[6147330, 161099, 765, 13, 290, "Output"]
}, Open  ]],
Cell[6148110, 161115, 59, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[6148194, 161119, 62, 1, 38, "Input"],
Cell[6148259, 161122, 35, 1, 38, "Output"]
}, Open  ]],
Cell[6148309, 161126, 148, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[6148482, 161133, 75, 1, 54, "Input"],
Cell[6148560, 161136, 65, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6148662, 161142, 53, 1, 38, "Input"],
Cell[6148718, 161145, 104, 2, 70, "Output"]
}, Open  ]],
Cell[6148837, 161150, 198, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[6149060, 161159, 118, 2, 38, "Input"],
Cell[6149181, 161163, 759, 15, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6149977, 161183, 83, 1, 38, "Input"],
Cell[6150063, 161186, 798, 13, 70, "Output"]
}, Open  ]],
Cell[6150876, 161202, 224, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[6151125, 161211, 101, 2, 38, "Input"],
Cell[6151229, 161215, 111, 2, 70, "Output"]
}, Open  ]],
Cell[6151355, 161220, 424, 11, 70, "Text"],

Cell[CellGroupData[{
Cell[6151804, 161235, 67, 1, 38, "Input"],
Cell[6151874, 161238, 35, 1, 38, "Output"]
}, Open  ]],
Cell[6151924, 161242, 231, 4, 70, "Text"],
Cell[6152158, 161248, 88, 1, 38, "Input"],
Cell[6152249, 161251, 73, 1, 40, "Input"],

Cell[CellGroupData[{
Cell[6152347, 161256, 161, 3, 62, "Input"],
Cell[6152511, 161261, 827, 14, 234, "Output"]
}, Open  ]],
Cell[6153353, 161278, 52, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[6153430, 161282, 67, 1, 38, "Input"],
Cell[6153500, 161285, 35, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6153572, 161291, 67, 1, 38, "Input"],
Cell[6153642, 161294, 35, 1, 38, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[6153726, 161301, 67, 0, 35, "Subsubsection"],
Cell[6153796, 161303, 233, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[6154054, 161313, 51, 1, 38, "Input"],
Cell[6154108, 161316, 175, 4, 70, "Output"]
}, Open  ]],
Cell[6154298, 161323, 66, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[6154389, 161327, 218, 4, 56, "Input"],
Cell[6154610, 161333, 413, 10, 70, "Output"]
}, Open  ]],
Cell[6155038, 161346, 182, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[6155245, 161355, 256, 4, 57, "Input"],
Cell[6155504, 161361, 416, 10, 70, "Output"]
}, Open  ]],
Cell[6155935, 161374, 56, 0, 45, "Text"],
Cell[6155994, 161376, 191, 3, 60, "Input"],
Cell[6156188, 161381, 64, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[6156277, 161385, 155, 3, 38, "Input"],
Cell[6156435, 161390, 67, 1, 70, "Output"]
}, Open  ]],
Cell[6156517, 161394, 178, 3, 57, "Text"],
Cell[6156698, 161399, 75, 1, 60, "Input"],
Cell[6156776, 161402, 246, 4, 59, "Text"],

Cell[CellGroupData[{
Cell[6157047, 161410, 220, 4, 56, "Input"],
Cell[6157270, 161416, 68, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6157375, 161422, 57, 1, 38, "Input"],
Cell[6157435, 161425, 142, 2, 70, "Output"]
}, Open  ]],
Cell[6157592, 161430, 432, 8, 160, "Text"],
Cell[6158027, 161440, 195, 3, 76, "Input"],

Cell[CellGroupData[{
Cell[6158247, 161447, 211, 4, 61, "Input"],
Cell[6158461, 161453, 481, 8, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6158979, 161466, 77, 1, 38, "Input"],
Cell[6159059, 161469, 1750, 29, 70, "Output"]
}, Open  ]],
Cell[6160824, 161501, 63, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[6160912, 161505, 79, 1, 57, "Input"],
Cell[6160994, 161508, 60, 1, 70, "Output"]
}, Open  ]],
Cell[6161069, 161512, 186, 5, 48, "Text"],
Cell[6161258, 161519, 109, 2, 54, "Input"],
Cell[6161370, 161523, 32, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[6161427, 161527, 136, 3, 54, "Input"],
Cell[6161566, 161532, 35, 1, 70, "Output"]
}, Open  ]],
Cell[6161616, 161536, 145, 5, 48, "Text"],
Cell[6161764, 161543, 86, 1, 54, "Input"],
Cell[6161853, 161546, 527, 13, 70, "Text"],
Cell[6162383, 161561, 519, 13, 76, "Text"],
Cell[6162905, 161576, 165, 3, 78, "Input"],
Cell[6163073, 161581, 1322, 31, 168, "Text"],
Cell[6164398, 161614, 282, 6, 161, "Input"],
Cell[6164683, 161622, 113, 3, 45, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6164833, 161630, 54, 0, 35, "Subsubsection"],
Cell[6164890, 161632, 599, 16, 70, "Text"],
Cell[6165492, 161650, 133, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[6165650, 161657, 72, 1, 38, "Input"],
Cell[6165725, 161660, 1544, 22, 353, "Output"]
}, Open  ]],
Cell[6167284, 161685, 39, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[6167348, 161689, 65, 1, 38, "Input"],
Cell[6167416, 161692, 56, 1, 54, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6167509, 161698, 68, 1, 38, "Input"],
Cell[6167580, 161701, 56, 1, 54, "Output"]
}, Open  ]],
Cell[6167651, 161705, 164, 3, 45, "Text"],
Cell[6167818, 161710, 64, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[6167907, 161714, 170, 3, 61, "Input"],
Cell[6168080, 161719, 2415, 39, 513, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6170532, 161763, 47, 1, 38, "Input"],
Cell[6170582, 161766, 35, 1, 38, "Output"]
}, Open  ]],
Cell[6170632, 161770, 302, 9, 45, "Text"],

Cell[CellGroupData[{
Cell[6170959, 161783, 181, 3, 84, "Input"],
Cell[6171143, 161788, 1807, 27, 410, "Output"]
}, Open  ]],
Cell[6172965, 161818, 72, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[6173062, 161822, 114, 2, 38, "Input"],
Cell[6173179, 161826, 35, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6173251, 161832, 114, 2, 38, "Input"],
Cell[6173368, 161836, 35, 1, 38, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[6173452, 161843, 56, 0, 35, "Subsubsection"],
Cell[6173511, 161845, 617, 16, 70, "Text"],
Cell[6174131, 161863, 138, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[6174294, 161870, 78, 1, 38, "Input"],
Cell[6174375, 161873, 3310, 51, 70, "Output"]
}, Open  ]],
Cell[6177700, 161927, 39, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[6177764, 161931, 65, 1, 38, "Input"],
Cell[6177832, 161934, 75, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6177944, 161940, 68, 1, 38, "Input"],
Cell[6178015, 161943, 101, 2, 70, "Output"]
}, Open  ]],
Cell[6178131, 161948, 164, 3, 45, "Text"],
Cell[6178298, 161953, 64, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[6178387, 161957, 203, 4, 61, "Input"],
Cell[6178593, 161963, 9437, 144, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6188067, 162112, 47, 1, 38, "Input"],
Cell[6188117, 162115, 35, 1, 70, "Output"]
}, Open  ]],
Cell[6188167, 162119, 308, 9, 45, "Text"],

Cell[CellGroupData[{
Cell[6188500, 162132, 217, 4, 84, "Input"],
Cell[6188720, 162138, 4132, 65, 70, "Output"]
}, Open  ]],
Cell[6192867, 162206, 72, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[6192964, 162210, 149, 3, 61, "Input"],
Cell[6193116, 162215, 35, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6193188, 162221, 149, 3, 61, "Input"],
Cell[6193340, 162226, 35, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6193412, 162232, 149, 3, 61, "Input"],
Cell[6193564, 162237, 35, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6193636, 162243, 69, 1, 38, "Input"],
Cell[6193708, 162246, 2106, 35, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[6195863, 162287, 46, 0, 35, "Subsubsection"],
Cell[6195912, 162289, 51, 0, 45, "Text"],
Cell[6195966, 162291, 863, 17, 293, "Input"],
Cell[6196832, 162310, 120, 3, 45, "Text"],
Cell[6196955, 162315, 454, 7, 164, "Input"],
Cell[6197412, 162324, 52, 0, 45, "Text"],
Cell[6197467, 162326, 121, 2, 69, "Input"],

Cell[CellGroupData[{
Cell[6197613, 162332, 68, 1, 38, "Input"],
Cell[6197684, 162335, 35, 1, 38, "Output"]
}, Open  ]],
Cell[6197734, 162339, 97, 2, 45, "Text"],
Cell[6197834, 162343, 213, 4, 84, "Input"],

Cell[CellGroupData[{
Cell[6198072, 162351, 103, 2, 38, "Input"],
Cell[6198178, 162355, 35, 1, 38, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

